function [BF] = FIRE_InitBaseFunction(Mesh,LOAD,SolverType)

BASTIFF = zeros(2,3,Mesh.CElement.NOTriangles);
ACOEFF  = zeros(1,3,Mesh.CElement.NOTriangles);

if strcmp(SolverType,'Diagonal')
  CMAT       = [1/3 0 0; 0 1/3 0; 0 0 1/3];
else
  CMAT       = [1/6 1/12 1/12; 1/12 1/6 1/12;1/12 1/12 1/6];
end

NMAT       = [1/3; 1/3; 1/3];
FMAT       = [1/3 1/6; 1/6 1/3];
VMAT       = [0.5; 0.5];

for i = 1:Mesh.CElement.NOTriangles
  % a(i)
  ACOEFF(1,1,i)  = 1/(2*Mesh.CElement.Matrix(i,8))*(Mesh.CNodes(Mesh.CElement.Matrix(i,4),2)*Mesh.CNodes(Mesh.CElement.Matrix(i,5),3) - ...
                                               Mesh.CNodes(Mesh.CElement.Matrix(i,5),2)*Mesh.CNodes(Mesh.CElement.Matrix(i,4),3));
  
  ACOEFF(1,2,i)  = 1/(2*Mesh.CElement.Matrix(i,8))*(Mesh.CNodes(Mesh.CElement.Matrix(i,5),2)*Mesh.CNodes(Mesh.CElement.Matrix(i,3),3) - ...
                                               Mesh.CNodes(Mesh.CElement.Matrix(i,3),2)*Mesh.CNodes(Mesh.CElement.Matrix(i,5),3));
  
  ACOEFF(1,3,i)  = 1/(2*Mesh.CElement.Matrix(i,8))*(Mesh.CNodes(Mesh.CElement.Matrix(i,3),2)*Mesh.CNodes(Mesh.CElement.Matrix(i,4),3) - ...
                                               Mesh.CNodes(Mesh.CElement.Matrix(i,4),2)*Mesh.CNodes(Mesh.CElement.Matrix(i,3),3));
                                             
  % b(i)
  BASTIFF(1,1,i) = 1/(2*Mesh.CElement.Matrix(i,8))*(Mesh.CNodes(Mesh.CElement.Matrix(i,4),3) - Mesh.CNodes(Mesh.CElement.Matrix(i,5),3));
  BASTIFF(1,2,i) = 1/(2*Mesh.CElement.Matrix(i,8))*(Mesh.CNodes(Mesh.CElement.Matrix(i,5),3) - Mesh.CNodes(Mesh.CElement.Matrix(i,3),3));
  BASTIFF(1,3,i) = 1/(2*Mesh.CElement.Matrix(i,8))*(Mesh.CNodes(Mesh.CElement.Matrix(i,3),3) - Mesh.CNodes(Mesh.CElement.Matrix(i,4),3));
  % c(i)
  BASTIFF(2,1,i) = 1/(2*Mesh.CElement.Matrix(i,8))*(Mesh.CNodes(Mesh.CElement.Matrix(i,5),2) - Mesh.CNodes(Mesh.CElement.Matrix(i,4),2));
  BASTIFF(2,2,i) = 1/(2*Mesh.CElement.Matrix(i,8))*(Mesh.CNodes(Mesh.CElement.Matrix(i,3),2) - Mesh.CNodes(Mesh.CElement.Matrix(i,5),2));
  BASTIFF(2,3,i) = 1/(2*Mesh.CElement.Matrix(i,8))*(Mesh.CNodes(Mesh.CElement.Matrix(i,4),2) - Mesh.CNodes(Mesh.CElement.Matrix(i,3),2));
end

BF.BBSTIFF = zeros(3,3,Mesh.CElement.NOTriangles);
BF.BSTIFF  = zeros(2,3,Mesh.CElement.NOTriangles);
BF.CSTIFF  = zeros(3,3,Mesh.CElement.NOTriangles);

for i = 1:Mesh.CElement.NOTriangles
  BF.BBSTIFF(:,:,i) = BASTIFF(:,:,i)'*[1 0; 0 1]*BASTIFF(:,:,i)*Mesh.CElement.Matrix(i,8);
  BF.CSTIFF(:,:,i)  = CMAT*Mesh.CElement.Matrix(i,8);
  BF.N(:,:,i)       = NMAT*Mesh.CElement.Matrix(i,8);
  BF.BSTIFF(:,:,i)  = BASTIFF(:,:,i);
end

%% 3. Prescribed transfer heat
if ~isempty(LOAD.tr_theta)
  BF.FSTIFF_T = zeros(2,2,size(LOAD.tr_theta,1));
  BF.VSTIFF_T = zeros(2,1,size(LOAD.tr_theta,1));

  for i = 1:size(LOAD.tr_theta,1)
    BF.FSTIFF_T(:,:,i) = FMAT*LOAD.tr_theta(i,5);
    BF.VSTIFF_T(:,:,i) = VMAT*LOAD.tr_theta(i,5);
  end
end
%% 4. Prescribed transfer moisture
if ~isempty(LOAD.tr_p)
  BF.FSTIFF_P = zeros(2,2,size(LOAD.tr_p,1));
  BF.VSTIFF_P = zeros(2,1,size(LOAD.tr_p,1));

  for i = 1:size(LOAD.tr_p,1)
    BF.FSTIFF_P(:,:,i) = FMAT*LOAD.tr_p(i,5);
    BF.VSTIFF_P(:,:,i) = VMAT*LOAD.tr_p(i,5);
  end
end
%% 5. Prescribed radiation
if ~isempty(LOAD.rad_theta)
  BF.FSTIFF_RAD = zeros(2,2,size(LOAD.rad_theta,1));
  BF.VSTIFF_RAD = zeros(2,1,size(LOAD.rad_theta,1));

  for i = 1:size(LOAD.rad_theta,1)
    BF.FSTIFF_RAD(:,:,i) = FMAT*LOAD.rad_theta(i,5);
    BF.VSTIFF_RAD(:,:,i) = VMAT*LOAD.rad_theta(i,5);
  end
end

%% Code Numbers
% Order [1.p 2.theta]
BF.CN.K = zeros(Mesh.CElement.NOTriangles,6);
for i = 1:Mesh.CElement.NOTriangles
 BF.CN.K(i,:) = [Mesh.CElement.Matrix(i,3:5) Mesh.CElement.Matrix(i,3:5)+Mesh.Boundary.NoFN];
 
 BF.CN.p(i,:)     = Mesh.CElement.Matrix(i,3:5);
 BF.CN.theta(i,:) = Mesh.CElement.Matrix(i,3:5)+Mesh.Boundary.NoFN;
end

if ~isempty(LOAD.tr_theta)
  BF.CN.tr_theta = zeros(size(LOAD.tr_theta,1),2);
  for i = 1:size(LOAD.tr_theta,1)
    BF.CN.tr_theta(i,:) = LOAD.tr_theta(i,3:4)+Mesh.Boundary.NoFN;
  end
end

if ~isempty(LOAD.tr_p)
  BF.CN.tr_p = zeros(size(LOAD.tr_p,1),2);
  for i = 1:size(LOAD.tr_theta,1)
    BF.CN.tr_p(i,:) = LOAD.tr_p(i,3:4);
  end
end

if ~isempty(LOAD.rad_theta)
  BF.CN.rad_theta = zeros(size(LOAD.rad_theta,1),2);
  for i = 1:size(LOAD.rad_theta,1)
    BF.CN.rad_theta(i,:) = LOAD.rad_theta(i,3:4)+Mesh.Boundary.NoFN;
  end
end


