function [OUTPUT] = FIRE_getMatPar(CElement,p,theta,StrengthGL,LOAD,ST,MatParVal,TraParVal)

CEN.theta = (theta(CElement.Matrix(:,3),1) + theta(CElement.Matrix(:,4),1) + theta(CElement.Matrix(:,5),1))/3;
CEN.p     = (p(CElement.Matrix(:,3),1) + p(CElement.Matrix(:,4),1) + p(CElement.Matrix(:,5),1))/3;

%% Material parameters
% [1.lambda_0,u 2.lambda_0,l 3.c_0,s 4.m_c 5.m_l0 6.theta_0 ...
%  7.permeability_0 8.rho_s 9.Stefan-Boltzman constant ...
%  10.relative surface emissivity 11.n 12.ft0 13.factor 14.fc0]

%% Material array
% [1.pSat 2.dpSat 3.wd 4.dwd/dtheta 5.w 6.dw/dp 7.dw/dtheta ...
%    8.hv 9.hd 10.lambda+lbd_w 11.rhos*cs+w*cw 12.cw 13.kappa ... 
%    14.rhos*cs 15.lambda 16.ft 17.fc]
MATPAR            = zeros(CElement.NOTriangles,9);

%% pSat
[MATPAR(:,1:2)]   = FIRE_getPSat(CEN.theta,2);
%% RH - relative humidity
CEN.RH            = CEN.p ./ MATPAR(:,1);
%% w,wd
[MATPAR(:,3:7)]   = FIRE_getW(CEN.RH,CEN.theta,MATPAR(:,1),MATPAR(:,2),MatParVal);
%% hv
[MATPAR(:,8)]     = FIRE_getHv(CEN.theta);
%% hd
[MATPAR(:,9)]     = 2.4e6;
%% lambda, c_s, cw
[MATPAR(:,10:12)] = FIRE_getThermalVal(CEN.theta,MatParVal);
MATPAR(:,15)      = MATPAR(:,10);
MATPAR(:,10)      = MATPAR(:,10) + MatParVal(11) * MATPAR(:,5) ./ MatParVal(5) * 0.6;
MATPAR(:,14)      = MATPAR(:,11) * MatParVal(8);
MATPAR(:,11)      = MATPAR(:,11) * MatParVal(8) + MATPAR(:,12) .* MATPAR(:,5);
%% kappa
[MATPAR(:,13)]    = FIRE_getKappa(CEN.theta,MatParVal);
%% strength
[MATPAR(:,16:17),OUTPUT.SpalIdx] ...
                  = FIRE_getStrength(CEN.theta,CEN.p,StrengthGL,MatParVal);


%% Matpar sort
OUTPUT.MatPar     = MATPAR;

%% Trapar calc
if ~isempty(LOAD.rad_theta)
  OUTPUT.alfaRad = zeros(size(LOAD.rad_theta,1),1);
  
  for i = 1:size(LOAD.rad_theta,1)
    TEMP.Outside        = LOAD.rad_theta(i,ST+5);
    TEMP.Boundary       = mean(theta(LOAD.rad_theta(i,3:4),1));
    OUTPUT.alfaRad(i,1) = MatParVal(9) * MatParVal(10) * ( (TEMP.Outside + 273.15)^2 + (TEMP.Boundary+ 273.15)^2) * ((TEMP.Outside + 273.15) + (TEMP.Boundary++ 273.15));
    
    
    if TEMP.Boundary < 100
      OUTPUT.alfaCon(i,1) = TraParVal(1);
    elseif TEMP.Boundary >= 100 && TEMP.Boundary < 1400
      OUTPUT.alfaCon(i,1) = TraParVal(1)*(1 + ((TEMP.Boundary-100)/1300)*2); 
    else
      OUTPUT.alfaCon(i,1) = TraParVal(1)*3;
    end
  end
end