function [Output] =  FIRE_getW(RH,theta,pSat,dpSat,MatPar)

%% Material parameters
% [1.lambda_0,u 2.lambda_0,l 3.c_0,s 4.m_c 5.m_l0 6.theta_0 7.permeability_0 8.rho_s ...
%  9.Stefan-Boltzman constant 10.relative surface emissivity

%% Init Water Properties
Water.Temp      = [0 0.01 4 5 10 15 20 25 30 35 40 45 50 55 60 65 70 75 80 85 90 95 100 105 110 115 120 125 130 135 140 145 150 155 160, ...
    165 170 175 180 185 190 195 200 220 225 240 250 260 275 300 325 350 360 374.1501];

Water.Density   = [916.8 999.8 1000 1000 999.8 999.2 998.3 997.1 995.7 994.1 992.3 990.2 988 986 983 980 978 975 972 968 965 962 958, ...
  954 951 947 943 939 935 931 926 922 918 912 907 902 897 893 887 882 876 870 864 840 834 814 799 784 756 714 654 575 528 528];
  
Water.Density_0 = interp1(Water.Temp,Water.Density,MatPar(6));
%% Water Dehydration 
Idx.nd = (theta > 100 & theta <= 700);
Idx.rd = (theta > 700);

% wd
Water.wd           = zeros(size(theta,1),1);
Water.wd(Idx.nd,1) = 0.04 * MatPar(4) * (theta(Idx.nd,1)-100)/100;
Water.wd(Idx.rd,1) = 0.24 * MatPar(4);

% dwd/dtheta
Water.dwd          = zeros(size(theta,1),1);
Water.dwd(Idx.nd,1) = 0.04 * MatPar(4) /100;

% Idx.nd = (theta > 100 & theta <= 300);
% Idx.rd = (theta > 300);
% 
% % wd
% Water.wd           = zeros(size(theta,1),1);
% Water.wd(Idx.nd,1) = 0.005 * MatPar(4) * (theta(Idx.nd,1)-100)/100;
% Water.wd(Idx.rd,1) = 0.01 * MatPar(4);
% 
% % dwd/dtheta
% Water.dwd          = zeros(size(theta,1),1);
% Water.dwd(Idx.nd,1) = 0.005 * MatPar(4) /100;



%% Material parameters
% [1.lambda_0,u 2.lambda_0,l 3.c_0,s 4.m_c 5.m_l0 6.theta_0 7.permeability_0 8.rho_s ...
%  9.Stefan-Boltzman constant 10.relative surface emissivity

%% Sorption Isotherm
Idx.st                     = (theta <= 374.1500);

% rho_theta

Water.Density_T            = zeros(size(theta,1),1);
Water.Density_T(Idx.st,1)  = interp1(Water.Temp,Water.Density,theta(Idx.st,1));

% (m(theta))
Water.Ratio                = zeros(size(theta,1),1);
Water.Ratio(Idx.st,1)      = 1.04 - ((theta(Idx.st,1)+10).^2) ./ (22.3*(MatPar(6)+10)^2 + (theta(Idx.st,1)+10).^2);
% w_096
Water.w_096                = zeros(size(theta,1),1);
Water.w_096(Idx.st,1)      = MatPar(4)*( 0.96 * MatPar(5) / MatPar(4) ) .^ ( 1 ./ Water.Ratio(Idx.st,1) );
% w_104
Water.w_104                = zeros(size(theta,1),1);
Water.w_104(Idx.st,1)      = ( MatPar(5) + Water.wd(Idx.st,1) ) .* Water.Density_T(Idx.st,1) / Water.Density_0;
% Water.w_104(Idx.st,1)      = ( MatPar(5) + Water.wd(Idx.st,1) );
% d(m(theta))/dtheta
Water.dRatio               = zeros(size(theta,1),1);
Water.dRatio(Idx.st,1)     = - 2*(theta(Idx.st,1)+10)*(22.3*(MatPar(6)+10)^2)./ ( (22.3*(MatPar(6)+10)^2 + (theta(Idx.st,1)+10).^2) ).^2;
% dw_096/dtheta
Water.dw_096               = zeros(size(theta,1),1);
Water.dw_096(Idx.st,1)     = - Water.w_096(Idx.st,1) ./ (Water.Ratio(Idx.st,1).^2) .* Water.dRatio(Idx.st,1) .* log( 0.96 * MatPar(5) / MatPar(4) );
% dw_104/dtheta
Water.dw_104               = zeros(size(theta,1),1);
Water.dw_104(Idx.st,1)     =  Water.dwd(Idx.st,1) .* Water.Density_T(Idx.st,1) / Water.Density_0;
% Water.dw_104(Idx.st,1)     =  Water.dwd(Idx.st,1);

Idx.RH_st                  = (RH > 1e-4 & RH <= 0.96) & Idx.st;
Idx.RH_nd                  = (RH > 0.96 & RH < 1.04)  & Idx.st;
Idx.RH_rd                  = (RH >= 1.04) & Idx.st;

% w
Water.w                    = zeros(size(theta,1),1);
Water.w(Idx.RH_st,1)       = MatPar(4)*( RH(Idx.RH_st,1) * MatPar(5)/MatPar(4) ) .^ ( 1 ./ Water.Ratio(Idx.RH_st,1) );
Water.w(Idx.RH_nd,1)       = Water.w_096(Idx.RH_nd,1) + ( RH(Idx.RH_nd,1) - 0.96 ) .* ( Water.w_104(Idx.RH_nd,1)-Water.w_096(Idx.RH_nd,1) )/0.08;
Water.w(Idx.RH_rd,1)       = ( MatPar(5) + Water.wd(Idx.RH_rd,1) ) .* ( 1 + 0.12*( RH(Idx.RH_rd,1)-1.04) ) .* Water.Density_T(Idx.RH_rd,1) / Water.Density_0;
% Water.w(Idx.RH_rd,1)       = ( MatPar(5) + Water.wd(Idx.RH_rd,1) ) .* ( 1 + 0.12*( RH(Idx.RH_rd,1)-1.04) ) ;

% dw/dtheta
Water.dwdtheta              = zeros(size(theta,1),1);
Water.dwdtheta(Idx.RH_st,1) = - Water.w(Idx.RH_st,1) .* ( 1 ./ (Water.Ratio(Idx.RH_st,1).^2) .* Water.dRatio(Idx.RH_st,1) .* log ( RH(Idx.RH_st,1) * MatPar(5)/MatPar(4) ) ...
  + 1 ./ ( pSat(Idx.RH_st,1) .* Water.Ratio(Idx.RH_st,1) ) .* dpSat(Idx.RH_st,1) );
Water.dwdtheta(Idx.RH_nd,1) = Water.dw_096(Idx.RH_nd,1) - RH(Idx.RH_nd,1) ./ pSat(Idx.RH_nd,1) .* dpSat(Idx.RH_nd,1) .* ( (Water.w_104(Idx.RH_nd,1) - Water.w_096(Idx.RH_nd,1)) / 0.08) ...
  + 1 / 0.08 * ( RH(Idx.RH_nd,1) - 0.96 ) .* (Water.dw_104(Idx.RH_nd,1) - Water.dw_096(Idx.RH_nd,1)) ;
Water.dwdtheta(Idx.RH_rd,1) = Water.dwd(Idx.RH_rd,1) .* ( 1 + 0.12*( RH(Idx.RH_rd,1) - 1.04) ) .* Water.Density_T(Idx.RH_rd,1) / Water.Density_0 ...
  - ( MatPar(5) + Water.wd(Idx.RH_rd,1) ) .* 0.12 .* RH(Idx.RH_rd,1) ./ pSat(Idx.RH_rd,1) .* dpSat(Idx.RH_rd,1) .* Water.Density_T(Idx.RH_rd,1) / Water.Density_0;
% Water.dwdtheta(Idx.RH_rd,1) = Water.dwd(Idx.RH_rd,1) .* ( 1 + 0.12*( RH(Idx.RH_rd,1) - 1.04) ) ...
%   - ( MatPar(5) + Water.wd(Idx.RH_rd,1) ) .* 0.12 .* RH(Idx.RH_rd,1) ./ pSat(Idx.RH_rd,1) .* dpSat(Idx.RH_rd,1);

% dw/dp
Water.dwdp              = zeros(size(theta,1),1);
Water.dwdp(Idx.RH_st,1) = MatPar(5) ./ (pSat(Idx.RH_st,1) .* Water.Ratio(Idx.RH_st,1)) .* ( RH(Idx.RH_st,1) * MatPar(5)/MatPar(4) ) .^ ( 1 ./ Water.Ratio(Idx.RH_st,1) -1 );
Water.dwdp(Idx.RH_nd,1) = 1 ./ pSat(Idx.RH_nd,1) .* ( Water.w_104(Idx.RH_nd,1) - Water.w_096(Idx.RH_nd,1) )/0.08;
Water.dwdp(Idx.RH_rd,1) = ( MatPar(5) + Water.wd(Idx.RH_rd,1) ) .* ( 0.12 ./ pSat(Idx.RH_rd,1) ) .* Water.Density_T(Idx.RH_rd,1) / Water.Density_0;
% Water.dwdp(Idx.RH_rd,1) = ( MatPar(5) + Water.wd(Idx.RH_rd,1) ) .* ( 0.12 ./ pSat(Idx.RH_rd,1) );

%% find smooth_derivative
if sum(Idx.RH_nd) > 0
  %% Correct dwdtheta
  %% 3/2
%   Derivative.dwdp_p2     = [209.831387847321,-421.491609848285,211.415703407491;50.1638530455879,-102.122953097198,51.9701979227291;49.6421578497833,-101.066517710600,51.4356288518995;49.1242614124507,-100.017785473052,50.9049634670161;48.6101413126544,-98.9767106034966,50.3781783960508;48.0997752001529,-97.9432474713304,49.8552503470825;47.5931407963562,-96.9173505982229,49.3361561091535;47.0902158952476,-95.8989746598676,48.8208725530927;46.5909783642770,-94.8880744876759,48.3093766323096;46.0954061452298,-93.8846050704254,47.8016453835677;45.6034772550574,-92.8885215558289,47.2976559277176;45.1151697866939,-91.8997792520803,46.7973854704198;44.6304619098309,-90.9183336293152,46.3008113028249;44.1493318716769,-89.9441403210431,45.8079108022412;43.6717579976844,-88.9771551255156,45.3186614327694;43.1977186922541,-88.0173340070493,44.8330407459167;42.7271924394123,-87.0646330972962,44.3510263811841;42.2601578034651,-86.1190086964695,43.8725960666323;41.7965934296271,-85.1804172745179,43.3977276194230;41.3364780446272,-84.2488154722563,42.9263989463377;40.8797904572912,-83.3241601024501,42.4585880442750;40.4265095591025,-82.4064081508568,41.9942730007265;39.9766143247385,-81.4955167772204,41.5334319942296;39.5300838125851,-80.5914433162220,41.0760432947992;39.0868971652337,-79.6941452783969,40.6220852643429;38.6470336099523,-78.8035803510007,40.1715363570511;38.2104724591400,-77.9197063988429,39.7243751197719;37.7771931107593,-77.0424814650763,39.2805801923639;37.3471750487483,-76.1718637719481,38.8401303080302;36.9203978434143,-75.3078117215147,38.4030042936352;36.4968411518104,-74.4502838963214,37.9691810700041;36.0764847180901,-73.5992390600415,37.5386396522025;35.6593083738472,-72.7546361580846,37.1113591498009;35.2452920384342,-71.9164343181638,36.6873187671199;34.8344157192680,-71.0845928508386,36.2664978034623;34.4266595121139,-70.2590712500135,35.8488756533251;34.0220036013566,-69.4398291934136,35.4344318065991;33.6204282602522,-68.6268265430209,35.0231458487498;33.2219138511666,-67.8200233454848,34.6149974609865;32.8264408257959,-67.0193798324988,34.2099664204133;32.4339897253751,-66.2248564211516,33.8080326001695;32.0517047900733,-65.4507418525403,33.4163290000729;31.6723025973253,-64.6824676958030,33.0275822693993;31.2957651413815,-63.9199972927850,32.6417737516428;30.9220744930919,-63.1632941445947,32.2588848731477;30.5512128001991,-62.4123219121293,31.8788971433368;30.1831622876179,-61.6670444165733,31.5017921549268;29.8179052576985,-60.9274256398646,31.1275515841281;29.4554240904786,-60.1934297251394,30.7561571908344;29.0957012439148,-59.4650209771366,30.3875908187917;28.7387192541063,-58.7421638625875,30.0218343957611;28.3897900076255,-58.0354822391554,29.6641913359162;28.0434927557550,-57.3341333213196,29.3092482731652;27.6998111363381,-56.6380837961890,28.9569882529896;27.3587288562157,-55.9473004943472,28.6073943955172;27.0202296914968,-55.2617503903394,28.2604498957339;26.6842974878118,-54.5814006031231,27.9161380236796;26.3509161605593,-53.9062183965094,27.5744421246379;26.0200696951319,-53.2361711795607,27.2353456193061;25.6917421471345,-52.5712265069744,26.8988320039574;25.3659176425885,-51.9113520794395,26.5648848505900;25.0425803781209,-51.2565157439640,26.2334878070625;24.7217146211457,-50.6066854941853,25.9046245972201;24.4033047100291,-49.9618294706516,25.5782790210082;24.0873350542470,-49.3219159610860,25.2544349545757;23.7737901345278,-48.6869134006231,24.9330763503666;23.4626545029868,-48.0567903720293,24.6141872372029;23.1539127832471,-47.4315156058957,24.2977517203538;22.8475496705497,-46.8110579808112,23.9837539815965;22.5435499318585,-46.1953865235242,23.6721782792701;22.2418984059464,-45.5844704090692,23.3630089483134;21.9425800034786,-44.9782789608865,23.0562304002992;21.6455797070824,-44.3767816509159,22.7518271234552;21.3508825714093,-43.7799480996756,22.4497836826794;21.0584737231859,-43.1877480763197,22.1500847195431;20.7683383612566,-42.6001514986789,21.8527149522871;20.4804617566177,-42.0171284332843,21.5576591758096;20.1948292524424,-41.4386490953749,21.2649022616459;19.9114262640975,-40.8646838488874,20.9744291579391;19.6302382791489,-40.2952032064253,20.6862248894020;19.3512508573647,-39.7301778292222,20.4002745572750;19.0744496307051,-39.1695785270807,20.1165633392729;18.7998203033065,-38.6133762582987,19.8350764895253;18.5273486514578,-38.0615421295826,19.5557993385107;18.2570205235682,-37.5140473959407,19.2787172929815;17.9888218401313,-36.9708634605732,19.0038158358863;17.7227385936761,-36.4319618747338,18.7310805262797;17.4587568487170,-35.8973143375907,18.4604969992312;17.1968627416925,-35.3668926960659,18.1920509657234;16.9370424808997,-34.8406689446653,17.9257282125463;16.6792823464227,-34.3186152252979,17.6615146021863;16.4235686900509,-33.8007038270755,17.3993960727051;16.1698879351975,-33.2869071861113,17.1393586376193;15.9182265768056,-32.7771978852969,16.8813883857683;15.6685711812517,-32.2715486540725,16.6254714811800;15.4209083862432,-31.7699323681853,16.3715941629301;15.1752249007104,-31.2723220494390,16.1197427449976;14.9315075046914,-30.7786908654280,15.8699036161126;14.6897430492139,-30.2890121292660,15.6220632396017;14.4499184561703,-29.8032592993021,15.3762081532274;14.2120207181883,-29.3214059788280,15.1323249690227;13.9836070596482,-28.8585672101694,14.8979593552232;13.7569933498397,-28.3993733717110,14.6654381358416;13.5321679283058,-27.9438007709348,14.4347492785456;13.3091191922650,-27.4918258340120,14.2058808120940;13.0878355965973,-27.0434251057415,13.9788208262881;12.8683056538268,-26.5985752494838,13.7535574719212;12.6505179340949,-26.1572530470748,13.5300789607181;12.4344610651340,-25.7194353987433,13.3083735652763;12.2201237322285,-25.2850993230007,13.0884296189943;12.0074946781745,-24.8542219565308,12.8702355159994;11.7965627032344,-24.4267805540675,12.6537797110700;11.5873166650844,-24.0027524882609,12.4390507195519;11.3797454787572,-23.5821152495317,12.2260371172697;11.1738381165818,-23.1648464459229,12.0147275404359;10.9695836081157,-22.7509238029337,11.8051106855527;10.7669710400747,-22.3403251633509,11.5971753093112;10.5659895562558,-21.9330284870662,11.3909102284847;10.3666283574586,-21.5290118508902,11.1863043198204;10.1688767013988,-21.1282534483524,10.9833465199242;9.97272390262099,-20.7307315894984,10.7820258251436;9.77815933240374,-20.3364247006728,10.5823312914451;9.58517241866304,-19.9453113242992,10.3842520342887;9.39375264585213,-19.5573701186529,10.1877772285001;9.20388955485487,-19.1725798576209,9.99289610813581;9.01557274287772,-18.7909194304601,9.79959796634842;8.82879186333698,-18.4123678415453,9.60787215524608;8.64353662574331,-18.0369042101126,9.41770808575043;8.45979679558007,-17.6645077699908,9.22909522744828;8.27756219418378,-17.2951578693369,9.04202310844582;8.09682269861391,-16.9288339703507,8.85648131521229;7.91756824152620,-16.5655156489971,8.67245949242764;7.73978881103869,-16.2051825947131,8.48994734282301;7.56347445059666,-15.8478146101141,8.30893462702045;7.38861525883257,-15.4933916106892,8.12941116336795;7.21520138942622,-15.1418936244984,7.95136682777483;7.04322305095894,-14.7933007918571,7.77479155354155;6.87267050676747,-14.4475933650208,7.59967533118937;6.70353407479269,-14.1047517078596,7.42600820828518;6.53580412742907,-13.7647562955340,7.25378028926724;6.36947109136792,-13.4275877141594,7.08298173526500;6.20452544744139,-13.0932266604714,6.91360276391988;6.04095773046294,-12.7616539414847,6.74563364920287;5.87875852906288,-12.4328504741424,6.57906472122724;5.71791848552701,-12.1067972849717,6.41388636606480;5.55842829562941,-11.7834755097279,6.25008902555642;5.40027870846261,-11.4628663930339,6.08766319712013;5.24346052626850,-11.1449512880202,5.92659943356032;5.08796460426556,-10.8297116559598,5.76688834287335;4.93378185047383,-10.5171290658964,5.60852058805125;4.78090322553916,-10.2071851942732,5.45148688688476;4.63340796481334,-9.90803879404530,5.29986019684049;4.48714647212137,-9.61138990054331,5.14949679779235;4.34211043183996,-9.31722164406801,5.00038813681909;4.19829157423452,-9.02551724876515,4.85252570898766;4.05568167534032,-8.73626003236835,4.70590105721427;3.91427255684089,-8.44943340593683,4.56050577212280;3.77405608594416,-8.16502087358867,4.41633149190128;3.63502417525637,-7.88300603222980,4.27336990215615;3.49716878265488,-7.60337257128117,4.13161273576587;3.36048191115668,-7.32610427239723,3.99105177273021;3.22495560878774,-7.05118500918655,3.85167884002069;3.09058196844934,-6.77859874692628,3.71348581142819;2.95735312778162,-6.50832954227157,3.57646460740793;2.82526126902675,-6.24036154296411,3.44060719492429;2.69429861889022,-5.97467898753721,3.30590558729388;2.56445744839859,-5.71126620501410,3.17235184402542;2.43573007275938,-5.45010761461040,3.03993807066170;2.30810885121465,-5.19118772542437,2.90865641861563;2.18158618689814,-4.93449113613440,2.77849908500990;2.05615452668658,-4.68000253468494,2.64945831251105;1.93180636105190,-4.42770669797445,2.52152638916455;1.80853422391124,-4.17758849153908,2.39469564822796;1.68633069247698,-3.92963286923663,2.26895846800419;1.56518838710322,-3.68382487292344,2.14430727167139;1.44509997113342,-3.44014963213393,2.02073452711424;1.32605815074438,-3.19859236375277,1.89823274675165;1.20805567479129,-2.95913837168949,1.77679448736577;1.09108533465110,-2.72177304654989,1.65641234992943;0.975139964063334,-2.48648186530243,1.53707897943125;0.860212438972163,-2.25325039094726,1.41878706470207;0.746295677365601,-2.02206427217972,1.30152933823877;0.633382639114931,-1.79290924305445,1.18529857602839;0.521466325812703,-1.56577112264668,1.07008759737104;0.410539780610054,-1.34063581471247,0.955889264702235;0.300596088052881,-1.11748930734664,0.842696483414260;0.191628373917552,-0.896317672640042,0.730502201677224;0.0836298050459511,-0.677107066335562,0.619299410259584;-0.0234064108208215,-0.459843727481600,0.509081142347480;-0.129487025208713,-0.244513978085752,0.399840473364239;-0.234618749078153,-0.0311042227663015,0.291570520788874;-0.338808252992120,0.180399051597452,0.184264443974059;-0.442062167284036,0.390009276214352,0.0779154439644505;-0.544387082227811,0.597739800734740,-0.0274832366870266;-0.645789548205921,0.803603893599728,-0.131938314100776;-0.746276075881716,1.00761474239882,-0.235456463256227;-0.845853136368097,1.20978545422013,-0.338044318173769;-0.944527161399302,1.41012905600671,-0.439708472099652;-1.04230454350256,1.60865849491245,-0.540455477690634;-1.13919163616972,1.80538663865790,-0.640291847198481;-1.23519475402944,2.00032627588690,-0.739224052654843;-1.32733814408010,2.18752567571975,-0.834280900755085;-1.41864683833590,2.37303544655374,-0.928483120309301;-1.50912665296632,2.55686737608751,-1.02183668145986;-1.59878336988970,2.73903318221602,-1.11434751878501;-1.68762273690550,2.91954451330678,-1.20602153144324;-1.77565046782720,3.09841294847739,-1.29686458331829;-1.86287224261749,3.27564999787738,-1.38688250316622;-1.94929370752187,3.45126710296693,-1.47608108476086;-2.03492047520426,3.62527563679940,-1.56446608704105;-2.11975812488218,3.79768690430287,-1.65204323425748;-2.20381220246376,3.96851214256533,-1.73881821612110;-2.28708822068426,4.13776252111868,-1.82479668795100;-2.36959165924299,4.30544914222350,-1.90998427082257;-2.45132796494163,4.47158304115646,-1.99438655171696;-2.53230255182153,4.63617518649561,-2.07800908366934;-2.61252080130291,4.79923648040939,-2.16085738591908;-2.69198806232351,4.96077775894438,-2.24293694405912;-2.77070965147817,5.12080979231485,-2.32425321018629;-2.84869085315800,5.27934328519142,-2.40481160305105;-2.92593691969098,5.43638887699238,-2.48461750820855;-3.00245307148121,5.59195714217232,-2.56367627816830;-3.07824449715062,5.74605859051554,-2.64199323254611;-3.15331635367894,5.89870366742585,-2.71957365821424;-3.22767376654465,6.04990275421833,-2.79642280945247;-3.30132182986691,6.19966616841282,-2.87254590809994;-3.37426560654650,6.34800416402542,-2.94794814370596;-3.44651012840744,6.49492693186133,-3.02263467368150;-3.51806039633839,6.64044459980697,-3.09661062345016;-3.58892138043580,6.78456723312573,-3.16988108660101;-3.65909802014440,6.92730483474808,-3.24245112503847;-3.72859522440060,7.06866734556760,-3.31432576913518;-3.79741787177352,7.20866464473213,-3.38551001788234;-3.86557081060864,7.34730654993999,-3.45600883904253;-3.93305885916884,7.48460281773104,-3.52582716929992;-3.99988680577763,7.62056314378186,-3.59496991441252;-4.06605940896147,7.75519716319922,-3.66344194936344;-4.13158139759155,7.88851445081221,-3.73124811851156;-4.19645747102734,8.02052452146800,-3.79839323574384;-4.26069229925820,8.15123683032339,-3.86488208462559;-4.32429052304549,8.28066077313760,-3.93071941855124;-4.38725675406567,8.40880568656671,-3.99590996089595;-4.44959557505224,8.53568084845583,-4.06045840516596;-4.51131153993789,8.66129547813147,-4.12436941514911;-4.57240917399604,8.78565873669282,-4.18764762506465;-4.63289297398421,8.90877972730645,-4.25029763971483;-4.69276740828456,9.03066749549539,-4.31232403463354;-4.75203691704613,9.15133102943133,-4.37373135623658;-4.81070591232673,9.27077926022638,-4.43452412197153;-4.86877877823420,9.38902106222310,-4.49470682046684;-4.92625987106714,9.50606525328382,-4.55428391168047;-4.98168566604479,9.61898469976938,-4.61179414125396;-5.03654572589008,9.73075882141344,-4.66872498054632;-5.09084414953276,9.84139591877768,-4.72508062986688;-5.14458501038483,9.95090424055651,-4.78086526317382;-5.19777235646350,10.0592919838303,-4.83608302820462;-5.25041021051402,10.1665672943180,-4.89073804660625;-5.30250257013223,10.2727382666300,-4.94483441406504;-5.35405340788740,10.3778129445201,-4.99837620043680;-5.40506667144493,10.4817993211387,-5.05136744987667;-5.45554628368858,10.5847053392835,-5.10381218096848;-5.50549614284325,10.6865388916525,-5.15571438685454;-5.55492012259753,10.7873078210957,-5.20707803536519;-5.60382207222516,10.8870199208646,-5.25790706914719;-5.65220581670762,10.9856829348646,-5.30820540579307;-5.70007515685627,11.0833045579053,-5.35797693797014;-5.74743386943362,11.1798924359499,-5.40722553354839;-5.79428570727571,11.2754541663665,-5.45595503572961;-5.84063439941296,11.3699972981763,-5.50416926317469;-5.88648365119180,11.4635293323031,-5.55187201013190;-5.93183714439591,11.5560577218219,-5.59906704656451;-5.97669853736684,11.6475898722070,-5.64575811827785;-6.02107146512519,11.7381331415801,-5.69194894704675;-6.06495953949099,11.8276948409573,-5.73764323074231;-6.10836634920361,11.9162822344952,-5.78284464345793;-6.15129546004298,12.0039025397391,-5.82755683563670;-6.19375041494815,12.0905629278663,-5.87178343419610;-6.23573473413793,12.1762705239333,-5.91552804265465;-6.27725191523027,12.2610324071203,-5.95879424125725;-6.31830543336049,12.3448556109735,-6.00158558709938;-6.35889874130114,12.4277471236510,-6.04390561425278;-6.39903526958091,12.5097138881655,-6.08575783389025;-6.43871842660133,12.5907628026242,-6.12714573440798;-6.47795159875705,12.6709007204744,-6.16807278155169;-6.51673815055198,12.7501344507417,-6.20854241853826;-6.55508142471775,12.8284707582721,-6.24855806617993;-6.59298474233064,12.9059163639714,-6.28812312300666;-6.63045140292848,12.9824779450449,-6.32724096538859;-6.66748468462746,13.0581621352355,-6.36591494765826;-6.70408784423806,13.1329755250615,-6.40414840223193;-6.74026411738168,13.2069246620548,-6.44194463973155;-6.77601671860616,13.2800160509975,-6.47930694910557;-6.81134884150059,13.3522561541562,-6.51623859774897;-6.84626365881099,13.4236513915189,-6.55274283162415;-6.88076432255477,13.4942081410286,-6.58882287538050;-6.91485396413504,13.5639327388174,-6.62448193247385;-6.94853569445501,13.6328314794398,-6.65972318528583;-6.98181260403091,13.7009106161038,-6.69454979524189;-7.01468776310639,13.7681763609043,-6.72896490293056;-7.04716422176426,13.8346348850517,-6.76297162822011;-7.07924501003996,13.9002923191034,-6.79657307037692;-7.10983683765538,13.9629620116596,-6.82867762673881;-7.14005151115868,14.0248677875849,-6.86039553457287;-7.16989187987344,14.0860154143516,-6.89172971097769;-7.19936077468046,14.1464106220067,-6.92268305407176;-7.22846100811720,14.2060591033760,-6.95325844309765;-7.25719537447652,14.2649665142660,-6.98345873852522;-7.28556664990609,14.3231384736670,-7.01328678215574;-7.31357759250676,14.3805805639545,-7.04274539722470;-7.34123094243072,14.4372983310898,-7.07183738850443;-7.36852942197993,14.4932972848214,-7.10056554240704;-7.39547573570371,14.5485828988844,-7.12893262708632;-7.42207257049613,14.6031606111995,-7.15694139253959;-7.44832259569317,14.6570358240717,-7.18459457070906;-7.47422846317010,14.7102139043892,-7.21189487558356;-7.49979280743739,14.7627001838194,-7.23884500329868;-7.52501824573731,14.8144999590063,-7.26544763223752;-7.54990737814020,14.8656184917672,-7.29170542313115;-7.57446278763973,14.9160610092870,-7.31762101915801;-7.59868704024848,14.9658327043136,-7.34319704604352;-7.62258268509274,15.0149387353516,-7.36843611215895;-7.64615225450772,15.0633842268564,-7.39334080862064;-7.66939826413159,15.1111742694264,-7.41791370938798;-7.69232321299966,15.1583139199952,-7.44215737136157;-7.71492958363805,15.2048082020227,-7.46607433448072;-7.73721984215770,15.2506621056870,-7.48966712182139;-7.75919643834631,15.2958805880721,-7.51293823969189;-7.78086180576262,15.3404685733602,-7.53589017773099;-7.80221836182755,15.3844309530176,-7.55852540900278;-7.82326850791698,15.4277725859841,-7.58084639009324;-7.84401462945344,15.4704982988597,-7.60285556120550;-7.86445909599749,15.5126128860913,-7.62455534625497;-7.88460426133868,15.5541211101583,-7.64594815296389;-7.90445246358640,15.5950277017574,-7.66703637295572;-7.92400602526051,15.6353373599877,-7.68782238184940;-7.94326725338088,15.6750547525331,-7.70830853935233;-7.96223843955767,15.7141845158466,-7.72849718935421;-7.98092186008002,15.7527312553306,-7.74839066001910;-7.99931977600568,15.7906995455203,-7.76799126387858;-8.01743443324925,15.8280939302626,-7.78730129792326;-8.03526806267069,15.8649189228974,-7.80632304369477;-8.05282288016294,15.9011790064352,-7.82505876737663;-8.07010108674001,15.9368786337376,-7.84351071988567;-8.08710486862363,15.9720222276928,-7.86168113696192;-8.10383639733050,16.0066141813941,-7.87957223925917;-8.12029782975871,16.0406588583156,-7.89718623243451;-8.13649130827351,16.0741605924867,-7.91452530723736;-8.15241896079373,16.1071236886686,-7.93159163959899;-8.16808290087649,16.1395524225263,-7.94838739072039;-8.18348522780292,16.1714510408035,-7.96491470716104;-8.19862802666213,16.2028237614934,-7.98117572092601;-8.21268564823677,16.2320192273243,-7.99634605167004;-8.22649697269376,16.2607153531785,-8.01126339000205;-8.24006395791700,16.2889161015464,-8.02592973977847;-8.25338854872037,16.3166254084242,-8.04034709143410;-8.26647267692264,16.3438471834660,-8.05451742205998;-8.27931826142254,16.3705853101376,-8.06844269548140;-8.29192720827384,16.3968436458688,-8.08212486233582;-8.30430141075943,16.4226260222049,-8.09556586014986;-8.31644274946612,16.4479362449591,-8.10876761341691;-8.32835309235754,16.4727780943605,-8.12173203367283;-8.34003429484905,16.4971553252074,-8.13446101957369;-8.35148819987999,16.5210716670143,-8.14695645697073;-8.36271663798697,16.5445308241610,-8.15922021898643;-8.37372142737685,16.5675364760414,-8.17125416609020;-8.38450437399864,16.5900922772099,-8.18306014617290;-8.39506727161589,16.6122018575292,-8.19463999462198;-8.40541190187855,16.6338688223159,-8.20599553439593;-8.41554003439415,16.6550967524862,-8.21712857609812;-8.42545342679905,16.6758892047005,-8.22804091805056;-8.43515382482961,16.6962497115084,-8.23873434636771;-8.44464296239195,16.7161817814910,-8.24921063502880;-8.45392256163324,16.7356888994055,-8.25947154595157;-8.46299433301073,16.7547745263264,-8.26951882906385;-8.47185997536213,16.7734420997881,-8.27935422237639;-8.48052117597410,16.7916950339245,-8.28897945205387;-8.48897961065187,16.8095367196110,-8.29839623248687;-8.49723694378788,16.8269705246037,-8.30760626636297;-8.50529482842996,16.8439997936785,-8.31661124473734;-8.51315490634919,16.8606278487689,-8.32541284710288;-8.52081880810821,16.8768579891052,-8.33401274146100;-8.52828815312848,16.8926934913511,-8.34241258439113;-8.53556454975732,16.9081376097405,-8.35061402112006;-8.54264959533457,16.9231935762125,-8.35861868559097;-8.54954487625950,16.9378646005479,-8.36642820053248;-8.55625196805658,16.9521538705028,-8.37404417752677;-8.56277243544221,16.9660645519444,-8.38146821707850;-8.56910783238908,16.9795997889818,-8.38870190868138;-8.57525970219236,16.9927627041008,-8.39574683088653;-8.58122957753456,17.0055563982954,-8.40260455136954;-8.58701898054971,17.0179839511984,-8.40927662699675;-8.59262942288814,17.0300484212135,-8.41576460389222;-8.59806240578076,17.0417528456455,-8.42207001750409;-8.60331942010184,17.0531002408280,-8.42819439266942;-8.60840194643353,17.0640936022547,-8.43413924368084;-8.61331145512805,17.0747359047058,-8.43990607435077;-8.61804940637130,17.0850301023771,-8.44549637807707;-8.62261725024459,17.0949791290056,-8.45091163790677;-8.62701642678753,17.1045858979971,-8.45615332660100;-8.63124836605917,17.1138533025510,-8.46122290669807;-8.63531448820025,17.1227842157859,-8.46612183057775;-8.63826914132394,17.1294872449107,-8.46990587690473;-8.64107082837068,17.1358795510644,-8.47353216700613;-8.64372084937333,17.1419637664190,-8.47700203257860;-8.64622049550020,17.1477425051812,-8.48031679622044;-8.64857104910723,17.1532183636994,-8.48347777148575;-8.65077378379080,17.1583939205702,-8.48648626293898;-8.65282996443950,17.1632717367447,-8.48934356620873;-8.65474084728631,17.1678543556340,-8.49205096804163;-8.65650767995992,17.1721443032142,-8.49460974635557;-8.65813170153617,17.1761440881307,-8.49702117029294;-8.65961414258978,17.1798562018035,-8.49928650027409;-8.66095622524472,17.1832831185300,-8.50140698804960;-8.66215916322522,17.1864272955885,-8.50338387675293;-8.66322416190580,17.1892911733399,-8.50521840095228;-8.66415241836226,17.1918771753317,-8.50691178670329;-8.66494512142128,17.1941877083989,-8.50846525160034;-8.66560345171022,17.1962251627649,-8.50988000482809;-8.66612858170634,17.1979919121423,-8.51115724721237;-8.66652167578705,17.1994903138341,-8.51229817127206;-8.66678389027796,17.2007227088326,-8.51330396126891;-8.66691637350237,17.2016914219191,-8.51417579325855;-8.66692026582954,17.2023987617626,-8.51491483514050;-8.66679669972348,17.2028470210185,-8.51552224670848;-8.66654679979055,17.2030384764261,-8.51599917969968;-8.66617168282787,17.2029753889064,-8.51634677784474;-8.66567245787068,17.2026600036585,-8.51656617691667;-8.66505022623985,17.2020945502564,-8.51665850477995;-8.66430608158932,17.2012812427453,-8.51662488143949;-8.66344110995277,17.2002222797365,-8.51646641908886;-8.66245638979076,17.1989198445030,-8.51618422215891;-8.66135299203674,17.1973761050733,-8.51577938736536;-8.66013198014367,17.1955932143261,-8.51525300375683;-8.65879441013010,17.1935733100837,-8.51460615276247;-8.65734133062605,17.1913185152056,-8.51383990823928;-8.65577378291828,17.1888309376801,-8.51295533651882;-8.65409280099604,17.1861126707175,-8.51195349645446;-8.65229941159590,17.1831657928412,-8.51083543946759;-8.65039463424691,17.1799923679792,-8.50960220959422;-8.64837948131539,17.1765944455555,-8.50825484353116;-8.64625495804872,17.1729740605786,-8.50679437068125;-8.64402206262047,17.1691332337334,-8.50522181319982;-8.64168178617396,17.1650739714697,-8.50353818603966;-8.63923511286571,17.1607982660906,-8.50174449699580;-8.63668301990978,17.1563080958420,-8.49984174675124;-8.63402647762037,17.1516054249997,-8.49783092892085;-8.63126644945536,17.1466922039577,-8.49571303009622;-8.62840389205895,17.1415703693144,-8.49348902988970;-8.62543975530450,17.1362418439601,-8.49115990097840;-8.62237498233693,17.1307085371629,-8.48872660914807;-8.61921050961463,17.1249723446536,-8.48619011333609;-8.61570411844497,17.1185488204753,-8.48330857623200;-8.61210236706357,17.1119311351312,-8.48032821549526;-8.60840615040160,17.1051211008105,-8.47724994809049;-8.60461635705854,17.0981205168797,-8.47407468449362;-8.60073386934145,17.0909311699629,-8.47080332873237;-8.59675956330418,17.0835548340211,-8.46743677842669;-8.59269430878688,17.0759932704325,-8.46397592482951;-8.58853896945398,17.0682482280699,-8.46042165286587;-8.58429440283378,17.0603214433806,-8.45677484117370;-8.57996146035599,17.0522146404631,-8.45303636214261;-8.57554098739060,17.0439295311459,-8.44920708195384;-8.57103382328552,17.0354678150638,-8.44528786061909;-8.56644080140459,17.0268311797350,-8.44127955201970;-8.56176274916483,17.0180213006371,-8.43718300394502;-8.55700048807477,17.0090398412846,-8.43299905813185;-8.55215483377024,16.9998884533018,-8.42872855030141;-8.54722659605288,16.9905687765005,-8.42437231019890;-8.54221657892587,16.9810824389534,-8.41993116163036;-8.53712558063117,16.9714310570685,-8.41540592250098;-8.53195439368560,16.9616162356637,-8.41079740485230;-8.52670380491750,16.9516395680399,-8.40610641489991;-8.52137459550211,16.9415026360538,-8.40133375306990;-8.51596754099809,16.9312070101914,-8.39648021403646;-8.51048341138261,16.9207542496397,-8.39154658675799;-8.50492297108747,16.9101459023596,-8.38653365451426;-8.49928697903371,16.8993835051561,-8.38144219494208;-8.49357618866693,16.8884685837505,-8.37627298007157;-8.48779134799219,16.8774026528506,-8.37102677636216;-8.48193319960895,16.8661872162221,-8.36570434473849;-8.47600248074497,16.8548237667569,-8.36030644062527;-8.46999992329118,16.8433137865443,-8.35483381398324;-8.46392625383568,16.8316587469396,-8.34928720934400;-8.45778219369736,16.8198601086326,-8.34366736584476;-8.45156845895996,16.8079193217165,-8.33797501726324;-8.44528576050570,16.7958378257563,-8.33221089205233;-8.43893480404826,16.7836170498555,-8.32637571337395;-8.43251629016644,16.7712584127245,-8.32047019913371;-8.42603091433675,16.7587633227466,-8.31449506201441;-8.41947936696656,16.7461331780456,-8.30845100951009;-8.41286233342647,16.7333693665508,-8.30233874395936;-8.40618049408292,16.7204732660637,-8.29615896257887;-8.39943452433041,16.7074462443231,-8.28991235749647;-8.39262509462365,16.6942896590704,-8.28359961578419;-8.38575287050942,16.6810048581141,-8.27722141949111;-8.37881851265816,16.6675931793939,-8.27077844567567;-8.37182267689587,16.6540559510455,-8.26427136643857;-8.36476601423501,16.6403944914632,-8.25770084895445;-8.35764917090608,16.6266101093636,-8.25106755550438;-8.35047278838847,16.6127041038487,-8.24437214350752;-8.34323750344141,16.5986777644685,-8.23761526555297;-8.33632195918417,16.5852884419225,-8.23117502226214;-8.32934504073992,16.5717738732476,-8.22467087809924;-8.32230740241851,16.5581353827686,-8.21810350283259;-8.31520969366687,16.5443742849758,-8.21147356126130;-8.30805255910121,16.5304918845907,-8.20478171324833;-8.30083663853915,16.5164894766306,-8.19802861375342;-8.29356256703145,16.5023683464728,-8.19121491286558;-8.28623097489379,16.4881297699195,-8.18434125583565;-8.27884248773835,16.4737750132612,-8.17740828310871;-8.27139772650471,16.4593053333396,-8.17041663035574;-8.26389730749148,16.4447219776114,-8.16336692850592;-8.25634184238682,16.4300261842104,-8.15625980377806;-8.24873193829937,16.4152191820099,-8.14909587771218;-8.24106819778862,16.4003021906841,-8.14187576720066;-8.23335121889554,16.3852764207706,-8.13460008451960;-8.22558159517233,16.3701430737301,-8.12726943735933;-8.21775991571299,16.3549033420086,-8.11988442885567;-8.20988676518246,16.3395584090961,-8.11244565761984;-8.20196272384676,16.3241094495880,-8.10495371776928;-8.19398836760242,16.3085576292445,-8.09740919895778;-8.18596426800534,16.2929041050491,-8.08981268640513;-8.17789099230018,16.2771500252678,-8.08216476092708;-8.16976910344933,16.2612965295081,-8.07446599896512;-8.16159916016144,16.2453447487767,-8.06671697261563;-8.15338171692008,16.2292958055373,-8.05891824965925;-8.14511732401233,16.2131508137687,-8.05107039359013;-8.13680652755641,16.1969108790206,-8.04317396364427;-8.12844986953031,16.1805770984717,-8.03522951482877;-8.12004788779954,16.1641505609857,-8.02723759795026;-8.11160111614441,16.1476323471664,-8.01919875964285;-8.10311008428802,16.1310235294148,-8.01111354239674;-8.09457531792356,16.1143251719840,-8.00298248458618;-8.08599733874131,16.0975383310338,-7.99480612049713;-8.07737666445539,16.0806640546851,-7.98658498035462;-8.06871380883156,16.0637033830761,-7.97831959035115;-8.06000928171279,16.0466573484138,-7.97001047267299;-8.05126358904648,16.0295269750292,-7.96165814552789;-8.04247723291051,16.0123132794305,-7.95326312317182;-8.03365071153979,15.9950172703560,-7.94482591593612;-8.02478451935149,15.9776399488257,-7.93634703025333;-8.01587914697209,15.9601823081959,-7.92782696868481;-8.00693508126202,15.9426453342091,-7.91926622994603;-7.99795280534155,15.9250300050464,-7.91066530893303;-7.98893279861658,15.9073372913794,-7.90202469674873;-7.97987553680333,15.8895681564206,-7.89334488072834;-7.97078149195347,15.8717235559742,-7.88462634446491;-7.96165113247947,15.8538044384868,-7.87586956783538;-7.95248492317874,15.8358117450970,-7.86707502702519;-7.94328332525874,15.8177464096858,-7.85824319455402;-7.93404679636127,15.7996093589259,-7.84937453930059;-7.92329375342179,15.7784372476909,-7.83898967792470;-7.91252081290456,15.7572235122701,-7.82858302855226;-7.90172830634159,15.7359688268737,-7.81815493390036;-7.89091656273464,15.7146738605770,-7.80770573408131;-7.88008590857074,15.6933392773516,-7.79723576661878;-7.86923666783793,15.6719657360975,-7.78674536646405;-7.85836916204121,15.6505538906754,-7.77623486601254;-7.84748371021801,15.6291043899385,-7.76570459511974;-7.83658062895328,15.6076178777629,-7.75515488111690;-7.82566023239566,15.5860949930806,-7.74458604882771;-7.81472283227192,15.5645363699089,-7.73399842058322;-7.80376873790323,15.5429426373834,-7.72339231623870;-7.79279825621926,15.5213144197868,-7.71276805318818;-7.78181169177437,15.4996523365817,-7.70212594638121;-7.77080934676156,15.4779570024391,-7.69146630833726;-7.75979152102833,15.4562290272703,-7.68078944916213;-7.74875851209101,15.4344690162566,-7.67009567656275;-7.73771061514958,15.4126775698790,-7.65938529586249;-7.72664812310276,15.3908552839492,-7.64865861001678;-7.71557132656222,15.3690027496380,-7.63791591962773;-7.70448051386724,15.3471205535057,-7.62715752295935;-7.69337597109924,15.3252092775311,-7.61638371595252;-7.68225798209645,15.3032694991419,-7.60559479224012;-7.67112682846761,15.2813017912418,-7.59479104316124;-7.65998278960675,15.2593067222414,-7.58397275777640;-7.64882614270717,15.2372848560858,-7.57314022288199;-7.63765716277560,15.2152367522841,-7.56229372302490;-7.62647612264605,15.1931629659370,-7.55143354051682;-7.61528329299398,15.1710640477658,-7.54055995544890;-7.60407894235017,15.1489405441407,-7.52967324570598;-7.59286333711411,15.1267929971079,-7.51877368698051;-7.58163674156842,15.1046219444188,-7.50786155278739;-7.57039941789189,15.0824279195567,-7.49693711447741;-7.55915162617323,15.0602114517647,-7.48600064125147;-7.54789362442476,15.0379730660734,-7.47505240017472;-7.53662566859562,15.0157132833277,-7.46409265619014;-7.52534801258516,14.9934326202143,-7.45312167213241;-7.51406090825627,14.9711315892886,-7.44213970874162;-7.50276460544863,14.9488106990014,-7.43114702467698;-7.49145935199167,14.9264704537256,-7.42014387653012;-7.48014539371789,14.9041113537831,-7.40913051883894;-7.46882297447558,14.8817338954706,-7.39810720410061;-7.45749233614189,14.8593385710863,-7.38707418278514;-7.44615371863571,14.8369258689557,-7.37603170334860;-7.43480735993028,14.8144962734577,-7.36498001224619;-7.42345349606611,14.7920502650505,-7.35391935394548;-7.41209236116345,14.7695883202972,-7.34284997093934;-7.40072418743488,14.7471109118909,-7.33177210375889;-7.38934920519791,14.7246185086809,-7.32068599098645;-7.37796764288721,14.7021115756971,-7.30959186926826;-7.36657972706719,14.6795905741757,-7.29848997332731;-7.35518568244411,14.6570559615837,-7.28738053597592;-7.34378573187837,14.6345081916440,-7.27626378812836;-7.33238009639667,14.6119477143601,-7.26513995881341;-7.32096899520400,14.5893749760402,-7.25400927518669;-7.30955264569581,14.5667904193222,-7.24287196254320;-7.29813126346975,14.5441944831975,-7.23172824432947;-7.28670506233771,14.5215876030351,-7.22057834215589;-7.27527425433755,14.4989702106059,-7.20942247580884;-7.26383904974490,14.4763427341064,-7.19826086326281;-7.25239965708469,14.4537055981820,-7.18709372069237;-7.24095628314294,14.4310592239514,-7.17592126248417;-7.22950913297821,14.4084040290291,-7.16474370124887;-7.21805840993305,14.3857404275495,-7.15356124783284;-7.20660431564542,14.3630688301893,-7.14237411132996;-7.19514705006011,14.3403896441911,-7.13118249909340;-7.18368681143992,14.3177032733863,-7.11998661674709;-7.17222379637693,14.2950101182174,-7.10878666819733;-7.16075819980359,14.2723105757609,-7.09758285564428;-7.14929021500391,14.2496050397500,-7.08637537959336;-7.13782003362435,14.2268939005964,-7.07516443886656;-7.12634784568485,14.2041775454133,-7.06395023061376;-7.11487383958978,14.1814563580368,-7.05273295032400;-7.10339820213863,14.1587307190484,-7.04151279183650;-7.09192111853681,14.1360010057964,-7.03028994735175;-7.08044277240652,14.1132675924179,-7.01906460744272;-7.06896334579713,14.0905308498605,-7.00783696106553;-7.05748301919600,14.0677911459034,-6.99660719557062;-7.04600197153881,14.0450488451792,-6.98537549671330;-7.03452038022012,14.0223043091946,-6.97414204866475;-7.02303842110377,13.9995578963519,-6.96290703402255;-7.01155626853311,13.9768099619698,-6.95167063382138;-7.00007409534143,13.9540608583043,-6.94043302754361;-6.98859207286204,13.9313109345694,-6.92919439312976;-6.97711037093847,13.9085605369575,-6.91795490698897;-6.96562915793455,13.8858100086604,-6.90671474400936;-6.95414860074452,13.8630596898891,-6.89547407756840;-6.94266886480285,13.8403099178942,-6.88423307954311;-6.93119011409434,13.8175610269864,-6.87299192032031;-6.91971251116377,13.7948133485556,-6.86175076880669;-6.90823621712589,13.7720672110919,-6.85050979243899;-6.89676139167503,13.7493229402044,-6.83926915719389;-6.88528819309486,13.7265808586416,-6.82802902759809;-6.87381677826797,13.7038412863102,-6.81678956673812;-6.86234730268541,13.6811045402950,-6.80555093627021;-6.85087992045628,13.6583709348781,-6.79431329643003;-6.83941478431711,13.6356407815579,-6.78307680604251;-6.82795204564130,13.6129143890685,-6.77184162253138;-6.81649185444843,13.5901920633981,-6.76060790192885;-6.80503435941353,13.5674741078084,-6.74937579888509;-6.79451342480757,13.5466283766148,-6.73907780476536;-6.78398716181854,13.5257709770625,-6.72877342778550;-6.77345577899396,13.5049023320548,-6.71846288226301;-6.76291948308495,13.4840228608654,-6.70814638068322;-6.75237847905919,13.4631329791646,-6.69782413371261;-6.74183297011361,13.4422330990448,-6.68749635021157;-6.73128315768711,13.4213236290467,-6.67716323724757;-6.72072924147326,13.4004049741844,-6.66682500010790;-6.71017141943266,13.3794775359705,-6.65648184231240;-6.69960988780555,13.3585417124420,-6.64613396562626;-6.68904484112408,13.3375978981842,-6.63578157007254;-6.67847647222462,13.3166464843565,-6.62542485394470;-6.66790497225990,13.2956878587163,-6.61506401381894;-6.65733053071121,13.2747224056439,-6.60469924456672;-6.64675333540038,13.2537505061667,-6.59433073936685;-6.63617357250172,13.2327725379830,-6.58395868971779;-6.62559142655390,13.2117888754864,-6.57358328544960;-6.61500708047178,13.1907998897897,-6.56320471473614;-6.60442071555803,13.1698059487478,-6.55282316410682;-6.59383251151486,13.1488074169821,-6.54243881845857;-6.58324264645551,13.1278046559033,-6.53205186106757;-6.57265129691577,13.1067980237347,-6.52166247360094;-6.56205863786528,13.0857878755350,-6.51127083612831;-6.55146484271902,13.0647745632217,-6.50087712713348;-6.54087008334837,13.0437584355934,-6.49048152352574;-6.53027453009240,13.0227398383522,-6.48008420065128;-6.51967835176894,13.0017191141266,-6.46968533230457;-6.50908171568556,12.9806966024934,-6.45928509073949;-6.49848478765051,12.9596726399997,-6.44888364668048;-6.48788773198367,12.9386475601853,-6.43848116933373;-6.47729071152727,12.9176216936040,-6.42807782639801;-6.46669388765661,12.8965953678456,-6.41767378407575;-6.45609742029076,12.8755689075573,-6.40726920708374;-6.44550146790310,12.8545426344649,-6.39686425866404;-6.43490618753183,12.8335168673944,-6.38645910059460;-6.42431173479041,12.8124919222925,-6.37605389319990;-6.41371826387795,12.7914681122480,-6.36564879536154;-6.40312592758946,12.7704457475127,-6.35524396452873;-6.39253487732608,12.7494251355213,-6.34483955672860;-6.38194526310527,12.7284065809128,-6.33443572657671;-6.37135723357085,12.7073903855501,-6.32403262728717;-6.36077093600307,12.6863768485410,-6.31363041068298;-6.35018651632852,12.6653662662575,-6.30322922720605;-6.33960411912999,12.6443589323563,-6.29282922592728;-6.32902388765634,12.6233551377984,-6.28243055455665;-6.31844596383223,12.6023551708689,-6.27203335945305;-6.30787048826780,12.5813593171962,-6.26163778563420;-6.29729760026824,12.5603678597721,-6.25124397678639;-6.28672743784340,12.5393810789704,-6.24085207527424;-6.27616013771727,12.5183992525662,-6.23046222215037;-6.26484621934398,12.4959233275098,-6.21932604814867;-6.25354189359683,12.4734658269103,-6.20819865190156;-6.24224724531188,12.4510269246817,-6.19708012256741;-6.23096235843382,12.4286067929290,-6.18597054838719;-6.21968731602227,12.4062056019612,-6.17487001669105;-6.20842220025833,12.3838235203045,-6.16377861390494;-6.19716709245076,12.3614607147150,-6.15269642555704;-6.18592207304243,12.3391173501915,-6.14162353628438;-6.17468722161645,12.3167935899882,-6.13056002983904;-6.16346261690249,12.2944895956272,-6.11950598909478;-6.15224833678287,12.2722055269113,-6.10846149605318;-6.14104445829878,12.2499415419361,-6.09742663185008;-6.12985105765637,12.2276977971026,-6.08640147676181;-6.11866821023276,12.2054744471296,-6.07538611021140;-6.10749599058211,12.1832716450653,-6.06438061077477;-6.09633447244162,12.1610895423005,-6.05338505618690;-6.08518372873746,12.1389282885796,-6.04239952334792;-6.07404383159068,12.1167880320131,-6.03142408832921;-6.06291485232305,12.0946689190897,-6.02045882637935;-6.05179686146302,12.0725710946876,-6.00950381193024;-6.04068992875136,12.0504947020866,-5.99855911860293;-6.02959412314702,12.0284398829798,-5.98762481921362;-6.01850951283287,12.0064067774849,-5.97670098577949;-6.00743616522129,11.9843955241562,-5.96578768952457;-5.99637414695993,11.9624062599957,-5.95488500088553;-5.98532352393729,11.9404391204645,-5.94399298951744;-5.97428436128825,11.9184942394942,-5.93311172429950;-5.96325672339973,11.8965717494984,-5.92224127334078;-5.95224067391607,11.8746717813833,-5.91138170398579;-5.94123627574459,11.8527944645592,-5.90053308282016;-5.93024359106101,11.8309399269514,-5.88969547567619;-5.91926268131482,11.8091082950112,-5.87886894763844;-5.90829360723474,11.7872996937270,-5.86805356304923;-5.89733642883392,11.7655142466343,-5.85724938551403;-5.88639120541535,11.7437520758274,-5.84645647790702;-5.87545799557711,11.7220133019698,-5.83567490237645;-5.86453685721754,11.7002980443044,-5.82490472034997;-5.85362784754054,11.6786064206645,-5.81414599254007;-5.84273102306062,11.6569385474839,-5.80339877894921;-5.83184643960813,11.6352945398077,-5.79266313887528;-5.82097415233429,11.6136745113023,-5.78193913091670;-5.81011421571629,11.5920785742658,-5.77122681297763;-5.79926668356237,11.5705068396384,-5.76052624227325;-5.78843160901670,11.5489594170120,-5.74983747533470;-5.77760904456444,11.5274364146407,-5.73916056801437;-5.76679904203663,11.5059379394507,-5.72849557549079;-5.75600165261519,11.4844640970503,-5.71784255227388;-5.74521692683763,11.4630149917397,-5.70720155220966;-5.73444491460203,11.4415907265206,-5.69657262848548;-5.72368566517177,11.4201914031063,-5.68595583363483;-5.71293922718034,11.3988171219313,-5.67535121954222;-5.70220564863609,11.3774679821608,-5.66475883744812;-5.69148497692693,11.3561440817001,-5.65417873795378;-5.68077725882500,11.3348455172046,-5.64361097102598;-5.67008254049137,11.3135723840887,-5.63305558600189;-5.65940086748064,11.2923247765354,-5.62251263159375;-5.64873228474549,11.2711027875059,-5.61198215589361;-5.63807683664133,11.2499065087481,-5.60146420637799;-5.62743456693075,11.2287360308064,-5.59095882991257;-5.61680551878807,11.2075914430308,-5.58046607275675;-5.60618973480384,11.1864728335858,-5.56998598056834;-5.59558725698918,11.1653802894591,-5.55951859840797;-5.58499812678032,11.1443138964712,-5.54906397074378;-5.57442238504292,11.1232737392838,-5.53862214145581;-5.56386007207642,11.1022599014090,-5.52819315384050;-5.55331122761840,11.0812724652175,-5.51777705061516;-5.54277589084887,11.0603115119481,-5.50737387392233;-5.53225410039455,11.0393771217155,-5.49698366533423;-5.52174589433308,11.0184693735196,-5.48660646585704;-5.51125131019727,10.9975883452536,-5.47624231593526;-5.50077038497928,10.9767341137129,-5.46589125545600;-5.49030315513479,10.9559067546031,-5.45555332375330;-5.47984965658712,10.9351063425485,-5.44522855961228;-5.46940992473133,10.9143329511007,-5.43491700127339;-5.45898399443831,10.8935866527463,-5.42461868643662;-5.44857190005881,10.8728675189158,-5.41433365226560;-5.43817367542753,10.8521756199912,-5.40406193539181;-5.42778935386705,10.8315110253144,-5.39380357191861;-5.41741896819178,10.8108738031950,-5.38355859742530;-5.40706255071202,10.7902640209186,-5.37332704697127;-5.39672013323776,10.7696817447546,-5.36310895509990;-5.38639174708265,10.7491270399638,-5.35290435584261;-5.37607742306782,10.7285999708069,-5.34271328272286;-5.36577719152572,10.7081006005514,-5.33253576875999;-5.35549108230400,10.6876289914804,-5.32237184647326;-5.34521912476923,10.6671852048991,-5.31222154788562;-5.33496134781068,10.6467693011435,-5.30208490452763;-5.32471777984410,10.6263813395872,-5.29196194744135;-5.31448844881539,10.6060213786493,-5.28185270718399;-5.30427338220429,10.5856894758019,-5.27175721383188;-5.29407260702808,10.5653856875773,-5.26167549698409;-5.28388614984522,10.5451100695757,-5.25160758576627;-5.27371403675890,10.5248626764719,-5.24155350883424;-5.26355629342073,10.5046435620235,-5.23151329437780;-5.25341294503423,10.4844527790773,-5.22148697012428;-5.24328401635841,10.4642903795771,-5.21147456334228;-5.23316953171131,10.4441564145702,-5.20147610084520;-5.22306951497343,10.4240509342152,-5.19149160899485;-5.21298398959129,10.4039739877884,-5.18152111370501;-5.20291297858078,10.3839256236911,-5.17156464044498;-5.19236311453511,10.3629190461088,-5.16112955284910;-5.18183179626005,10.3419491188636,-5.15071251766019;-5.17131901756084,10.3210158318907,-5.14031353113691;-5.16082477202164,10.3001191746698,-5.12993258930299;-5.15034905300754,10.2792591362287,-5.11956968794930;-5.13989185366638,10.2584357051477,-5.10922482263582;-5.12945316693066,10.2376488695631,-5.09889798869358;-5.11903298551948,10.2168986171709,-5.08858918122665;-5.10863130194025,10.1961849352310,-5.07829839511408;-5.09824810849075,10.1755078105709,-5.06802562501185;-5.08788339726076,10.1548672295891,-5.05777086535475;-5.07753716013404,10.1342631782593,-5.04753411035835;-5.06720938879009,10.1136956421339,-5.03731535402088;-5.05690007470597,10.0931646063478,-5.02711459012510;-5.04660920915807,10.0726700556218,-5.01693181224019;-5.03633678322393,10.0522119742665,-5.00676701372361;-5.02608278778400,10.0317903461860,-4.99662018772301;-5.01584721352339,10.0114051548814,-4.98649132717796;-5.00563005093366,9.99105638345411,-4.97638042482188;-4.99543129031449,9.97074401460985,-4.96628747318383;-4.98525092177550,9.95046803066198,-4.95621246459029;-4.97508893523791,9.93022841353498,-4.94615539116699;-4.96494532043625,9.91002514476802,-4.93611624484071;-4.95482006692007,9.88985820551839,-4.92609501734097;-4.94471316405565,9.86972757656499,-4.91609170020193;-4.93462460102762,9.84963323831167,-4.90610628476398;-4.92455436684072,9.82957517079081,-4.89613876217566;-4.91450245032132,9.80955335366646,-4.88618912339522;-4.90446884011920,9.78956776623793,-4.87625735919244;-4.89445352470908,9.76961838744297,-4.86634346015033;-4.88445649239233,9.74970519586118,-4.85644741666678;-4.87447773129852,9.72982816971732,-4.84656921895630;-4.86451722938706,9.70998728688449,-4.83670885705166;-4.85457497444877,9.69018252488751,-4.82686632080557;-4.84465095410748,9.67041386090605,-4.81704159989235;-4.83474515582160,9.65068127177793,-4.80723468380953;-4.82485756688566,9.63098473400222,-4.79744556187949;-4.81498817443192,9.61132422374257,-4.78767422325116;-4.80513696543185,9.59169971683019,-4.77792065690153;-4.79530392669771,9.57211118876708,-4.76818485163731;-4.78548904488402,9.55255861472912,-4.75846679609649;-4.77569230648915,9.53304196956921,-4.74876647874998;-4.76591369785677,9.51356122782028,-4.73908388790310;-4.75615320517733,9.49411636369832,-4.72941901169717;-4.74641081448958,9.47470735110556,-4.71977183811113;-4.73668651168207,9.45533416363329,-4.71014235496295;-4.72698028249452,9.43599677456501,-4.70053054991129;-4.71729211251941,9.41669515687936,-4.69093641045694;-4.70762198720327,9.39742928325301,-4.68135992394434;-4.69796989184826,9.37819912606368,-4.67180107756312;-4.68874004583246,9.35981317773899,-4.66266349562551;-4.67952503498273,9.34145655937159,-4.65354036744202;-4.67032486571626,9.32312928554205,-4.64443170125467;-4.66113954416450,9.30483137024962,-4.63533750500983;-4.65196907617561,9.28656282691714,-4.62625778636068;-4.64281346731694,9.26832366839603,-4.61719255266977;-4.63367272287730,9.25011390697099,-4.60814181101140;-4.62454684786950,9.23193355436500,-4.59910556817412;-4.61543584703258,9.21378262174394,-4.59008383066311;-4.60633972483419,9.19566111972144,-4.58107660470258;-4.59725848547301,9.17756905836363,-4.57208389623821;-4.58819213288093,9.15950644719371,-4.56310571093948;-4.57914067072546,9.14147329519675,-4.55414205420205;-4.57010410241195,9.12346961082421,-4.54519293115009;-4.56108243108585,9.10549540199850,-4.53625834663856;-4.55207565963501,9.08755067611770,-4.52733830525562;-4.54308379069192,9.06963544005995,-4.51843281132483;-4.53410682663586,9.05174970018800,-4.50954186890748;-4.52514476959514,9.03389346235361,-4.50066548180479;-4.51619762144935,9.01606673190211,-4.49180365356021;-4.50726538383140,8.99826951367663,-4.48295638746163;-4.49834805812981,8.98050181202265,-4.47412368654358;-4.48944564549080,8.96276363079223,-4.46530555358946;-4.48055814682039,8.94505497334834,-4.45650199113366;-4.47168556278656,8.92737584256913,-4.44771300146380;-4.46282789382132,8.90972624085223,-4.43893858662282;-4.45398514012283,8.89210617011895,-4.43017874841116;-4.44515730165740,8.87451563181839,-4.42143348838885;-4.43634437816161,8.85695462693175,-4.41270280787763;-4.42754636914432,8.83942315597628,-4.40398670796303;-4.41876327388872,8.82192121900963,-4.39528518949650;-4.40999509145430,8.80444881563364,-4.38659825309736;-4.40124182067888,8.78700594499858,-4.37792589915495;-4.39250346018059,8.76959260580710,-4.36926812783063;-4.38378000835981,8.75220879631824,-4.36062493905980;-4.37507146340118,8.73485451435136,-4.35199633255388;-4.36637782327550,8.71752975729010,-4.34338230780234;-4.35769908574164,8.70023452208627,-4.33478286407464;-4.34903524834851,8.68296880526370,-4.32619800042221;-4.34038630843693,8.66573260292217,-4.31762771568041;-4.33175226314149,8.64852591074115,-4.30907200847044;-4.32313310939249,8.63134872398364,-4.30053087720129;-4.31452884391772,8.61420103749989,-4.29200432007160;-4.30593946324439,8.59708284573122,-4.28349233507160;-4.29736496370091,8.57999414271367,-4.27499491998498;-4.28880534141870,8.56293492208172,-4.26651207239074;-4.28026059233406,8.54590517707190,-4.25804378966506;-4.27173071218986,8.52890490052648,-4.24959006898310;-4.26321569653749,8.51193408489713,-4.24115090732093;-4.25471554073842,8.49499272224832,-4.23272630145721;-4.24623023996616,8.47808080426114,-4.22431624797510;-4.23775978920783,8.46119832223656,-4.21592074326398;-4.22930418326603,8.44434526709918,-4.20753978352128;-4.22086341676048,8.42752162940054,-4.19917336475419;-4.21243748412974,8.41072739932267,-4.19082148278145;-4.20402637963290,8.39396256668144,-4.18248413323504;-4.19563009735133,8.37722712093013,-4.17416131156201;-4.18724863119025,8.36052105116264,-4.16585301302606;-4.17888197488044,8.34384434611692,-4.15755923270933;-4.17053012197991,8.32719699417834,-4.14927996551406;-4.16219306587547,8.31057898338294,-4.14101520616428;-4.15387079978443,8.29399030142077,-4.13276494920745;-4.14556331675615,8.27743093563914,-4.12452918901614;-4.13727060967367,8.26090087304584,-4.11630791978965;-4.12899267125528,8.24440010031236,-4.10810113555566;-4.12072949405615,8.22792860377714,-4.09990883017184;-4.11248107046980,8.21148636944869,-4.09173099732743;-4.10424739272975,8.19507338300872,-4.08356763054487;-4.09602845291101,8.17868962981536,-4.07541872318139;-4.08782424293162,8.16233509490613,-4.06728426843054;-4.07963475455420,8.14600976300117,-4.05916425932377;-4.07145997938741,8.12971361850617,-4.05105868873199;-4.06329990888749,8.11344664551548,-4.04296754936710;-4.05515453435972,8.09720882781510,-4.03489083378352;-4.04702384695994,8.08100014888571,-4.02682853437968;-4.03890783769599,8.06482059190562,-4.01878064339959;-4.03080649742911,8.04867013975362,-4.01074715293423;-4.02271981687550,8.03254877501212,-4.00272805492314;-4.01464778660769,8.01645647996991,-3.99472334115585;-4.00659039705595,8.00039323662505,-3.98673300327331;-3.99854763850974,7.98435902668778,-3.97875703276938;-3.99051950111909,7.96835383158335,-3.97079542099225;-3.98250597489603,7.95237763245487,-3.96284815914593;-3.97450704971590,7.93643041016602,-3.95491523829152;-3.96652271531883,7.92051214530400,-3.94699664934883;-3.95855296131100,7.90462281818212,-3.93909238309760;-3.95059777716603,7.88876240884260,-3.93120243017896;-3.94265715222640,7.87293089705942,-3.92332678109685;-3.93473107570467,7.85712826234083,-3.91546542621931;-3.92681953668484,7.84135448393213,-3.90761835577987;-3.91892252412369,7.82560954081833,-3.89978555987892;-3.91104002685209,7.80989341172679,-3.89196702848503;-3.90317203357624,7.79420607512982,-3.88416275143627;-3.89531853287903,7.77854750924735,-3.87637271844156;-3.88747951322125,7.76291769204943,-3.86859691908194;-3.87965496294289,7.74731660125888,-3.86083534281191;-3.87184487026441,7.73174421435380,-3.85308797896070;-3.86404922328795,7.71620050857004,-3.84535481673353;-3.85626800999861,7.70068546090384,-3.83763584521294;-3.84850121826563,7.68519904811422,-3.82993105336000;-3.84047252076020,7.66918858107666,-3.82196452297362;-3.83246025447948,7.65321077053816,-3.81401418108605;-3.82446439387807,7.63726556641034,-3.80608000324631;-3.81648491338398,7.62135291854630,-3.79816196497127;-3.80852178739931,7.60547277674193,-3.79026004174623;-3.80057499030091,7.58962509073731,-3.78237420902573;-3.79264449644086,7.57380981021770,-3.77450444223402;-3.78473028014720,7.55802688481500,-3.76665071676580;-3.77683231572447,7.54227626410887,-3.75881300798681;-3.76895057745428,7.52655789762795,-3.75099129123445;-3.76108503959596,7.51087173485111,-3.74318554181841;-3.75323567638710,7.49521772520863,-3.73539573502131;-3.74540246204416,7.47959581808341,-3.72762184609929;-3.73758537076304,7.46400596281214,-3.71986385028261;-3.72978437671960,7.44844810868640,-3.71212172277622;-3.72199945407031,7.43292220495397,-3.70439543876047;-3.71423057695276,7.41742820081986,-3.69668497339156;-3.70647771948623,7.40196604544753,-3.68899030180224;-3.69874085577226,7.38653568796000,-3.68131139910234;-3.69101995989514,7.37113707744088,-3.67364824037930;-3.68331500592256,7.35577016293573,-3.66600080069891;-3.67562596790603,7.34043489345291,-3.65836905510567;-3.66795281988151,7.32513121796485,-3.65075297862351;-3.66029553586990,7.30985908540905,-3.64315254625628;-3.65265408987759,7.29461844468924,-3.63556773298834;-3.64502845589692,7.27940924467635,-3.62799851378506;-3.63741860790680,7.26423143420968,-3.62044486359343;-3.62982451987315,7.24908496209795,-3.61290675734258;-3.62224616574946,7.23396977712027,-3.60538416994430;-3.61468351947722,7.21888582802721,-3.59787707629357;-3.60713655498652,7.20383306354190,-3.59038545126917;-3.59960524619648,7.18881143236098,-3.58290926973407;-3.59208956701578,7.17382088315565,-3.57544850653609;-3.58458949134314,7.15886136457266,-3.56800313650833;-3.57710499306778,7.14393282523530,-3.56057313446968;-3.56963604606998,7.12903521374447,-3.55315847522542;-3.56218262422146,7.11416847867954,-3.54575913356762;-3.55474470138592,7.09933256859944,-3.53837508427568;-3.54732225141950,7.08452743204356,-3.53100630211688;-3.53991524817123,7.06975301753269,-3.52365276184676;-3.53252366548350,7.05500927357007,-3.51631443820972;-3.52514747719255,7.04029614864224,-3.50899130593945;-3.51778665712885,7.02561359121999,-3.50168333975939;-3.51044117911769,7.01096154975942,-3.49439051438332;-3.50311101697943,6.99633997270257,-3.48711280451564;-3.49579614453014,6.98174880847868,-3.47985018485204;-3.48849653558192,6.96718800550485,-3.47260263007985;-3.48121216394338,6.95265751218702,-3.46537011487850;-3.47394300342006,6.93815727692090,-3.45815261392006;-3.46668902781488,6.92368724809277,-3.45095010186960;-3.46077448524408,6.91189609276279,-3.44508487211155;-3.45486539420156,6.90011567739661,-3.43922491387924;-3.44896178997485,6.88834607334548,-3.43337026321875;-3.44306370745895,6.87658735117147,-3.42752095577997;-3.43717118115922,6.86483958065333,-3.42167702681950;-3.43128424519442,6.85310283079257,-3.41583851120375;-3.42540293329969,6.84137716981946,-3.41000544341190;-3.41952727882942,6.82966266519879,-3.40417785753882;-3.41365731476023,6.81795938363587,-3.39835578729806;-3.40779307369385,6.80626739108225,-3.39253926602474;-3.40193458785998,6.79458675274153,-3.38672832667843;-3.39608188911918,6.78291753307517,-3.38092300184608;-3.39023500896569,6.77125979580803,-3.37512332374481;-3.38439397853022,6.75961360393415,-3.36932932422480;-3.37855882858278,6.74797901972234,-3.36354103477205;-3.37272958953548,6.73635610472172,-3.35775848651125;-3.36690629144521,6.72474491976727,-3.35198171020847;-3.36108896401642,6.71314552498534,-3.34621073627397;-3.35527763660387,6.70155797979909,-3.34044559476493;-3.34947233821526,6.68998234293388,-3.33468631538812;-3.34367309751394,6.67841867242271,-3.32893292750266;-3.33787994282159,6.66686702561149,-3.32318546012266;-3.33209290212084,6.65532745916441,-3.31744394191989;-3.32631200305786,6.64380002906913,-3.31170840122638;-3.32053727294501,6.63228479064206,-3.30597886603712;-3.31476873876342,6.62078179853353,-3.30025536401258;-3.30900642716552,6.60929110673295,-3.29453792248135;-3.30325036447760,6.59781276857384,-3.28882656844264;-3.29750057670236,6.58634683673908,-3.28312132856890;-3.29175708952142,6.57489336326579,-3.27742222920831;-3.28601992829775,6.56345239955039,-3.27172929638727;-3.28028911807825,6.55202399635360,-3.26604255581294;-3.27456468359610,6.54060820380534,-3.26036203287566;-3.26884664927328,6.52920507140959,-3.25468775265144;-3.26313503922294,6.51781464804938,-3.24901973990441;-3.25742987725184,6.50643698199146,-3.24335801908919;-3.25173118686270,6.49507212089118,-3.23770261435334;-3.24603899125663,6.48372011179730,-3.23205354953974;-3.24035331333540,6.47238100115657,-3.22641084818894;-3.23467417570383,6.46105483481852,-3.22077453354150;-3.22900160067213,6.44974165804015,-3.21514462854038;-3.22333561025813,6.43844151549045,-3.20952115583322;-3.21767622618964,6.42715445125507,-3.20390413777464;-3.21202346990669,6.41588050884087,-3.19829359642854;-3.20637736256376,6.40461973118039,-3.19268955357036;-3.20073792503206,6.39337216063643,-3.18709203068933;-3.19510517790173,6.38213783900646,-3.18150104899074;-3.18947914148404,6.37091680752703,-3.17591662939811;-3.18385983581359,6.35970910687817,-3.17033879255542;-3.17824728065049,6.34851477718785,-3.16476755882931;-3.17283583711284,6.33772256625248,-3.15939700295235;-3.16742988115604,6.32694120146159,-3.15403179039218;-3.16202943944492,6.31617073674428,-3.14867194840030;-3.15663453833204,6.30541122540202,-3.14331750391325;-3.15124520386004,6.29466272011335,-3.13796848355486;-3.14586146176401,6.28392527293874,-3.13262491363879;-3.14048333747391,6.27319893532529,-3.12728682017084;-3.13511085611679,6.26248375811139,-3.12195422885126;-3.12974404251924,6.25177979153141,-3.11662716507716;-3.12438292120962,6.24108708522034,-3.11130565394479;-3.11902751642033,6.23040568821834,-3.10598972025183;-3.11367785209014,6.21973564897530,-3.10067938849970;-3.10833395186643,6.20907701535545,-3.09537468289583;-3.10299583910742,6.19842983464180,-3.09007562735592;-3.09766353688439,6.18779415354056,-3.08478224550612;-3.09233706798387,6.17717001818560,-3.07949456068533;-3.08701645490990,6.16655747414295,-3.07421259594736;-3.08170171988616,6.15595656641506,-3.06893637406314;-3.07639288485811,6.14536733944513,-3.06366591752289;-3.07108997149518,6.13478983712151,-3.05840124853827;-3.06579300119288,6.12422410278190,-3.05314238904454;-3.06050199507494,6.11367017921763,-3.04788936070266;-3.05521697399536,6.10312810867788,-3.04264218490144;-3.04993795854054,6.09259793287384,-3.03740088275963;-3.04466496903135,6.08207969298289,-3.03216547512798;-3.03939802552518,6.07157342965279,-3.02693598259136;-3.03413714781795,6.06107918300561,-3.02171242547072;-3.02888235544619,6.05059699264197,-3.01649482382525;-3.02363366768902,6.04012689764503,-3.01128319745433;-3.01839110357016,6.02966893658444,-3.00607756589954;-3.01315468185992,6.01922314752043,-3.00087794844671;-3.00792442107713,6.00878956800762,-2.99568436412782;-3.00270033949116,5.99836823509913,-2.99049683172305;-2.99748245512384,5.98795918535035,-2.98531536976270;-2.99227078575135,5.97756245482284,-2.98013999652912;-2.98706534890618,5.96717807908819,-2.97497073005866;-2.98186616187902,5.95680609323182,-2.96980758814355;-2.97667324172064,5.94644653185678,-2.96465058833384;-2.97148660524379,5.93609942908756,-2.95949974793929;-2.96630626902499,5.92576481857369,-2.95435508403117;-2.96113224940649,5.91544273349364,-2.94921661344421;-2.95596456249801,5.90513320655832,-2.94408435277839;-2.95080322417859,5.89483627001486,-2.93895831840079;-2.94564825009843,5.88455195565020,-2.93383852644743;-2.94049965568064,5.87428029479469,-2.92872499282504;-2.93535745612305,5.86402131832567,-2.92361773321287;-2.93022166639998,5.85377505667105,-2.91851676306448;-2.92509230126400,5.84354153981283,-2.91342209760952;-2.91996937524765,5.83332079729057,-2.90833375185546;-2.91485290266519,5.82311285820490,-2.90325174058931;-2.90957816065170,5.81258825614167,-2.89801158468809;-2.90431097074688,5.80207865593918,-2.89277886130759;-2.89905134044647,5.79158407305318,-2.88755357841907;-2.89379927707090,5.78110452258641,-2.88233574381632;-2.88855478776666,5.77064001929152,-2.87712536511704;-2.88331787950783,5.76019057757397,-2.87192244976438;-2.87808855909744,5.74975621149487,-2.86672700502833;-2.87286683316898,5.73933693477393,-2.86153903800721;-2.86765270818769,5.72893276079220,-2.85635855562902;-2.86244619045204,5.71854370259483,-2.85118556465284;-2.85724728609511,5.70816977289407,-2.84602007167034;-2.85205600108595,5.69781098407179,-2.84086208310706;-2.84687234123097,5.68746734818240,-2.83571160522383;-2.84169631217528,5.67713887695555,-2.83056864411816;-2.83652791940404,5.66682558179876,-2.82543320572555;-2.83136716824382,5.65652747380022,-2.82030529582088;-2.82621406386390,5.64624456373137,-2.81518492001975;-2.82106861127764,5.63597686204965,-2.81007208377978;-2.81593081534374,5.62572437890108,-2.80496679240199;-2.81080068076755,5.61548712412278,-2.79986905103202;-2.80567821210239,5.60526510724580,-2.79477886466153;-2.80056341375081,5.59505833749744,-2.78969623812942;-2.79545628996588,5.58486682380400,-2.78462117612315;-2.79035684485242,5.57469057479321,-2.77955368318002;-2.78526508236829,5.56452959879681,-2.77449376368840;-2.78018100632564,5.55438390385300,-2.76944142188901;-2.77510462039212,5.54425349770901,-2.76439666187619;-2.77003592809213,5.53413838782349,-2.75935948759909;-2.76497493280800,5.52403858136896,-2.75432990286291;-2.75992163778125,5.51395408523425,-2.74930791133014;-2.75487604611379,5.50388490602704,-2.74429351652178;-2.74983816076907,5.49383105007602,-2.73928672181851;-2.74480798457329,5.48379252343346,-2.73428753046187;-2.73978552021660,5.47376933187753,-2.72929594555554;-2.73477077025420,5.46376148091454,-2.72431197006638;-2.72976373710757,5.45376897578142,-2.71933560682571;-2.72476442306561,5.44379182144799,-2.71436685853042;-2.71977283028571,5.43383002261913,-2.70940572774411;-2.71478896079499,5.42388358373726,-2.70445221689828;-2.70981281649132,5.41395250898440,-2.69950632829340;-2.70484439914455,5.40403680228461,-2.69456806410012;-2.69988371039751,5.39413646730603,-2.68963742636030;-2.69493075176718,5.38425150746325,-2.68471441698817;-2.68998552464577,5.37438192591941,-2.67979903777143;-2.68504803030178,5.36452772558841,-2.67489129037232;-2.68011826988112,5.35468890913711,-2.66999117632878;-2.67519624440814,5.34486547898740,-2.66509869705538;-2.67028195478670,5.33505743731837,-2.66021385384455;-2.66537540180127,5.32526478606851,-2.65533664786757;-2.66047658611788,5.31548752693764,-2.65046708017557;-2.65558550828527,5.30572566138918,-2.64560515170072;-2.65070216873585,5.29597919065211,-2.64075086325713;-2.64582656778672,5.28624811572302,-2.63590421554195;-2.64095870564074,5.27653243736822,-2.63106520913640;-2.63609858238751,5.26683215612577,-2.62623384450676;-2.63124619800432,5.25714727230737,-2.62141012200537;-2.62640155235726,5.24747778600051,-2.61659404187169;-2.62156464520208,5.23782369707038,-2.61178560423323;-2.61673547618528,5.22818500516184,-2.60698480910658;-2.61191404484500,5.21856170970138,-2.60219165639837;-2.60710035061202,5.20895380989903,-2.59740614590625;-2.60229439281074,5.19936130475041,-2.59262827731987;-2.59749617066009,5.18978419303846,-2.58785805022181;-2.59270568327450,5.18022247333547,-2.58309546408856;-2.58792292966482,5.17067614400490,-2.57834051829144;-2.58314790873928,5.16114520320330,-2.57359321209757;-2.57838061930438,5.15162964888217,-2.56885354467079;-2.57362106006583,5.14212947878966,-2.56412151507256;-2.56886922962945,5.13264469047265,-2.55939712226291;-2.56412512650210,5.12317528127836,-2.55468036510135;-2.55938874909251,5.11372124835622,-2.54997124234774;-2.55466009571225,5.10428258865968,-2.54526975266322;-2.54993916457659,5.09485929894800,-2.54057589461114;-2.54522595380533,5.08545137578795,-2.53588966665785;-2.54052046142375,5.07605881555560,-2.53121106717364;-2.53582268536341,5.06668161443808,-2.52654009443362;-2.53113262346303,5.05731976843525,-2.52187674661854;-2.52645027346937,5.04797327336148,-2.51722102181573;-2.52177563303803,5.03864212484730,-2.51257291801984;-2.51710869973433,5.02932631834107,-2.50793243313378;-2.51244947103410,5.02002584911075,-2.50329956496953;-2.50779794432457,5.01074071224547,-2.49867431124899;-2.50315411690512,5.00147090265723,-2.49405666960476;-2.49851798598815,4.99221641508249,-2.48944663758101;-2.49388954869988,4.98297724408387,-2.48484421263430;-2.48926880208112,4.97375338405172,-2.48024939213436;-2.48465574308810,4.96454482920570,-2.47566217336490;-2.48005036859326,4.95535157359642,-2.47108255352442;-2.47545267538605,4.94617361110705,-2.46651052972704;-2.47086266017363,4.93701093545475,-2.46194609900319;-2.46628031958177,4.92786354019236,-2.45738925830048;-2.46170565015551,4.91873141870989,-2.45284000448442;-2.45713864836001,4.90961456423614,-2.44829833433928;-2.45257931058121,4.90051296984002,-2.44376424456870;-2.44802763312669,4.89142662843231,-2.43923773179663;-2.44348361222631,4.88235553276694,-2.43471879256788;-2.43894724403306,4.87329967544266,-2.43020742334909;-2.43441852462371,4.86425904890441,-2.42570362052930;-2.42989744999956,4.85523364544478,-2.42120738042074;-2.42538401608719,4.84622345720557,-2.41671869925962;-2.42087821873918,4.83722847617914,-2.41223757320675;-2.41638005373476,4.82824869420984,-2.40776399834835;-2.41188951678060,4.81928410299550,-2.40329797069670;-2.40740660351151,4.81033469408886,-2.39883948619093;-2.40293130949103,4.80140045889881,-2.39438854069761;-2.39846363021228,4.79248138869202,-2.38994513001156;-2.39400356109852,4.78357747459413,-2.38550924985648;-2.38955109750390,4.77468870759123,-2.38108089588567;-2.38510623471413,4.76581507853118,-2.37666006368271;-2.38066896794713,4.75695657812497,-2.37224674876208;-2.37623929235371,4.74811319694805,-2.36784094656994;-2.37181720301824,4.73928492544170,-2.36344265248473;-2.36740269495931,4.73047175391433,-2.35905186181782;-2.36299576313036,4.72167367254279,-2.35466856981425;-2.35859640242035,4.71289067137364,-2.35029277165328;-2.35420460765442,4.70412274032456,-2.34592446244912;-2.34982037359445,4.69536986918545,-2.34156363725152;-2.34544369493982,4.68663204761992,-2.33721029104649;-2.34107456632793,4.67790926516636,-2.33286441875682;-2.33671298233485,4.66920151123930,-2.32852601524278;-2.33235893747598,4.66050877513067,-2.32419507530279;-2.32801242620664,4.65183104601097,-2.31987159367392;-2.32367344292268,4.64316831293054,-2.31555556503262;-2.31934198196106,4.63452056482073,-2.31124698399526;-2.31501803760051,4.62588779049524,-2.30694584511878;-2.31070160406207,4.61726997865115,-2.30265214290127;-2.30639267550974,4.60866711787023,-2.29836587178258;-2.30209124605098,4.60007919662003,-2.29408702614488;-2.29779730973742,4.59150620325521,-2.28981560031334;-2.29351086056533,4.58294812601854,-2.28555158855661;-2.28923189247622,4.57440495304208,-2.28129498508742;-2.28496039935747,4.56587667234845,-2.27704578406324;-2.28069637504283,4.55736327185187,-2.27280397958676;-2.27643981331297,4.54886473935922,-2.26856956570648;-2.27219070789613,4.54038106257139,-2.26434253641732;-2.26794905246860,4.53191222908416,-2.26012288566110;-2.26371484065527,4.52345822638943,-2.25591060732717;-2.25948806603020,4.51501904187627,-2.25170569525292;-2.25526872211717,4.50659466283209,-2.24750814322435;-2.25105680239017,4.49818507644354,-2.24331794497656;-2.24685230027401,4.48979026979784,-2.23913509419437;-2.24265520914476,4.48141022988360,-2.23495958451281;-2.23846552233034,4.47304494359201,-2.23079140951761;-2.23428323311104,4.46469439771790,-2.22663056274584;-2.23010833471999,4.45635857896072,-2.22247703768630;-2.22594082034372,4.44803747392558,-2.21833082778014;-2.22178068312265,4.43973106912430,-2.21419192642133;-2.21762791615162,4.43143935097643,-2.21006032695716;-2.21348251248032,4.42316230581024,-2.20593602268879;-2.20934446511388,4.41489991986372,-2.20181900687171;-2.20521376701333,4.40665217928562,-2.19770927271628;-2.20109041109608,4.39841907013639,-2.19360681338819;-2.19697439023638,4.39020057838915,-2.18951162200896;-2.19286569726589,4.38199668993072,-2.18542369165645;-2.18876432497409,4.37380739056254,-2.18134301536533;-2.18467026610873,4.36563266600162,-2.17726958612755;-2.18058351337642,4.35747250188156,-2.17320339689285;-2.17650405944298,4.34932688375340,-2.16914444056919;-2.17243189693393,4.34119579708659,-2.16509271002324;-2.16836701843502,4.33307922726999,-2.16104819808087;-2.16430941649264,4.32497715961268,-2.15701089752759;-2.16025908361422,4.31688957934493,-2.15298080110900;-2.15621601226881,4.30881647161914,-2.14895790153127;-2.15218019488742,4.30075782151071,-2.14494219146159;-2.14815162386348,4.29271361401884,-2.14093366352858;-2.14413029155334,4.28468383406762,-2.13693231032279;-2.14011619027667,4.27666846650675,-2.13293812439712;-2.13610931231686,4.26866749611248,-2.12895109826726;-2.13210964992151,4.26068090758843,-2.12497122441211;-2.12811719530284,4.25270868556654,-2.12099849527424;-2.12413194063810,4.24475081460781,-2.11703290326030;-2.12015387806999,4.23680727920323,-2.11307444074147;-2.11618299970713,4.22887806377463,-2.10912310005385;-2.11221929762436,4.22096315267540,-2.10517887349887;-2.10826276386332,4.21306253019150,-2.10124175334379;-2.10431339043267,4.20517618054211,-2.09731173182200;-2.10037116930867,4.19730408788055,-2.09338880113352;-2.09643609243545,4.18944623629504,-2.08947295344535;-2.09250815172550,4.18160260980956,-2.08556418089190;-2.08858733905998,4.17377319238455,-2.08166247557538;-2.08467364628921,4.16595796791784,-2.07776782956622;-2.08076706523301,4.15815692024530,-2.07388023490345;-2.07686758768106,4.15037003314169,-2.06999968359506;-2.07297520539333,4.14259729032141,-2.06612616761843;-2.06908991010045,4.13483867543930,-2.06225967892072;-2.06521169350407,4.12709417209137,-2.05840020941922;-2.06134054727727,4.11936376381554,-2.05454775100174;-2.05747646306489,4.11164743409243,-2.05070229552701;-2.05361943248395,4.10394516634612,-2.04686383482503;-2.04976944712396,4.09625694394479,-2.04303236069743;-2.04592649854732,4.08858275020157,-2.03920786491788;-2.04209057828969,4.08092256837521,-2.03539033923243;-2.03826167786032,4.07327638167077,-2.03157977535983;-2.03443978874242,4.06564417324040,-2.02777616499198;-2.03062490239350,4.05802592618401,-2.02397949979422;-2.02681701024575,4.05042162355001,-2.02018977140571;-2.02301610370636,4.04283124833593,-2.01640697143975;-2.01922217415789,4.03525478348926,-2.01263109148421;-2.01543521295854,4.02769221190795,-2.00886212310174;-2.01165521144264,4.02014351644127,-2.00510005783026;-2.00788216092078,4.01260867989032,-2.00134488718319;-2.00411605268034,4.00508768500888,-1.99759660264985;-2.00035687798572,3.99758051450394,-1.99385519569579;-1.99660462807865,3.99008715103642,-1.99012065776306;-1.99285929417859,3.98260757722180,-1.98639298027065;-1.98912086748301,3.97514177563083,-1.98267215461471;-1.98538933916770,3.96768972879006,-1.97895817216893;-1.98166470038712,3.96025141918264,-1.97525102428487;-1.97794694227471,3.95282682924883,-1.97155070229226;-1.97423605594317,3.94541594138665,-1.96785719749930;-1.97053203248483,3.93801873795258,-1.96417050119303;-1.96683486297189,3.93063520126208,-1.96049060463956;-1.96314453845681,3.92326531359033,-1.95681749908448;-1.95946104997251,3.91590905717268,-1.95315117575308;-1.95578438853278,3.90856641420542,-1.94949162585071;-1.95211454513250,3.90123736684629,-1.94583884056307;-1.94845151074797,3.89392189721506,-1.94219281105647;-1.94479527633720,3.88661998739423,-1.93855352847819;-1.94114583284020,3.87933161942945,-1.93492098395674;-1.93750317117927,3.87205677533032,-1.93129516860217;-1.93386728225929,3.86479543707076,-1.92767607350634;-1.93023815696802,3.85754758658972,-1.92406368974323;-1.92661578617633,3.85031320579167,-1.92045800836922;-1.92300016073854,3.84309227654721,-1.91685902042333;-1.91939127149269,3.83588478069368,-1.91326671692763;-1.91578910926078,3.82869070003556,-1.90968108888735;-1.91219366484908,3.82151001634516,-1.90610212729127;-1.90860492904838,3.81434271136318,-1.90252982311199;-1.90502289263427,3.80718876679911,-1.89896416730614;-1.90144754636742,3.80004816433191,-1.89540515081471;-1.89787888099381,3.79292088561049,-1.89185276456330;-1.89431688724503,3.78580691225421,-1.88830699946239;-1.89076155583853,3.77870622585351,-1.88476784640759;-1.88721287747784,3.77161880797026,-1.88123529627989;-1.88367084285292,3.76454464013847,-1.87770933994600;-1.88013544264033,3.75748370386467,-1.87418996825851;-1.87660666750348,3.75043598062844,-1.87067717205617;-1.87308450809296,3.74340145188299,-1.86717094216422;-1.86956895504672,3.73638009905557,-1.86367126939454;-1.86605999899033,3.72937190354803,-1.86017814454595;-1.86255763053725,3.72237684673724,-1.85669155840444;-1.85906184028903,3.71539490997568,-1.85321150174346;-1.85557261883561,3.70842607459186,-1.84973796532411;-1.85208995675550,3.70147032189081,-1.84627093989541;-1.84861384461604,3.69452763315452,-1.84281041619452;-1.84514427297366,3.68759798964252,-1.83935638494699;-1.84168123237407,3.68068137259227,-1.83590883686704;-1.83822471335251,3.67377776321960,-1.83246776265770;-1.83477470643400,3.66688714271926,-1.82903315301113;-1.83133120213355,3.66000949226531,-1.82560499860880;-1.82781694153642,3.65299028425202,-1.82210615477797;-1.82430959919325,3.64598487789897,-1.81861418151644;-1.82080916339358,3.63899324992704,-1.81512906728145;-1.81731562242914,3.63201537706097,-1.81165080053184;-1.81382896459411,3.62505123602966,-1.80817936972818;-1.81034917818515,3.61810080356645,-1.80471476333290;-1.80687625150168,3.61116405640948,-1.80125696981048;-1.80341017284592,3.60424097130192,-1.79780597762759;-1.79995093052314,3.59733152499242,-1.79436177525326;-1.79649851284172,3.59043569423524,-1.79092435115901;-1.79305290811336,3.58355345579064,-1.78749369381902;-1.78961410465322,3.57668478642522,-1.78406979171028;-1.78618209078002,3.56982966291208,-1.78065263331269;-1.78275685481625,3.56298806203127,-1.77724220710932;-1.77933838508827,3.55615996056995,-1.77383850158642;-1.77592666992644,3.54934533532272,-1.77044150523364;-1.77252169766533,3.54254416309196,-1.76705120654421;-1.76912345664376,3.53575642068802,-1.76366759401495;-1.76573193520501,3.52898208492953,-1.76029065614657;-1.76234712169692,3.52222113264369,-1.75692038144366;-1.75896900447208,3.51547354066658,-1.75355675841498;-1.75559757188787,3.50873928584331,-1.75019977557345;-1.75223281230667,3.50201834502843,-1.74684942143638;-1.74887471409599,3.49531069508609,-1.74350568452557;-1.74552326562852,3.48861631289034,-1.74016855336745;-1.74217845528236,3.48193517532540,-1.73683801649319;-1.73884027144108,3.47526725928590,-1.73351406243887;-1.73550870249390,3.46861254167720,-1.73019667974561;-1.73218373683573,3.46197099941549,-1.72688585695961;-1.72886536286740,3.45534260942821,-1.72358158263240;-1.72555356899569,3.44872734865419,-1.72028384532087;-1.72224834363350,3.44212519404392,-1.71699263358747;-1.71894967520000,3.43553612255987,-1.71370793600026;-1.71565755212067,3.42896011117660,-1.71042974113309;-1.71237196282745,3.42239713688104,-1.70715803756566;-1.70909289575890,3.41584717667283,-1.70389281388372;-1.70582033936025,3.40931020756441,-1.70063405867911;-1.70255428208357,3.40278620658133,-1.69738176054992;-1.69929471238786,3.39627515076250,-1.69413590810063;-1.69604161873912,3.38977701716030,-1.69089648994213;-1.69279498961054,3.38329178284096,-1.68766349469194;-1.68955481348258,3.37681942488468,-1.68443691097427;-1.68632107884305,3.37035992038587,-1.68121672742012;-1.68309377418722,3.36391324645337,-1.67800293266743;-1.67987288801799,3.35747938021072,-1.67479551536116;-1.67665840884591,3.35105829879626,-1.67159446415340;-1.67345032518937,3.34464997936347,-1.66839976770351;-1.67024862557463,3.33825439908106,-1.66521141467817;-1.66705329853595,3.33187153513331,-1.66202939375153;-1.66386433261569,3.32550136472009,-1.65885369360529;-1.66074894402717,3.31927832901549,-1.65575143131474;-1.65763952576252,3.31306720543797,-1.65265509983037;-1.65453606820219,3.30686797486236,-1.64956468966766;-1.65143856172602,3.30068061816173,-1.64648019134097;-1.64834699671328,3.29450511620756,-1.64340159536356;-1.64526136354294,3.28834144987022,-1.64032889224787;-1.64218165259370,3.28218960001907,-1.63726207250558;-1.63910785424421,3.27604954752285,-1.63420112664778;-1.63603995887319,3.26992127324997,-1.63114604518512;-1.63297795685953,3.26380475806869,-1.62809681862793;-1.62992183858249,3.25769998284755,-1.62505343748639;-1.62687159442180,3.25160692845551,-1.62201589227065;-1.62382721475777,3.24552557576226,-1.61898417349094;-1.62078868997151,3.23945590563855,-1.61595827165778;-1.61775601044496,3.23339789895642,-1.61293817728204;-1.61472916656109,3.22735153658939,-1.60992388087510;-1.61170814870401,3.22131679941285,-1.60691537294901;-1.60869294725909,3.21529366830426,-1.60391264401659;-1.60568355261312,3.20928212414339,-1.60091568459156;-1.60267995515439,3.20328214781261,-1.59792448518869;-1.59968214527283,3.19729372019711,-1.59493903632389;-1.59669011336020,3.19131682218524,-1.59195932851441;-1.59370384981011,3.18535143466861,-1.58898535227887;-1.59072334501820,3.17939753854247,-1.58601709813746;-1.58774858938226,3.17345511470589,-1.58305455661203;-1.58477957330236,3.16752414406205,-1.58009771822622;-1.58181628718091,3.16160460751838,-1.57714657350558;-1.57885872142287,3.15569648598695,-1.57420111297770;-1.57590686643579,3.14979976038458,-1.57126132717230;-1.57296071262996,3.14391441163312,-1.56832720662139;-1.57002025041852,3.13804042065967,-1.56539874185934;-1.56708547021757,3.13217776839686,-1.56247592342305;-1.56415636244630,3.12632643578304,-1.55955874185202;-1.56123291752706,3.12048640376242,-1.55664718768846;-1.55831512588553,3.11465765328548,-1.55374125147748;-1.55540297795078,3.10884016530906,-1.55084092376708;-1.55249646415541,3.10303392079657,-1.54794619510836;-1.54959557493564,3.09723890071830,-1.54505705605560;-1.54670030073142,3.09145508605155,-1.54217349716634;-1.54381063198653,3.08568245778090,-1.53929550900153;-1.54092655914872,3.07992099689839,-1.53642308212562;-1.53804807266977,3.07417068440373,-1.53355620710665;-1.53517516300560,3.06843150130453,-1.53069487451637;-1.53230782061641,3.06270342861648,-1.52783907493036;-1.52944603596670,3.05698644736355,-1.52498879892809;-1.52658979952551,3.05128053857829,-1.52214403709309;-1.52373910176634,3.04558568330184,-1.51930478001295;-1.52089393316742,3.03990186258432,-1.51647101827955;-1.51805428421166,3.03422905748488,-1.51364274248900;-1.51522014538685,3.02856724907199,-1.51081994324191;-1.51239150718572,3.02291641842361,-1.50800261114334;-1.50956836010602,3.01727654662736,-1.50519073680300;-1.50675069465065,3.01164761478073,-1.50238431083531;-1.50393850132770,3.00602960399122,-1.49958332385944;-1.50113177065059,3.00042249537660,-1.49678776649950;-1.49833049313815,2.99482627006508,-1.49399762938458;-1.49553465931468,2.98924090919540,-1.49121290314881;-1.49274425971009,2.98366639391713,-1.48843357843154;-1.48995928485995,2.97810270539080,-1.48565964587735;-1.48717972530557,2.97254982478804,-1.48289109613618;-1.48440557159414,2.96700773329183,-1.48012791986338;-1.48163681427874,2.96147641209659,-1.47737010771986;-1.47887344391851,2.95595584240844,-1.47461765037213;-1.47611545107866,2.95044600544530,-1.47187053849238;-1.47336282633057,2.94494688243706,-1.46912876275859;-1.47061556025194,2.93945845462585,-1.46639231385462;-1.46787364342676,2.93398070326601,-1.46366118247026;-1.46513706644548,2.92851360962448,-1.46093535930134;-1.46240581990506,2.92305715498078,-1.45821483504981;-1.45967989440901,2.91761132062725,-1.45549960042380;-1.45695928056757,2.91217608786924,-1.45278964613772;-1.45424396899767,2.90675143802519,-1.45008496291235;-1.45153395032307,2.90133735242682,-1.44738554147487;-1.44882921517444,2.89593381241929,-1.44469137255900;-1.44612975418944,2.89054079936139,-1.44200244690503;-1.44343555801272,2.88515829462557,-1.43931875525992;-1.44074661729611,2.87978627959823,-1.43664028837736;-1.43806292269861,2.87442473567983,-1.43396703701789;-1.43538446488648,2.86907364428491,-1.43129899194887;-1.43271123453332,2.86373298684243,-1.42863614394469;-1.43004322232014,2.85840274479580,-1.42597848378673;-1.42738041893544,2.85308289960303,-1.42332600226350;-1.42472281507526,2.84777343273688,-1.42067869017066;-1.42207040144326,2.84247432568503,-1.41803653831115;-1.41942316875077,2.83718555995015,-1.41539953749518;-1.41678110771691,2.83190711705013,-1.41276767854039;-1.41414420906857,2.82663897851813,-1.41014095227187;-1.41151246354057,2.82138112590272,-1.40751934952219;-1.40888586187564,2.81613354076809,-1.40490286113155;-1.40626439482455,2.81089620469409,-1.40229147794777;-1.40364805314616,2.80566909927641,-1.39968519082642;-1.40103682760744,2.80045220612670,-1.39708399063084;-1.39843070898360,2.79524550687269,-1.39448786823221;-1.39582968805807,2.79004898315831,-1.39189681450963;-1.39323375562265,2.78486261664381,-1.38931082035016;-1.39064290247752,2.77968638900593,-1.38672987664893;-1.38805711943128,2.77452028193794,-1.38415397430912;-1.38547639730108,2.76936427714985,-1.38158310424210;-1.38290072691260,2.76421835636842,-1.37901725736744;-1.38033009910016,2.75908250133741,-1.37645642461301;-1.37766152613115,2.75375072344278,-1.37379777041046;-1.37499851113512,2.74843004231022,-1.37114464512298;-1.37234104246914,2.74312043472770,-1.36849703720385;-1.36968910851119,2.73782187752468,-1.36585493512687;-1.36704269766012,2.73253434757208,-1.36321832738639;-1.36440179833570,2.72725782178237,-1.36058720249731;-1.36176639897860,2.72199227710945,-1.35796154899508;-1.35913648805035,2.71673769054869,-1.35534135543564;-1.35651205403336,2.71149403913692,-1.35272661039549;-1.35389308543090,2.70626129995235,-1.35011730247160;-1.35127957076713,2.70103945011468,-1.34751342028151;-1.34867149858701,2.69582846678495,-1.34491495246321;-1.34606885745637,2.69062832716559,-1.34232188767521;-1.34347163596187,2.68543900850044,-1.33973421459650;-1.34087982271099,2.68026048807465,-1.33715192192656;-1.33829340633201,2.67509274321469,-1.33457499838532;-1.33571237547405,2.66993575128843,-1.33200343271320;-1.33313671880698,2.66478948970494,-1.32943721367106;-1.33056642502148,2.65965393591461,-1.32687633004021;-1.32800148282900,2.65452906740909,-1.32432077062240;-1.32544188096175,2.64941486172126,-1.32177052423979;-1.32288760817268,2.64431129642522,-1.31922557973499;-1.32033865323550,2.63921834913628,-1.31668592597100;-1.31779500494465,2.63413599751092,-1.31415155183123;-1.31525665211526,2.62906421924673,-1.31162244621946;-1.31272358358320,2.62400299208251,-1.30909859805986;-1.31019578820501,2.61895229379813,-1.30657999629697;-1.30767325485792,2.61391210221451,-1.30406662989568;-1.30515597243984,2.60888239519372,-1.30155848784126;-1.30264392986930,2.60386315063876,-1.29905555913923;-1.30013711608553,2.59885434649374,-1.29655783281554;-1.29763552004835,2.59385596074369,-1.29406529791638;-1.29513913073819,2.58886797141464,-1.29157794350824;-1.29264793715613,2.58389035657357,-1.28909575867795;-1.29016192832380,2.57892309432832,-1.28661873253255;-1.28768109328340,2.57396616282764,-1.28414685419939;-1.28520542109772,2.56901954026116,-1.28168011282604;-1.28273490085009,2.56408320485930,-1.27921849758032;-1.28026952164438,2.55915713489335,-1.27676199765028;-1.27780927260494,2.55424130867525,-1.27431060224414;-1.27535414287666,2.54933570455780,-1.27186430059037;-1.27290412162492,2.54444030093449,-1.26942308193759;-1.27045919803556,2.53955507623946,-1.26698693555459;-1.26801936131486,2.53468000894753,-1.26455585073031;-1.26558460068958,2.52981507757416,-1.26212981677386;-1.26315490540687,2.52496026067535,-1.25970882301441;-1.26073026473432,2.52011553684775,-1.25729285880131;-1.25831066795988,2.51528088472847,-1.25488191350396;-1.25589610439191,2.51045628299514,-1.25247597651185;-1.25348656335911,2.50564171036590,-1.25007503723455;-1.25112733515625,2.50092775330785,-1.24772431915030;-1.24877287961543,2.49622332569890,-1.24537834940611;-1.24642318717296,2.49152840847175,-1.24303711851671;-1.24407824828054,2.48684298258963,-1.24070061701192;-1.24173805340519,2.48216702904620,-1.23836883543664;-1.23940259302933,2.47750052886562,-1.23604176435085;-1.23707185765078,2.47284346310264,-1.23371939432966;-1.23474583778274,2.46819581284251,-1.23140171596328;-1.23242452395380,2.46355755920104,-1.22908871985705;-1.23010790670794,2.45892868332457,-1.22678039663139;-1.22779597660458,2.45430916639004,-1.22447673692190;-1.22548872421852,2.44969898960499,-1.22217773137930;-1.22318614014000,2.44509813420754,-1.21988337066944;-1.22088821497467,2.44050658146642,-1.21759364547334;-1.21859493934359,2.43592431268094,-1.21530854648714;-1.21630630388329,2.43135130918109,-1.21302806442218;-1.21402229924569,2.42678755232746,-1.21075219000494;-1.21174291609818,2.42223302351130,-1.20848091397706;-1.20946814512356,2.41768770415447,-1.20621422709537;-1.20719797702009,2.41315157570951,-1.20395212013186;-1.20493240250147,2.40862461965964,-1.20169458387370;-1.20267141229685,2.40410681751871,-1.19944160912328;-1.20041499715082,2.39959815083125,-1.19719318669812;-1.19816314782344,2.39509860117249,-1.19494930743095;-1.19591585509020,2.39060815014829,-1.19270996216971;-1.19367310974207,2.38612677939529,-1.19047514177752;-1.19143490258543,2.38165447058068,-1.18824483713269;-1.18920122444218,2.37719120540245,-1.18601903912873;-1.18697206614961,2.37273696558922,-1.18379773867435;-1.18474741856052,2.36829173290035,-1.18158092669347;-1.18252727254314,2.36385548912586,-1.17936859412521;-1.18031161898115,2.35942821608647,-1.17716073192387;-1.17810044877370,2.35500989563361,-1.17495733105898;-1.17589375283542,2.35060050964941,-1.17275838251527;-1.17369152209634,2.34620004004666,-1.17056387729267;-1.17149374750199,2.34180846876887,-1.16837380640630;-1.16930042001332,2.33742577779024,-1.16618816088651;-1.16711153060674,2.33305194911563,-1.16400693177882;-1.16492707027415,2.32868696478066,-1.16183011014400;-1.16274703002283,2.32433080685155,-1.15965768705797;-1.16057140087554,2.31998345742525,-1.15748965361189;-1.15840017387050,2.31564489862939,-1.15532600091210;-1.15623334006134,2.31131511262224,-1.15316672008013;-1.15407089051715,2.30699408159276,-1.15101180225273;-1.15191281632241,2.30268178776055,-1.14886123858181;-1.14975910857710,2.29837821337591,-1.14671502023450;-1.14760975839657,2.29408334071977,-1.14457313839312;-1.14546475691163,2.28979715210368,-1.14243558425515;-1.14332409526849,2.28551962986988,-1.14030234903328;-1.14118776462877,2.28125075639116,-1.13817342395534;-1.13905575616953,2.27699051407104,-1.13604880026440;-1.13692806108322,2.27273888534359,-1.13392846921866;-1.13480467057769,2.26849585267347,-1.13181242209148;-1.13268557587620,2.26426139855598,-1.12970065017140;-1.13057076821738,2.26003550551698,-1.12759314476214;-1.12846023885528,2.25581815611295,-1.12548989718257;-1.12635397905930,2.25160933293090,-1.12339089876668;-1.12425198011425,2.24740901858841,-1.12129614086364;-1.12215423332030,2.24321719573364,-1.11920561483777;-1.12006072999294,2.23903384704520,-1.11711931206849;-1.11797146146311,2.23485895523234,-1.11503722395039;-1.11588641907701,2.23069250303473,-1.11295934189317;-1.11380559419624,2.22653447322262,-1.11088565732167;-1.11172897819773,2.22238484859667,-1.10881616167580;-1.10965656247374,2.21824361198808,-1.10675084641063;-1.10758833843185,2.21411074625850,-1.10468970299632;-1.10552429749496,2.20998623430000,-1.10263272291812;-1.10346443110130,2.20587005903512,-1.10057989767636;-1.10140873070437,2.20176220341682,-1.09853121878649;-1.09935718777299,2.19766265042844,-1.09648667777901;-1.09730979379126,2.19357138308372,-1.09444626619949;-1.09526654025858,2.18948838442682,-1.09240997560858;-1.09322741868958,2.18541363753221,-1.09037779758197;-1.09119242061419,2.18134712550471,-1.08834972371041;-1.08916153757757,2.17728883147949,-1.08632574559968;-1.08713476114015,2.17323873862205,-1.08430585487062;-1.08511208287759,2.16919683012815,-1.08229004315905;-1.08309349438077,2.16516308922384,-1.08027830211586;-1.08107898725578,2.16113749916542,-1.07827062340688;-1.07906855312395,2.15712004323947,-1.07626699871303;-1.07706218362180,2.15311070476277,-1.07426741973015;-1.07505987040103,2.14910946708231,-1.07227187816909;-1.07306160512852,2.14511631357525,-1.07028036575566;-1.07106737948634,2.14113122764896,-1.06829287423066;-1.06907718517170,2.13715419274093,-1.06630939534982;-1.06709101389699,2.13318519231880,-1.06432992088385;-1.06510885738971,2.12922420988032,-1.06235444261837;-1.06313070739251,2.12527122895329,-1.06038295235391;-1.06115655566315,2.12132623309565,-1.05841544190597;-1.05918639397451,2.11738920589533,-1.05645190310491;-1.05722021411457,2.11346013097033,-1.05449232779602;-1.05525800788637,2.10953899196864,-1.05253670783946;-1.05329976710806,2.10562577256821,-1.05058503511027;-1.05134548361285,2.10172045647702,-1.04863730149836;-1.04939514924898,2.09782302743293,-1.04669349890849;-1.04744875587976,2.09393346920376,-1.04475361926028;-1.04550629538352,2.09005176558720,-1.04281765448817;-1.04356775965361,2.08617790041083,-1.04088559654142;-1.04163314059837,2.08231185753208,-1.03895743738412;-1.03970243014118,2.07845362083823,-1.03703316899516;-1.03777562022036,2.07460317424631,-1.03511278336821;-1.03585270278921,2.07076050170319,-1.03319627251171;-1.03393366981600,2.06692558718547,-1.03128362844889;-1.03201851328394,2.06309841469947,-1.02937484321770;-1.03010722519119,2.05927896828127,-1.02746990887090;-1.02819979755079,2.05546723199655,-1.02556881747589;-1.02629622239073,2.05166318994075,-1.02367156111488;-1.02439649175387,2.04786682623885,-1.02177813188471;-1.02250059769796,2.04407812504551,-1.01988852189697;-1.02060853229563,2.04029707054493,-1.01800272327791;-1.01872028763433,2.03652364695087,-1.01612072816844;-1.01683585581642,2.03275783850667,-1.01424252872415;-1.01495522895899,2.02899962948507,-1.01236811711525;-1.01307839919405,2.02524900418843,-1.01049748552661;-1.01120535866833,2.02150594694842,-1.00863062615769;-1.00933609954340,2.01777044212625,-1.00676753122258;-1.00747061399557,2.01404247411244,-1.00490819294993;-1.00560889421593,2.01032202732692,-1.00305260358301;-1.00375093241031,2.00660908621898,-1.00120075537963;-1.00189672079926,2.00290363526719,-0.999352640612155;-1.00004625161807,1.99920565897941,-0.997508251567484;-0.998199517116722,1.99551514189279,-0.995667580547061;-0.996356509559872,1.99183206857368,-0.993830619866813;-0.994517221226865,1.98815642361762,-0.991997361857180;-0.992681644411711,1.98448819164937,-0.990167798863091;-0.990849771423053,1.98082735732280,-0.988341923243934;-0.989021594584155,1.97717390532088,-0.986519727373541;-0.987197106232916,1.97352782035570,-0.984701203640209;-0.985376298721818,1.96988908716839,-0.982886344446640;-0.983559164417944,1.96625769052912,-0.981075142209968;-0.981745695702922,1.96263361523702,-0.979267589361699;-0.979935884972964,1.95901684612024,-0.977463678347750;-0.978129724638788,1.95540736803582,-0.975663401628375;-0.976327207125651,1.95180516586970,-0.973866751678197;-0.974528324873325,1.94821022453676,-0.972073720986185;-0.972733070336065,1.94462252898067,-0.970284302055619;-0.970941435982594,1.94104206417392,-0.968498487404085;-0.969153414296106,1.93746881511778,-0.966716269563467;-0.967368997774229,1.93390276684228,-0.964937641079920;-0.965588178929033,1.93034390440618,-0.963162594513870;-0.963810950286996,1.92679221289692,-0.961391122439992;-0.962037304388978,1.92324767743058,-0.959623217447174;-0.960267233790245,1.91971028315192,-0.957858872138546;-0.958500731060393,1.91618001523419,-0.956098079131404;-0.956737788783398,1.91265685887932,-0.954340831057265;-0.954978399557534,1.90914079931767,-0.952587120561776;-0.953222555995426,1.90563182180817,-0.950836940304777;-0.951470250723965,1.90212991163817,-0.949090282960212;-0.949721476384349,1.89863505412348,-0.947347141216170;-0.947976225632006,1.89514723460826,-0.945607507774813;-0.946265955097893,1.89172937042789,-0.943902792850036;-0.944559046680829,1.88831822135389,-0.942201425067524;-0.942855493705331,1.88491377406826,-0.940503397797127;-0.941155289507333,1.88151601527574,-0.938808704419958;-0.939458427434205,1.87812493170380,-0.937117338328409;-0.937764900844755,1.87474051010266,-0.935429292926164;-0.936074703109199,1.87136273724521,-0.933744561628157;-0.934387827609197,1.86799159992713,-0.932063137860620;-0.932704267737798,1.86462708496675,-0.930385015061022;-0.931024016899468,1.86126917920508,-0.928710186678099;-0.929347068510096,1.85791786950589,-0.927038646171858;-0.927673415996954,1.85457314275555,-0.925370387013544;-0.926003052798711,1.85123498586314,-0.923705402685648;-0.924335972365426,1.84790338576037,-0.922043686681905;-0.922672168158533,1.84457832940158,-0.920385232507278;-0.921011633650867,1.84125980376382,-0.918730033677983;-0.919354362326625,1.83794779584669,-0.917078083721453;-0.917700347681364,1.83464229267243,-0.915429376176334;-0.916049583222012,1.83134328128589,-0.913783904592500;-0.914402062466854,1.82805074875450,-0.912141662531037;-0.912757778945504,1.82476468216826,-0.910502643564214;-0.911116726198943,1.82148506863974,-0.908866841275528;-0.909478897779482,1.81821189530410,-0.907234249259660;-0.907844287250762,1.81494514931900,-0.905604861122477;-0.906212888187744,1.81168481786465,-0.903978670481030;-0.904584694176710,1.80843088814377,-0.902355670963545;-0.902959698815253,1.80518334738160,-0.900735856209421;-0.901337895712266,1.80194218282584,-0.899119219869215;-0.899719278487943,1.79870738174670,-0.897505755604646;-0.898103840773768,1.79547893143684,-0.895895457088583;-0.896491576212501,1.79225681921136,-0.894288318005035;-0.894882478458185,1.78904103240783,-0.892684332049155;-0.893276541176128,1.78583155838620,-0.891083492927222;-0.891673758042899,1.78262838452886,-0.889485794356638;-0.890074122746318,1.77943149824058,-0.887891230065924;-0.888477628985451,1.77624088694850,-0.886299793794709;-0.886884270470607,1.77305653810214,-0.884711479293725;-0.885294040923315,1.76987843917337,-0.883126280324797;-0.883706934076336,1.76670657765637,-0.881544190660840;-0.882122943673637,1.76354094106765,-0.879965204085847;-0.880542063470392,1.76038151694603,-0.878389314394880;-0.878964287232978,1.75722829285261,-0.876816515394075;-0.877389608738956,1.75408125637075,-0.875246800900615;-0.875818021777068,1.75094039510607,-0.873680164742735;-0.874249520147231,1.74780569668643,-0.872116600759714;-0.872684097660520,1.74467714876190,-0.870556102801857;-0.871121748139174,1.74155473900476,-0.868998664730501;-0.869562465416576,1.73843845510949,-0.867444280417998;-0.868006243337238,1.73532828479270,-0.865892943747701;-0.866453075756810,1.73222421579319,-0.864344648613970;-0.864846884184199,1.72901408395586,-0.862743399367777;-0.863243989933363,1.72581053916895,-0.861145434181370;-0.861644385829786,1.72261356711047,-0.859550745920129;-0.860048064714622,1.71942315348968,-0.857959327464973;-0.858455019444683,1.71623928404702,-0.856371171712341;-0.856865242892391,1.71306194455407,-0.854786271574153;-0.855278727945760,1.70989112081348,-0.853204619977787;-0.853695467508363,1.70672679865893,-0.851626209866046;-0.852115454499293,1.70356896395502,-0.850051034197125;-0.850538681853142,1.70041760259727,-0.848479085944585;-0.848965142519974,1.69727270051201,-0.846910358097329;-0.847394829465282,1.69413424365637,-0.845344843659559;-0.845827735669973,1.69100221801817,-0.843782535650761;-0.844263854130321,1.68787660961589,-0.842223427105660;-0.842703177857954,1.68475740449861,-0.840667511074203;-0.841145699879812,1.68164458874593,-0.839114780621529;-0.839591413238124,1.67853814846793,-0.837565228827928;-0.838040310990372,1.67543806980512,-0.836018848788825;-0.836492386209266,1.67234433892834,-0.834475633614740;-0.834947631982711,1.66925694203873,-0.832935576431265;-0.833406041413782,1.66617586536769,-0.831398670379036;-0.831867607620686,1.66310109517678,-0.829864908613693;-0.830332323736739,1.66003261775766,-0.828334284305865;-0.828800182910336,1.65697041943208,-0.826806790641131;-0.827271178304911,1.65391448655178,-0.825282420819990;-0.825745303098926,1.65086480549842,-0.823761168057841;-0.824222550485822,1.64782136268356,-0.822243025584940;-0.822702913674001,1.64478414454858,-0.820727986646386;-0.821186385886798,1.64175313756463,-0.819216044502082;-0.819672960362437,1.63872832823254,-0.817707192426702;-0.818162630354019,1.63570970308282,-0.816201423709678;-0.816655389129478,1.63269724867553,-0.814698731655151;-0.815151229971564,1.62969095160027,-0.813199109581959;-0.813650146177804,1.62669079847613,-0.811702550823596;-0.812152131060473,1.62369677595159,-0.810209048728188;-0.810657177946574,1.62070887070448,-0.808718596658467;-0.809165280177795,1.61772706944193,-0.807231187991731;-0.807676431110494,1.61475135890031,-0.805746816119833;-0.806190624115656,1.61178172584515,-0.804265474449132;-0.804707852578868,1.60881815707112,-0.802787156400477;-0.803228109900297,1.60586063940193,-0.801311855409173;-0.801751389494656,1.60290915969031,-0.799839564924961;-0.800277684791166,1.59996370481792,-0.798370278411972;-0.798806989233547,1.59702426169531,-0.796903989348719;-0.797339296279960,1.59409081726185,-0.795440691228043;-0.795874599403011,1.59116335848570,-0.793980377557114;-0.794412892089694,1.58824187236371,-0.792523041857379;-0.792954167841380,1.58532634592140,-0.791068677664542;-0.791498420173775,1.58241676621288,-0.789617278528537;-0.790045642616902,1.57951312032079,-0.788168838013494;-0.788620882776913,1.57666550669717,-0.786748366761593;-0.787198969010377,1.57382357884611,-0.785330730325384;-0.785779895343074,1.57098732484157,-0.783915922763752;-0.784363655813068,1.56815673278202,-0.782503938147759;-0.782950244470685,1.56533179079034,-0.781094770560620;-0.781539655378497,1.56251248701383,-0.779688414097688;-0.780131882611299,1.55969880962415,-0.778284862866432;-0.778726920256089,1.55689074681729,-0.776884110986417;-0.777324762412046,1.55408828681352,-0.775486152589283;-0.775925403190513,1.55129141785734,-0.774090981818727;-0.774528836714972,1.54850012821746,-0.772698592830482;-0.773135057121031,1.54571440618675,-0.771308979792298;-0.771744058556397,1.54293424008222,-0.769922136883922;-0.770355835180860,1.54015961824493,-0.768538058297076;-0.768970381166267,1.53739052904000,-0.767156738235439;-0.767587690696506,1.53462696085653,-0.765778170914624;-0.766207757967489,1.53186890210762,-0.764402350562167;-0.764830577187126,1.52911634123026,-0.763029271417498;-0.763456142575306,1.52636926668531,-0.761658927731920;-0.762084448363873,1.52362766695749,-0.760291313768596;-0.760715488796616,1.52089153055532,-0.758926423802526;-0.759349258129239,1.51816084601106,-0.757564252120525;-0.757985750629348,1.51543560188070,-0.756204793021210;-0.756624960576420,1.51271578674391,-0.754848040814966;-0.755266882261794,1.51000138920398,-0.753493989823941;-0.753911509988645,1.50729239788783,-0.752142634382021;-0.752558838071963,1.50458880144590,-0.750793968834804;-0.751208860838540,1.50189058855217,-0.749447987539590;-0.749861572626936,1.49919774790408,-0.748104684865352;-0.748516967787471,1.49651026822251,-0.746764055192720;-0.747175040682200,1.49382813825174,-0.745426092913965;-0.745835785684891,1.49115134675941,-0.744090792432969;-0.744499197181014,1.48847988253646,-0.742758148165221;-0.743165269567703,1.48581373439711,-0.741428154537775;-0.741833997253750,1.48315289117881,-0.740100805989248;-0.740505374659583,1.48049734174222,-0.738776096969796;-0.739179396217240,1.47784707497112,-0.737454021941087;-0.737856056370355,1.47520207977243,-0.736134575376292;-0.736535349574133,1.47256234507613,-0.734817751760055;-0.735217270295330,1.46992785983524,-0.733503545588476;-0.733901813012235,1.46729861302577,-0.732191951369097;-0.732588972214652,1.46467459364666,-0.730882963620874;-0.731278742403871,1.46205579071980,-0.729576576874161;-0.729971118092658,1.45944219328991,-0.728272785670691;-0.728666093805226,1.45683379042458,-0.726971584563550;-0.727363664077220,1.45423057121415,-0.725672968117167;-0.726063823455696,1.45163252477173,-0.724376930907282;-0.724766566499102,1.44903964023315,-0.723083467520942;-0.723471887777250,1.44645190675689,-0.721792572556463;-0.722179781871306,1.44386931352406,-0.720504240623419;-0.720867791831515,1.44124694377086,-0.719196047955146;-0.719558460951301,1.43862988699827,-0.717890504575069;-0.718251783458552,1.43601813168059,-0.716587604739786;-0.716947753594026,1.43341166631780,-0.715287342718672;-0.715646365611316,1.43081047943549,-0.713989712793848;-0.714347613776842,1.42821455958480,-0.712694709260164;-0.713051492369804,1.42562389534240,-0.711402326425160;-0.711757995682162,1.42303847531039,-0.710112558609049;-0.710467118018614,1.42045828811629,-0.708825400144684;-0.709178853696556,1.41788332241294,-0.707540845377530;-0.707893197046072,1.41531356687850,-0.706258888665647;-0.706610142409898,1.41274901021635,-0.704979524379656;-0.705329684143388,1.41018964115506,-0.703702746902711;-0.704051816614500,1.40763544844833,-0.702428550630474;-0.702776534203763,1.40508642087493,-0.701156929971094;-0.701503831304250,1.40254254723868,-0.699887879345170;-0.700233702321555,1.40000381636834,-0.698621393185739;-0.698966141673759,1.39747021711761,-0.697357465938232;-0.697701143791409,1.39494173836503,-0.696096092060462;-0.696438703117492,1.39241836901398,-0.694837266022591;-0.695178814107407,1.38990009799259,-0.693580982307107;-0.693921471228935,1.38738691425369,-0.692327235408794;-0.692666668962218,1.38487880677476,-0.691076019834707;-0.691414401799727,1.38237576455788,-0.689827330104147;-0.690164664246245,1.37987777662971,-0.688581160748640;-0.688917450818826,1.37738483204135,-0.687337506311896;-0.687672756046783,1.37489691986840,-0.686096361349800;-0.686430574471654,1.37241402921081,-0.684857720430375;-0.685190900647175,1.36993614919288,-0.683621578133760;-0.683953729139261,1.36746326896320,-0.682387929052185;-0.682719054525969,1.36499537769461,-0.681156767789941;-0.681486871397484,1.36253246458409,-0.679928088963361;-0.680257174356085,1.36007451885280,-0.678701887200786;-0.679029958016115,1.35762152974594,-0.677478157142545;-0.677805217003972,1.35517348653276,-0.676256893440930;-0.676582945958061,1.35273037850648,-0.675038090760163;-0.675363139528786,1.35029219498423,-0.673821743776380;-0.674145792378514,1.34785892530702,-0.672607847177601;-0.672930899181554,1.34543055883971,-0.671396395663702;-0.671718454624124,1.34300708497087,-0.670187383946389;-0.670508453404343,1.34058849311285,-0.668980806749185;-0.669300890232181,1.33817477270162,-0.667776658807386;-0.668095759829449,1.33576591319680,-0.666574934868048;-0.666893056929774,1.33336190408155,-0.665375629689959;-0.665692776278563,1.33096273486256,-0.664178738043612;-0.664494912632990,1.32856839506997,-0.662984254711182;-0.663299460761960,1.32617887425735,-0.661792174486498;-0.662106415446090,1.32379416200162,-0.660602492175023;-0.660915771477678,1.32141424790301,-0.659415202593819;-0.659727523660686,1.31903912158502,-0.658230300571536;-0.658541666810709,1.31666877269436,-0.657047780948375;-0.657358195754947,1.31430319090089,-0.655867638576067;-0.656177105332189,1.31194236589759,-0.654689868317851;-0.654998390392774,1.30958628740049,-0.653514465048444;-0.653822045798583,1.30723494514865,-0.652341423654020;-0.652648066422999,1.30488832890407,-0.651170739032185;-0.651476447150894,1.30254642845167,-0.650002406091950;-0.650307182878590,1.30020923359923,-0.648836419753704;-0.649140268513848,1.29787673417734,-0.647672774949201;-0.647975698975835,1.29554892003934,-0.646511466621518;-0.646813469195103,1.29322578106130,-0.645352489725047;-0.645653574113559,1.29090730714195,-0.644195839225457;-0.644496008684448,1.28859348820262,-0.643041510099680;-0.643340767872320,1.28628431418722,-0.641889497335878;-0.642187846653011,1.28397977506215,-0.640739795933425;-0.641037240013616,1.28167986081630,-0.639592400902880;-0.639888942952470,1.27938456146097,-0.638447307265964;-0.638742950479110,1.27709386702983,-0.637304510055532;-0.637599257614263,1.27480776757886,-0.636164004315551;-0.636457859389818,1.27252625318631,-0.635025785101076;-0.635318750848802,1.27024931395266,-0.633889847478231;-0.634181927045353,1.26797694000056,-0.632756186524175;-0.633047383044696,1.26570912147478,-0.631624797327082;-0.631915113923122,1.26344584854217,-0.630495674986119;-0.630785114767960,1.26118711139160,-0.629368814611421;-0.629657380677558,1.25893290023394,-0.628244211324067;-0.628531906761252,1.25668320530197,-0.627121860256055;-0.627408688139349,1.25443801685036,-0.626001756550280;-0.626287719943092,1.25219732515561,-0.624883895360505;-0.625168997314651,1.24996112051603,-0.623768271851347;-0.624052515407085,1.24772939325164,-0.622654881198243;-0.622938269384332,1.24550213370417,-0.621543718587436;-0.621826254421168,1.24327933223698,-0.620434779215938;-0.620716465703199,1.24106097923505,-0.619328058291521;-0.619608898426827,1.23884706510489,-0.618223551032686;-0.618503547799232,1.23663758027451,-0.617121252668639;-0.617400409038346,1.23443251519340,-0.616021158439271;-0.616299477372828,1.23223186033242,-0.614923263595128;-0.615200748042041,1.23003560618382,-0.613827563397396;-0.614104216296036,1.22784374326116,-0.612734053117875;-0.613009877395510,1.22565626209924,-0.611642728038949;-0.611917726611804,1.22347315325412,-0.610553583453573;-0.610827759226866,1.22129440730302,-0.609466614665244;-0.609739970533230,1.21912001484425,-0.608381816987976;-0.608654355833996,1.21694996649725,-0.607299185746282;-0.607570910442804,1.21478425290246,-0.606218716275148;-0.606489629683812,1.21262286472134,-0.605140403920011;-0.605410508891669,1.21046579263625,-0.604064244036735;-0.604333543411495,1.20831302735046,-0.602990231991585;-0.603258728598862,1.20616455958811,-0.601918363161212;-0.602186059819762,1.20402038009412,-0.600848632932625;-0.601115532450591,1.20188047963416,-0.599781036703167;-0.600047141878122,1.19974484899463,-0.598715569880496;-0.598980883499483,1.19761347898257,-0.597652227882555;-0.597916752722135,1.19548636042567,-0.596591006137561;-0.596854744963850,1.19336348417218,-0.595531900083973;-0.595794855652683,1.19124484109085,-0.594474905170471;-0.594737080226957,1.18913042207096,-0.593420016855936;-0.593681414135231,1.18702021802219,-0.592367230609423;-0.592627852836287,1.18491421987463,-0.591316541910147;-0.591576391799103,1.18281241857870,-0.590267946247451;-0.590527026502825,1.18071480510514,-0.589221439120787;-0.589479752436753,1.17862137044494,-0.588177016039697;-0.588434565100313,1.17653210560929,-0.587134672523785;-0.587391460003039,1.17444700162956,-0.586094404102699;-0.586350432664545,1.17236604955723,-0.585056206316108;-0.585311478614508,1.17028924046388,-0.584020074713678;-0.584274593392640,1.16821656544108,-0.582986004855050;-0.583239772548672,1.16614801560043,-0.581953992309821;-0.582207011642322,1.16408358207345,-0.580924032657515;-0.581176306243289,1.16202325601157,-0.579896121487573;-0.580147651931213,1.15996702858606,-0.578870254399317;-0.579121044295663,1.15791489098801,-0.577846427001940;-0.578096478936115,1.15586683442829,-0.576824634914474;-0.577073951461922,1.15382285013746,-0.575804873765774;-0.576053457492303,1.15178292936579,-0.574787139194496;-0.575034992656313,1.14974706338317,-0.573771426849076;-0.574018552592823,1.14771524347908,-0.572757732387704;-0.573004132950501,1.14568746096254,-0.571746051478303;-0.571991729387782,1.14366370716209,-0.570736379798513;-0.570981337572861,1.14164397342573,-0.569728713035664;-0.569972953183655,1.13962825112087,-0.568723046886757;-0.568966571907790,1.13761653163428,-0.567719377058437;-0.567962189442576,1.13560880637208,-0.566717699266980;-0.566959801494993,1.13360506675968,-0.565718009238267;-0.565959403781657,1.13160530424170,-0.564720302707763;-0.564960992028808,1.12960951028201,-0.563724575420494;-0.563964561972285,1.12761767636359,-0.562730823131027;-0.562970109357502,1.12562979398858,-0.561739041603452;-0.561977629939434,1.12364585467815,-0.560749226611354;-0.560987119482586,1.12166584997254,-0.559761373937799;-0.559998573760983,1.11968977143094,-0.558775479375309;-0.559011988558136,1.11771761063151,-0.557791538725836;-0.558027359667028,1.11574935917130,-0.556809547800753;-0.557044682890095,1.11378500866623,-0.555829502420822;-0.556063954039199,1.11182455075103,-0.554851398416179;-0.555085168935611,1.10986797707921,-0.553875231626311;-0.554108323409987,1.10791527932300,-0.552900997900035;-0.553133413302347,1.10596644917335,-0.551928693095475;-0.552160434462059,1.10402147833982,-0.550958313080048;-0.551189382747810,1.10208035855062,-0.549989853730434;-0.550220254027593,1.10014308155250,-0.549023310932566;-0.549253044178680,1.09820963911074,-0.548058680581596;-0.548287749087603,1.09628002300910,-0.547095958581886;-0.547324364650138,1.09435422504979,-0.546135140846984;-0.546362886771273,1.09243223705341,-0.545176223299599;-0.545403311365201,1.09051405085893,-0.544219201871587;-0.544445634355289,1.08859965832363,-0.543264072503925;-0.543489851674061,1.08668905132306,-0.542310831146692;-0.542535959263177,1.08478222175102,-0.541359473759054;-0.541583953073414,1.08287916151950,-0.540409996309234;-0.540633829064645,1.08097986255863,-0.539462394774501;-0.539685583205816,1.07908431681667,-0.538516665141143;-0.538739211474925,1.07719251625995,-0.537572803404448;-0.537794709859011,1.07530445287281,-0.536630805568689;-0.536852074354117,1.07342011865761,-0.535690667647093;-0.535911300965289,1.07153950563464,-0.534752385661838;-0.534972385706539,1.06966260584212,-0.533815955644014;-0.534035324600831,1.06778941133610,-0.532881373633611;-0.533100113680067,1.06591991419050,-0.531948635679506;-0.532166748985060,1.06405410649702,-0.531017737839433;-0.531235226565514,1.06219198036509,-0.530088676179966;-0.530305542480002,1.06033352792186,-0.529161446776501;-0.529377692795954,1.05847874131216,-0.528236045713231;-0.528451673589630,1.05662761269844,-0.527312469083136;-0.527527480946102,1.05478013426073,-0.526390712987954;-0.526605110959238,1.05293629819662,-0.525470773538166;-0.525684559731673,1.05109609672122,-0.524552646852971;-0.524765823374797,1.04925952206708,-0.523636329060275;-0.523848898008732,1.04742656648421,-0.522721816296663;-0.522933779762316,1.04559722224000,-0.521809104707385;-0.522020464773078,1.04377148161921,-0.520898190446335;-0.521108949187221,1.04194933692387,-0.519989069676030;-0.520199229159601,1.04013078047333,-0.519081738567589;-0.519291300853711,1.03831580460415,-0.518176193300720;-0.518385160441658,1.03650440167010,-0.517272430063695;-0.517480804104143,1.03469656404210,-0.516370445053332;-0.516578228030447,1.03289228410818,-0.515470234474979;-0.515677428418403,1.03109155427347,-0.514571794542487;-0.514778401474382,1.02929436696013,-0.513675121478197;-0.513881143413278,1.02750071460731,-0.512780211512925;-0.512985650458477,1.02571058967115,-0.511887060885931;-0.512091918841850,1.02392398462471,-0.510995665844907;-0.511199944803723,1.02214089195791,-0.510106022645961;-0.510309724592865,1.02036130417756,-0.509218127553587;-0.509421254466469,1.01858521380724,-0.508331976840663;-0.508534530690129,1.01681261338735,-0.507447566788415;-0.507649549537822,1.01504349547499,-0.506564893686407;-0.506766307291892,1.01327785264395,-0.505683953832522;-0.505884800243024,1.01151567748472,-0.504804743532939;-0.505005024690236,1.00975696260438,-0.503927259102119;-0.504126976940851,1.00800170062660,-0.503051496862786;-0.503250653310478,1.00624988419159,-0.502177453145902;-0.502376050123001,1.00450150595609,-0.501305124290654;-0.501503163710553,1.00275655859330,-0.500434506644437;-0.500631990413501,1.00101503479284,-0.499565596562831;-0.499762526580423,0.999276927260750,-0.498698390409583;-0.498894768568097,0.997542228719413,-0.497832884556590;-0.498028712741474,0.995810931907542,-0.496969075383882;-0.497164355473666,0.994083029580136,-0.496106959279599;-0.496301693145920,0.992358514508437,-0.495246532639976;-0.495440722147609,0.990637379479903,-0.494387791869325;-0.494581438876206,0.988919617298167,-0.493530733380015;-0.493723839737268,0.987205220782994,-0.492675353592453;-0.492867921144421,0.985494182770260,-0.491821648935070;-0.492013679519334,0.983786496111899,-0.490969615844298;-0.491161111291710,0.982082153675876,-0.490119250764553;-0.490310212899256,0.980381148346141,-0.489270550148218;-0.489460980787678,0.978683473022611,-0.488423510455626;-0.488613411410656,0.976989120621116,-0.487578128155041;-0.487767501229822,0.975298084073366,-0.486734399722635;-0.486923246714749,0.973610356326925,-0.485892321642479;-0.486080644342932,0.971925930345163,-0.485051890406520;-0.485239690599765,0.970244799107226,-0.484213102514561;-0.484400381978525,0.968566955607996,-0.483375954474247;-0.483562714980360,0.966892392858067,-0.482540442801050;-0.482726686114263,0.965221103883692,-0.481706564018241;-0.481892291897057,0.963553081726758,-0.480874314656883;-0.481059528853379,0.961888319444751,-0.480043691255806;-0.480228393515659,0.960226810110714,-0.479214690361593;-0.479398882424105,0.958568546813213,-0.478387308528561;-0.478570992126684,0.956913522656315,-0.477561542318747;-0.477744719179107,0.955261730759533,-0.476737388301884;-0.476920060144802,0.953613164257795,-0.475914843055386;-0.476097011594910,0.951967816301425,-0.475093903164335;-0.475275570108259,0.950325680056090,-0.474274565221459;-0.474455732271346,0.948686748702770,-0.473456825827113;-0.473637494678322,0.947051015437725,-0.472640681589265;-0.472820853930977,0.945418473472466,-0.471826129123482;-0.472005806638714,0.943789116033699,-0.471013165052899;-0.471192349418546,0.942162936363325,-0.470201786008223;-0.470380478895060,0.940539927718367,-0.469391988627694;-0.469570191700419,0.938920083370970,-0.468583769557087;-0.468761484474327,0.937303396608336,-0.467777125449677;-0.467954353864026,0.935689860732713,-0.466972052966236;-0.467148796524270,0.934079469061350,-0.466168548775009;-0.466344809117311,0.932472214926463,-0.465366609551698;-0.465542388312885,0.930868091675207,-0.464566231979448;-0.464741530788185,0.929267092669628,-0.463767412748822;-0.463942233227857,0.927669211286650,-0.462970148557797;-0.463144492323972,0.926074440918022,-0.462174436111734;-0.462348304776015,0.924482774970293,-0.461380272123370;-0.461553667290867,0.922894206864774,-0.460587653312795;-0.460760576582788,0.921308730037517,-0.459796576407442;-0.459969029373398,0.919726337939258,-0.459007038142064;-0.459179022391662,0.918147024035406,-0.458219035258721;-0.458390552373875,0.916570781805999,-0.457432564506762;-0.457603616063641,0.914997604745666,-0.456647622642807;-0.456818210211862,0.913427486363610,-0.455864206430735;-0.456034331576714,0.911860420183552,-0.455082312641661;-0.455251976923635,0.910296399743719,-0.454301938053925;-0.454471143025311,0.908735418596800,-0.453523079453074;-0.453691826661653,0.907177470309915,-0.452745733631842;-0.452914024619784,0.905622548464578,-0.451969897390140;-0.452137733694021,0.904070646656669,-0.451195567535031;-0.451362950685862,0.902521758496405,-0.450422740880725;-0.450589672403968,0.900975877608302,-0.449651414248555;-0.449817895664140,0.899432997631134,-0.448881584466957;-0.449047617289313,0.897893112217916,-0.448113248371463;-0.448278834109535,0.896356215035863,-0.447346402804682;-0.447511542961949,0.894822299766359,-0.446581044616279;-0.446745740690780,0.893291360104926,-0.445817170662967;-0.445981424147315,0.891763389761186,-0.445054777808481;-0.445218590189890,0.890238382458833,-0.444293862923569;-0.444457235683877,0.888716331935609,-0.443534422885979;-0.443697357501656,0.887197231943252,-0.442776454580430;-0.442938952522614,0.885681076247484,-0.442019954898612;-0.442182017633118,0.884167858627964,-0.441264920739156;-0.441426549726502,0.882657572878268,-0.440511349007629;-0.440672545703054,0.881150212805848,-0.439759236616510;-0.439920002469994,0.879645772232000,-0.439008580485180;-0.439168916941471,0.878144244991854,-0.438259377539907;-0.438419286038525,0.876645624934299,-0.437511624713819;-0.437671106689095,0.875149905921997,-0.436765318946905;-0.436924375827986,0.873657081831319,-0.436020457185985;-0.436179090396862,0.872167146552334,-0.435277036384703;-0.435435247344227,0.870680093988762,-0.434535053503507;-0.434692843625413,0.869195918057962,-0.433794505509639;-0.433951876202557,0.867714612690875,-0.433055389377109;-0.433212342044593,0.866236171832016,-0.432317702086691;-0.432474238127233,0.864760589439431,-0.431581440625900;-0.431737561432950,0.863287859484669,-0.430846601988981;-0.431002308950968,0.861817975952753,-0.430113183176890;-0.430268477677236,0.860350932842140,-0.429381181197280;-0.429536064614426,0.858886724164704,-0.428650593064485;-0.428805066771909,0.857425343945698,-0.427921415799511;-0.428075481165739,0.855966786223720,-0.427193646430009;-0.427347304818644,0.854511045050688,-0.426467281990269;-0.426620534760003,0.853058114491808,-0.425742319521202;-0.425895168025837,0.851607988625541,-0.425018756070323;-0.425171201658791,0.850160661543577,-0.424296588691740;-0.424448632708118,0.848716127350800,-0.423575814446133;-0.423727458229667,0.847274380165263,-0.422856430400748;-0.423007675285863,0.845835414118150,-0.422138433629371;-0.422289280945697,0.844399223353756,-0.421421821212319;-0.421572272284706,0.842965802029446,-0.420706590236427;-0.420856646384964,0.841535144315638,-0.419992737795030;-0.420142400335062,0.840107244395759,-0.419280260987947;-0.419429531230092,0.838682096466222,-0.418569156921468;-0.418718036171638,0.837259694736399,-0.417859422708338;-0.418007912267757,0.835840033428587,-0.417151055467747;-0.417299156632963,0.834423106777980,-0.416444052325306;-0.416591766388217,0.833008909032637,-0.415738410413042;-0.415885738660905,0.831597434453454,-0.415034126869374;-0.415181070584832,0.830188677314139,-0.414331198839108;-0.414477759300199,0.828782631901174,-0.413629623473414;-0.413775801953594,0.827379292513793,-0.412929397929818;-0.413075195697976,0.825978653463950,-0.412230519372182;-0.412375937692656,0.824580709076286,-0.411532984970692;-0.411678025103287,0.823185453688102,-0.410836791901842;-0.410981455101851,0.821792881649341,-0.410141937348425;-0.410286224866643,0.820402987322542,-0.409448418499511;-0.409592331582249,0.819015765082818,-0.408756232550436;-0.408899772439542,0.817631209317829,-0.408065376702789;-0.408208544635665,0.816249314427752,-0.407375848164393;-0.407518645374011,0.814870074825252,-0.406687644149299;-0.406830071864216,0.813493484935455,-0.406000761877763;-0.406142821322138,0.812119539195911,-0.405315198576235;-0.405456890969849,0.810748232056577,-0.404630951477347;-0.404772278035618,0.809379557979787,-0.403948017819897;-0.404088979753891,0.808013511440210,-0.403266394848831;-0.403406993365288,0.806650086924842,-0.402586079815239;-0.402726316116581,0.805289278932960,-0.401907069976329;-0.402046945260680,0.803931081976106,-0.401229362595421;-0.401368878056625,0.802575490578050,-0.400552954941929;-0.400692111769564,0.801222499274770,-0.399877844291352;-0.400016643670742,0.799872102614415,-0.399204027925251;-0.399342471037490,0.798524295157285,-0.398531503131245;-0.398669591153207,0.797179071475796,-0.397860267202990;-0.397998001307350,0.795836426154466,-0.397190317440170;-0.397327698795411,0.794496353789861,-0.396521651148478;-0.396658680918920,0.793158848990602,-0.395854265639610;-0.395990944985409,0.791823906377299,-0.395188158231238;-0.395324488308420,0.790491520582559,-0.394523326247015;-0.394659308207475,0.789161686250936,-0.393859767016542;-0.393995402008071,0.787834398038908,-0.393197477875368;-0.393332767041663,0.786509650614857,-0.392536456164969;-0.392671400645652,0.785187438659035,-0.391876699232741;-0.392011300163367,0.783867756863530,-0.391218204431976;-0.391352462944058,0.782550599932260,-0.390560969121861;-0.390694886342877,0.781235962580920,-0.389904990667453;-0.390038567720867,0.779923839536976,-0.389250266439673;-0.389383504444947,0.778614225539624,-0.388596793815291;-0.388729693887901,0.777307115339773,-0.387944570176912;-0.388077133428360,0.776002503700008,-0.387293592912959;-0.387425820450794,0.774700385394573,-0.386643859417666;-0.386775752345494,0.773400755209336,-0.385995367091060;-0.386126926508562,0.772103607941772,-0.385348113338954;-0.385479340341892,0.770808938400919,-0.384702095572919;-0.384832991253167,0.769516741407375,-0.384057311210292;-0.384187876655834,0.768227011793253,-0.383413757674144;-0.383543993969099,0.766939744402158,-0.382771432393276;-0.382901340617910,0.765654934089170,-0.382130332802208;-0.382259914032943,0.764372575720802,-0.381490456341155;-0.381619711650593,0.763092664174990,-0.380851800456027;-0.380980730912956,0.761815194341053,-0.380214362598406;-0.380342969267820,0.760540161119680,-0.379578140225540;-0.379706424168648,0.759267559422891,-0.378943130800324;-0.379071093074566,0.757997384174010,-0.378309331791289;-0.378436973450357,0.756729630307665,-0.377676740672594;-0.377804062766434,0.755464292769723,-0.377045354924005;-0.377172358498840,0.754201366517295,-0.376415172030888;-0.376541858129227,0.752940846518695,-0.375786189484193;-0.375912559144848,0.751682727753416,-0.375158404780441;-0.375284459038538,0.750427005212109,-0.374531815421715;-0.374657555308712,0.749173673896553,-0.373906418915644;-0.374031845459339,0.747922728819634,-0.373282212775389;-0.373407326999939,0.746674165005313,-0.372659194519634;-0.372783997445564,0.745427977488602,-0.372037361672570;-0.372161854316792,0.744184161315547,-0.371416711763887;-0.371540895139704,0.742942711543188,-0.370797242328751;-0.370921117445886,0.741703623239551,-0.370178950907808;-0.370302518772400,0.740466891483604,-0.369561835047154;-0.369685096661783,0.739232511365246,-0.368945892298334;-0.369068848662029,0.738000477985277,-0.368331120218325;-0.368453772326580,0.736770786455370,-0.367717516369524;-0.367839865214311,0.735543431898053,-0.367105078319737;-0.367227124889516,0.734318409446677,-0.366493803642164;-0.366615548921899,0.733095714245394,-0.365883689915389;-0.366005134886561,0.731875341449133,-0.365274734723366;-0.365395880363984,0.730657286223573,-0.364666935655407;-0.364787782940023,0.729441543745122,-0.364060290306172;-0.364180840205893,0.728228109200888,-0.363454796275652;-0.363575049758149,0.727016977788653,-0.362850451169158;-0.362970409198689,0.725808144716856,-0.362247252597314;-0.362366916134728,0.724601605204564,-0.361645198176041;-0.361764568178789,0.723397354481446,-0.361044285526540;-0.361163362948697,0.722195387787748,-0.360444512275289;-0.360563298067557,0.720995700374273,-0.359845876054025;-0.359964371163750,0.719798287502356,-0.359248374499731;-0.359359774667003,0.718589533162144,-0.358645210100134;-0.358756335780646,0.717383092641828,-0.358043199981727;-0.358154052066835,0.716178961070240,-0.357442341715319;-0.357552921093244,0.714977133587226,-0.356842632877211;-0.356952940433046,0.713777605343619,-0.356244071049180;-0.356354107664900,0.712580371501208,-0.355646653818462;-0.355756420372941,0.711385427232719,-0.355050378777746;-0.355159876146765,0.710192767721785,-0.354455243525159;-0.354564472581415,0.709002388162919,-0.353861245664249;-0.353970207277371,0.707814283761489,-0.353268382803974;-0.353377077840533,0.706628449733697,-0.352676652558695;-0.352785081882214,0.705444881306547,-0.352086052548155;-0.352194217019119,0.704263573717818,-0.351496580397468;-0.351604480873340,0.703084522216046,-0.350908233737111;-0.351015871072339,0.701907722060493,-0.350321010202906;-0.350428385248935,0.700733168521119,-0.349734907436008;-0.349842021041294,0.699560856878567,-0.349149923082898;-0.349256776092913,0.698390782424127,-0.348566054795362;-0.348672648052611,0.697222940459714,-0.347983300230483;-0.348089634574510,0.696057326297842,-0.347401657050628;-0.347507733318032,0.694893935261603,-0.346821122923436;-0.346926941947877,0.693732762684636,-0.346241695521803;-0.346347258134017,0.692573803911110,-0.345663372523874;-0.345768679551678,0.691417054295685,-0.345086151613023;-0.345191203881333,0.690262509203500,-0.344510030477847;-0.344614828808685,0.689110164010148,-0.343935006812156;-0.344039552024659,0.687960014101643,-0.343361078314952;-0.343465371225385,0.686812054874396,-0.342788242690420;-0.342892284112187,0.685666281735199,-0.342216497647921;-0.342320288391573,0.684522690101192,-0.341645840901973;-0.341749381775220,0.683381275399842,-0.341076270172242;-0.341179561979963,0.682242033068916,-0.340507783183527;-0.340610826727783,0.681104958556462,-0.339940377665754;-0.340043173745793,0.679970047320774,-0.339374051353954;-0.339476600766227,0.678837294830382,-0.338808801988261;-0.338911105526429,0.677706696564016,-0.338244627313895;-0.338346685768840,0.676578248010588,-0.337681525081150;-0.337783339240982,0.675451944669160,-0.337119493045378;-0.337221063695454,0.674327782048933,-0.336558528966989;-0.336659856889912,0.673205755669209,-0.335998630611423;-0.336099716587062,0.672085861059380,-0.335439795749155;-0.335540640554648,0.670968093758893,-0.334882022155667;-0.334982626565434,0.669852449317232,-0.334325307611448;-0.334425672397200,0.668738923293892,-0.333769649901976;-0.333869775832723,0.667627511258354,-0.333215046817705;-0.333314934659776,0.666518208790071,-0.332661496154064;-0.332761146671099,0.665411011478425,-0.332108995711427;-0.332208409664406,0.664305914922728,-0.331557543295120;-0.331656721442357,0.663202914732174,-0.331007136715395;-0.331106079812558,0.662102006525833,-0.330457773787427;-0.330556482587543,0.661003185932622,-0.329909452331299;-0.330007927584766,0.659906448591281,-0.329362170171990;-0.329460412626583,0.658811790150345,-0.328815925139364;-0.328913935540249,0.657719206268133,-0.328270715068159;-0.328368494157899,0.656628692612710,-0.327726537797974;-0.327824086316542,0.655540244861877,-0.327183391173261;-0.327280709858047,0.654453858703144,-0.326641273043309;-0.326738362629127,0.653369529833697,-0.326100181262233;-0.326197042481337,0.652287253960390,-0.325560113688967;-0.325656747271054,0.651207026799711,-0.325021068187247;-0.325117474859471,0.650128844077768,-0.324483042625604;-0.324579223112584,0.649052701530261,-0.323946034877352;-0.324041989901178,0.647978594902457,-0.323410042820572;-0.323505773100817,0.646906519949168,-0.322875064338106;-0.322970570591837,0.645836472434740,-0.322341097317546;-0.322436380259329,0.644768448133010,-0.321808139651216;-0.321903199993129,0.643702442827305,-0.321276189236170;-0.321371027687810,0.642638452310402,-0.320745243974176;-0.320839861242665,0.641576472384512,-0.320215301771699;-0.320309698561701,0.640516498861262,-0.319686360539905;-0.319780537553627,0.639458527561667,-0.319158418194633;-0.319252376131843,0.638402554316116,-0.318631472656400;-0.318725212214421,0.637348574964332,-0.318105521850373;-0.318199043724107,0.636296585355369,-0.317580563706372;-0.317673868588302,0.635246581347580,-0.317056596158852;-0.317149684739052,0.634198558808600,-0.316533617146895;-0.316626490113037,0.633152513615318,-0.316011624614197;-0.316104282651561,0.632108441653858,-0.315490616509057;-0.315583060300542,0.631066338819561,-0.314970590784368;-0.315062821010496,0.630026201016957,-0.314451545397604;-0.314543562736534,0.628988024159748,-0.313933478310813;-0.314025283438345,0.627951804170783,-0.313416387490601;-0.313507981080187,0.626917536982036,-0.312900270908125;-0.312991653630872,0.625885218534585,-0.312385126539076;-0.312476299063769,0.624854844778599,-0.311870952363682;-0.311961915356775,0.623826411673300,-0.311357746366681;-0.311448500492317,0.622799915186957,-0.310845506537322;-0.310936052457335,0.621775351296852,-0.310334230869348;-0.310424569243275,0.620752715989269,-0.309823917360986;-0.309914048846078,0.619732005259469,-0.309314564014943;-0.309404489266165,0.618713215111665,-0.308806168838386;-0.308895888508431,0.617696341559007,-0.308298729842936;-0.308388244582233,0.616681380623553,-0.307792245044659;-0.307881555501380,0.615668328336260,-0.307286712464052;-0.307375819284121,0.614657180736951,-0.306782130126036;-0.306871033953137,0.613647933874300,-0.306278496059942;-0.306367197535526,0.612640583805807,-0.305775808299503;-0.305864308062797,0.611635126597786,-0.305274064882844;-0.305362363570860,0.610631558325333,-0.304773263852468;-0.304861362100009,0.609629875072313,-0.304273403255251;-0.304361301694921,0.608630072931337,-0.303774481142427;-0.303862180404639,0.607632148003738,-0.303276495569582;-0.303363996282562,0.606636096399557,-0.302779444596639;-0.302866747386438,0.605641914237515,-0.302283326287849;-0.302370431778352,0.604649597645001,-0.301788138711786;-0.301875047524714,0.603659142758043,-0.301293879941330;-0.301380592696252,0.602670545721291,-0.300800548053657;-0.300887065368001,0.601683802688004,-0.300308141130238;-0.300394463619291,0.600698909820013,-0.299816657256817;-0.299902785533736,0.599715863287716,-0.299326094523405;-0.299412029199231,0.598734659270051,-0.298836451024277;-0.298922192707931,0.597755293954477,-0.298347724857951;-0.298433274156249,0.596777763536956,-0.297859914127184;-0.297945271644846,0.595802064221927,-0.297373016938963;-0.297458183278615,0.594828192222294,-0.296887031404490;-0.296972007166676,0.593856143759399,-0.296401955639177;-0.296486741422366,0.592885915063008,-0.295917787762636;-0.296002384163222,0.591917502371280,-0.295434525898660;-0.295518933510985,0.590950901930767,-0.294952168175229;-0.295036387591575,0.589986109996374,-0.294470712724486;-0.294554744535091,0.589023122831350,-0.293990157682735;-0.294074002475799,0.588061936707271,-0.293510501190429;-0.293594159552118,0.587102547904007,-0.293031741392159;-0.293115213906616,0.586144952709714,-0.292553876436644;-0.292637163685996,0.585189147420815,-0.292076904476726;-0.292160007041089,0.584235128341973,-0.291600823669355;-0.291683742126844,0.583282891786076,-0.291125632175580;-0.291208367102314,0.582332434074219,-0.290651328160544;-0.290733880130653,0.581383751535680,-0.290177909793467;-0.290260279379100,0.580436840507903,-0.289705375247641;-0.289787563018977,0.579491697336483,-0.289233722700423;-0.289315729225670,0.578548318375139,-0.288762950333219;-0.288844776178629,0.577606699985703,-0.288293056331479;-0.288374702061347,0.576666838538089,-0.287824038884683;-0.287905505061365,0.575728730410291,-0.287355896186340;-0.287437183370247,0.574792371988349,-0.286888626433968;-0.286969735183584,0.573857759666336,-0.286422227829092;-0.286503158700974,0.572924889846337,-0.285956698577232;-0.286037452126021,0.571993758938439,-0.285492036887894;-0.285572613666320,0.571064363360698,-0.285028240974560;-0.285108641533448,0.570136699539127,-0.284565309054678;-0.284645533942958,0.569210763907682,-0.284103239349656;-0.284183289114367,0.568286552908239,-0.283642030084850;-0.283721905271145,0.567364062990568,-0.283181679489553;-0.283261380640711,0.566443290612325,-0.282722185796988;-0.282801713454419,0.565524232239037,-0.282263547244302;-0.282342901947552,0.564606884344069,-0.281805762072552;-0.281884944359308,0.563691243408610,-0.281348828526693;-0.281427838932796,0.562777305921668,-0.280892744855579;-0.280971583915024,0.561865068380030,-0.280437509311944;-0.280509617973458,0.560941407279075,-0.279976570255669;-0.280048520903175,0.560019483056858,-0.279516497768400;-0.279588290893214,0.559099292094193,-0.279057290044956;-0.279128926136710,0.558180830780085,-0.278598945284241;-0.278670424830883,0.557264095511694,-0.278141461689225;-0.278212785177032,0.556349082694331,-0.277684837466942;-0.277756005380516,0.555435788741419,-0.277229070828471;-0.277300083650753,0.554524210074492,-0.276774159988933;-0.276845018201207,0.553614343123161,-0.276320103167479;-0.276390807249377,0.552706184325102,-0.275866898587281;-0.275937449016790,0.551799730126041,-0.275414544475522;-0.275484941728988,0.550894976979722,-0.274963039063386;-0.275033283615521,0.549991921347896,-0.274512380586047;-0.274582472909935,0.549090559700299,-0.274062567282661;-0.274132507849767,0.548190888514638,-0.273613597396360;-0.273683386676526,0.547292904276560,-0.273165469174233;-0.273235107635695,0.546396603479648,-0.272718180867325;-0.272787668976712,0.545501982625386,-0.272271730730624;-0.272341068952966,0.544609038223154,-0.271826117023052;-0.271895305821786,0.543717766790200,-0.271381338007455;-0.271450377844431,0.542828164851627,-0.270937391950596;-0.271006283286077,0.541940228940362,-0.270494277123137;-0.270563020415816,0.541053955597158,-0.270051991799646;-0.270120587506638,0.540169341370552,-0.269610534258568;-0.269678982835428,0.539286382816863,-0.269169902782231;-0.269238204682952,0.538405076500168,-0.268730095656831;-0.268798251333852,0.537525418992281,-0.268291111172420;-0.268359121076629,0.536647406872733,-0.267852947622899;-0.267920812203644,0.535771036728763,-0.267415603306012;-0.267483323011099,0.534896305155284,-0.266979076523329;-0.267046651799037,0.534023208754881,-0.266543365580248;-0.266610796871324,0.533151744137780,-0.266108468785972;-0.266175756535647,0.532281907921840,-0.265674384453515;-0.265741529103498,0.531413696732522,-0.265241110899677;-0.265308112890169,0.530547107202879,-0.264808646445047;-0.264875506214743,0.529682135973539,-0.264376989413989;-0.264443707400087,0.528818779692684,-0.263946138134635;-0.264012714772834,0.527957035016031,-0.263516090938872;-0.263582526663384,0.527096898606812,-0.263086846162337;-0.263153141405888,0.526238367135759,-0.262658402144403;-0.262724557338244,0.525381437281092,-0.262230757228180;-0.262296772802084,0.524526105728486,-0.261803909760493;-0.261869786142768,0.523672369171066,-0.261377858091884;-0.261443595709372,0.522820224309381,-0.260952600576594;-0.261018199854682,0.521969667851397,-0.260528135572564;-0.260593596935183,0.521120696512461,-0.260104461441415;-0.260169785311052,0.520273307015304,-0.259681576548449;-0.259746763346147,0.519427496090010,-0.259259479262637;-0.259324529407998,0.518583260473996,-0.258838167956602;-0.258903081867803,0.517740596912009,-0.258417641006626;-0.258482419100410,0.516899502156091,-0.257997896792627;-0.258062539484319,0.516059972965577,-0.257578933698159;-0.257643441401665,0.515222006107066,-0.257160750110398;-0.257225123238212,0.514385598354407,-0.256743344420136;-0.256807583383347,0.513550746488686,-0.256326715021773;-0.256390820230064,0.512717447298201,-0.255910860313305;-0.255974832174964,0.511885697578451,-0.255495778696318;-0.255559617618243,0.511055494132117,-0.255081468575980;-0.255145174963678,0.510226833769039,-0.254667928361030;-0.254731502618628,0.509399713306213,-0.254255156463771;-0.254318598994017,0.508574129567754,-0.253843151300061;-0.253906462504332,0.507750079384898,-0.253431911289306;-0.253495091567608,0.506927559595971,-0.253021434854446;-0.253084484605426,0.506106567046381,-0.252611720421954;-0.252674640042900,0.505287098588595,-0.252202766421824;-0.252265556308669,0.504469151082124,-0.251794571287560;-0.251857231834891,0.503652721393512,-0.251387133456175;-0.251449665057231,0.502837806396306,-0.250980451368171;-0.251042854414858,0.502024402971053,-0.250574523467543;-0.250636798350428,0.501212508005274,-0.250169348201764;-0.250231495310085,0.500402118393448,-0.249764924021774;-0.249826943743447,0.499593231037007,-0.249361249381981;-0.249423142103599,0.498785842844298,-0.248958322740242;-0.249020088847084,0.497979950730587,-0.248556142557864;-0.248617782433897,0.497175551618032,-0.248154707299589;-0.248216221327474,0.496372642435664,-0.247754015433588;-0.247815403994686,0.495571220119383,-0.247354065431456;-0.247415328905828,0.494771281611924,-0.246954855768196;-0.247015994534612,0.493972823862857,-0.246556384922220;-0.246617399358164,0.493175843828563,-0.246158651375336;-0.246219541857005,0.492380338472213,-0.245761653612738;-0.245822420515054,0.491586304763765,-0.245365390123004;-0.245426033819612,0.490793739679933,-0.244969859398081;-0.245030380261357,0.490002640204183,-0.244575059933281;-0.244635458334335,0.489213003326706,-0.244180990227274;-0.244241266535955,0.488424826044412,-0.243787648782075;-0.243847803366979,0.487638105360911,-0.243395034103043;-0.243455067331508,0.486852838286486,-0.243003144698864;-0.243063056936985,0.486069021838096,-0.242611979081553;-0.242671770694181,0.485286653039348,-0.242221535766440;-0.242281207117184,0.484505728920477,-0.241831813272159;-0.241891364723399,0.483726246518350,-0.241442810120652;-0.241502242033532,0.482948202876423,-0.241054524837146;-0.241113837571590,0.482171595044748,-0.240666955950159;-0.240726149864864,0.481396420079944,-0.240280101991480;-0.240339177443931,0.480622675045188,-0.239893961496172;-0.239952918842636,0.479850357010194,-0.239508533002555;-0.239567372598093,0.479079463051202,-0.239123815052204;-0.239182537250675,0.478309990250965,-0.238739806189943;-0.238798411344000,0.477541935698719,-0.238356504963826;-0.238414993424933,0.476775296490190,-0.237973909925146;-0.238032282043568,0.476010069727556,-0.237592019628411;-0.237650275753230,0.475246252519444,-0.237210832631347;-0.237268973110463,0.474483841980920,-0.236830347494889;-0.236888372675019,0.473722835233457,-0.236450562783168;-0.236508473009856,0.472963229404933,-0.236071477063509;-0.236129272681127,0.472205021629609,-0.235693088906419;-0.235750770258172,0.471448209048119,-0.235315396885582;-0.235372964313515,0.470692788807450,-0.234938399577854;-0.234995853422849,0.469938758060931,-0.234562095563248;-0.234619436165039,0.469186113968216,-0.234186483424937;-0.234243711122099,0.468434853695265,-0.233811561749232;-0.233868676879200,0.467684974414336,-0.233437329125590;-0.233494332024653,0.466936473303965,-0.233063784146596;-0.233120675149907,0.466189347548953,-0.232690925407959;-0.232747704849536,0.465443594340353,-0.232318751508507;-0.232375419721237,0.464699210875452,-0.231947261050175;-0.232003818365819,0.463956194357755,-0.231576452638000;-0.231632899387195,0.463214541996974,-0.231206324880114;-0.231262661392378,0.462474251009008,-0.230836876387733;-0.230893102991475,0.461735318615940,-0.230468105775158;-0.230524222797670,0.460997742046007,-0.230100011659759;-0.230156019427226,0.460261518533591,-0.229732592661969;-0.229788491499478,0.459526645319213,-0.229365847405283;-0.229421637636819,0.458793119649507,-0.228999774516245;-0.229055456464696,0.458060938777209,-0.228634372624440;-0.228689946611606,0.457330099961144,-0.228269640362491;-0.228325106709082,0.456600600466210,-0.227905576366049;-0.227960935391692,0.455872437563365,-0.227542179273788;-0.227597431297028,0.455145608529611,-0.227179447727393;-0.227234593065704,0.454420110647985,-0.226817380371561;-0.226872419341340,0.453695941207532,-0.226455975853984;-0.226510908770560,0.452973097503303,-0.226095232825350;-0.226150060002988,0.452251576836341,-0.225735149939333;-0.225789871691235,0.451531376513651,-0.225375725852582;-0.225430342490897,0.450812493848210,-0.225016959224724;-0.225071471060541,0.450094926158931,-0.224658848718345;-0.224713256061707,0.449378670770661,-0.224301392998990;-0.224355696158893,0.448663725014165,-0.223944590735157;-0.223998790019551,0.447950086226106,-0.223588440598282;-0.223642536314084,0.447237751749044,-0.223232941262746;-0.223286933715831,0.446526718931406,-0.222878091405851;-0.222931980901066,0.445816985127482,-0.222523889707826;-0.222577676548990,0.445108547697411,-0.222170334851816;-0.222224019341720,0.444401404007163,-0.221817425523873;-0.221871007964291,0.443695551428529,-0.221465160412953;-0.221518641104639,0.442990987339104,-0.221113538210905;-0.221166917453598,0.442287709122273,-0.220762557612466;-0.220815835704898,0.441585714167203,-0.220412217315257;-0.220465394555149,0.440884999868822,-0.220062516019770;-0.220115592703843,0.440185563627810,-0.219713452429367;-0.219766428853341,0.439487402850585,-0.219365025250272;-0.219417901708870,0.438790514949286,-0.219017233191559;-0.219070009978511,0.438094897341762,-0.218670074965153;-0.218722752373201,0.437400547451560,-0.218323549285818;-0.218376127606717,0.436707462707910,-0.217977654871153;-0.218030134395675,0.436015640545708,-0.217632390441583;-0.217684771459521,0.435325078405510,-0.217287754720353;-0.217340037520525,0.434635773733511,-0.216943746433525;-0.216995931303775,0.433947723981537,-0.216600364309963;-0.216652451537170,0.433260926607031,-0.216257607081337;-0.216309596951412,0.432575379073039,-0.215915473482109;-0.215967366279998,0.431891078848191,-0.215573962249525;-0.215625758259220,0.431208023406700,-0.215233072123617;-0.215284771628151,0.430526210228337,-0.214892801847186;-0.214944405128642,0.429845636798422,-0.214553150165805;-0.214604657505317,0.429166300607820,-0.214214115827807;-0.214265527505562,0.428488199152910,-0.213875697584277;-0.213927013879520,0.427811329935584,-0.213537894189049;-0.213589115380089,0.427135690463236,-0.213200704398702;-0.213251830762909,0.426461278248739,-0.212864126972546;-0.212915158786358,0.425788090810441,-0.212528160672620;-0.212579098211547,0.425116125672145,-0.212192804263686;-0.212243647802314,0.424445380363107,-0.211858056513225;-0.211908806325211,0.423775852418004,-0.211523916191420;-0.211574572549508,0.423107539376946,-0.211190382071163;-0.211240945247179,0.422440438785443,-0.210857452928041;-0.210907923192894,0.421774548194397,-0.210525127540329;-0.210575505164025,0.421109865160101,-0.210193404688990;-0.210243689940622,0.420446387244210,-0.209862283157661;-0.209912476305420,0.419784112013732,-0.209531761732649;-0.209581863043830,0.419123037041032,-0.209201839202933;-0.209251848943925,0.418463159903791,-0.208872514360141;-0.208922432796449,0.417804478185021,-0.208543785998562;-0.208593613394791,0.417146989473031,-0.208215652915124;-0.208265389534997,0.416490691361428,-0.207888113909400;-0.207937760015753,0.415835581449100,-0.207561167783594;-0.207610723638381,0.415181657340203,-0.207234813342540;-0.207284279206835,0.414528916644149,-0.206909049393689;-0.206958425527694,0.413877356975594,-0.206583874747112;-0.206633161410152,0.413226975954424,-0.206259288215485;-0.206308485666017,0.412577771205746,-0.205935288614087;-0.205984397109704,0.411929740359877,-0.205611874760797;-0.205660894558225,0.411282881052319,-0.205289045476082;-0.205337976831188,0.410637190923768,-0.204966799582994;-0.205015642750787,0.409992667620084,-0.204645135907163;-0.204693891141797,0.409349308792283,-0.204324053276792;-0.204372720831570,0.408707112096530,-0.204003550522648;-0.204052130650026,0.408066075194127,-0.203683626478064;-0.203732119429647,0.407426195751492,-0.203364279978919;-0.203402216338997,0.406766530762777,-0.203035055657993;-0.203072922023923,0.406108082869672,-0.202706438656226;-0.202744235230143,0.405450849565038,-0.202378427722849;-0.202416154706208,0.404794828347403,-0.202051021609918;-0.202088679203492,0.404140016720930,-0.201724219072298;-0.201761807476191,0.403486412195428,-0.201398018867672;-0.201435538281310,0.402834012286313,-0.201072419756519;-0.201109870378659,0.402182814514613,-0.200747420502117;-0.200784802530848,0.401532816406950,-0.200423019870533;-0.200460333503278,0.400884015495517,-0.200099216630615;-0.200136462064130,0.400236409318073,-0.199776009553984;-0.199813186984368,0.399589995417931,-0.199453397415033;-0.199490507037723,0.398944771343937,-0.199131378990916;-0.199168421000693,0.398300734650465,-0.198809953061540;-0.198846927652530,0.397657882897391,-0.198489118409561;-0.198526025775236,0.397016213650094,-0.198168873820376;-0.198205714153560,0.396375724479433,-0.197849218082117;-0.197885991574986,0.395736412961739,-0.197530149985645;-0.197566856829727,0.395098276678795,-0.197211668324539;-0.197248308710722,0.394461313217832,-0.196893771895098;-0.196930346013625,0.393825520171504,-0.196576459496323;-0.196612967536800,0.393190895137887,-0.196259729929921;-0.196296172081316,0.392557435720455,-0.195943582000291;-0.195979958450937,0.391925139528075,-0.195628014514520;-0.195664325452121,0.391294004174991,-0.195313026282381;-0.195349271894004,0.390664027280807,-0.194998616116315;-0.195034796588406,0.390035206470480,-0.194684782831438;-0.194720898349813,0.389407539374305,-0.194371525245525;-0.194407575995376,0.388781023627896,-0.194058842179005;-0.194094828344904,0.388155656872184,-0.193746732454960;-0.193782654220858,0.387531436753396,-0.193435194899112;-0.193471052448343,0.386908360923043,-0.193124228339819;-0.193160021855102,0.386286427037910,-0.192813831608069;-0.192849561271509,0.385665632760042,-0.192504003537474;-0.192539669530567,0.385045975756729,-0.192194742964263;-0.192230345467894,0.384427453700498,-0.191886048727275;-0.191921587921722,0.383810064269091,-0.191577919667952;-0.191613395732889,0.383193805145465,-0.191270354630336;-0.191305767744834,0.382578674017769,-0.190963352461059;-0.190998702803588,0.381964668579337,-0.190656912009338;-0.190692199757770,0.381351786528670,-0.190351032126970;-0.190386257458581,0.380740025569435,-0.190045711668325;-0.190080874759796,0.380129383410435,-0.189740949490337;-0.189776050517755,0.379519857765608,-0.189436744452502;-0.189471783591365,0.378911446354015,-0.189133095416868;-0.189168072842087,0.378304146899828,-0.188830001248035;-0.188864917133931,0.377697957132304,-0.188527460813138;-0.188562315333453,0.377092874785792,-0.188225472981853;-0.188260266309742,0.376488897599711,-0.187924036626383;-0.187958768934422,0.375886023318530,-0.187623150621452;-0.187657822081638,0.375284249691774,-0.187322813844302;-0.187357424628059,0.374683574473999,-0.187023025174689;-0.187057575452864,0.374083995424780,-0.186723783494870;-0.186758273437735,0.373485510308701,-0.186425087689600;-0.186459517466862,0.372888116895347,-0.186126936646129;-0.186161306426924,0.372291812959287,-0.185829329254193;-0.185863639207090,0.371696596280059,-0.185532264406005;-0.185566514699010,0.371102464642166,-0.185235740996259;-0.185269931796812,0.370509415835059,-0.184939757922110;-0.184973889397095,0.369917447653125,-0.184644314083180;-0.184678386398919,0.369326557895675,-0.184349408381547;-0.184383421703806,0.368736744366937,-0.184055039721738;-0.184088994215728,0.368148004876035,-0.183761207010724;-0.183795102841104,0.367560337236984,-0.183467909157918;-0.183501746488794,0.366973739268677,-0.183175145075162;-0.183208924070092,0.366388208794872,-0.182882913676725;-0.182916634498721,0.365803743644180,-0.182591213879300;-0.182624876690826,0.365220341650055,-0.182300044601993;-0.182333649564969,0.364638000650781,-0.182009404766318;-0.182042952042125,0.364056718489458,-0.181719293296195;-0.181752783045672,0.363476493013995,-0.181429709117938;-0.181463141501389,0.362897322077099,-0.181140651160258;-0.181174026337447,0.362319203536256,-0.180852118354247;-0.180885436484405,0.361742135253725,-0.180564109633379;-0.180597370875204,0.361166115096523,-0.180276623933502;-0.180309828445165,0.360591140936424,-0.179989660192835;-0.180022808131973,0.360017210649931,-0.179703217351956;-0.179736308875682,0.359444322118279,-0.179417294353804;-0.179450329618705,0.358872473227412,-0.179131890143667;-0.179164869305807,0.358301661867982,-0.178847003669180;-0.178879926884100,0.357731885935328,-0.178562633880317;-0.178595501303041,0.357163143329476,-0.178278779729389;-0.178311591514420,0.356595431955116,-0.177995440171034;-0.178028196472361,0.356028749721598,-0.177712614162214;-0.177745315133308,0.355463094542915,-0.177430300662207;-0.177462946456031,0.354898464337702,-0.177148498632605;-0.177181089401607,0.354334857029211,-0.176867207037307;-0.176899742933430,0.353772270545316,-0.176586424842512;-0.176618906017186,0.353210702818484,-0.176306151016712;-0.176338577620867,0.352650151785778,-0.176026384530694;-0.176058756714751,0.352090615388836,-0.175747124357525;-0.175779442271406,0.351532091573875,-0.175468369472554;-0.175500633265678,0.350974578291656,-0.175190118853399;-0.175222328674690,0.350418073497499,-0.174912371479951;-0.174944527477833,0.349862575151251,-0.174635126334361;-0.174667228656761,0.349308081217288,-0.174358382401035;-0.174390431195390,0.348754589664500,-0.174082138666634;-0.174114134079887,0.348202098466279,-0.173806394120064;-0.173838336298667,0.347650605600510,-0.173531147752470;-0.173563036842389,0.347100109049560,-0.173256398557235;-0.173288234703946,0.346550606800265,-0.172982145529970;-0.173013928878465,0.346002096843921,-0.172708387668511;-0.172740118363298,0.345454577176273,-0.172435123972912;-0.172466802158020,0.344908045797509,-0.172162353445446;-0.172193979264417,0.344362500712238,-0.171890075090587;-0.171921648686491,0.343817939929491,-0.171618287915018;-0.171649809430443,0.343274361462703,-0.171346990927616;-0.171378460504680,0.342731763329708,-0.171076183139457;-0.171107600919798,0.342190143552721,-0.170805863563796;-0.170837229688582,0.341649500158332,-0.170536031216074;-0.170567345826007,0.341109831177503,-0.170266685113912;-0.170297948349219,0.340571134645541,-0.169997824277099;-0.170029036277542,0.340033408602100,-0.169729447727590;-0.169760608632466,0.339496651091169,-0.169461554489505;-0.169492664437643,0.338960860161053,-0.169194143589114;-0.169225202718888,0.338426033864379,-0.168927214054846;-0.168958222504160,0.337892170258064,-0.168660764917267;-0.168691722823573,0.337359267403329,-0.168394795209091;-0.168425702709380,0.336827323365669,-0.168129303965165;-0.168160161195970,0.336296336214849,-0.167864290222463;-0.167895097319867,0.335766304024900,-0.167599753020089;-0.167630510119718,0.335237224874096,-0.167335691399265;-0.167366398636295,0.334709096844962,-0.167072104403329;-0.167102761912485,0.334181918024244,-0.166808991077727;-0.166839598993286,0.333655686502910,-0.166546350470012;-0.166576908925805,0.333130400376143,-0.166284181629837;-0.166314690759248,0.332606057743320,-0.166022483608949;-0.166052943544919,0.332082656708010,-0.165761255461185;-0.165791666336211,0.331560195377961,-0.165500496242466;-0.165530858188607,0.331038671865094,-0.165240205010795;-0.165270518159669,0.330518084285486,-0.164980380826249;-0.165010645309036,0.329998430759366,-0.164721022750974;-0.164751238698417,0.329479709411101,-0.164462129849183;-0.164492297391592,0.328961918369192,-0.164203701187147;-0.164233820454398,0.328445055766257,-0.163945735833194;-0.163975806954730,0.327929119739023,-0.163688232857700;-0.163718255962535,0.327414108428321,-0.163431191333089;-0.163461166549806,0.326900019979070,-0.163174610333823;-0.163204537790581,0.326386852540273,-0.162918488936402;-0.162948368760931,0.325874604265001,-0.162662826219355;-0.162692658538960,0.325363273310387,-0.162407621263237;-0.162437406204802,0.324852857837619,-0.162152873150625;-0.162182610840612,0.324343356011925,-0.161898580966111;-0.161928271530561,0.323834766002564,-0.161644743796301;-0.161674387360836,0.323327085982819,-0.161391360729804;-0.161420957419630,0.322820314129987,-0.161138430857233;-0.161167980797138,0.322314448625367,-0.160885953271197;-0.160915456585557,0.321809487654255,-0.160633927066300;-0.160663383879075,0.321305429405928,-0.160382351339129;-0.160411761773871,0.320802272073643,-0.160131225188259;-0.160164852476258,0.320308540618351,-0.159884804526949;-0.159918379686488,0.319815681892440,-0.159638819371427;-0.159672342540849,0.319323694169381,-0.159393268860307;-0.159426740177503,0.318832575726389,-0.159148152134069;-0.159181571736471,0.318342324844396,-0.158903468335049;-0.158936836359639,0.317852939808057,-0.158659216607441;-0.158692533190747,0.317364418905740,-0.158415396097287;-0.158448661375387,0.316876760429504,-0.158172005952475;-0.158205220061001,0.316389962675115,-0.157929045322737;-0.157962208396869,0.315904023942006,-0.157686513359638;-0.157719625534115,0.315418942533297,-0.157444409216580;-0.157477470625695,0.314934716755770,-0.157202732048793;-0.157235742826394,0.314451344919862,-0.156961481013329;-0.156994441292826,0.313968825339666,-0.156720655269063;-0.156753565183426,0.313487156332910,-0.156480253976684;-0.156513113658445,0.313006336220957,-0.156240276298696;-0.156273085879947,0.312526363328792,-0.156000721399405;-0.156033481011807,0.312047235985018,-0.155761588444925;-0.155794298219705,0.311568952521843,-0.155522876603168;-0.155555536671118,0.311091511275072,-0.155284585043839;-0.155317195535324,0.310614910584103,-0.155046712938436;-0.155079273983389,0.310139148791916,-0.154809259460243;-0.154841771188171,0.309664224245062,-0.154572223784326;-0.154604686324308,0.309190135293657,-0.154335605087529;-0.154368018568220,0.308716880291377,-0.154099402548471;-0.154131767098103,0.308244457595443,-0.153863615347540;-0.153895931093922,0.307772865566618,-0.153628242666890;-0.153660509737412,0.307302102569196,-0.153393283690436;-0.153425502212068,0.306832166970994,-0.153158737603853;-0.153190907703148,0.306363057143348,-0.152924603594568;-0.152956725397662,0.305894771461098,-0.152690880851756;-0.152722954484372,0.305427308302586,-0.152457568566341;-0.152489594153786,0.304960666049643,-0.152224665930986;-0.152256643598156,0.304494843087581,-0.151992172140090;-0.152024102011472,0.304029837805192,-0.151760086389788;-0.151791968589457,0.303565648594729,-0.151528407877942;-0.151560242529569,0.303102273851910,-0.151297135804141;-0.151328923030989,0.302639711975900,-0.151066269369695;-0.151098009294619,0.302177961369303,-0.150835807777629;-0.150867500523084,0.301717020438166,-0.150605750232684;-0.150637395920722,0.301256887591956,-0.150376095941307;-0.150407694693581,0.300797561243565,-0.150146844111657;-0.150178396049415,0.300339039809285,-0.149917993953583;-0.149949499197681,0.299881321708823,-0.149689544678643;-0.149721003349536,0.299424405365274,-0.149461495500080;-0.149492907717830,0.298968289205119,-0.149233845632831;-0.149265211517107,0.298512971658227,-0.149006594293518;-0.149037913963593,0.298058451157828,-0.148779740700444;-0.148811014275201,0.297604726140519,-0.148553284073588;-0.148584511671521,0.297151795046258,-0.148327223634607;-0.148358405373818,0.296699656318341,-0.148101558606822;-0.148132694605032,0.296248308403414,-0.147876288215227;-0.147907378589765,0.295797749751448,-0.147651411686473;-0.147682456554285,0.295347978815744,-0.147426928248871;-0.147457927726522,0.294898994052919,-0.147202837132389;-0.147233791336057,0.294450793922894,-0.146979137568641;-0.147010046614128,0.294003376888900,-0.146755828790892;-0.146786692793617,0.293556741417456,-0.146532910034047;-0.146563729109055,0.293110885978372,-0.146310380534654;-0.146341154796608,0.292665809044732,-0.146088239530892;-0.146118969094082,0.292221509092892,-0.145866486262574;-0.145897171240917,0.291777984602475,-0.145645119971143;-0.145675760478180,0.291335234056360,-0.145424139899662;-0.145454736048564,0.290893255940668,-0.145203545292817;-0.145234097196383,0.290452048744769,-0.144983335396910;-0.145013843167571,0.290011610961261,-0.144763509459855;-0.144793973209675,0.289571941085972,-0.144544066731178;-0.144574486571852,0.289133037617948,-0.144325006462008;-0.144355382504866,0.288694899059442,-0.144106327905075;-0.144136660261084,0.288257523915916,-0.143888030314710;-0.143918319094472,0.287820910696024,-0.143670112946836;-0.143700358260592,0.287385057911612,-0.143452575058967;-0.143482777016598,0.286949964077705,-0.143235415910204;-0.143265574621233,0.286515627712507,-0.143018634761233;-0.143048750334823,0.286082047337384,-0.142802230874319;-0.142832303419274,0.285649221476862,-0.142586203513300;-0.142616233138073,0.285217148658624,-0.142370551943591;-0.142400538756277,0.284785827413489,-0.142155275432172;-0.142185219540515,0.284355256275423,-0.141940373247591;-0.141970274758982,0.283925433781520,-0.141725844659956;-0.141755703681433,0.283496358471991,-0.141511688940932;-0.141541505579188,0.283068028890173,-0.141297905363741;-0.141327679725117,0.282640443582505,-0.141084493203154;-0.141114225393644,0.282213601098530,-0.140871451735489;-0.140901141860743,0.281787499990885,-0.140658780238609;-0.140688428403928,0.281362138815294,-0.140446477991914;-0.140476084302261,0.280937516130563,-0.140234544276345;-0.140264108836337,0.280513630498571,-0.140022978374373;-0.140052501288284,0.280090480484261,-0.139811779569999;-0.139841260941765,0.279668064655636,-0.139600947148748;-0.139630387081968,0.279246381583754,-0.139390480397673;-0.139419878995603,0.278825429842713,-0.139180378605339;-0.139209735970903,0.278405208009652,-0.138970641061832;-0.138999957297614,0.277985714664741,-0.138761267058746;-0.138790542267001,0.277566948391174,-0.138552255889186;-0.138581490171829,0.277148907775160,-0.138343606847760;-0.138372800306380,0.276731591405922,-0.138135319230580;-0.138164471966430,0.276314997875682,-0.137927392335253;-0.137956504449260,0.275899125779660,-0.137719825460884;-0.137748897053642,0.275483973716066,-0.137512617908064;-0.137541649079843,0.275069540286093,-0.137305768978878;-0.137334759829620,0.274655824093907,-0.137099277976891;-0.137128228606213,0.274242823746647,-0.136893144207151;-0.136922054714345,0.273830537854410,-0.136687366976183;-0.136716237460217,0.273418965030251,-0.136481945591986;-0.136510776151506,0.273008103890170,-0.136276879364027;-0.136305670097361,0.272597953053112,-0.136072167603246;-0.136100918608398,0.272188511140955,-0.135867809622042;-0.135896520996699,0.271779776778507,-0.135663804734278;-0.135692476575809,0.271371748593497,-0.135460152255273;-0.135488784660728,0.270964425216564,-0.135256851501797;-0.135285444567916,0.270557805281265,-0.135053901792077;-0.135082455615279,0.270151887424046,-0.134851302445780;-0.134879817122177,0.269746670284259,-0.134649052784025;-0.134677528409409,0.269342152504137,-0.134447152129363;-0.134475588799220,0.268938332728796,-0.134245599805788;-0.134273997615293,0.268535209606227,-0.134044395138727;-0.134072754182744,0.268132781787292,-0.133843537455036;-0.133871857828123,0.267731047925711,-0.133643026083002;-0.133671307879406,0.267330006678059,-0.133442860352332;-0.133471103665998,0.266929656703761,-0.133243039594156;-0.133271244518722,0.266529996665086,-0.133043563141022;-0.133071729769823,0.266131025227136,-0.132844430326892;-0.132872558752958,0.265732741057839,-0.132645640487138;-0.132673730803200,0.265335142827954,-0.132447192958544;-0.132475245257029,0.264938229211048,-0.132249087079293;-0.132277101452329,0.264541998883500,-0.132051322188972;-0.132079298728390,0.264146450524494,-0.131853897628569;-0.131881836425900,0.263751582816010,-0.131656812740464;-0.131684713886943,0.263357394442820,-0.131460066868430;-0.131487930454995,0.262963884092474,-0.131263659357627;-0.131291485474922,0.262571050455305,-0.131067589554603;-0.131095378292979,0.262178892224417,-0.130871856807288;-0.130899608256801,0.261787408095678,-0.130676460464990;-0.130704174715407,0.261396596767714,-0.130481399878394;-0.130509077019188,0.261006456941903,-0.130286674399557;-0.130314314519912,0.260616987322370,-0.130092283381907;-0.130119886570720,0.260228186615982,-0.129898226180238;-0.129925792526117,0.259840053532334,-0.129704502150708;-0.129732031741974,0.259452586783756,-0.129511110650837;-0.129538603575522,0.259065785085288,-0.129318051039496;-0.129345507385354,0.258679647154696,-0.129125322676919;-0.129152742531413,0.258294171712449,-0.128932924924685;-0.128960308374998,0.257909357481717,-0.128740857145723;-0.128768204278756,0.257525203188371,-0.128549118704307;-0.128576429606679,0.257141707560969,-0.128357708966052;-0.128384983724104,0.256758869330753,-0.128166627297915;-0.128193865997706,0.256376687231645,-0.127975873068185;-0.128003075795496,0.255995160000235,-0.127785445646485;-0.127812612486821,0.255614286375782,-0.127595344403768;-0.127622475442357,0.255234065100204,-0.127405568712314;-0.127432664034109,0.254854494918071,-0.127216117945727;-0.127243177635406,0.254475574576602,-0.127026991478930;-0.127054015620897,0.254097302825656,-0.126838188688165;-0.126865177366553,0.253719678417731,-0.126649708950989;-0.126676662249656,0.253342700107947,-0.126461551646268;-0.126488469648805,0.252966366654056,-0.126273716154181;-0.126300598943906,0.252590676816421,-0.126086201856207;-0.126113049516171,0.252215629358019,-0.125899008135134;-0.125925820748119,0.251841223044436,-0.125712134375045;-0.125738912023567,0.251467456643848,-0.125525579961321;-0.125552322727629,0.251094328927036,-0.125339344280640;-0.125366052246716,0.250721838667362,-0.125153426720965;-0.125180099968529,0.250349984640771,-0.124967826671552;-0.124994465282060,0.249978765625785,-0.124782543522939;-0.124809147577584,0.249608180403495,-0.124597576666948;-0.124624146246662,0.249238227757560,-0.124412925496681;-0.124439460682132,0.248868906474189,-0.124228589406511;-0.124255090278110,0.248500215342152,-0.124044567792090;-0.124071034429990,0.248132153152764,-0.123860860050340;-0.123887292534433,0.247764718699881,-0.123677465579448;-0.123703863989369,0.247397910779889,-0.123494383778866;-0.123520748193994,0.247031728191711,-0.123311614049309;-0.123337944548770,0.246666169736792,-0.123129155792752;-0.123155452455414,0.246301234219093,-0.122947008412425;-0.122973271316900,0.245936920445084,-0.122765171312808;-0.122791400537463,0.245573227223753,-0.122583643899639;-0.122609839522580,0.245210153366576,-0.122402425579895;-0.122428587678983,0.244847697687534,-0.122221515761805;-0.122247644414648,0.244485859003094,-0.122040913854837;-0.122067009138791,0.244124636132201,-0.121860619269694;-0.121886681261873,0.243764027896292,-0.121680631418324;-0.121706660195587,0.243404033119263,-0.121500949713901;-0.121526945352863,0.243044650627484,-0.121321573570833;-0.121347536147864,0.242685879249788,-0.121142502404756;-0.121168431995979,0.242327717817461,-0.120963735632530;-0.120989632313823,0.241970165164237,-0.120785272672238;-0.120811136519238,0.241613220126301,-0.120607112943184;-0.120632944031282,0.241256881542272,-0.120429255865885;-0.120455054270231,0.240901148253205,-0.120251700862076;-0.120277466657579,0.240546019102583,-0.120074447354701;-0.120100180616030,0.240191492936313,-0.119897494767914;-0.119923195569498,0.239837568602716,-0.119720842527073;-0.119746510943102,0.239484244952527,-0.119544490058741;-0.119570126163168,0.239131520838889,-0.119368436790682;-0.119394040657220,0.238779395117341,-0.119192682151854;-0.119218253853984,0.238427866645824,-0.119017225572415;-0.119042765183377,0.238076934284662,-0.118842066483710;-0.118867574076515,0.237726596896571,-0.118667204318278;-0.118692679965700,0.237376853346640,-0.118492638509843;-0.118518082284422,0.237027702502334,-0.118318368493312;-0.118343780467359,0.236679143233488,-0.118144393704777;-0.118169773950367,0.236331174412299,-0.117970713581505;-0.117996062170484,0.235983794913318,-0.117797327561940;-0.117822644565928,0.235637003613460,-0.117624235085704;-0.117649520576084,0.235290799391971,-0.117451435593582;-0.117476689641515,0.234945181130452,-0.117278928527534;-0.117304151203951,0.234600147712835,-0.117106713330684;-0.117131904706288,0.234255698025383,-0.116934789447316;-0.116959949592586,0.233911830956688,-0.116763156322878;-0.116788285308065,0.233568545397658,-0.116591813403973;-0.116616911299106,0.233225840241522,-0.116420760138361;-0.116445827013244,0.232883714383817,-0.116249995974954;-0.116275031899168,0.232542166722382,-0.116079520363814;-0.116104525406717,0.232201196157360,-0.115909332756148;-0.115934306986878,0.231860801591189,-0.115739432604312;-0.115764376091786,0.231520981928595,-0.115569819361802;-0.115594732174714,0.231181736076585,-0.115400492483252;-0.115425374690081,0.230843062944454,-0.115231451424436;-0.115256303093439,0.230504961443760,-0.115062695642260;-0.115087516841477,0.230167430488338,-0.114894224594763;-0.114919015392019,0.229830468994287,-0.114726037741114;-0.114750798204014,0.229494075879960,-0.114558134541607;-0.114582864737544,0.229158250065966,-0.114390514457661;-0.114415214453811,0.228822990475162,-0.114223176951818;-0.114247846815143,0.228488296032651,-0.114056121487739;-0.114080761284986,0.228154165665770,-0.113889347530198;-0.113913957327905,0.227820598304094,-0.113722854545088;-0.113747434409579,0.227487592879423,-0.113556641999412;-0.113581191996800,0.227155148325785,-0.113390709361281;-0.113415229557467,0.226823263579417,-0.113225056099914;-0.113249546560590,0.226491937578782,-0.113059681685633;-0.113084142476283,0.226161169264541,-0.112894585589863;-0.112919016775763,0.225830957579567,-0.112729767285128;-0.112754168931343,0.225501301468921,-0.112565226245047;-0.112589598416439,0.225172199879867,-0.112400961944336;-0.112425304705558,0.224843651761855,-0.112236973858801;-0.112261287274300,0.224515656066515,-0.112073261465338;-0.112097545599358,0.224188211747661,-0.111909824241930;-0.111934079158509,0.223861317761278,-0.111746661667643;-0.111770887430618,0.223534973065521,-0.111583773222628;-0.111607969895630,0.223209176620708,-0.111421158388113;-0.111445326034572,0.222883927389317,-0.111258816646403;-0.111282955329550,0.222559224335982,-0.111096747480881;-0.111120857263745,0.222235066427486,-0.110934950376001;-0.110959031321406,0.221911452632752,-0.110773424817283;-0.110797476987860,0.221588381922851,-0.110612170291319;-0.110636193749498,0.221265853270982,-0.110451186285766;-0.110475181093778,0.220943865652480,-0.110290472289342;-0.110314438509222,0.220622418044802,-0.110130027791826;-0.110142296689648,0.220278170337599,-0.109958200719900;-0.109970454337965,0.219934521439410,-0.109786672501200;-0.109798910868430,0.219591470179148,-0.109615442551345;-0.109627665696564,0.219249015388257,-0.109444510287217;-0.109456718239152,0.218907155900705,-0.109273875126955;-0.109286067914232,0.218565890552968,-0.109103536489952;-0.109115714141105,0.218225218184043,-0.108933493796859;-0.108945656340317,0.217885137635420,-0.108763746469568;-0.108775893933671,0.217545647751096,-0.108594293931224;-0.108606426344212,0.217206747377555,-0.108425135606213;-0.108437252996229,0.216868435363770,-0.108256270920160;-0.108268373315256,0.216530710561196,-0.108087699299933;-0.108099786728058,0.216193571823755,-0.107919420173627;-0.107931492662642,0.215857018007848,-0.107751432970576;-0.107763490548243,0.215521047972333,-0.107583737121339;-0.107595779815328,0.215185660578528,-0.107416332057702;-0.107428359895587,0.214850854690201,-0.107249217212672;-0.107261230221936,0.214516629173563,-0.107082392020480;-0.107094390228511,0.214182982897273,-0.106915855916574;-0.106927839350666,0.213849914732416,-0.106749608337612;-0.106761577024968,0.213517423552512,-0.106583648721470;-0.106595602689199,0.213185508233496,-0.106417976507227;-0.106429915782349,0.212854167653731,-0.106252591135172;-0.106264515744612,0.212523400693981,-0.106087492046796;-0.106099402017390,0.212193206237422,-0.105922678684790;-0.105934574043280,0.211863583169628,-0.105758150493042;-0.105770031266083,0.211534530378567,-0.105593906916636;-0.105605773130789,0.211206046754596,-0.105429947401846;-0.105441799083585,0.210878131190459,-0.105266271396138;-0.105278108571846,0.210550782581273,-0.105102878348162;-0.105114701044132,0.210223999824530,-0.104939767707752;-0.104951575950189,0.209897781820086,-0.104776938925923;-0.104788732740943,0.209572127470160,-0.104614391454869;-0.104626170868497,0.209247035679325,-0.104452124747955;-0.104463889786133,0.208922505354507,-0.104290138259725;-0.104301888948301,0.208598535404969,-0.104128431445887;-0.104140167810628,0.208275124742326,-0.103967003763320;-0.103978725829900,0.207952272280513,-0.103805854670064;-0.103817562464073,0.207629976935800,-0.103644983625323;-0.103656677172265,0.207308237626779,-0.103484390089458;-0.103496069414749,0.206987053274357,-0.103324073523988;-0.103335738652960,0.206666422801758,-0.103164033391585;-0.103175684349479,0.206346345134500,-0.103004269156067;-0.103015905968048,0.206026819200419,-0.102844780282409;-0.102856402973548,0.205707843929632,-0.102685566236723;-0.102697174832011,0.205389418254555,-0.102526626486268;-0.102538221010610,0.205071541109882,-0.102367960499441;-0.102379540977661,0.204754211432596,-0.102209567745780;-0.102221134202612,0.204437428161941,-0.102051447695950;-0.102063000156051,0.204121190239442,-0.101893599821757;-0.101905138309696,0.203805496608880,-0.101736023596130;-0.101747548136395,0.203490346216297,-0.101578718493127;-0.101590229110124,0.203175738009988,-0.101421683987931;-0.101433180705983,0.202861670940497,-0.101264919556845;-0.101276402400191,0.202548143960604,-0.101108424677289;-0.101119893670090,0.202235156025334,-0.100952198827804;-0.100963653994137,0.201922706091941,-0.100796241488041;-0.100807682851903,0.201610793119907,-0.100640552138763;-0.100651979724069,0.201299416070928,-0.100485130261841;-0.100496544092427,0.200988573908929,-0.100329975340253;-0.100341375439873,0.200678265600036,-0.100175086858079;-0.100186473250409,0.200368490112589,-0.100020464300501;-0.100031837009134,0.200059246417119,-0.0998661071537970;-0.0998774662022505,0.199750533486362,-0.0997120149053429;-0.0997233603170532,0.199442350295241,-0.0995581870436068;-0.0995695188419310,0.199134695820864,-0.0994046230581463;-0.0994159412663651,0.198827569042523,-0.0992513224396092;-0.0992626270809210,0.198520968941677,-0.0990982846797249;-0.0991095757772548,0.198214894501968,-0.0989455092713102;-0.0989567868481022,0.197909344709191,-0.0987929957082590;-0.0988042597872803,0.197604318551307,-0.0986407434855434;-0.0986519940896869,0.197299815018437,-0.0984887520992140;-0.0984999892512911,0.196995833102842,-0.0983370210463893;-0.0983482447691384,0.196692371798936,-0.0981855498252619;-0.0981967601413426,0.196389430103267,-0.0980343379350899;-0.0980455348670881,0.196087007014525,-0.0978833848761989;-0.0978945684466238,0.195785101533528,-0.0977326901499765;-0.0977438603812607,0.195483712663216,-0.0975822532588698;-0.0975934101733711,0.195182839408651,-0.0974320737063841;-0.0974432173263877,0.194882480777016,-0.0972821509970827;-0.0972932813447953,0.194582635777596,-0.0971324846365780;-0.0971436017341345,0.194283303421786,-0.0969830741315357;-0.0969941780009975,0.193984482723084,-0.0968339189896702;-0.0968450096530209,0.193686172697077,-0.0966850187197379;-0.0966960961988924,0.193388372361452,-0.0965363728315434;-0.0965474371483397,0.193091080735976,-0.0963879808359286;-0.0963990320121333,0.192794296842497,-0.0962398422447754;-0.0962508803020820,0.192498019704944,-0.0960919565710016;-0.0961029815310298,0.192202248349313,-0.0959443233285576;-0.0959553352128579,0.191906981803672,-0.0957969420324279;-0.0958079408624751,0.191612219098146,-0.0956498121986223;-0.0956607979958227,0.191317959264922,-0.0955029333441804;-0.0955139061298656,0.191024201338233,-0.0953563049871627;-0.0953672647825954,0.190730944354368,-0.0952099266466538;-0.0952208734730256,0.190438187351654,-0.0950637978427576;-0.0950747317211886,0.190145929370458,-0.0949179180965942;-0.0949288390481336,0.189854169453178,-0.0947722869302980;-0.0947831949759265,0.189562906644247,-0.0946269038670175;-0.0946377990276436,0.189272139990115,-0.0944817684309088;-0.0944926507273732,0.188981868539257,-0.0943368801471377;-0.0943477496002107,0.188692091342160,-0.0941922385418742;-0.0942030951722568,0.188402807451321,-0.0940478431422914;-0.0940586869706170,0.188114015921246,-0.0939036934765642;-0.0939145245233957,0.187825715808438,-0.0937597890738643;-0.0937706073596973,0.187537906171399,-0.0936161294643605;-0.0936269350096210,0.187250586070619,-0.0934727141792140;-0.0934835070042631,0.186963754568583,-0.0933295427505804;-0.0933403228757074,0.186677410729749,-0.0931866147116006;-0.0931973821570307,0.186391553620558,-0.0930439295964055;-0.0930546843822951,0.186106182309425,-0.0929014869401092;-0.0929122290865478,0.185821295866732,-0.0927592862788081;-0.0927700158058192,0.185536893364825,-0.0926173271495795;-0.0926280440771196,0.185252973878012,-0.0924756090904780;-0.0924863134384371,0.184969536482554,-0.0923341316405334;-0.0923448234287364,0.184686580256664,-0.0921928943397498;-0.0922035735879544,0.184404104280499,-0.0920518967291008;-0.0920625634570009,0.184122107636163,-0.0919111383505307;-0.0919217925777537,0.183840589407690,-0.0917706187469491;-0.0917812604930577,0.183559548681053,-0.0916303374622303;-0.0916409667467230,0.183278984544151,-0.0914902940412113;-0.0915009108835207,0.182998896086806,-0.0913504880296880;-0.0913610924491836,0.182719282400760,-0.0912109189744148;-0.0912215109904017,0.182440142579672,-0.0910715864231017;-0.0910821660548206,0.182161475719108,-0.0909324899244112;-0.0909430571910401,0.181883280916545,-0.0907936290279580;-0.0908041839486104,0.181605557271357,-0.0906550032843047;-0.0906655458780321,0.181328303884818,-0.0905166122449616;-0.0905271425307516,0.181051519860096,-0.0903784554623829;-0.0903889734591608,0.180775204302245,-0.0902405324899654;-0.0902510382165946,0.180499356318208,-0.0901028428820467;-0.0901133363573267,0.180223975016801,-0.0899653861939010;-0.0899758674365714,0.179949059508723,-0.0898281619817405;-0.0898386310104776,0.179674608906540,-0.0896911698027093;-0.0897016266361282,0.179400622324688,-0.0895544092148841;-0.0895648538715394,0.179127098879464,-0.0894178797772715;-0.0894283122756548,0.178854037689023,-0.0892815810498037;-0.0892920014083481,0.178581437873376,-0.0891455125933405;-0.0891559208304163,0.178309298554385,-0.0890096739696627;-0.0890200701035811,0.178037618855754,-0.0888740647414734;-0.0888844487904851,0.177766397903033,-0.0887386844723944;-0.0887490564546893,0.177495634823606,-0.0886035327269633;-0.0886138926606730,0.177225328746692,-0.0884686090706339;-0.0884789569738290,0.176955478803339,-0.0883339130697712;-0.0883442489604637,0.176686084126418,-0.0881994442916514;-0.0882097681877942,0.176417143850624,-0.0880652023044591;-0.0880755142239458,0.176148657112464,-0.0879311866772848;-0.0879414866379508,0.175880623050260,-0.0877973969801235;-0.0878076849997453,0.175613040804143,-0.0876638327838725;-0.0876741088801685,0.175345909516045,-0.0875304936603288;-0.0875407578509596,0.175079228329700,-0.0873973791821879;-0.0874076314847556,0.174812996390637,-0.0872644889230408;-0.0872747293550905,0.174547212846176,-0.0871318224573727;-0.0871420510363919,0.174281876845427,-0.0869993793605607;-0.0870095961039796,0.174016987539280,-0.0868671592088715;-0.0868773641340638,0.173752544080407,-0.0867351615794603;-0.0867453547037419,0.173488545623253,-0.0866033860503668;-0.0866135673909982,0.173224991324036,-0.0864718322005160;-0.0864820017747004,0.172961880340741,-0.0863404996097132;-0.0863506574345982,0.172699211833115,-0.0862093878586443;-0.0862195339513215,0.172436984962664,-0.0860784965288728;-0.0860886309063776,0.172175198892651,-0.0859478252028374;-0.0859579478821506,0.171913852788089,-0.0858173734638515;-0.0858274844618974,0.171652945815737,-0.0856871408960989;-0.0856972402297476,0.171392477144098,-0.0855571270846341;-0.0855672147707003,0.171132445943414,-0.0854273316153789;-0.0854374076706224,0.170872851385661,-0.0852977540751206;-0.0853078185162479,0.170613692644551,-0.0851683940515116;-0.0851784468951731,0.170354968895515,-0.0850392511330642;-0.0850492923958574,0.170096679315714,-0.0849103249091517;-0.0849203546076200,0.169838823084026,-0.0847816149700054;-0.0847916331206377,0.169581399381044,-0.0846531209067114;-0.0846631275259447,0.169324407389074,-0.0845248423112115;-0.0845348374154277,0.169067846292126,-0.0843967787762978;-0.0844067623818265,0.168811715275919,-0.0842689298956133;-0.0842789020187316,0.168556013527868,-0.0841412952636495;-0.0841512559205805,0.168300740237083,-0.0840138744757428;-0.0840238236826590,0.168045894594372,-0.0838866671280759;-0.0838966049010954,0.167791475792225,-0.0837596728176719;-0.0837695991728617,0.167537483024818,-0.0836328911423953;-0.0836428060957705,0.167283915488010,-0.0835063217009491;-0.0835162252684727,0.167030772379334,-0.0833799640928727;-0.0833898562904568,0.166778052897997,-0.0832538179185408;-0.0832636987620448,0.166525756244876,-0.0831278827791597;-0.0831377522843929,0.166273881622510,-0.0830021582767677;-0.0830120164594883,0.166022428235104,-0.0828766440142320;-0.0828864908901466,0.165771395288518,-0.0827513395952463;-0.0827611751800124,0.165520781990266,-0.0826262446243307;-0.0826360689335537,0.165270587549514,-0.0825013587068275;-0.0825111717560633,0.165020811177071,-0.0823766814489011;-0.0823864832536559,0.164771452085394,-0.0822522124575358;-0.0822620030332647,0.164522509488573,-0.0821279513405327;-0.0821377307026431,0.164273982602338,-0.0820038977065106;-0.0820136658703587,0.164025870644048,-0.0818800511649008;-0.0818898081457935,0.163778172832691,-0.0817564113259470;-0.0817661571391433,0.163530888388879,-0.0816329778007042;-0.0816427124614129,0.163284016534844,-0.0815097502010351;-0.0815194737244173,0.163037556494435,-0.0813867281396099;-0.0813964405407770,0.162791507493114,-0.0812639112299027;-0.0812736125239185,0.162545868757952,-0.0811412990861915;-0.0811509892880714,0.162300639517629,-0.0810188913235554;-0.0810285704482661,0.162055819002422,-0.0808966875578723;-0.0809063556203338,0.161811406444210,-0.0807746874058188;-0.0807843444209024,0.161567401076467,-0.0806528904848664;-0.0806625364673961,0.161323802134255,-0.0805312964132807;-0.0805409313780338,0.161080608854230,-0.0804099048101203;-0.0804195287718258,0.160837820474625,-0.0802887152952329;-0.0802983282685742,0.160595436235258,-0.0801677274892565;-0.0801773294888689,0.160353455377522,-0.0800469410136145;-0.0800565320540871,0.160111877144385,-0.0799263554905157;-0.0799359355863917,0.159870700780384,-0.0798059705429528;-0.0798155397087279,0.159629925531621,-0.0796857857946990;-0.0796953440448245,0.159389550645763,-0.0795658008703087;-0.0795753482191881,0.159149575372035,-0.0794460153951126;-0.0794555518571050,0.158909998961217,-0.0793264289952189;-0.0793359545846371,0.158670820665642,-0.0792070412975097;-0.0792165560286209,0.158432039739191,-0.0790878519296395;-0.0790973558166666,0.158193655437292,-0.0789688605200348;-0.0789783535771546,0.157955667016913,-0.0788500666978904;-0.0788595489392353,0.157718073736560,-0.0787314700931690;-0.0787409415328264,0.157480874856273,-0.0786130703365989;-0.0786225309886114,0.157244069637625,-0.0784948670596720;-0.0785043169380388,0.157007657343717,-0.0783768598946439;-0.0783862990133186,0.156771637239173,-0.0782590484745293;-0.0782684768474223,0.156536008590138,-0.0781414324331025;-0.0781508500740801,0.156300770664275,-0.0780240114048949;-0.0780334183277789,0.156065922730759,-0.0779067850251927;-0.0779161812437626,0.155831464060279,-0.0777897529300371;-0.0777991384580280,0.155597393925029,-0.0776729147562202;-0.0776822896073242,0.155363711598708,-0.0775562701412848;-0.0775656343291512,0.155130416356514,-0.0774398187235229;-0.0774491722617570,0.154897507475141,-0.0773235601419721;-0.0773329030441381,0.154664984232782,-0.0772074940364172;-0.0772168263160351,0.154432845909113,-0.0770916200473849;-0.0771009417179331,0.154201091785303,-0.0769759378161448;-0.0769852488910593,0.153969721144001,-0.0768604469847065;-0.0768697474773805,0.153738733269337,-0.0767451471958178;-0.0767544371196036,0.153508127446919,-0.0766300380929643;-0.0766393174611713,0.153277902963828,-0.0765151193203660;-0.0765243881462626,0.153048059108614,-0.0764003905229770;-0.0764096488197900,0.152818595171296,-0.0762858513464833;-0.0762950991273978,0.152589510443354,-0.0761715014373010;-0.0761807387154613,0.152360804217733,-0.0760573404425754;-0.0760665672310843,0.152132475788829,-0.0759433680101780;-0.0759525843220979,0.151904524452497,-0.0758295837887066;-0.0758387896370591,0.151676949506039,-0.0757159874274825;-0.0757251828252477,0.151449750248207,-0.0756025785765483;-0.0756117635366672,0.151222925979194,-0.0754893568866685;-0.0754985314220409,0.150996476000637,-0.0753763220093255;-0.0753854861328115,0.150770399615608,-0.0752634735967195;-0.0752726273211394,0.150544696128616,-0.0751508113017666;-0.0751509273928008,0.150301309192202,-0.0750293208617630;-0.0750294346128490,0.150058336498600,-0.0749080371801987;-0.0749081485855577,0.149815777256536,-0.0747869598621717;-0.0747870689160384,0.149573630676411,-0.0746660885136159;-0.0746661952102378,0.149331895970297,-0.0745454227412984;-0.0745455270749342,0.149090572351928,-0.0744249621528159;-0.0744250641177389,0.148849659036703,-0.0743047063565964;-0.0743048059470907,0.148609155241675,-0.0741846549618933;-0.0741847521722564,0.148369060185556,-0.0740648075787864;-0.0740649024033285,0.148129373088704,-0.0739451638181788;-0.0739452562512218,0.147890093173123,-0.0738257232917944;-0.0738258133276739,0.147651219662464,-0.0737064856121780;-0.0737065732452409,0.147412751782011,-0.0735874503926907;-0.0735875356172973,0.147174688758687,-0.0734686172475103;-0.0734687000580332,0.146937029821044,-0.0733499857916286;-0.0733500661824527,0.146699774199263,-0.0732315556408491;-0.0732316336063719,0.146462921125147,-0.0731133264117855;-0.0731134019464167,0.146226469832119,-0.0729952977218599;-0.0729953708200221,0.145990419555219,-0.0728774691893009;-0.0728775398454289,0.145754769531099,-0.0727598404331415;-0.0727599086416826,0.145519518998018,-0.0726424110732177;-0.0726424768286317,0.145284667195843,-0.0725251807301663;-0.0725252440269250,0.145050213366039,-0.0724081490254227;-0.0724082098580106,0.144816156751671,-0.0722913155812198;-0.0722913739441344,0.144582496597396,-0.0721746800205863;-0.0721747359083363,0.144349232149462,-0.0720582419673434;-0.0720582953744509,0.144116362655704,-0.0719420010461049;-0.0719420519671036,0.143883887365538,-0.0718259568822737;-0.0718260053117102,0.143651805529962,-0.0717101091020412;-0.0717101550344742,0.143420116401546,-0.0715944573323848;-0.0715945007623853,0.143188819234434,-0.0714790012010663;-0.0714790421232181,0.142957913284338,-0.0713637403366305;-0.0713637787455289,0.142727397808536,-0.0712486743684022;-0.0712487102586551,0.142497272065863,-0.0711338029264854;-0.0711338362927138,0.142267535316716,-0.0710191256417622;-0.0710191564785980,0.142038186823042,-0.0709046421458886;-0.0709046704479773,0.141809225848342,-0.0707903520712956;-0.0707903778332938,0.141580651657661,-0.0706762550511849;-0.0706762782677623,0.141352463517588,-0.0705623507195291;-0.0705623713853674,0.141124660696251,-0.0704486387110686;-0.0704486568208614,0.140897242463315,-0.0703351186613105;-0.0703351342097643,0.140670208089978,-0.0702217902065268;-0.0702218031883595,0.140443556848965,-0.0701086529837520;-0.0701086633936944,0.140217288014528,-0.0699957066307823;-0.0699957144635770,0.139991400862439,-0.0698829507861732;-0.0698829560365749,0.139765894669992,-0.0697703850892379;-0.0697703877520143,0.139540768715994,-0.0696580091800462;-0.0696580092499757,0.139316022280762,-0.0695458226994210;-0.0695458201712954,0.139091654646124,-0.0694338252889387;-0.0694338201575616,0.138867665095410,-0.0693220165909264;-0.0693220088511130,0.138644052913453,-0.0692103962484595;-0.0692103858950383,0.138420817386582,-0.0690989639053622;-0.0690989509331725,0.138197957802622,-0.0689877192062029;-0.0689877036100967,0.137975473450887,-0.0688766617962946;-0.0688766435711364,0.137753363622181,-0.0687657913216929;-0.0687657704623581,0.137531627608788,-0.0686551074291928;-0.0686550839305705,0.137310264704477,-0.0685446097663297;-0.0685445836233194,0.137089274204490,-0.0684342979813746;-0.0684342691888890,0.136868655405546,-0.0683241717233350;-0.0683241402762984,0.136648407605833,-0.0682142306419518;-0.0682141965353003,0.136428530105005,-0.0681044743876978;-0.0681044376163803,0.136209022204184,-0.0679949026117768;-0.0679948631707532,0.135989883205947,-0.0678855149661205;-0.0678854728503634,0.135771112414330,-0.0677763111033883;-0.0677762663078824,0.135552709134825,-0.0676672906769650;-0.0676672431967060,0.135334672674370,-0.0675584533409585;-0.0675584031709552,0.135117002341353,-0.0674497987501997;-0.0674497458854723,0.134899697445606,-0.0673413265602395;-0.0673412709958199,0.134682757298399,-0.0672330364273471;-0.0672329781582799,0.134466181212441,-0.0671249280085099;-0.0671248670298506,0.134249968501874,-0.0670170009614296;-0.0670169372682470,0.134034118482271,-0.0669092549445233;-0.0669091885318965,0.133818630470633,-0.0668016896169185;-0.0668016204799396,0.133603503785382,-0.0666943046384548;-0.0666942327722275,0.133388737746365,-0.0665870996696802;-0.0665870250693197,0.133174331674843,-0.0664800743718498;-0.0664799970324839,0.132960284893493,-0.0663732284069253;-0.0663731483236930,0.132746596726403,-0.0662665614375716;-0.0662664786056239,0.132533266499069,-0.0661600731271566;-0.0661599875416565,0.132320293538389,-0.0660537631397492;-0.0660536747958712,0.132107677172667,-0.0659476311401173;-0.0659475400330483,0.131895416731601,-0.0658416767937272;-0.0658415829186653,0.131683511546287,-0.0657358997667407;-0.0657358031188956,0.131471960949211,-0.0656302997260140;-0.0656302003006084,0.131260764274248,-0.0655248763390974;-0.0655247741313640,0.131049920856659,-0.0654196292742310;-0.0654195242794159,0.130839430033087,-0.0653145582003463;-0.0653144504137064,0.130629291141556,-0.0652096627870621;-0.0652095522038660,0.130419503521461,-0.0651049427046839;-0.0651048293202125,0.130210066513577,-0.0650003976242028;-0.0650002814337481,0.130000979460042,-0.0648960272172930;-0.0648959082161594,0.129792241704366,-0.0647918311563112;-0.0647917093398140,0.129583852591419,-0.0646878091142940;-0.0646876844777608,0.129375811467433,-0.0645839607649574;-0.0645838333037270,0.129168117679998,-0.0644802857826943;-0.0644801554921173,0.128960770578057,-0.0643767838425736;-0.0643766507180127,0.128753769511904,-0.0642734546203388;-0.0642733186571676,0.128547113833183,-0.0641702977924058;-0.0641701589860102,0.128340802894881,-0.0640673130358619;-0.0640671713816389,0.128134836051328,-0.0639645000284639;-0.0639643555218220,0.127929212658192,-0.0638618584486365;-0.0638617110849967,0.127723932072480,-0.0637593879754722;-0.0637592377502660,0.127518993652528,-0.0636570882887274;-0.0636569351973986,0.127314396758004,-0.0635549590688228;-0.0635548031068264,0.127110140749901,-0.0634529999968409;-0.0634528411596436,0.126906224990539,-0.0633512107545251;-0.0633510490376051,0.126702648843557,-0.0632495910242778;-0.0632494264231247,0.126499411673910,-0.0631481404891589;-0.0631479729992742,0.126296512847871,-0.0630468588328848;-0.0630466884497811,0.126093951733023,-0.0629457457398262;-0.0629455724590274,0.125891727698258,-0.0628448008950069;-0.0628446247120492,0.125689840113776,-0.0627440239841029;-0.0627438448945333,0.125488288351076,-0.0626434146934399;-0.0626432326928173,0.125287071782961,-0.0625429727099927;-0.0625427877938870,0.125086189783529,-0.0624426977213830;-0.0624425098853754,0.124885641728170,-0.0623425894158782;-0.0623423986555624,0.124685426993571,-0.0622426474823910;-0.0622424537933708,0.124485544957702,-0.0621428716104757;-0.0621426749883673,0.124285994999821,-0.0620432614903290;-0.0620430619307595,0.124086776500467,-0.0619438168127871;-0.0619436143113948,0.123887888841458,-0.0618445372693245;-0.0618443318217600,0.123689331405892,-0.0617454225520537;-0.0617452141539777,0.123491103578138,-0.0616464723537217;-0.0616462610008071,0.123293204743835,-0.0615476863677103;-0.0615474720556416,0.123095634289893,-0.0614490642880346;-0.0614488470125062,0.122898391604485,-0.0613506058093394;-0.0613503855660589,0.122701476077047,-0.0612523106269014;-0.0612520874115863,0.122504887098273,-0.0611541784366243;-0.0611539522450042,0.122308624060116,-0.0610562089350396;-0.0610559797628550,0.122112686355782,-0.0609584018193044;-0.0609581696623068,0.121917073379726,-0.0608607567871993;-0.0608605216411525,0.121721784527653,-0.0607632735371291;-0.0607630353978069,0.121526819196513,-0.0606659517681186;-0.0606657106313068,0.121332176784498,-0.0605687911798135;-0.0605685470413093,0.121137856691041,-0.0604717914724782;-0.0604715443280890,0.120943858316808,-0.0603749523469932;-0.0603747021925390,0.120750181063704,-0.0602782735048565;-0.0602780203361673,0.120556824334863,-0.0601817546481791;-0.0601814984610968,0.120363787534646,-0.0600853954796860;-0.0600851362700635,0.120171070068643,-0.0599891957027134;-0.0599889334664146,0.119978671343664,-0.0598931550212078;-0.0598928897541080,0.119786590767741,-0.0597972731397249;-0.0597970048377103,0.119594827750122,-0.0597015497634275;-0.0597012784223958,0.119403381701272,-0.0596059845980853;-0.0596057102139450,0.119212252032866,-0.0595105773500723;-0.0595102999187429,0.119021438157789,-0.0594153277263658;-0.0594150472437783,0.118830939490132,-0.0593202354345456;-0.0593199518966419,0.118640755445190,-0.0592253001827921;-0.0592250135855252,0.118450885439460,-0.0591305216798852;-0.0591302320192192,0.118261328890637,-0.0590358996352027;-0.0590356069071124,0.118072085217610,-0.0589414337587189;-0.0589411379591906,0.117883153840463,-0.0588471237610039;-0.0588468248860348,0.117694534180471,-0.0587529693532216;-0.0587526673988199,0.117506225660094,-0.0586589702471285;-0.0586586652093133,0.117318227702979,-0.0585651261550726;-0.0585648180298742,0.117130539733955,-0.0584714367899919;-0.0584711255734515,0.116943161179030,-0.0583779018654130;-0.0583775875535829,0.116756091465390,-0.0582845210954500;-0.0582842036843929,0.116569330021394,-0.0581912941948027;-0.0581909736805933,0.116382876276575,-0.0580982208787565;-0.0580978972574795,0.116196729661632,-0.0580053008631793;-0.0580049741309307,0.116010889608434,-0.0579125338645214;-0.0579122040174081,0.115825355550010,-0.0578199195998142;-0.0578195866339540,0.115640126920554,-0.0577274577866682;-0.0577271216981901,0.115455203155417,-0.0576351481432728;-0.0576348089283158,0.115270583691105,-0.0575429903883931;-0.0575426480431083,0.115086267965279,-0.0574509842413712;-0.0574506387619195,0.114902255416751,-0.0573591294221224;-0.0573587808046761,0.114718545485479,-0.0572674256511357;-0.0572670738918780,0.114535137612571,-0.0571758726494718;-0.0571755177445963,0.114352031240273,-0.0570844701387615;-0.0570841120844733,0.114169225811977,-0.0569932178412055;-0.0569928566337198,0.113986720772208,-0.0569021154795716;-0.0569017511151146,0.113804515566629,-0.0568111627771945;-0.0568107952520037,0.113622609642036,-0.0567203594579749;-0.0567199887682976,0.113441002446355,-0.0566297052463766;-0.0566293313884721,0.113259693428641,-0.0565391998674275;-0.0565388228375646,0.113078682039073,-0.0564488430467158;-0.0564484628411748,0.112897967728951,-0.0563586345103908;-0.0563582511254628,0.112717549950701,-0.0562685739851610;-0.0562681874171470,0.112537428157861,-0.0561786611982919;-0.0561782714435048,0.112357601805088,-0.0560888958776069;-0.0560885029323693,0.112178070348150,-0.0559992777514836;-0.0559988816121291,0.111998833243926,-0.0559098065488540;-0.0559094072117273,0.111819889950403,-0.0558204819992034;-0.0558200794606591,0.111641239926673,-0.0557313038325681;-0.0557308980889724,0.111462882632931,-0.0556422717795358;-0.0556418628272643,0.111284817530473,-0.0555533855712419;-0.0555529734066819,0.111107044081692,-0.0554646449393711;-0.0554642295589200,0.110929561750078,-0.0553760496161541;-0.0553756310162199,0.110752370000213,-0.0552875993343671;-0.0552871775113690,0.110575468297770,-0.0551992938273314;-0.0551988687776982,0.110398856109510,-0.0551111328289101;-0.0551107045490820,0.110222532903280,-0.0550231160735092;-0.0550226845599366,0.110046498148010,-0.0549352432960750;-0.0549348085452185,0.109870751313713,-0.0548475142320928;-0.0548470762404246,0.109695291871478,-0.0547599286175873;-0.0547594873815890,0.109520119293470,-0.0546724861891190;-0.0546720417052831,0.109345233052931,-0.0545851866837849;-0.0545847389486149,0.109170632624172,-0.0544980298392169;-0.0544975788492257,0.108996317482572,-0.0544110153935793;-0.0544105611452915,0.108822287104578,-0.0543241430855701;-0.0543236855755200,0.108648540967703,-0.0542374126544174;-0.0542369518791499,0.108475078550518,-0.0541508238398795;-0.0541503597959500,0.108301899332657,-0.0540643763822436;-0.0540639090662178,0.108129002794808,-0.0539780700223239;-0.0539775994307785,0.107956388418717,-0.0538919045014620;-0.0538914306309834,0.107784055687181,-0.0538058795615239;-0.0538054024087090,0.107612004084046,-0.0537199949448996;-0.0537195145063561,0.107440233094208,-0.0536342503945025;-0.0536337666668479,0.107268742203605,-0.0535486456537672;-0.0535481586336303,0.107097530899223,-0.0534631804666496;-0.0534626901506685,0.106926598669085,-0.0533778545776243;-0.0533773609624477,0.106755945002254,-0.0532926677316841;-0.0532921708139717,0.106585569388829,-0.0532076196743396;-0.0532071194507605,0.106415471319941,-0.0531227101516166;-0.0531222066188510,0.106245650287757,-0.0530379389100564;-0.0530374320647941,0.106076105785469,-0.0529533056967133;-0.0529527955356550,0.105906837307299,-0.0528688102591547;-0.0528682967790109,0.105737844348491,-0.0527844523454588;-0.0527839355429504,0.105569126405314,-0.0527002317042146;-0.0526997115760730,0.105400682975055,-0.0526161480845200;-0.0526156246274864,0.105232513556020,-0.0525322012359807;-0.0525316744468070,0.105064617647532,-0.0524483909087098;-0.0524478607841577,0.104896994749926,-0.0523647168533255;-0.0523641833901670,0.104729644364547,-0.0522811788209509;-0.0522806420159686,0.104562565993751,-0.0521977765632130;-0.0521972364131989,0.104395759140900,-0.0521145098322404;-0.0521139663339973,0.104229223310360,-0.0520313783806635;-0.0520308315310043,0.104062958007500,-0.0519483819616130;-0.0519478317573602,0.103896962738688,-0.0518655203287180;-0.0518649667667051,0.103731237011293,-0.0517827932361063;-0.0517822363131762,0.103565780333674,-0.0517002004384022;-0.0516996401514081,0.103400592215188,-0.0516177416907255;-0.0516171780365311,0.103235672166182,-0.0515354167486915;-0.0515348497241697,0.103071019697991,-0.0514532253684077;-0.0514526549704425,0.102906634322939,-0.0513711673064756;-0.0513705935319604,0.102742515554331,-0.0512892423199870;-0.0512886651658255,0.102578662906459,-0.0512074501665245;-0.0512068696296302,0.102415075894591,-0.0511257906041596;-0.0511252066814562,0.102251754034977,-0.0510442633914521;-0.0510436760798735,0.102088696844840,-0.0509628682874490;-0.0509622775839388,0.101925903842378,-0.0508816050516830;-0.0508810109531950,0.101763374546761,-0.0508004734441720;-0.0507998759476699,0.101601108478128,-0.0507194732254175;-0.0507188723278744,0.101439105157585,-0.0506386041564034;-0.0506379998548038,0.101277364107205,-0.0505578659985965;-0.0505572582899333,0.101115884850022,-0.0504772585139429;-0.0504766473952198,0.100954666910031,-0.0503967814648690;-0.0503961669330997,0.100793709812189,-0.0503164346142799;-0.0503020285414185,0.100605435061722,-0.0502224499617648;-0.0502080498514544,0.100417479695633,-0.0501286247338702;-0.0501142305627624,0.100229843113108,-0.0500349586307116;-0.0500205703755236,0.100042524714579,-0.0499414513530295;-0.0499270689905439,0.0998555239017330,-0.0498481026021873;-0.0498337261092508,0.0996688400774966,-0.0497549120801695;-0.0497405414336941,0.0994824726460417,-0.0496618794895811;-0.0496475146665426,0.0992964210127786,-0.0495690045336455;-0.0495546455110848,0.0991106845843557,-0.0494762869162037;-0.0494619336712251,0.0989252627686538,-0.0493837263417120;-0.0493693788514840,0.0987401549747855,-0.0492913225152415;-0.0492769807569966,0.0985553606130917,-0.0491990751424762;-0.0491847390935104,0.0983708790951388,-0.0491069839297120;-0.0490926535673846,0.0981867098337158,-0.0490150485838546;-0.0490007238855885,0.0980028522428318,-0.0489232688124190;-0.0489089497556996,0.0978193057377121,-0.0488316443235270;-0.0488173308859035,0.0976360697347979,-0.0487401748259072;-0.0487258669849910,0.0974531436517407,-0.0486488600288924;-0.0486345577623576,0.0972705269074012,-0.0485576996424188;-0.0485434029280022,0.0970882189218465,-0.0484666933770249;-0.0484524021925251,0.0969062191163461,-0.0483758409438490;-0.0483615552671273,0.0967245269133713,-0.0482851420546294;-0.0482708618636087,0.0965431417365902,-0.0481945964217017;-0.0481803216943666,0.0963620630108661,-0.0481042037579979;-0.0480899344723950,0.0961812901622555,-0.0480139637770457;-0.0479996999112828,0.0960008226180035,-0.0479238761929659;-0.0479096177252122,0.0958206598065430,-0.0478339407204721;-0.0478196876289577,0.0956408011574902,-0.0477441570748687;-0.0477299093378850,0.0954612461016441,-0.0476545249720499;-0.0476402825679491,0.0952819940709815,-0.0475650441284985;-0.0475508070356931,0.0951030444986558,-0.0474757142612838;-0.0474614824582473,0.0949243968189940,-0.0473865350880612;-0.0473723085533270,0.0947460504674934,-0.0472975063270704;-0.0472832850392322,0.0945680048808202,-0.0472086276971338;-0.0471944116348456,0.0943902594968060,-0.0471198989176562;-0.0471056880596313,0.0942128137544445,-0.0470313197086220;-0.0470171140336339,0.0940356670938905,-0.0469428897905951;-0.0469286892774768,0.0938588189564565,-0.0468546088847173;-0.0468404135123607,0.0936822687846087,-0.0467664767127061;-0.0467522864600630,0.0935060160219673,-0.0466784929968551;-0.0466643078429358,0.0933300601133008,-0.0465906574600309;-0.0465764773839052,0.0931544005045262,-0.0465029698256733;-0.0464887948064691,0.0929790366427035,-0.0464154298177927;-0.0464012598346969,0.0928039679760357,-0.0463280371609698;-0.0463138721932278,0.0926291939538651,-0.0462407915803540;-0.0462266316072692,0.0924547140266699,-0.0461536928016616;-0.0461395378025959,0.0922805276460637,-0.0460667405511756;-0.0460525905055485,0.0921066342647905,-0.0459799345557431;-0.0459657894430322,0.0919330333367238,-0.0458932745427750;-0.0458791343425158,0.0917597243168643,-0.0458067602402448;-0.0457926249320296,0.0915867066613352,-0.0457203913766861;-0.0457062609401657,0.0914139798273829,-0.0456341676811933;-0.0456200420960744,0.0912415432733703,-0.0455480888834179;-0.0455339681294652,0.0910693964587788,-0.0454621547135695;-0.0454480387706045,0.0908975388442025,-0.0453763649024133;-0.0453622537503139,0.0907259698913464,-0.0452907191812689;-0.0452766127999703,0.0905546890630258,-0.0452052172820098;-0.0451911156515028,0.0903836958231602,-0.0451198589370610;-0.0451057620373934,0.0902129896367744,-0.0450346438793988;-0.0450205516906746,0.0900425699699943,-0.0449495718425492;-0.0449354843449277,0.0898724362900431,-0.0448646425605859;-0.0448505597342834,0.0897025880652425,-0.0447798557681307;-0.0447657775934182,0.0895330247650060,-0.0446952112003505;-0.0446811376575552,0.0893637458598394,-0.0446107085929573;-0.0445966396624616,0.0891947508213374,-0.0445263476822064;-0.0445122833444481,0.0890260391221805,-0.0444421282048953;-0.0444280684403678,0.0888576102361346,-0.0443580498983630;-0.0443439946876135,0.0886894636380446,-0.0442741125004871;-0.0442600618241189,0.0885215988038367,-0.0441903157496849;-0.0441762695883556,0.0883540152105130,-0.0441066593849106;-0.0440926177193322,0.0881867123361494,-0.0440231431456545;-0.0440091059565936,0.0880196896598943,-0.0439397667719419;-0.0439257340402193,0.0878529466619645,-0.0438565300043316;-0.0438425017108223,0.0876864828236445,-0.0437734325839152;-0.0437594087095484,0.0875202976272834,-0.0436904742523155;-0.0436764547780737,0.0873543905562915,-0.0436076547516851;-0.0435936396586056,0.0871887610951404,-0.0435249738247064;-0.0435109630938789,0.0870234087293578,-0.0434424312145885;-0.0434284248271567,0.0868583329455264,-0.0433600266650675;-0.0433460246022286,0.0866935332312827,-0.0432777599204051;-0.0432637621634088,0.0865290090753115,-0.0431956307253863;-0.0431816372555362,0.0863647599673474,-0.0431136388253203;-0.0430996496239722,0.0862007853981694,-0.0430317839660373;-0.0430177990146001,0.0860370848596002,-0.0429500658938883;-0.0429360851738232,0.0858736578445025,-0.0428684843557437;-0.0428545078485646,0.0857105038467784,-0.0427870390989923;-0.0427730667862657,0.0855476223613659,-0.0427057298715403;-0.0426917617348844,0.0853850128842367,-0.0426245564218095;-0.0426105924428945,0.0852226749123932,-0.0425435184987363;-0.0425295586592851,0.0850606079438691,-0.0424626158517716;-0.0424486601335578,0.0848988114777221,-0.0423818482308778;-0.0423678966157276,0.0847372850140371,-0.0423012153865294;-0.0422872678563202,0.0845760280539197,-0.0422207170697108;-0.0422067736063710,0.0844150400994955,-0.0421403530319153;-0.0421264136174253,0.0842543206539088,-0.0420601230251447;-0.0420461876415351,0.0840938692213179,-0.0419800268019067;-0.0419660954312600,0.0839336853068956,-0.0419000641152155;-0.0418861367396643,0.0837737684168241,-0.0418202347185891;-0.0418063113203174,0.0836141180582958,-0.0417405383660496;-0.0417266189272914,0.0834547337395078,-0.0416609748121206;-0.0416849074817964,0.0833713161630515,-0.0416193360871095;-0.0416432498206864,0.0832880061324572,-0.0415777510359679;-0.0416016458646495,0.0832048034891751,-0.0415362195795888;-0.0415600955344981,0.0831217080749040,-0.0414947416389891;-0.0415185987511685,0.0830387197315895,-0.0414533171353089;-0.0414771554357197,0.0829558383014231,-0.0414119459898110;-0.0414357655093350,0.0828730636268443,-0.0413706281238816;-0.0413944288933200,0.0827903955505374,-0.0413293634590292;-0.0413531455091038,0.0827078339154329,-0.0412881519168852;-0.0413119152782379,0.0826253785647063,-0.0412469934192027;-0.0412707381223963,0.0825430293417777,-0.0412058878878574;-0.0412296139633760,0.0824607860903131,-0.0411648352448472;-0.0411885427230954,0.0823786486542210,-0.0411238354122910;-0.0411475243235955,0.0822966168776549,-0.0410828883124301;-0.0411065586870387,0.0822146906050108,-0.0410419938676265;-0.0410656457357093,0.0821328696809284,-0.0410011520003638;-0.0410247853920132,0.0820511539502903,-0.0409603626332468;-0.0409839775784769,0.0819695432582204,-0.0409196256890007;-0.0409432222177490,0.0818880374500859,-0.0408789410904718;-0.0409025192325981,0.0818066363714945,-0.0408383087606266;-0.0408618685459138,0.0817253398682954,-0.0407977286225518;-0.0408212700807065,0.0816441477865792,-0.0407572005994547;-0.0407807237601068,0.0815630599726765,-0.0407167246146622;-0.0407402295073655,0.0814820762731583,-0.0406763005916210;-0.0406997872458531,0.0814011965348349,-0.0406359284538973;-0.0406593968990603,0.0813204206047564,-0.0405956081251769;-0.0406190583905973,0.0812397483302122,-0.0405553395292648;-0.0405787716441936,0.0811591795587297,-0.0405151225900847;-0.0405385365836982,0.0810787141380752,-0.0404749572316796;-0.0404983531330792,0.0809983519162531,-0.0404348433782111;-0.0404582212164231,0.0809180927415043,-0.0403947809539590;-0.0404181407579358,0.0808379364623080,-0.0403547698833215;-0.0403781116819413,0.0807578829273801,-0.0403148100908152;-0.0403381339128821,0.0806779319856727,-0.0402749015010744;-0.0402982073753190,0.0805980834863745,-0.0402350440388514;-0.0402583319939304,0.0805183372789093,-0.0401952376290158;-0.0402185076935131,0.0804386932129372,-0.0401554821965549;-0.0401787343989810,0.0803591511383527,-0.0401157776665730;-0.0401390120353658,0.0802797109052851,-0.0400761239642915;-0.0400993405278165,0.0802003723640988,-0.0400365210150492;-0.0400597198015988,0.0801211353653910,-0.0399969687443006;-0.0400201497820958,0.0800419997599936,-0.0399574670776177;-0.0399806303948071,0.0799629653989712,-0.0399180159406883;-0.0399411615653489,0.0798840321336215,-0.0398786152593166;-0.0399017432194539,0.0798051998154750,-0.0398392649594226;-0.0398623752829706,0.0797264682962936,-0.0397999649670422;-0.0398230576818643,0.0796478374280726,-0.0397607152083271;-0.0397837903422154,0.0795693070630371,-0.0397215156095443;-0.0397445731902204,0.0794908770536446,-0.0396823660970760;-0.0397054061521912,0.0794125472525831,-0.0396432665974200;-0.0396662891545548,0.0793343175127703,-0.0396042170371882;-0.0396272221238541,0.0792561876873557,-0.0395652173431082;-0.0395882049867458,0.0791781576297163,-0.0395262674420214;-0.0395492376700024,0.0791002271934605,-0.0394873672608840;-0.0395103201005107,0.0790223962324247,-0.0394485167267666;-0.0394714522052717,0.0789446646006743,-0.0394097157668534;-0.0394326339114009,0.0788670321525028,-0.0393709643084426;-0.0393938651461280,0.0787894987424321,-0.0393322622789466;-0.0393551458367963,0.0787120642252114,-0.0392936096058907;-0.0393164759108633,0.0786347284558176,-0.0392550062169140;-0.0392778552958995,0.0785574912894539,-0.0392164520397685;-0.0392392839195894,0.0784803525815510,-0.0391779470023194;-0.0392007617097299,0.0784033121877645,-0.0391394910325446;-0.0391622885942320,0.0783263699639776,-0.0391010840585348;-0.0391238645011189,0.0782495257662982,-0.0390627260084934;-0.0390854893585266,0.0781727794510589,-0.0390244168107355;-0.0390471630947035,0.0780961308748179,-0.0389861563936888;-0.0390088856380108,0.0780195798943580,-0.0389479446858932;-0.0389706569169215,0.0779431263666856,-0.0389097816159998;-0.0389324768600205,0.0778667701490312,-0.0388716671127718;-0.0388943453960050,0.0777905110988490,-0.0388336011050836;-0.0388562624536837,0.0777143490738165,-0.0387955835219214;-0.0388182279619764,0.0776382839318330,-0.0387576142923816;-0.0387802418499146,0.0775623155310213,-0.0387196933456724;-0.0387423040466410,0.0774864437297259,-0.0386818206111124;-0.0387044144814091,0.0774106683865131,-0.0386439960181308;-0.0386665730835833,0.0773349893601709,-0.0386062194962676;-0.0386287797826384,0.0772594065097077,-0.0385684909751725;-0.0385910345081600,0.0771839196943533,-0.0385308103846056;-0.0385533371898439,0.0771085287735580,-0.0384931776544372;-0.0385156877574956,0.0770332336069911,-0.0384555927146465;-0.0384780861410316,0.0769580340545435,-0.0384180554953236;-0.0384405322704770,0.0768829299763237,-0.0383805659266669;-0.0384030260759670,0.0768079212326596,-0.0383431239389843;-0.0383655674877466,0.0767330076840992,-0.0383057294626934;-0.0383281564361694,0.0766581891914070,-0.0382683824283197;-0.0382907928516987,0.0765834656155667,-0.0382310827664984;-0.0382534766649064,0.0765088368177794,-0.0381938304079728;-0.0382162078064732,0.0764343026594634,-0.0381566252835946;-0.0381789862071887,0.0763598630022545,-0.0381194673243239;-0.0381418117979502,0.0762855177080041,-0.0380823564612287;-0.0381046845097643,0.0762112666387818,-0.0380452926254853;-0.0380676042737448,0.0761371096568713,-0.0380082757483772;-0.0380305710211140,0.0760630466247733,-0.0379713057612958;-0.0379935846832016,0.0759890774052033,-0.0379343825957400;-0.0379566451914450,0.0759152018610916,-0.0378975061833157;-0.0379197524773894,0.0758414198555842,-0.0378606764557361;-0.0378829064726865,0.0757677312520399,-0.0378238933448209;-0.0378461071090958,0.0756941359140330,-0.0377871567824972;-0.0378093543184833,0.0756206337053507,-0.0377504667007982;-0.0377726480328221,0.0755472244899937,-0.0377138230318635;-0.0377359881841916,0.0754739081321758,-0.0376772257079393;-0.0376993747047778,0.0754006844963236,-0.0376406746613777;-0.0376628075268730,0.0753275534470757,-0.0376041698246365;-0.0376262865828754,0.0752545148492832,-0.0375677111302797;-0.0375898118052892,0.0751815685680083,-0.0375312985109764;-0.0375533831267247,0.0751087144685256,-0.0374949318995017;-0.0375170004798973,0.0750359524163196,-0.0374586112287355;-0.0374806637976282,0.0749632822770861,-0.0374223364316630;-0.0374443730128437,0.0748907039167316,-0.0373861074413742;-0.0374081280585752,0.0748182172013715,-0.0373499241910640;-0.0373719288679595,0.0747458219973328,-0.0373137866140321;-0.0373357753742375,0.0746735181711502,-0.0372776946436822;-0.0372996675107551,0.0746013055895683,-0.0372416482135227;-0.0372636052109628,0.0745291841195407,-0.0372056472571661;-0.0372275884084149,0.0744571536282284,-0.0371696917083283;-0.0371916170367705,0.0743852139830017,-0.0371337815008298;-0.0371556910297921,0.0743133650514381,-0.0370979165685943;-0.0371198103213463,0.0742416067013223,-0.0370620968456489;-0.0370839748454033,0.0741699388006469,-0.0370263222661244;-0.0370481845360368,0.0740983612176107,-0.0369905927642544;-0.0370124393274238,0.0740268738206193,-0.0369549082743757;-0.0369767391538446,0.0739554764782846,-0.0369192687309279;-0.0369410839496822,0.0738841690594238,-0.0368836740684532;-0.0369054736494228,0.0738129514330601,-0.0368481242215963;-0.0368699081876549,0.0737418234684218,-0.0368126191251044;-0.0368343874990700,0.0736707850349424,-0.0367771587138270;-0.0367989115184617,0.0735998360022594,-0.0367417429227152;-0.0367634801807257,0.0735289762402148,-0.0367063716868224;-0.0367280934208599,0.0734582056188547,-0.0366710449413035;-0.0366927511739640,0.0733875240084285,-0.0366357626214150;-0.0366574533752396,0.0733169312793894,-0.0366005246625149;-0.0366221999599896,0.0732464273023929,-0.0365653310000623;-0.0365869908636185,0.0731760119482978,-0.0365301815696176;-0.0365518260216322,0.0731056850881652,-0.0364950763068420;-0.0365167053696371,0.0730354465932572,-0.0364600151474971;-0.0364816288433413,0.0729652963350395,-0.0364249980274460;-0.0364465963785530,0.0728952341851772,-0.0363900248826513;-0.0364116079111816,0.0728252600155382,-0.0363550956491767;-0.0363766633772365,0.0727553736981900,-0.0363202102631854;-0.0363243288117610,0.0726507086658543,-0.0362679642588334;];
%   Derivative.dwdtheta_p2 = [-9257.28385196662,18592.9652476153,-9324.84257208204;-2157.23593970005,4391.86590962151,-2235.18607668780;-2148.15149798617,4373.64069626518,-2226.05681353124;-2139.01632104953,4355.31408802450,-2216.87697589928;-2129.83056509451,4336.88639714424,-2207.64671957413;-2120.59438606111,4318.35793534060,-2198.36620007426;-2111.30793962556,4299.72901380245,-2189.03557265502;-2101.97138120078,4280.99994319223,-2179.65499230905;-2092.58486593685,4262.17103364690,-2170.22461376680;-2083.14854872155,4243.24259477905,-2160.74459149707;-2073.66258418072,4224.21493567752,-2151.21507970729;-2064.12712667893,4205.08836490884,-2141.63623234428;-2054.54233031975,4185.86319051777,-2132.00820309451;-2044.90834894633,4166.53972002839,-2122.33114538461;-2035.22533614190,4147.11826044515,-2112.60521238197;-2025.49344523019,4127.59911825367,-2102.83055699502;-2015.71282927590,4107.98259942174,-2093.00733187387;-2005.88364108518,4088.26900940028,-2083.13568941066;-1996.00603320612,4068.45865312418,-2073.21578174009;-1986.08015792921,4048.55183501342,-2063.24776073987;-1976.10616728769,4028.54885897366,-2053.23177803114;-1966.08421305824,4008.45002839762,-2043.16798497902;-1956.01444676127,3988.25564616568,-2033.05653269303;-1945.89701966137,3967.96601464678,-2022.89757202747;-1935.73208276786,3947.58143569951,-2012.69125358199;-1925.51978683515,3927.10221067286,-2002.43772770193;-1915.26028236332,3906.52864040732,-1992.13714447894;-1904.95371959846,3885.86102523565,-1981.78965375130;-1894.60024853320,3865.09966498380,-1971.39540510439;-1884.20001890703,3844.24485897174,-1960.95454787113;-1873.75318020691,3823.29690601448,-1950.46723113247;-1863.25988166761,3802.25610442294,-1939.93360371781;-1852.72027227221,3781.12275200479,-1929.35381420548;-1842.13450075247,3759.89714606526,-1918.72801092305;-1831.50271558940,3738.57958340831,-1908.05634194800;-1820.82506501356,3717.17036033716,-1897.33895510794;-1810.10169700558,3695.66977265542,-1886.57599798119;-1799.33275929656,3674.07811566777,-1875.76761789709;-1788.51839936853,3652.39568418097,-1864.91396193657;-1777.65876445489,3630.62277250473,-1854.01517693249;-1766.75400154080,3608.75967445248,-1843.07140947012;-1756.21788963603,3587.63400313363,-1832.49582938501;-1745.63624903173,3566.41734363471,-1821.87486636581;-1735.00922728012,3545.10999090403,-1811.20866756472;-1724.33697168404,3523.71223939129,-1800.49737988515;-1713.61962929732,3502.22438304843,-1789.74114998210;-1702.85734692523,3480.64671533043,-1778.94012426264;-1692.05027112488,3458.97952919616,-1768.09444888627;-1681.19854820573,3437.22311710936,-1757.20426976542;-1670.30232422993,3415.37777103939,-1746.26973256585;-1659.36174501277,3393.44378246203,-1735.29098270703;-1648.70428151012,3372.07613685353,-1724.59500899931;-1638.00220681684,3350.61933645711,-1713.85456669809;-1627.25566703754,3329.07367332795,-1703.06980151247;-1616.46480802937,3307.43943902648,-1692.24085890467;-1605.62977540252,3285.71692461945,-1681.36788409058;-1594.75071452046,3263.90642068033,-1670.45102203995;-1583.82777050059,3242.00821729066,-1659.49041747706;-1572.86108821446,3220.02260404042,-1648.48621488093;-1561.85081228831,3197.94987002927,-1637.43855848592;-1550.79708710348,3175.79030386715,-1626.34759228200;-1539.70005679672,3153.54419367512,-1615.21346001523;-1528.55986526075,3131.21182708629,-1604.03630518819;-1517.37665614454,3108.79349124649,-1592.81627106032;-1506.15057285381,3086.28947281529,-1581.55350064839;-1494.88175855139,3063.70005796662,-1570.24813672690;-1483.57035615771,3041.02553238982,-1558.90032182853;-1472.21650835109,3018.26618129022,-1547.51019824444;-1460.82035756819,2995.42228938999,-1536.07790802471;-1449.38204600449,2972.49414092915,-1524.60359297885;-1437.90171561456,2949.48201966614,-1513.08739467606;-1426.37950811256,2926.38620887871,-1501.52945444570;-1414.81556497261,2903.20699136474,-1489.92991337767;-1403.21002742918,2879.94464944304,-1478.28891232285;-1391.56303647752,2856.59946495412,-1466.60659189344;-1379.87473287401,2833.17171926097,-1454.88309246338;-1368.14525713654,2809.66169324983,-1443.11855416872;-1356.37474954500,2786.06966733107,-1431.31311690807;-1344.56335014162,2762.39592143998,-1419.46692034298;-1332.71119873125,2738.64073503729,-1407.58010389822;-1320.81843488196,2714.80438711029,-1395.65280676231;-1308.88519792530,2690.88715617352,-1383.68516788789;-1296.91162695665,2666.88932026931,-1371.67732599199;-1284.89786083573,2642.81115696890,-1359.62941955657;-1272.84403818682,2618.65294337283,-1347.54158682871;-1260.75029739938,2594.41495611218,-1335.41396582128;-1248.61677662815,2570.09747134881,-1323.24669431299;-1236.44361379377,2545.70076477656,-1311.03990984904;-1224.23094658299,2521.22511162170,-1298.79374974132;-1211.97891244915,2496.67078664385,-1286.50835106888;-1199.68764861256,2472.03806413677,-1274.18385067831;-1187.35729206074,2447.32721792883,-1261.82038518400;-1174.98797954897,2422.53852138415,-1249.41809096870;-1162.57984760061,2397.67224740317,-1236.97710418376;-1150.13303250735,2372.72866842319,-1224.49756074949;-1137.64767032976,2347.70805641945,-1211.97959635561;-1125.12389689755,2322.61068290569,-1199.42334646158;-1112.56184780994,2297.43681893487,-1186.82894629695;-1099.96165843611,2272.18673510002,-1174.19653086178;-1087.32346391543,2246.86070153479,-1161.52623492691;-1074.64739915797,2221.45898791440,-1148.81819303444;-1062.56172468941,2197.23819904081,-1136.69974088081;-1050.43742121452,2172.94021214641,-1124.54278477865;-1038.27462484897,2148.56529931849,-1112.34746047461;-1026.07347147647,2124.11373218055,-1100.11390348392;-1013.83409674902,2099.58578189293,-1087.84224909071;-1001.55663608733,2074.98171915352,-1075.53263234835;-989.241224681039,2050.30181419831,-1063.18518807976;-976.887997489402,2025.54633680270,-1050.80005087803;-964.497089241324,2000.71555628157,-1038.37735510645;-952.068634435875,1975.80974149033,-1025.91723489909;-939.602767342680,1950.82916082572,-1013.41982416111;-927.099622002205,1925.77408222631,-1000.88525656909;-914.559332226109,1900.64477317328,-988.313665571384;-901.982031597709,1875.44150069132,-975.705184388569;-889.367853472196,1850.16453134904,-963.059946013658;-876.716930977127,1824.81413125999,-950.378083212606;-864.029397012648,1799.39056608310,-937.659728524520;-851.305384251953,1773.89410102357,-924.905014262123;-838.545025141584,1748.32500083351,-912.114072512055;-825.748451901819,1722.68352981267,-899.287035135255;-812.915796526966,1696.96995180908,-886.424033767258;-800.047190785709,1671.18453021969,-873.525199818541;-787.142766221577,1645.32752799135,-860.590664474990;-774.202654153142,1619.39920762120,-847.620558698096;-761.226985674434,1593.39983115745,-834.615013225374;-748.215891655295,1567.32966020017,-821.574158570710;-735.169502741747,1541.18895590196,-808.498125024736;-722.087949356158,1514.97797896831,-795.387042654988;-708.971361697891,1488.69698965890,-782.241041306560;-695.819869743338,1462.34624778765,-769.060250602134;-682.633603246430,1435.92601272376,-755.844799942493;-669.412691738975,1409.43654339237,-742.594818506853;-656.157264530938,1382.87809827514,-729.310435253149;-642.867450710744,1356.25093541083,-715.991778918332;-629.543379145748,1329.55531239626,-702.638978018843;-616.185178482420,1302.79148638667,-689.252160850791;-602.792977146821,1275.95971409668,-675.831455490437;-589.366903344737,1249.06025180055,-662.376989794322;-575.907085062258,1222.09335533335,-648.888891399843;-562.413650065889,1195.05928009115,-635.367287725370;-548.886725902974,1167.95828103192,-621.812305970669;-535.326439902146,1140.79061267638,-608.224073117344;-521.732919173325,1113.55652910804,-594.602715928842;-508.106290608351,1086.25628397442,-580.948360951081;-494.446680881254,1058.89013048761,-567.261134512725;-480.754216448430,1031.45832142466,-553.541162725352;-467.029023549066,1003.96110912837,-539.788571483884;-453.271228205533,976.398745508098,-526.003486466979;-439.480956223542,948.771482040086,-512.186033137184;-425.658333192577,921.079569768311,-498.336336741367;-412.255870195406,894.228091146187,-484.906242208863;-398.820581209555,867.311013474592,-471.443430054785;-385.352592485987,840.328589121218,-457.948026187200;-371.852030057862,813.281070018346,-444.420156296930;-358.319019740836,786.168707663434,-430.859945857837;-344.753687133475,758.991753119965,-417.267520127251;-331.156157617500,731.750457017915,-403.643004146202;-317.526556358142,704.445069554480,-389.986522739784;-303.865008304458,677.075840494694,-376.298200517462;-290.171638189577,649.643019171936,-362.578161873325;-276.446570531131,622.146854488781,-348.826530986514;-262.689929631482,594.587594917455,-335.043431821444;-248.901839578088,566.965488500571,-321.228988128177;-235.082424243772,539.280782851664,-307.383323442685;-221.231807287111,511.533725155975,-293.506561087241;-207.350112152594,483.724562170756,-279.598824170574;-193.437462071130,455.853540226296,-265.660235588383;-179.493980060148,427.920905226116,-251.690918023427;-165.519788924108,399.926902647990,-237.690993946041;-151.515011254693,371.871777544335,-223.660585614330;-137.479769431125,343.755774542840,-209.599815074480;-123.414185620432,315.579137846994,-195.508804161023;-109.318381777869,287.342111236936,-181.387674497264;-95.1924796471208,259.044938069861,-167.236547495478;-81.0366007606830,230.687861280774,-153.055544357294;-66.8508664400339,202.271123382842,-138.844786073863;-52.6353977960398,173.794966468199,-124.604393426264;-38.3903157293167,145.259632208674,-110.334486985868;-24.1157409303302,116.665361855987,-96.0351871144322;-9.81179387989053,88.0123962427408,-81.7066139646008;4.52140515067992,59.3009757827559,-67.3488874800665;18.8837360991845,30.5313404717949,-52.9621273959351;33.2750791122800,1.70372988810698,-38.5464532389965;47.6953145451743,-27.1816168069679,-24.1019843280267;62.1443229613336,-56.1244608684123,-9.62883977408060;76.6219851322075,-85.1245639669833,4.87286151923483;91.1281820369062,-114.181688188565,19.4030008554367;105.662794861948,-143.295596033664,33.9614597449158;120.225705000907,-172.466050416705,48.5481199045818;134.816794054227,-201.692814665661,63.1628632576823;149.435943828792,-230.975652521188,77.8055719333689;164.083036337803,-260.314328136386,92.4761282665784;178.757953800366,-289.708606075971,107.174414797618;193.460578641181,-319.158251315648,121.900314271857;208.190793490444,-348.663029241932,136.653709639630;222.948481183352,-378.222705651136,151.434484055738;237.733524759961,-407.837046749102,166.242520879312;252.545807464804,-437.505819150429,181.077703673426;267.385212746691,-467.228789878085,195.939916204907;282.251624258382,-497.005726362734,210.829042443995;296.710156082210,-525.966798824189,225.310836674600;311.196145571794,-554.982740255553,239.819995676153;325.709475781614,-584.053316890195,254.356402820811;340.250029971639,-613.178295372261,268.919941685681;354.817691606839,-642.357442755717,283.510496052349;369.412344357040,-671.590526504037,298.127949906719;384.033872096567,-700.877314489508,312.772187438665;398.682158904065,-730.217574992858,327.443093041853;413.357089062073,-759.611076702414,342.140551313311;428.058547056861,-789.057588713768,356.864447053269;442.786417578067,-818.556880529058,371.614665264798;457.540585518537,-848.108722056642,386.391091153646;472.320935973928,-877.712883610309,401.193610127849;487.127354242538,-907.369135908935,416.022107797549;501.959725824876,-937.077250075625,430.876469974579;516.817936423557,-966.836997637504,445.756582672347;531.701871942945,-996.648150524998,460.662332105486;546.611418488854,-1026.51048107125,475.593604689553;561.546462368374,-1056.42376201174,490.550287040854;576.506890089558,-1086.38776648370,505.532265976136;591.492588361005,-1116.40226802526,520.539428512166;606.503444091853,-1146.46704057543,535.571661865725;621.539344391331,-1176.58185847320,550.628853453163;636.600176568494,-1206.74649645703,565.710890890131;651.685828132063,-1236.96072966452,580.817661991427;666.796186790069,-1267.22433363169,595.949054770633;681.931140449615,-1297.53708429251,611.104957439881;697.090577216544,-1327.89875797824,626.285258409526;712.274385395348,-1358.30913141724,641.489846288045;727.482453488714,-1388.76798173407,656.718609881593;742.714670197374,-1419.27508644920,671.971438193850;757.970924419783,-1449.83022347832,687.248220425696;773.251105251938,-1480.43317113205,702.548845975039;788.555101986993,-1511.08370811509,717.873204436419;803.882804115086,-1541.78161352595,733.221185600845;819.234101323132,-1572.52666685647,748.592679455585;834.608883494372,-1603.31864799097,763.987576183714;850.007040708335,-1634.15733720616,779.405766164078;865.428463240488,-1665.04251517040,794.847139970944;880.873041561890,-1695.97396294307,810.311588373655;896.340666339085,-1726.95146197430,825.799002336522;911.831228433773,-1757.97479410438,841.309273018498;927.344618902569,-1789.04374156318,856.842291772934;942.880728996709,-1820.15808696967,872.397950147288;958.439450161863,-1851.31761333147,887.976139882937;974.020674037881,-1882.52210404437,903.576752914925;989.624292458445,-1913.77134289162,919.199681371612;1005.25019745092,-1945.06511404366,934.844817574534;1020.89828123611,-1976.40320205760,950.512054038140;1036.56843622786,-2007.78539187646,966.201283469421;1051.98177962889,-2038.65388078629,981.634033659255;1067.41740947033,-2069.56690225620,997.088992002752;1082.87521799875,-2100.52424089394,1012.56605103918;1098.35509765440,-2131.52568169448,1028.06510350098;1113.85694107100,-2162.57101003949,1043.58604231356;1129.38064107542,-2193.66001169676,1059.12876059492;1144.92609068752,-2224.79247281989,1074.69315165562;1160.49318311976,-2255.96817994747,1090.27910899823;1176.08181177717,-2287.18692000300,1105.88652631742;1191.69187025682,-2318.44848029394,1121.51529749938;1207.32325234783,-2349.75264851159,1137.16531662184;1222.97585203104,-2381.09921273053,1152.83647795373;1238.64956347870,-2412.48796140798,1168.52867595490;1254.34428105421,-2443.91868338325,1184.24180527583;1270.05989931209,-2475.39116787765,1199.97576075760;1285.79631299748,-2506.90520449360,1215.73043743142;1301.55341704599,-2538.46058321426,1231.50573051846;1317.33110658355,-2570.05709440323,1247.30153542970;1333.12927692600,-2601.69452880373,1263.11774776551;1348.94782357905,-2633.37267753848,1278.95426331563;1364.78664223782,-2665.09133210891,1294.81097805873;1380.64562878676,-2696.85028439489,1310.68778816226;1396.52467929937,-2728.64932665418,1326.58458998225;1412.42369003791,-2760.48825152184,1342.50128006295;1428.34255745327,-2792.36685201008,1358.43775513678;1444.28117818459,-2824.28492150731,1374.39391212385;1460.23944905913,-2856.24225377810,1390.36964813196;1476.21726709208,-2888.23864296257,1406.36486045625;1492.21452948613,-2920.27388357575,1422.37944657892;1508.23113363139,-2952.34777050727,1438.41330416907;1524.26697710523,-2984.46009902105,1454.46633108255;1540.32195767174,-3016.61066475433,1470.53842536142;1556.39597328185,-3048.79926371782,1486.62948523412;1572.48892207291,-3081.02569229480,1502.73940911495;1588.60070236842,-3113.28974724074,1518.86809560389;1604.73121267798,-3145.59122568311,1535.01544348654;1620.88035169685,-3177.92992512048,1551.18135173361;1637.04801830589,-3210.30564342240,1567.36571950094;1653.23411157118,-3242.71817882875,1583.56844612911;1669.43853074393,-3275.16732994941,1599.78943114328;1685.66117526020,-3307.65289576377,1616.02857425301;1701.90194474062,-3340.17467562019,1632.28577535190;1718.16073899021,-3372.73246923561,1648.56093451745;1734.43745799820,-3405.32607669519,1664.85395201088;1750.73200193766,-3437.95529845158,1681.16472827675;1767.04427116547,-3470.61993532487,1697.49316394292;1783.37416622189,-3503.31978850168,1713.83915982015;1799.72158783056,-3536.05465953524,1730.20261690209;1816.08643689805,-3568.82435034439,1746.58343636478;1832.46861451372,-3601.62866321346,1762.98151956662;1848.59969524700,-3633.93071154767,1779.12883626289;1864.74831314935,-3666.26779944829,1795.29362525834;1880.91436916678,-3698.63972891217,1811.47578776750;1897.09776442861,-3731.04630230263,1827.67522518773;1913.29840024731,-3763.48732234910,1843.89183909905;1929.51617811812,-3795.96259214637,1860.12553126377;1945.75099971898,-3828.47191515442,1876.37620362637;1962.00276691025,-3861.01509519783,1892.64375831326;1978.27138173444,-3893.59193646539,1908.92809763255;1994.55674641609,-3926.20224350964,1925.22912407382;2010.85876336144,-3958.84582124644,1941.54674030791;2027.17733515834,-3991.52247495459,1957.88084918675;2043.51236457584,-4024.23201027515,1974.23135374299;2059.86375456418,-4056.97423321132,1990.59815718997;2076.23140825443,-4089.74895012783,2006.98116292137;2092.61522895832,-4122.55596775046,2023.38027451103;2109.01512016801,-4155.39509316573,2039.79539571274;2125.43098555589,-4188.26613382039,2056.22643046005;2141.86272897440,-4221.16889752108,2072.67328286601;2158.31025445564,-4254.10319243361,2089.13585722289;2174.77346621139,-4287.06882708293,2105.61405800214;2191.25226863277,-4320.06561035247,2122.10778985405;2207.74656629000,-4353.09335148370,2138.61695760753;2224.25626393224,-4386.15186007573,2155.14146626994;2240.78126648738,-4419.24094608499,2171.68122102687;2257.32147906171,-4452.36041982450,2188.23612724186;2273.87680693999,-4485.51009196396,2204.80609045636;2290.44715558488,-4518.68977352881,2221.39101638932;2307.03243063696,-4551.89927590002,2237.99081093706;2323.63253791445,-4585.13841081368,2254.60538017306;2340.24738341305,-4618.40699036068,2271.23463034783;2356.87687330561,-4651.70482698597,2287.87846788851;2373.52091394200,-4685.03173348840,2304.53679939879;2390.17941184897,-4718.38752302034,2321.20953165875;2406.85227372976,-4751.77200908697,2337.89657162448;2423.53940646411,-4785.18500554627,2354.59782642807;2440.24071710785,-4818.62632660821,2371.31320337724;2456.95611289275,-4852.09578683446,2388.04260995515;2473.68550122644,-4885.59320113818,2404.78595382034;2490.42878969205,-4919.11838478336,2421.54314280636;2507.18588604803,-4952.67115338447,2438.31408492161;2523.95669822804,-4986.25132290616,2455.09868834922;2540.74113434059,-5019.85870966259,2471.89686144667;2557.53910266899,-5053.49313031736,2488.70851274578;2574.35051167102,-5087.15440188280,2505.53355095233;2591.17526997882,-5120.84234171974,2522.37188494602;2608.01328639864,-5154.55676753709,2539.22342378013;2624.86446991059,-5188.29749739123,2556.08807668137;2641.72872966853,-5222.06434968593,2572.96575304968;2658.60597499981,-5255.85714317164,2589.85636245804;2675.23766078925,-5289.15875319330,2606.50174042424;2691.88253503224,-5322.48671040869,2623.16025423576;2708.54050693475,-5355.84083332490,2639.83181334369;2725.21148587681,-5389.22094079694,2656.51632737271;2741.89538141215,-5422.62685202705,2673.21370612072;2758.59210326811,-5456.05838656443,2689.92385955872;2775.30156134534,-5489.51536430480,2706.64669783059;2792.02366571763,-5522.99760548991,2723.38213125285;2808.75832663178,-5556.50493070732,2740.13007031453;2825.50545450724,-5590.03716088979,2756.89042567687;2842.26495993609,-5623.59411731503,2773.66310817323;2859.03675368276,-5657.17562160533,2790.44802880886;2875.82074668372,-5690.78149572686,2807.24509876058;2892.61685004752,-5724.41156198974,2824.05422937679;2909.42497505432,-5758.06564304715,2840.87533217705;2926.24503315594,-5791.74356189534,2857.70831885208;2943.07693597550,-5825.44514187305,2874.55310126345;2959.92059530725,-5859.17020666100,2891.40959144337;2976.77592311639,-5892.91858028170,2908.27770159452;2993.64283153892,-5926.69008709899,2925.15734408991;3010.52123288132,-5960.48455181753,2942.04843147258;3027.41103962049,-5994.30179948263,2958.95087645547;3044.31216440344,-6028.14165547962,2975.86459192120;3061.22452004723,-6062.00394553370,2992.78949092194;3078.14801953856,-6095.88849570922,3009.72548667905;3095.08257603377,-6129.79513240957,3026.67249258303;3112.02810285861,-6163.72368237682,3043.63042219335;3128.98451350801,-6197.67397269114,3060.59918923815;3145.95172164580,-6231.64583077035,3077.57870761403;3162.92964110467,-6265.63908436981,3094.56889138598;3179.91818588593,-6299.65356158190,3111.56965478712;3196.91727015926,-6333.68909083557,3128.58091221848;3213.92680826257,-6367.74550089603,3145.60257824886;3230.94671470177,-6401.82262086429,3162.63456761456;3247.97690415061,-6435.92028017684,3179.67679521928;3265.01729145054,-6470.03830860545,3196.72917613396;3282.06779161035,-6504.17653625627,3213.79162559638;3299.12831980617,-6538.33479357001,3230.86405901120;3316.19879138114,-6572.51291132120,3247.94639194964;3333.27912184531,-6606.71072061798,3265.03854014935;3350.36922687539,-6640.92805290164,3282.14041951416;3367.46902231461,-6675.16473994631,3299.25194611399;3384.57842417246,-6709.42061385845,3316.37303618453;3401.69734862462,-6743.69550707670,3333.50360612719;3418.82571201262,-6777.98925237121,3350.64357250876;3435.96343084379,-6812.30168284356,3367.79285206139;3453.11042179096,-6846.63263192613,3384.95136168226;3470.26660169238,-6880.98193338193,3402.11901843347;3487.43188755141,-6915.34942130400,3419.29573954181;3504.60619653646,-6949.73493011534,3436.48144239863;3521.41576975514,-6983.39089220723,3453.30291830252;3538.23474558880,-7017.06563441074,3470.13375508673;3555.06304080687,-7050.75899035018,3486.97386974358;3571.90057234476,-7084.47079398166,3503.82317943089;3588.74725730370,-7118.20087959270,3520.68160147184;3605.60301295051,-7151.94908180184,3537.54905335472;3622.46775671739,-7185.71523555812,3554.42545273274;3639.34140620183,-7219.49917614107,3571.31071742395;3656.22387916629,-7253.30073915991,3588.20476541090;3673.11509353810,-7287.11976055339,3605.10751484054;3690.01496740923,-7320.95607658944,3622.01888402402;3706.92341903618,-7354.80952386475,3638.93879143652;3723.84036683968,-7388.67993930435,3655.86715571701;3740.76572940458,-7422.56716016132,3672.80389566815;3757.69942547964,-7456.47102401632,3689.74893025598;3774.64137397733,-7490.39136877731,3706.70217860985;3791.59149397377,-7524.32803267929,3723.66356002227;3808.54970470824,-7558.28085428343,3740.63299394845;3825.51592558336,-7592.24967247740,3757.61040000649;3842.49007616467,-7626.23432647450,3774.59569797696;3859.47207618051,-7660.23465581345,3791.58880780275;3876.46184552188,-7694.25050035807,3808.58964958896;3893.45930424218,-7728.28170029684,3825.59814360262;3910.46437255708,-7762.32809614256,3842.61421027261;3927.47697084428,-7796.38952873191,3859.63777018933;3944.49701964345,-7830.46583922533,3876.66874410474;3961.52443965586,-7864.55686910626,3893.70705293192;3978.55915174440,-7898.66246018117,3910.75261774510;3995.60107693322,-7932.78245457889,3927.80535977934;4012.65013640770,-7966.91669475052,3944.86520043047;4029.70625151417,-8001.06502346889,3961.93206125481;4046.76934375972,-8035.22728382808,3979.00586396897;4063.83933481208,-8069.40331924336,3996.08653044977;4080.91614649949,-8103.59297345076,4013.17398273407;4097.99970081032,-8137.79609050644,4030.26814301842;4115.08991989310,-8172.01251478665,4047.36893365906;4132.18672605622,-8206.24209098717,4064.47627717164;4149.29004176783,-8240.48466412313,4081.59009623113;4166.39978965555,-8274.74007952841,4098.71031367150;4183.51589250642,-8309.00818285556,4115.83685248571;4200.63827326663,-8343.28882007519,4132.96963582539;4217.76685504141,-8377.58183747582,4150.10858700078;4234.90156109476,-8411.88708166337,4167.25362948043;4252.04231484935,-8446.20439956086,4184.40468689112;4269.18903988634,-8480.53363840810,4201.56168301764;4286.34165994518,-8514.87464576133,4218.72454180265;4303.50009892340,-8549.22726949274,4235.89318734645;4320.66428087650,-8583.59135779028,4253.06754390682;4337.83413001776,-8617.96675915724,4270.24753589890;4355.00957071799,-8652.35332241185,4287.43308789490;4372.07038883464,-8686.51060329908,4304.50416277069;4389.13681970080,-8720.67908863057,4321.58081898929;4406.20878788212,-8754.85862761359,4338.66298131682;4423.28621810179,-8789.04906977027,4355.75057467650;4440.36903524010,-8823.25026493683,4372.84352414818;4457.45716433450,-8857.46206326354,4389.94175496843;4474.55053057929,-8891.68431521423,4407.04519253023;4491.64905932544,-8925.91687156589,4424.15376238280;4508.75267608054,-8960.15958340851,4441.26739023148;4525.86130650847,-8994.41230214454,4458.38600193752;4542.97487642934,-9028.67487948867,4475.50952351791;4560.09331181928,-9062.94716746743,4492.63788114522;4577.21653881023,-9097.22901841882,4509.77100114741;4594.34448368979,-9131.52028499195,4526.90881000763;4611.47707290111,-9165.82082014683,4544.05123436415;4628.61423304256,-9200.13047715373,4561.19820100999;4645.75589086779,-9234.44910959335,4578.34963689306;4662.90197328528,-9268.77657135577,4595.50546911560;4680.05240735842,-9303.11271664078,4612.66562493435;4697.20712030519,-9337.45739995712,4629.83003176020;4714.36603949801,-9371.81047612225,4646.99861715801;4731.52909246363,-9406.17180026207,4664.17130884654;4748.69620688286,-9440.54122781046,4681.34803469820;4765.86731059048,-9474.91861450902,4698.52872273888;4783.04233157506,-9509.30381640676,4715.71330114786;4800.22119797875,-9543.69668985965,4732.90169825754;4817.40383809711,-9578.09709153032,4750.09384255329;4834.59018037900,-9612.50487838779,4767.28966267333;4851.78015342632,-9646.91990770698,4784.48908740852;4868.97368599398,-9681.34203706864,4801.69204570225;4886.17070698949,-9715.77112435858,4818.89846665011;4903.37114547311,-9750.20702776783,4836.10827949994;4920.57493065740,-9784.64960579195,4853.32141365151;4937.78199190719,-9819.09871723076,4870.53779865639;4954.99225873938,-9853.55422118807,4887.75736421778;4972.20566082279,-9888.01597707136,4904.98004019038;4989.42212797795,-9922.48384459133,4922.20575658015;5006.64159017700,-9956.95768376172,4939.43444354424;5023.86397754342,-9991.43735489876,4956.66603139067;5041.08922035196,-10025.9227186211,4973.90045057835;5058.31724902846,-10060.4136358492,4991.13763171679;5075.54799414959,-10094.9099678052,5008.37750556592;5092.78138644280,-10129.4115760125,5025.62000303603;5110.01735678608,-10163.9183222954,5042.86505518748;5127.25583620785,-10198.4300687791,5060.11259323067;5144.49675588671,-10232.9466778886,5077.36254852572;5161.74004715135,-10267.4680123490,5094.61485258240;5178.98564148035,-10301.9939351854,5111.86943705997;5196.23347050205,-10336.5243097215,5129.12623376698;5213.48346599429,-10371.0589995806,5146.38517466108;5230.96745941870,-10406.0616987264,5163.87775007862;5248.45315719221,-10441.0677890425,5181.37200840007;5265.94049205618,-10476.0771360784,5198.86788254457;5283.42939689992,-10511.0896056794,5216.36530557873;5300.91980476048,-10546.1050639859,5233.86421071649;5318.41164882260,-10581.1233774337,5251.36453131905;5335.90486241840,-10616.1444127530,5268.86620089457;5353.39937902732,-10651.1680369685,5286.36915309809;5370.89513227592,-10686.1941173990,5303.87332173136;5388.39205593773,-10721.2225216571,5321.37864074265;5405.89008393307,-10756.2531176488,5338.88504422661;5423.38915032893,-10791.2857735731,5356.39246642413;5440.88918933872,-10826.3203579217,5373.90084172210;5458.39013532224,-10861.3567394791,5391.41010465337;5475.89192278543,-10896.3947873217,5408.92018989651;5493.39448638019,-10931.4343708176,5426.43103227561;5510.89776090429,-10966.4753596267,5443.94256676023;5528.40168130120,-11001.5176236998,5461.45472846518;5545.90618265982,-11036.5610332788,5478.96745265030;5563.41120021454,-11071.6054588959,5496.48067472050;5580.91666934480,-11106.6507713735,5513.99433022528;5598.42252557523,-11141.6968418242,5531.50835485896;5615.92870457519,-11176.7435416499,5549.02268446012;5633.43514215886,-11211.7907425418,5566.53725501177;5650.94177428494,-11246.8383164801,5584.05200264101;5668.44853705655,-11281.8861357336,5601.56686361894;5685.95536672104,-11316.9340728595,5619.08177436047;5703.46219966981,-11351.9820007026,5636.59667142413;5720.96897243826,-11387.0297923959,5654.11149151205;5738.47562170549,-11422.0773213594,5671.62617146963;5755.98208429426,-11457.1244613003,5689.14064828551;5773.48829717073,-11492.1710862124,5706.65485909130;5790.99419744441,-11527.2170703760,5724.16874116157;5808.49972236787,-11562.2622883574,5741.68223191350;5826.00480933674,-11597.3066150088,5759.19526890696;5843.50939588939,-11632.3499254677,5776.70778984409;5861.01341970693,-11667.3920951569,5794.21973256937;5878.51681861290,-11702.4329997840,5811.73103506932;5896.01953057327,-11737.4725153410,5829.24163547244;5913.52149369612,-11772.5105181043,5846.75147204895;5931.02264623163,-11807.5468846339,5864.26048321072;5948.52292657182,-11842.5814917737,5881.76860751111;5966.02227325045,-11877.6142166507,5899.27578364473;5983.52062494282,-11912.6449366748,5916.78195044737;6001.01792046571,-11947.6735295387,5934.28704689584;6018.51409877707,-11982.6998732174,5951.79101210777;6036.00909897600,-12017.7238459677,5969.29378534145;6053.50286030254,-12052.7453263284,5986.79530599579;6070.99532213747,-12087.7641931195,6004.29551360992;6088.48642400226,-12122.7803254422,6021.79434786336;6104.85634368381,-12155.5539293680,6038.17363474152;6121.22633040019,-12188.3276531579,6054.55297330106;6137.59632168858,-12221.1013719438,6070.93230123945;6153.96625523060,-12253.8749611462,6087.31155639819;6170.33606885212,-12286.6482964738,6103.69067676263;6186.70570052310,-12319.4212539234,6120.06960046177;6203.07508835755,-12352.1937097797,6136.44826576826;6219.44417061315,-12384.9655406146,6152.82661109801;6235.81288569126,-12417.7366232873,6169.20457501018;6252.18117213673,-12450.5068349434,6185.58209620700;6268.54896863762,-12483.2760530152,6201.95911353353;6284.91621402520,-12516.0441552210,6218.33556597759;6301.28284727368,-12548.8110195648,6234.71139266955;6317.64880750008,-12581.5765243362,6251.08653288216;6334.01403396404,-12614.3405481097,6267.46092603038;6350.37846606772,-12647.1029697447,6283.83451167130;6366.74204335561,-12679.8636683851,6300.20722950389;6383.10470551430,-12712.6225234590,6316.57901936885;6399.46639237242,-12745.3794146780,6332.94982124848;6415.82704390042,-12778.1342220376,6349.31957526651;6432.18660021042,-12810.8868258161,6365.68822168790;6448.54500155609,-12843.6371065750,6382.05570091878;6464.90218833238,-12876.3849451581,6398.42195350614;6481.25810107548,-12909.1302226914,6414.78692013780;6497.61268046258,-12941.8728205829,6431.15054164217;6513.96586731173,-12974.6126205220,6447.51275898811;6530.31760258174,-13007.3495044794,6463.87351328484;6546.66782737190,-13040.0833547069,6480.23274578166;6563.01648292190,-13072.8140537366,6496.59039786783;6579.36351061170,-13105.5414843809,6512.94641107250;6595.70885196125,-13138.2655297325,6529.30072706442;6612.05244863044,-13170.9860731633,6545.65328765182;6628.39424241892,-13203.7029983248,6562.00403478235;6644.73417526591,-13236.4161891473,6578.35291054276;6661.07218925001,-13269.1255298399,6594.69985715883;6677.40822658915,-13301.8309048900,6611.04481699525;6693.74222964034,-13334.5321990631,6627.38773255536;6710.07414089950,-13367.2292974023,6643.72854648104;6726.40390300141,-13399.9220852282,6660.06720155259;6742.73145871938,-13432.6104481385,6676.40364068849;6759.05675096528,-13465.2942720075,6692.73780694533;6775.37972278925,-13497.9734429861,6709.06964351760;6791.70031737954,-13530.6478475013,6725.39909373748;6808.01847806248,-13563.3173722559,6741.72610107483;6824.33414830213,-13595.9819042282,6758.05060913684;6840.64727170032,-13628.6413306715,6774.37256166809;6856.95779199636,-13661.2955391144,6790.69190255020;6873.26565306690,-13693.9444173596,6807.00857580176;6889.57079892580,-13726.5878534842,6823.32252557819;6905.87317372396,-13759.2257358392,6839.63369617149;6922.17272174919,-13791.8579530493,6855.94203201023;6938.46938742600,-13824.4843940123,6872.24747765926;6954.76311531549,-13857.1049478992,6888.54997781961;6971.05385011517,-13889.7195041535,6904.84947732834;6987.34153665878,-13922.3279524909,6921.14592115834;7003.62611991619,-13954.9301828994,6937.43925441824;7019.90754499320,-13987.5260856387,6953.72942235220;7036.18575713139,-14020.1155512396,6970.01637033974;7052.46070170797,-14052.6984705044,6986.30004389565;7068.73232423565,-14085.2747345058,7002.58038866981;7085.00057036239,-14117.8442345872,7018.85735044696;7101.26538587137,-14150.4068623620,7035.13087514667;7117.52671668077,-14182.9625097137,7051.40090882309;7133.78450884357,-14215.5110687949,7067.66739766481;7150.03870854746,-14248.0524320277,7083.93028799472;7166.28926211468,-14280.5864921030,7100.18952626989;7182.53611600187,-14313.1131419805,7116.44505908136;7198.77921679983,-14345.6322748879,7132.69683315396;7215.01851123345,-14378.1437843209,7148.94479534624;7231.25394616158,-14410.6475640430,7165.18889265027;7247.48546857677,-14443.1435080850,7181.42907219147;7263.71302560517,-14475.6315107446,7197.66528122847;7279.93656450643,-14508.1114665864,7213.89746715298;7296.15603267344,-14540.5832704414,7230.12557748959;7312.37137763222,-14573.0468174065,7246.34955989561;7328.58254704184,-14605.5020028446,7262.56936216103;7344.78948869410,-14637.9487223840,7278.78493220819;7360.99215051358,-14670.3868719183,7294.99621809178;7377.19048055725,-14702.8163476058,7311.20316799854;7393.38442701456,-14735.2370458694,7327.40573024728;7409.57393820711,-14767.6488633963,7343.60385328858;7425.75896258855,-14800.0516971376,7359.79748570468;7441.93944874446,-14832.4454443082,7375.98657620937;7458.11534539216,-14864.8300023859,7392.17107364779;7474.28660138053,-14897.2052691121,7408.35092699626;7490.45316568991,-14929.5711424903,7424.52608536217;7506.61498743195,-14961.9275207870,7440.69649798385;7522.77201584939,-14994.2743025303,7456.86211423032;7538.92420031598,-15026.6113865104,7473.02288360124;7555.07149033627,-15058.9386717789,7489.17875572668;7571.21383554548,-15091.2560576485,7505.32968036700;7587.35118570936,-15123.5634436928,7521.47560741272;7603.48349072405,-15155.8607297460,7537.61648688434;7619.61070061586,-15188.1478159027,7553.75226893218;7635.73276554117,-15220.4246025171,7569.88290383621;7651.84963578624,-15252.6909902033,7586.00834200598;7667.96126176717,-15284.9468798348,7602.12853398040;7684.06759402955,-15317.1921725440,7618.24343042756;7700.16858324852,-15349.4267697220,7634.35298214469;7716.26418022841,-15381.6505730183,7650.45714005785;7733.40051756675,-15415.9559874015,7667.60049713868;7750.52996709784,-15450.2476166611,7684.73696714658;7767.65248211272,-15484.5253674199,7701.86650349008;7784.76801602726,-15518.7891465500,7718.98905970220;7801.87652238237,-15553.0388611736,7736.10458944060;7818.97795484325,-15587.2744186612,7753.21304648686;7836.07226719989,-15621.4957266327,7770.31438474699;7853.15941336669,-15655.7026929566,7787.40855825105;7870.23934738207,-15689.8952257496,7804.49552115273;7887.31202340866,-15724.0732333761,7821.57522772956;7904.37739573306,-15758.2366244489,7838.64763238271;7921.43541876555,-15792.3853078276,7855.71268963662;7938.48604704013,-15826.5191926191,7872.77035413908;7955.52923521436,-15860.6381881774,7889.82058066112;7972.56493806916,-15894.7422041030,7906.86332409672;7989.59311050848,-15928.8311502422,7923.89853946254;8006.61370755965,-15962.9049366882,7940.92618189824;8023.62668437272,-15996.9634737790,7957.94620666587;8040.63199622059,-16031.0066720986,7974.95856914993;8057.62959849881,-16065.0344424759,7991.96322485721;8074.61944672548,-16099.0466959848,8008.96012941671;8091.60149654100,-16133.0433439436,8025.94923857934;8108.57570370798,-16167.0242979148,8042.93050821786;8125.54202411130,-16200.9894697055,8059.90389432696;8142.50041375742,-16234.9387713656,8076.86935302252;8159.45082877492,-16268.8721151892,8093.82684054218;8176.39322541383,-16302.7894137130,8110.77631324471;8193.32756004588,-16336.6905797171,8127.71772761015;8210.25378916387,-16370.5755262235,8144.65104023930;8227.17186938202,-16404.4441664968,8161.57620785401;8244.08175743575,-16438.2964140440,8178.49318729697;8260.98341018105,-16472.1321826130,8195.40193553106;8277.87678459504,-16505.9513861938,8212.30240963996;8294.76183777541,-16539.7539390175,8229.19456682754;8311.63852694023,-16573.5397555555,8246.07836441771;8328.50680942798,-16607.3087505202,8262.95375985441;8345.36664269745,-16641.0608388642,8279.82071070155;8362.21798432756,-16674.7959357804,8296.67917464280;8379.06079201696,-16708.5139567010,8313.52910948123;8395.89502358427,-16742.2148172977,8330.37047313950;8412.72063696771,-16775.8984334817,8347.20322365950;8429.53759022496,-16809.5647214025,8364.02731920225;8446.34584153311,-16843.2135974485,8380.84271804784;8463.14534918858,-16876.8449782467,8397.64937859530;8479.93607160682,-16910.4587806618,8414.44725936235;8496.71796732206,-16944.0549217960,8431.23631898513;8513.49099498756,-16977.6333189893,8448.01651621848;8530.25511337519,-17011.1938898190,8464.78780993546;8547.01028137530,-17044.7365520990,8481.55015912730;8563.75645799648,-17078.2612238796,8498.30352290308;8579.48152041649,-17109.7435243710,8514.03726810074;8595.19883963541,-17141.2103309620,8529.76327430297;8610.90837305146,-17172.6615584814,8545.48149901033;8626.61007818369,-17204.0971219995,8561.19189984386;8642.30391267249,-17235.5169368293,8576.89443454560;8657.98983427926,-17266.9209185253,8592.58906097819;8673.66780088612,-17298.3089828836,8608.27573712472;8689.33777049574,-17329.6810459412,8623.95442108841;8704.99970123151,-17361.0370239762,8639.62507109287;8720.65355133719,-17392.3768335076,8655.28764548173;8736.29927917646,-17423.7003912937,8670.94210271819;8751.93684323342,-17455.0076143338,8686.58840138550;8767.56620211186,-17486.2984198663,8702.22650018628;8783.18731453548,-17517.5727253693,8717.85635794267;8798.80013934766,-17548.8304485600,8733.47793359618;8814.40463551094,-17580.0715073941,8749.09118620710;8830.00076210769,-17611.2958200663,8764.69607495520;8845.58847833895,-17642.5033050089,8780.29255913859;8861.16774352512,-17673.6938808926,8795.88059817438;8876.73851710539,-17704.8674666256,8811.46015159814;8892.30075863769,-17736.0239813533,8827.03117906378;8907.85442779873,-17767.1633444587,8842.59364034372;8923.39948438329,-17798.2854755606,8858.14749532803;8938.93588830471,-17829.3902945149,8873.69270402504;8954.46359959448,-17860.4777214135,8889.22922656086;8969.98257840210,-17891.5476765844,8904.75702317928;8985.49278499475,-17922.6000805907,8920.27605424142;9000.99417975757,-17953.6348542311,8935.78628022599;9016.48672319318,-17984.6519185394,8951.28766172889;9031.97037592142,-18015.6511947835,8966.78015946285;9047.44509867974,-18046.6326044664,8982.26373425788;9062.91085232252,-18077.5960693249,8997.73834706057;9078.36759782111,-18108.5415113295,9013.20395893416;9093.81529626370,-18139.4688526842,9028.66053105837;9109.25390885539,-18170.3780158269,9044.10802472947;9124.68339691745,-18201.2689234273,9059.54640135961;9140.10372188781,-18232.1414983887,9074.97562247722;9155.51484532047,-18262.9956638460,9090.39564972647;9170.91672888575,-18293.8313431670,9105.80644486750;9186.30933436978,-18324.6484599505,9121.20796977593;9201.69262367451,-18355.4469380273,9136.60018644286;9217.06655881752,-18386.2267014588,9151.98305697470;9232.43110193210,-18416.9876745382,9167.35654359319;9247.78621526657,-18447.7297817881,9182.72060863480;9263.13186118479,-18478.4529479624,9198.07521455117;9278.46800216560,-18509.1570980447,9213.42032390862;9293.79460080277,-18539.8421572483,9228.75589938805;9309.11161980462,-18570.5080510155,9244.08190378456;9324.41902199463,-18601.1547050186,9259.39830000808;9339.71677031037,-18631.7820451582,9274.70505108229;9355.00482780387,-18662.3899975635,9290.00212014502;9370.28315764138,-18692.9784885920,9305.28947044797;9385.55172310321,-18723.5474448293,9320.56706535656;9400.81048758355,-18754.0967930885,9335.83486834976;9416.05941459039,-18784.6264604102,9351.09284302003;9431.29846774539,-18815.1363740621,9366.34095307312;9446.52761078358,-18845.6264615387,9381.57916232786;9461.74680755350,-18876.0966505611,9396.80743471625;9476.95602201663,-18906.5468690765,9412.02573428288;9492.15521824767,-18936.9770452580,9427.23402518524;9507.34436043419,-18967.3871075046,9442.43227169338;9522.52341287659,-18997.7769844407,9457.62043818983;9537.69233998761,-19028.1466049152,9472.79848916913;9552.85110629277,-19058.4958980025,9487.96638923827;9567.99967642970,-19088.8247930009,9503.12410311603;9583.13801514839,-19119.1332194336,9518.27159563321;9598.26608731054,-19149.4211070468,9533.40883173203;9613.38385789025,-19179.6883858114,9548.53577646672;9628.49129197270,-19209.9349859206,9563.65239500233;9643.58835475537,-19240.1608377915,9578.75865261582;9658.67501154655,-19270.3658720632,9593.85451469469;9673.75122776627,-19300.5500195980,9608.93994673782;9688.81696894559,-19330.7132114799,9624.01491435482;9703.87220072648,-19360.8553790149,9639.07938326585;9718.91688886193,-19390.9764537307,9654.13331930182;9733.95099921568,-19421.0763673763,9669.17668840399;9748.97449776195,-19451.1550519218,9684.20945662387;9763.98735058541,-19481.2124395577,9699.23159012302;9778.98952388097,-19511.2484626952,9714.24305517297;9793.98098395391,-19541.2630539658,9729.24381815525;9808.96169721936,-19571.2561462208,9744.23384556097;9823.93163020230,-19601.2276725309,9759.21310399072;9838.89074953747,-19631.1775661863,9774.18156015457;9853.83902196924,-19661.1057606961,9789.13918087190;9868.77641435127,-19691.0121897881,9804.08593307102;9883.70289364665,-19720.8967874087,9819.02178378938;9898.61842692753,-19750.7594877224,9833.94670017319;9913.52298137519,-19780.6002251116,9848.86064947743;9928.41652427951,-19810.4189341759,9863.76359906538;9943.29902303935,-19840.2155497327,9878.65551640902;9958.17044516209,-19869.9900068164,9893.53636908845;9973.03075826329,-19899.7422406775,9908.40612479174;9987.87993006726,-19929.4721867839,9923.26475131528;10002.7179284058,-19959.1797808184,9938.11221656278;10017.5447212195,-19988.8649586810,9952.94848854620;10032.3602765561,-20018.5276564864,9967.77353538464;10047.1645625715,-20048.1678105647,9982.58732530471;10061.9575475289,-20077.7853574612,9997.38982664028;10076.7391997989,-20107.3802339356,10012.1810078323;10091.5094878599,-20136.9523769628,10026.9608374288;10105.3196800675,-20164.6041965597,10040.7819801316;10119.1196522257,-20192.2355712262,10054.5929137613;10132.9093714068,-20219.8464351247,10068.3936054618;10146.6888047927,-20247.4367226365,10082.1840224863;10160.4579196748,-20275.0063683618,10095.9641321970;10174.2166834539,-20302.5553071195,10109.7339020655;10187.9650636399,-20330.0834739466,10123.4932996718;10201.7030278518,-20357.5908040979,10137.2422927049;10215.4305438174,-20385.0772330464,10150.9808489624;10229.1475793734,-20412.5426964820,10164.7089363502;10242.8541024651,-20439.9871303118,10178.4265228827;10256.5500811459,-20467.4104706593,10192.1335766822;10270.2354835779,-20494.8126538651,10205.8300659790;10283.9102780312,-20522.1936164855,10219.5159591113;10297.5744328838,-20549.5532952930,10233.1912245252;10311.2279166218,-20576.8916272752,10246.8558307739;10324.8706978388,-20604.2085496355,10260.5097465185;10338.5027452360,-20631.5039997919,10274.1529405268;10352.1240276221,-20658.7779153776,10287.7853816743;10365.7345139128,-20686.0302342393,10301.4070389429;10379.3341731314,-20713.2608944390,10315.0178814218;10392.9229744076,-20740.4698342511,10328.6178783063;10406.5008869783,-20767.6569921648,10342.2069988988;10420.0678801868,-20794.8223068816,10355.7852126076;10433.6239234834,-20821.9657173166,10369.3524889476;10447.1689864241,-20849.0871625970,10382.9087975394;10460.7030386717,-20876.1865820624,10396.4541081098;10474.2260499948,-20903.2639152649,10409.9883904912;10487.7379902678,-20930.3191019675,10423.5116146218;10501.2388294714,-20957.3520821455,10437.0237505451;10514.7285376914,-20984.3627959848,10450.5247684100;10528.2070851193,-21011.3511838824,10464.0146384707;10541.6744420520,-21038.3171864458,10477.4933310863;10555.1305788915,-21065.2607444926,10490.9608167209;10568.5754661450,-21092.1817990508,10504.4170659433;10582.0090744243,-21119.0802913575,10517.8620494268;10595.4313744463,-21145.9561628595,10531.2957379492;10608.8423370321,-21172.8093552127,10544.7181023928;10622.2419331078,-21199.6398102820,10558.1291137439;10635.6301337034,-21226.4474701402,10571.5287430928;10649.0069099532,-21253.2322770689,10584.9169616337;10662.3722330955,-21279.9941735574,10598.2937406647;10675.7260744724,-21306.7331023023,10611.6590515869;10689.0684055300,-21333.4490062083,10625.0128659057;10702.3991978176,-21360.1418283863,10638.3551552290;10715.7184229882,-21386.8115121544,10651.6858912683;10729.0260527980,-21413.4580010371,10665.0050458379;10742.3220591063,-21440.0812387651,10678.3125908550;10755.6064138755,-21466.6811692747,10691.6084983395;10768.8790891708,-21493.2577367081,10704.8927404139;10783.0592763132,-21521.6494464940,10719.0831555696;10797.2265773457,-21550.0153798008,10733.2607004869;10811.3809662622,-21578.3554846283,10747.4253492138;10825.5224171565,-21606.6697091748,10761.5770758978;10839.6509042211,-21634.9580018373,10775.7158547848;10853.7664017484,-21663.2203112113,10789.8416602204;10867.8688841297,-21691.4565860905,10803.9544666486;10881.9583258553,-21719.6667754666,10818.0542486124;10896.0347015144,-21747.8508285287,10832.1409807534;10910.0979857948,-21776.0086946631,10846.2146378112;10924.1481534830,-21804.1403234534,10860.2751946241;10938.1851794639,-21832.2456646796,10874.3226261284;10952.2090387207,-21860.3246683188,10888.3569073585;10966.2197063348,-21888.3772845435,10902.3780134466;10980.2171574853,-21916.4034637226,10916.3859196225;10994.2013674497,-21944.4031564204,10930.3806012138;11008.1723116027,-21972.3763133966,10944.3620336455;11022.1299654170,-22000.3228856062,10958.3301924399;11036.0743044626,-22028.2428241987,10972.2850532163;11050.0053044067,-22056.1360805181,10986.2265916914;11063.9229410139,-22084.0026061029,11000.1547836785;11077.8271901454,-22111.8423526848,11014.0696050876;11091.7180277599,-22139.6552721903,11027.9710319256;11105.5954299124,-22167.4413167383,11041.8590402955;11119.4593727547,-22195.2004386415,11055.7336063971;11133.3098325349,-22222.9325904048,11069.5947065259;11147.1467855978,-22250.6377247263,11083.4423170740;11160.9702083837,-22278.3157944955,11097.2764145286;11174.7800774299,-22305.9667527949,11111.0969754736;11188.5763693687,-22333.5905528978,11124.9039765879;11202.3590609287,-22361.1871482697,11138.6973946463;11216.1281289341,-22388.7564925666,11152.4772065185;11229.8835503043,-22416.2985396356,11166.2433891699;11243.6253020543,-22443.8132435146,11179.9959196606;11257.3533612943,-22471.3005584315,11193.7347751459;11271.0677052295,-22498.7604388045,11207.4599328757;11284.7683111601,-22526.1928392414,11221.1713701949;11298.4551564810,-22553.5977145393,11234.8690645424;11312.1282186816,-22580.9750196847,11248.5529934517;11325.7874753464,-22608.3247098533,11262.2231345510;11339.4329041536,-22635.6467404087,11275.8794655619;11353.0644828762,-22662.9410669037,11289.5219643004;11366.6821893807,-22690.2076450785,11303.1506086762;11380.2860016280,-22717.4464308613,11316.7653766926;11393.8758976728,-22744.6573803681,11330.3662464466;11407.4518556632,-22771.8404499018,11343.9531961286;11421.0138538412,-22798.9955959525,11357.5262040222;11434.5618705421,-22826.1227751971,11371.0852485043;11448.0958841940,-22853.2219444981,11384.6303080444;11461.6158733187,-22880.2930609053,11398.1613612052;11475.1218165309,-22907.3360816535,11411.6783866422;11488.6136925379,-22934.3509641634,11425.1813631031;11502.0914801399,-22961.3376660413,11438.6702694285;11515.5551582295,-22988.2961450776,11452.1450845508;11529.0047057919,-23015.2263592486,11465.6057874950;11542.4401019045,-23042.1282667142,11479.0523573779;11555.8613257369,-23069.0018258189,11492.4847734082;11569.2683565507,-23095.8469950911,11505.9030148865;11582.6611736993,-23122.6637332425,11519.3070612048;11596.0397566279,-23149.4519991687,11532.6968918468;11609.4040848733,-23176.2117519480,11546.0724863873;11622.7541380637,-23202.9429508414,11559.4338244924;11636.0898959188,-23229.6455552930,11572.7808859194;11649.4113382492,-23256.3195249286,11586.1136505163;11662.7184449567,-23282.9648195561,11599.4320982220;11676.0111960340,-23309.5813991653,11612.7362090660;11689.2895715646,-23336.1692239274,11626.0259631685;11702.5535517225,-23362.7282541941,11639.3013407396;11715.8031167725,-23389.2584504993,11652.5623220802;11729.0382470691,-23415.7597735560,11665.8088875808;11742.2589230579,-23442.2321842587,11679.0410177224;11755.4651252738,-23468.6756436812,11692.2586930753;11768.6568343421,-23495.0901130774,11705.4618942997;11781.8340309776,-23521.4755538807,11718.6506021453;11794.9966959851,-23547.8319277036,11731.8247974514;11808.1448102586,-23574.1591963377,11744.9844611464;11821.2783547816,-23600.4573217530,11758.1295742477;11834.3973106268,-23626.7262660979,11771.2601178618;11847.5016589563,-23652.9659916993,11784.3760731843;11860.5913810208,-23679.1764610618,11797.4774214992;11873.6664581600,-23705.3576368672,11810.5641441793;11886.7268718022,-23731.5094819750,11823.6362226857;11899.7726034644,-23757.6319594213,11836.6936385678;11912.8036347520,-23783.7250324195,11849.7363734633;11925.8199473585,-23809.7886643590,11862.7644090978;11938.8215230657,-23835.8228188056,11875.7777272849;11951.8083437436,-23861.8274595011,11888.7763099259;11964.7803913496,-23887.8025503625,11901.7601390098;11977.7376479291,-23913.7480554826,11914.7291966129;11990.6800956152,-23939.6639391292,11927.6834648991;12003.6077166284,-23965.5501657450,11940.6229261194;12016.5204932763,-23991.4066999468,11953.5475626118;12029.4184079540,-24017.2335065263,11966.4573568014;12042.3014431433,-24043.0305504485,11979.3522911998;12055.1695814134,-24068.7977968530,11992.2323484058;12068.0228054197,-24094.5352110519,12005.0975111041;12080.8610979047,-24120.2427585310,12017.9477620663;12093.6844416970,-24145.9204049490,12030.7830841499;12106.4928197121,-24171.5681161374,12043.6034602989;12119.2862149512,-24197.1858580993,12056.4088735429;12131.2003756256,-24221.0450118271,12068.3363440832;12143.1005691549,-24244.8762277319,12080.2498658611;12154.9867773654,-24268.6794694663,12092.1494207324;12166.8589821713,-24292.4547008593,12104.0349906409;12178.7171655748,-24316.2018859149,12115.9065576180;12190.5613096655,-24339.9209888128,12127.7641037825;12202.3913966209,-24363.6119739075,12139.6076113404;12214.2074087060,-24387.2748057291,12151.4370625855;12226.0093282726,-24410.9094489809,12163.2524398978;12237.7971377603,-24434.5158685415,12175.0537257448;12249.5708196950,-24458.0940294624,12186.8409026805;12261.3303566903,-24481.6438969701,12198.6139533457;12273.0757314456,-24505.1654364630,12210.3728604676;12284.8069267477,-24528.6586135134,12222.1176068597;12296.5239254694,-24552.1233938666,12233.8481754219;12308.2267105698,-24575.5597434396,12245.5645491398;12319.9152650946,-24598.9676283226,12257.2667110855;12331.5895721748,-24622.3470147767,12268.9546444162;12343.2496150279,-24645.6978692357,12280.6283323753;12354.8953769570,-24669.0201583043,12292.2877582916;12366.5268413506,-24692.3138487580,12303.9329055790;12378.1439916828,-24715.5789075438,12315.5637577368;12389.7468115133,-24738.8153017791,12327.1802983497;12401.3352844864,-24762.0229987510,12338.7825110868;12412.9093943318,-24785.2019659171,12350.3703797022;12424.4691248641,-24808.3521709049,12361.9438880349;12436.0144599828,-24831.4735815110,12373.5030200084;12447.5453836716,-24854.5661657010,12385.0477596301;12459.0618799991,-24877.6298916099,12396.5780909923;12470.5639331180,-24900.6647275408,12408.0939982711;12482.0515272654,-24923.6706419656,12419.5954657266;12493.5246467622,-24946.6476035236,12431.0824777027;12504.9832760135,-24969.5955810224,12442.5550186271;12516.4273995079,-24992.5145434369,12454.0130730109;12527.8570018181,-25015.4044599094,12465.4566254489;12539.2720675998,-25038.2652997487,12476.8856606189;12550.6725815924,-25061.0970324308,12488.3001632820;12562.0585286183,-25083.8996275972,12499.7001182820;12573.4298935832,-25106.6730550568,12511.0855105463;12584.7866614757,-25129.4172847830,12522.4563250841;12596.1288173671,-25152.1322869155,12533.8125469878;12607.4563464114,-25174.8180317589,12545.1541614320;12618.7692338454,-25197.4744897834,12556.4811536739;12630.0674649878,-25220.1016316230,12567.7935090524;12641.3510252400,-25242.6994280766,12579.0912129887;12652.6199000853,-25265.2678501075,12590.3742509861;12663.8740750891,-25287.8068688425,12601.6426086293;12675.1135358985,-25310.3164555717,12612.8962715847;12686.3382682423,-25332.7965817493,12624.1352256004;12697.5482579311,-25355.2472189922,12635.3594565055;12695.5499767915,-25349.8408956223,12632.0137470539;12711.5450983625,-25381.8625525834,12648.0161782180;12727.5188751418,-25413.8415154475,12663.9972938452;12743.4713024473,-25445.7777748477,12679.9570892578;12759.4023756628,-25477.6713215478,12695.8955598438;12775.3120902381,-25509.5221464443,12711.8127010572;12791.2004416885,-25541.3302405644,12727.7085084169;12807.0674255949,-25573.0955950664,12743.5829775078;12822.9130376039,-25604.8182012401,12759.4361039799;12838.7372734277,-25636.4980505058,12775.2678835484;12854.5401288431,-25668.1351344139,12791.0783119936;12870.3215996928,-25699.7294446455,12806.8673851608;12886.0816818841,-25731.2809730116,12822.6350989601;12901.8203713897,-25762.7897114533,12838.3814493667;12917.5376642465,-25794.2556520407,12854.1064324199;12933.2335565569,-25825.6787869740,12869.8100442241;12948.9080444874,-25857.0591085821,12885.4922809478;12964.5611242690,-25888.3966093230,12901.1531388238;12980.1927921977,-25919.6912817836,12916.7926141495;12995.8030446331,-25950.9431186793,12932.4107032860;13011.3918779994,-25982.1521128534,12948.0074026586;13026.9592887846,-26013.3182572775,12963.5827087564;13042.5052735411,-26044.4415450515,12979.1366181325;13058.0298288848,-26075.5219694023,12994.6691274033;13073.5329514954,-26106.5595236846,13010.1802332492;13089.0146381162,-26137.5542013799,13025.6699324136;13104.4748855544,-26168.5059960974,13041.1382217036;13119.9136906801,-26199.4149015724,13056.5850979894;13135.3310504270,-26230.2809116668,13072.0105582043;13150.7269617920,-26261.1040203691,13087.4145993445;13166.1014218349,-26291.8842217937,13102.7972184695;13181.4544276789,-26322.6215101813,13118.1584127013;13196.7859765096,-26353.3158798975,13133.4981792244;13212.0960655755,-26383.9673254339,13148.8165152864;13227.3846921879,-26414.5758414074,13164.1134181969;13242.6518537205,-26445.1414225591,13179.3888853280;13257.8975476095,-26475.6640637560,13194.6429141142;13273.1217713535,-26506.1437599892,13209.8755020520;13288.3245225129,-26536.5805063734,13225.0866466998;13303.5057987108,-26566.9742981487,13240.2763456783;13318.6655976318,-26597.3251306782,13255.4445966695;13333.8039170227,-26627.6329994490,13270.5913974176;13348.9207546919,-26657.8979000719,13285.7167457281;13364.0161085095,-26688.1198282803,13300.8206394680;13379.0899764071,-26718.2987799311,13315.9030765657;13394.1423563778,-26748.4347510038,13330.9640550109;13409.1732464761,-26778.5277376010,13346.0035728545;13424.1826448176,-26808.5777359468,13361.0216282082;13439.1705495790,-26838.5847423882,13376.0182192451;13454.1369589981,-26868.5487533935,13390.9933441985;13469.9005176412,-26900.1071373937,13406.7644139294;13485.6418076810,-26931.6209793190,13422.5132454402;13501.3608284714,-26963.0902778705,13438.2398380791;13517.0575794262,-26994.5150318684,13453.9441912533;13532.7320600177,-27025.8952402506,13469.6263044291;13548.3842697773,-27057.2309020723,13485.2861771311;13564.0142082952,-27088.5220165068,13500.9238089429;13579.6218752206,-27119.7685828451,13516.5391995067;13595.2072702608,-27150.9706004945,13532.1323485230;13610.7703931823,-27182.1280689801,13547.7032557507;13626.3112438092,-27213.2409879431,13563.2519210069;13641.8298220248,-27244.3093571419,13578.7783441670;13657.3261277698,-27275.3331764504,13594.2825251641;13672.8001610435,-27306.3124458595,13609.7644639896;13688.2519219030,-27337.2471654754,13625.2241606926;13703.6814104632,-27368.1373355199,13640.6616153796;13719.0886268969,-27398.9829563310,13656.0768282153;13734.4735714345,-27429.7840283607,13671.4697994210;13749.8362443639,-27460.5405521773,13686.8405292764;13765.1766460306,-27491.2525284632,13702.1890181178;13780.4947768372,-27521.9199580155,13717.5152663389;13795.7906372439,-27552.5428417461,13732.8192743904;13811.0642277675,-27583.1211806804,13748.1010427800;13826.3155489824,-27613.6549759583,13763.3605720724;13841.5446015194,-27644.1442288331,13778.5978628886;13856.7513860664,-27674.5889406718,13793.8129159067;13871.9359033678,-27704.9891129547,13809.0057318611;13887.0981542249,-27735.3447472755,13824.1763115428;13902.2381394952,-27765.6558453404,13839.3246557990;13917.3558600926,-27795.9224089681,13854.4507655329;13932.4513169873,-27826.1444400901,13869.5546417041;13947.5245112058,-27856.3219407504,13884.6362853283;13962.5754438303,-27886.4549131043,13899.6956974766;13977.6041159994,-27916.5433594198,13914.7328792765;13992.6105289072,-27946.5872820758,13929.7478319107;14007.5946838037,-27976.5866835627,13944.7405566175;14022.5565819944,-28006.5415664826,13959.7110546911;14037.4962248403,-28036.4519335479,13974.6593274806;14052.4136137580,-28066.3177875822,13989.5853763905;14067.3087502193,-28096.1391315195,14004.4892028805;14082.1816357511,-28125.9159684038,14019.3708084652;14097.0322719356,-28155.6483013900,14034.2301947144;14111.8606604097,-28185.3361337420,14049.0673632524;14126.6668028653,-28214.9794688339,14063.8823157584;14141.4507010492,-28244.5783101494,14078.6750539662;14156.2123567628,-28274.1326612811,14093.4455796642;14170.9517718619,-28303.6425259306,14108.1938946948;14185.6689482569,-28333.1079079086,14122.9200009552;14200.3638879125,-28362.5288111344,14137.6239003966;14215.0365928476,-28391.9052396356,14152.3055950242;14228.8872921413,-28419.6375747759,14166.1665198271;14242.7165005331,-28447.3269229068,14180.0059825184;14256.5242193204,-28474.9732866124,14193.8239843826;14270.3104498557,-28502.5766685875,14207.6205267593;14284.0751935467,-28530.1370716368,14221.3956110431;14297.8184518560,-28557.6544986744,14235.1492386831;14311.5402263006,-28585.1289527240,14248.8814111831;14325.2405184528,-28612.5604369190,14262.5921301017;14338.9193299389,-28639.9489545011,14276.2813970513;14352.5766624400,-28667.2945088217,14289.9492136994;14366.2125176914,-28694.5971033402,14303.5955817670;14379.8268974826,-28721.8567416247,14317.2205030296;14393.4198036573,-28749.0734273513,14330.8239793164;14406.9912381135,-28776.2471643047,14344.4060125109;14420.5412028024,-28803.3779563764,14357.9666045498;14434.0696997297,-28830.4658075661,14371.5057574239;14447.5767309544,-28857.5107219805,14385.0234731772;14461.0622985894,-28884.5127038340,14398.5197539076;14474.5264048006,-28911.4717574469,14411.9946017658;14487.9690518078,-28938.3878872472,14425.4480189562;14501.3902418837,-28965.2610977686,14438.8800077359;14514.7899773543,-28992.0913936517,14452.2905704153;14528.1682605986,-29018.8787796425,14465.6797093575;14541.5250940485,-29045.6232605931,14479.0474269786;14554.8604801889,-29072.3248414613,14492.3937257472;14568.1744215570,-29098.9835273099,14505.7186081845;14581.4669207433,-29125.5993233076,14519.0220768643;14594.7379803900,-29152.1722347271,14532.3041344125;14607.9876031924,-29178.7022669465,14545.5647835076;14621.2157918976,-29205.1894254483,14558.8040268799;14634.4225493052,-29231.6337158191,14572.0218673120;14647.6078782665,-29258.0351437496,14585.2183076382;14660.7717816850,-29284.3937150345,14598.3933507448;14673.9142625161,-29310.7094355720,14611.5469995697;14687.0353237670,-29336.9823113641,14624.6792571025;14700.1349684961,-29363.2123485155,14637.7901263842;14713.2131998139,-29389.3995532343,14650.8796105073;14726.2700208818,-29415.5439318308,14663.9477126152;14739.3054349130,-29441.6454907189,14676.9944359032;14752.3194451716,-29467.7042364139,14690.0197836170;14765.3120549727,-29493.7201755337,14703.0237590536;14778.2832676826,-29519.6933147976,14716.0063655606;14791.2330867186,-29545.6236610275,14728.9676065367;14804.1615155484,-29571.5112211462,14741.9074854309;14817.0685576906,-29597.3560021777,14754.8260057429;14829.9542167143,-29623.1580112472,14767.7231710226;14842.8184962390,-29648.9172555809,14780.5989848707;14855.6613999348,-29674.6337425054,14793.4534509376;14868.4829315216,-29700.3074794480,14806.2865729239;14881.2830947698,-29725.9384739356,14819.0983545805;14894.0618934995,-29751.5267335958,14831.8887997078;14906.8193315811,-29777.0722661557,14844.6579121563;14919.5554129345,-29802.5750794419,14857.4056958259;14932.2701415294,-29828.0351813802,14870.1321546662;14944.9635213849,-29853.4525799956,14882.8372926762;14957.6355565699,-29878.8272834123,14895.5211139043;14970.2862512025,-29904.1592998531,14908.1836224482;14982.9156094500,-29929.4486376387,14920.8248224545;14995.5236355291,-29954.6953051890,14933.4447181192;15008.1103337053,-29979.8993110212,14946.0433136868;15020.6757082931,-30005.0606637507,14958.6206134510;15033.2197636559,-30030.1793720905,14971.1766217539;15045.7425042059,-30055.2554448511,14983.7113429864;15058.2439344036,-30080.2888909396,14996.2247815877;15070.7240587584,-30105.2797193610,15008.7169420457;15083.1828818280,-30130.2279392165,15021.1878288964;15095.6204082182,-30155.1335597037,15033.6374467238;15108.0366425832,-30179.9965901170,15046.0658001602;15120.4315896252,-30204.8170398468,15058.4728938858;15132.8052540945,-30229.5949183793,15070.8587326288;15145.1576407892,-30254.3302352965,15083.2233211649;15157.4887545550,-30279.0230002757,15095.5666643174;15169.7986002855,-30303.6732230897,15107.8887669575;15182.0871829218,-30328.2809136062,15120.1896340035;15194.3545074523,-30352.8460817881,15132.4692704213;15206.6005789130,-30377.3687376923,15144.7276812236;15218.8254023870,-30401.8488914709,15156.9648714708;15231.0289830044,-30426.2865533693,15169.1808462696;15243.2113259425,-30450.6817337279,15181.3756107744;15255.3724364254,-30475.0344429799,15193.5491701855;15267.5123197241,-30499.3446916531,15205.7015297508;15279.6309811563,-30523.6124903677,15217.8326947640;15291.7284260862,-30547.8378498375,15229.9426705658;15303.8046599246,-30572.0207808695,15242.0314625431;15315.8596881287,-30596.1612943629,15254.0990761290;15327.8935162018,-30620.2594013097,15266.1455168028;15339.9061496935,-30644.3151127942,15278.1707900899;15351.8975941995,-30668.3284399928,15290.1749015617;15363.8678553613,-30692.2993941733,15302.1578568351;15375.8169388666,-30716.2279866963,15314.1196615733;15387.7448504484,-30740.1142290124,15326.0603214846;15399.6515958857,-30763.9581326647,15337.9798423232;15411.5371810027,-30787.7597092865,15349.8782298885;15423.4016116694,-30811.5189706026,15361.7554900254;15435.2448938009,-30835.2359284276,15373.6116286236;15447.0670333576,-30858.9105946672,15385.4466516185;15458.8680363449,-30882.5429813171,15397.2605649902;15470.6479088134,-30906.1331004628,15409.0533747636;15482.4066568584,-30929.6809642796,15420.8250870085;15494.1442866201,-30953.1865850324,15432.5757078393;15505.8608042835,-30976.6499750759,15444.3052434153;15517.5562160780,-31000.0711468530,15456.0136999397;15529.2305282774,-31023.4501128962,15467.7010836606;15540.8837472003,-31046.7868858268,15479.3674008702;15552.5158792092,-31070.0814783542,15491.0126579049;15564.1269307108,-31093.3339032761,15502.6368611448;15575.7169081560,-31116.5441734785,15514.2400170144;15587.2858180396,-31139.7123019354,15525.8221319819;15598.8336669001,-31162.8383017081,15537.3832125591;15610.3604613201,-31185.9221859456,15548.9232653017;15621.8662079255,-31208.9639678841,15560.4422968088;15633.3509133858,-31231.9636608467,15571.9403137228;15644.8145844141,-31254.9212782435,15583.4173227296;15656.2572277668,-31277.8368335713,15594.8733305583;15667.6788502433,-31300.7103404132,15606.3083439811;15679.0794586863,-31323.5418124382,15617.7223698131;15690.4590599815,-31346.3312634018,15629.1154149125;15701.8176610574,-31369.0787071449,15640.4874861802;15713.1552688856,-31391.7841575944,15651.8385905598;15724.4718904800,-31414.4476287620,15663.1687350374;15735.7675328974,-31437.0691347449,15674.4779266419;15747.0422032369,-31459.6486897253,15685.7661724442;15758.2959086401,-31482.1863079701,15697.0334795577;15769.5286562908,-31504.6820038303,15708.2798551379;15780.7404534153,-31527.1357917422,15719.5053063827;15791.9313072814,-31549.5476862252,15730.7098405314;15803.1012251992,-31571.9177018831,15741.8934648656;15814.2502145209,-31594.2458534035,15753.0561867086;15825.3782826399,-31616.5321555572,15764.1980134251;15836.4854369918,-31638.7766231983,15775.3189524216;15847.5716850535,-31660.9792712643,15786.4190111462;15858.6370343433,-31683.1401147754,15797.4981970881;15869.6814924210,-31705.2591688343,15808.5565177777;15880.7050668875,-31727.3364486262,15819.5939807866;15891.7077653850,-31749.3719694191,15830.6105937278;15902.6895955968,-31771.3657465622,15841.6063642548;15913.6505652466,-31793.3177954870,15852.5813000620;15924.5906820997,-31815.2281317066,15863.5354088847;15935.5099539616,-31837.0967708156,15874.4686984987;15946.4083886786,-31858.9237284895,15885.3811767205;15957.2859941375,-31880.7090204854,15896.2728514068;15968.1427782656,-31902.4526626405,15907.1437304547;15978.9787490303,-31924.1546708732,15917.9938218017;15989.7939144395,-31945.8150611819,15928.8231334252;16000.5882825411,-31967.4338496455,15939.6316733427;16011.3618614229,-31989.0110524228,15950.4194496116;16022.1146592125,-32010.5466857517,15961.1864703289;16032.8466840778,-32032.0407659511,15971.9327436319;16043.5579442259,-32053.4933094181,15982.6582776969;16054.2484479038,-32074.9043326292,15993.3630807399;16064.9182033977,-32096.2738521400,16004.0471610164;16075.5672190336,-32117.6018845853,16014.7105268212;16086.1955031764,-32138.8884466776,16025.3531864882;16096.8030642303,-32160.1335552082,16035.9751483904;16107.3899106388,-32181.3372270464,16046.5764209398;16117.9560508842,-32202.4994791399,16057.1570125874;16128.5014934876,-32223.6203285134,16067.7169318228;16139.0262470091,-32244.6997922699,16078.2561871745;16149.5303200472,-32265.7378875888,16088.7747872094;16160.0137212393,-32286.7346317275,16099.2727405331;16170.4764592611,-32307.6900420202,16109.7500557894;16180.9185428265,-32328.6041358771,16120.2067416604;16191.3399806879,-32349.4769307856,16130.6428068664;16201.7407816360,-32370.3084443095,16141.0582601660;16212.1209544993,-32391.0986940882,16151.4531103554;16222.4805081443,-32411.8476978372,16161.8273662689;16232.8194514754,-32432.5554733478,16172.1810367785;16243.1377934347,-32453.2220384867,16182.5141307939;16253.4355430024,-32473.8474111962,16192.8266572627;16263.7127091955,-32494.4316094930,16203.1186251693;16273.9693010691,-32514.9746514697,16213.3900435361;16284.2053277153,-32535.4765552925,16223.6409214223;16294.4207982636,-32555.9373392031,16233.8712679248;16304.6157218807,-32576.3570215166,16244.0810921769;16314.7901077702,-32596.7356206228,16254.2704033494;16324.9439651728,-32617.0731549851,16264.4392106498;16335.0773033659,-32637.3696431407,16274.5875233225;16345.1901316638,-32657.6251037002,16284.7153506482;16355.2824594175,-32677.8395553477,16294.8227019446;16365.3542960143,-32698.0130168402,16304.9095865657;16375.4056508783,-32718.1455070075,16314.9760139018;16385.4365334694,-32738.2370447520,16325.0219933794;16395.4469532845,-32758.2876490492,16335.0475344616;16405.4369198560,-32778.2973389460,16345.0526466470;16415.4064427526,-32798.2661335620,16355.0373394705;16425.3555315792,-32818.1940520886,16365.0016225029;16435.2841959761,-32838.0811137886,16374.9455053506;16445.1924456195,-32857.9273379965,16384.8689976558;16455.0802902214,-32877.7327441180,16394.7721090962;16464.9477395293,-32897.4973516300,16404.6548493850;16474.7948033261,-32917.2211800802,16414.5172282708;16484.6214914299,-32936.9042490867,16424.3592555373;16494.4278136943,-32956.5465783388,16434.1809410037;16504.2137800080,-32976.1481875954,16443.9822945240;16513.9794002947,-32995.7090966858,16453.7633259873;16523.7246845131,-33015.2293255089,16463.5240453175;16533.4496426565,-33034.7088940337,16473.2644624734;16543.1542847534,-33054.1478222986,16482.9845874483;16552.8386208667,-33073.5461304109,16492.6844302703;16562.5026610937,-33092.9038385474,16502.3640010018;16572.1464155666,-33112.2209669539,16512.0233097397;16581.7698944514,-33131.4975359441,16521.6623666149;16591.3731079490,-33150.7335659014,16531.2811817931;16600.9560662938,-33169.9290772765,16540.8797654734;16610.5187797548,-33189.0840905889,16550.4581278894;16620.0612586346,-33208.1986264254,16560.0162793083;16629.5835132697,-33227.2727054407,16569.5542300310;16639.0855540308,-33246.3063483575,16579.0719903926;16648.5673913216,-33265.2995759651,16588.5695707613;16658.0290355800,-33284.2524091205,16598.0469815390;16667.4704972768,-33303.1648687472,16607.5042331608;16676.8917869167,-33322.0369758359,16616.9413360956;16686.2929150373,-33340.8687514432,16626.3583008450;16695.6738922094,-33359.6602166924,16635.7551379437;16705.0347290371,-33378.4113927731,16645.1318579599;16714.3754361574,-33397.1223009408,16654.4884714944;16723.6960242400,-33415.7929625165,16663.8249891806;16732.9965039876,-33434.4233988867,16673.1414216850;16742.2768861356,-33453.0136315036,16682.4377797064;16751.5371814518,-33471.5636818844,16691.7140739765;16760.7774007366,-33490.0735716113,16700.9703152590;16769.9975548228,-33508.5433223312,16710.2065143504;16779.1976545755,-33526.9729557556,16719.4226820788;16788.3777108920,-33545.3624936606,16728.6188293052;16797.5377347017,-33563.7119578863,16737.7949669220;16806.6777369660,-33582.0213703366,16746.9511058538;16815.7977286781,-33600.2907529796,16756.0872570571;16824.8977208633,-33618.5201278468,16765.2034315200;16833.9777245783,-33636.7095170330,16774.2996402624;16843.0377509116,-33654.8589426967,16783.3758943357;16852.0778109832,-33672.9684270588,16792.4322048226;16861.0979159446,-33691.0379924038,16801.4685828375;16870.0980769782,-33709.0676610779,16810.4850395258;16879.0783052983,-33727.0574554905,16819.4815860641;16888.0386121499,-33745.0073981129,16828.4582336601;16896.9790088092,-33762.9175114789,16837.4149935526;16905.8995065831,-33780.7878181833,16846.3518770111;16914.8001168097,-33798.6183408837,16855.2688953361;16923.6808508575,-33816.4091022982,16864.1660598584;16932.5417201261,-33834.1601252069,16873.0433819398;16941.3827360453,-33851.8714324509,16881.9008729726;16950.2039100752,-33869.5430469316,16890.7385443791;16959.0052537069,-33887.1749916119,16899.5564076123;16967.7867784614,-33904.7672895151,16908.3544741554;16976.5484958896,-33922.3199637243,16917.1327555214;16985.2904175729,-33939.8330373833,16925.8912632536;16994.0125551226,-33957.3065336958,16934.6300089252;17002.7149201799,-33974.7404759250,16943.3490041391;17011.3975244155,-33992.1348873939,16952.0482605281;17020.0603795302,-34009.4897914848,16960.7277897546;17027.9877816269,-34025.3737148274,16968.6729700931;17035.8960686138,-34041.2193988580,16976.5990563050;17043.7852516035,-34057.0268657829,16984.5060594656;17051.6553417390,-34072.7961378686,16992.3939906799;17059.5063501932,-34088.5272374423,17000.2628610838;17067.3382881693,-34104.2201868910,17008.1126818425;17075.1511669001,-34119.8750086614,17015.9434641513;17082.9449976486,-34135.4917252605,17023.7552192356;17090.7197917075,-34151.0703592544,17031.5479583501;17098.4755603992,-34166.6109332687,17039.3216927794;17106.2123150756,-34182.1134699885,17047.0764338377;17113.9300671179,-34197.5779921569,17054.8121928683;17121.6288279369,-34213.0045225765,17062.5289812438;17129.3086089730,-34228.3930841085,17070.2268103666;17136.9694216952,-34243.7436996724,17077.9056916678;17144.6112776020,-34259.0563922457,17085.5656366075;17152.2341882206,-34274.3311848639,17093.2066566749;17159.8381651074,-34289.5681006206,17100.8287633881;17167.4232198477,-34304.7671626669,17108.4319682940;17174.9893640550,-34319.9283942112,17116.0162829679;17182.5366093719,-34335.0518185193,17123.5817190140;17190.0649674694,-34350.1374589138,17131.1282880647;17197.5744500469,-34365.1853387749,17138.6560017811;17205.0650688322,-34380.1954815384,17146.1648718523;17212.5368355812,-34395.1679106974,17153.6549099957;17219.9897620782,-34410.1026498012,17161.1261279568;17227.4238601354,-34424.9997224550,17168.5785375093;17234.8391415929,-34439.8591523198,17176.0121504545;17242.2356183189,-34454.6809631128,17183.4269786217;17249.6133022092,-34469.4651786063,17190.8230338679;17256.9722051873,-34484.2118226285,17198.2003280778;17264.3123392043,-34498.9209190622,17205.5588731636;17271.6337162388,-34513.5924918453,17212.8986810648;17278.9363482970,-34528.2265649710,17220.2197637485;17286.2202474119,-34542.8231624864,17227.5221332089;17293.4854256443,-34557.3823084935,17234.8058014674;17300.7318950818,-34571.9040271486,17242.0707805726;17307.9596678391,-34586.3883426617,17249.3170825999;17315.1687560578,-34600.8352792970,17256.5447196519;17322.3591719064,-34615.2448613722,17263.7537038575;17329.5309275803,-34629.6171132587,17270.9440473727;17336.6840353010,-34643.9520593807,17278.1157623800;17343.8185073173,-34658.2497242163,17285.2688610884;17350.9343559040,-34672.5101322959,17292.4033557334;17358.0315933622,-34686.7333082027,17299.5192585767;17365.1102320199,-34700.9192765733,17306.6165819065;17372.1702842307,-34715.0680620956,17313.6953380369;17379.2117623744,-34729.1796895103,17320.7555393081;17386.2346788571,-34743.2541836101,17327.7971980864;17393.2390461105,-34757.2915692393,17334.8203267639;17400.9256009758,-34772.6933836163,17342.5246019958;17408.5930430275,-34788.0569622367,17350.2097843290;17416.2413854168,-34803.3823313845,17357.8758868743;17423.8706413208,-34818.6695173943,17365.5229227675;17431.4808239404,-34833.9185466490,17373.1509051691;17439.0719465013,-34849.1294455809,17380.7598472636;17446.6440222538,-34864.3022406713,17388.3497622604;17454.1970644720,-34879.4369584495,17395.9206633927;17461.7310864546,-34894.5336254937,17403.4725639181;17469.2461015245,-34909.5922684306,17411.0054771186;17476.7421230284,-34924.6129139345,17418.5194162996;17484.2191643372,-34939.5955887281,17426.0143947910;17491.6772388457,-34954.5403195818,17433.4904259463;17499.1163599720,-34969.4471333130,17440.9475231427;17506.5365411586,-34984.3160567871,17448.3856997811;17513.9377958710,-34999.1471169166,17455.8049692861;17521.3201375987,-35013.9403406609,17463.2053451055;17528.6835798543,-35028.6957550265,17470.5868407109;17536.0281361739,-35043.4133870663,17477.9494695969;17543.3538201168,-35058.0932638799,17485.2932452814;17550.6606452654,-35072.7354126130,17492.6181813053;17557.9486252254,-35087.3398604577,17499.9242912329;17565.2177736251,-35101.9066346521,17507.2115886510;17572.4681041162,-35116.4357624801,17514.4800871698;17579.6996303728,-35130.9272712708,17521.7298004217;17586.9123660919,-35145.3811883994,17528.9607420622;17594.1063249930,-35159.7975412858,17536.1729257692;17601.2815208184,-35174.1763573955,17543.3663652433;17608.4379673327,-35188.5176642385,17550.5410742073;17615.5756783228,-35202.8214893698,17557.6970664066;17622.6946675980,-35217.0878603888,17564.8343556085;17629.7949489896,-35231.3168049395,17571.9529556028;17636.8765363514,-35245.5083507099,17579.0528802012;17643.9394435589,-35259.6625254323,17586.1341432375;17650.9836845097,-35273.7793568827,17593.1967585674;17658.0092731230,-35287.8588728808,17600.2407400682;17665.0162233399,-35301.9011012897,17607.2661016391;17672.0045491234,-35315.9060700162,17614.2728572011;17678.9742644578,-35329.8738070102,17621.2610206966;17685.9253833490,-35343.8043402644,17628.2306060894;17692.8579198243,-35357.6976978144,17635.1816273647;17699.7718879323,-35371.5539077385,17642.1140985292;17706.6673017429,-35385.3729981575,17649.0280336106;17713.5441753470,-35399.1549972343,17655.9234466577;17720.4025228568,-35412.8999331745,17662.8003517406;17727.2423584053,-35426.6078342249,17669.6587629500;17734.0636961466,-35440.2787286749,17676.4986943980;17740.8665502554,-35453.9126448550,17683.3201602168;17747.6509349271,-35467.5096111370,17690.1231745599;17754.4168643780,-35481.0696559346,17696.9077516009;17761.1643528447,-35494.5928077024,17703.6739055346;17767.8934145842,-35508.0790949353,17710.4216505753;17774.6040638744,-35521.5285461701,17717.1510009587;17781.2963150128,-35534.9411899831,17723.8619709399;17787.9701823176,-35548.3170549918,17730.5545747947;17794.6256801268,-35561.6561698535,17737.2288268188;17801.2628227989,-35574.9585632661,17743.8847413281;17807.8816247119,-35588.2242639669,17750.5223326582;17814.4821002638,-35601.4533007331,17757.1416151646;17821.0642638723,-35614.6457023815,17763.7426032226;17827.6281299752,-35627.8014977685,17770.3253112274;17834.1737130296,-35640.9207157897,17776.8897535935;17840.7010275120,-35654.0033853793,17783.4359447549;17847.2100879186,-35667.0495355110,17789.9638991652;17853.7009087651,-35680.0591951972,17796.4736312974;17860.1735045859,-35693.0323934884,17802.9651556435;17866.6278899351,-35705.9691594737,17809.4384867148;17873.0640793858,-35718.8695222808,17815.8936390417;17879.4820875302,-35731.7335110751,17822.3306271738;17885.8819289793,-35744.5611550601,17828.7494656793;17892.2636183629,-35757.3524834767,17835.1501691454;17898.6271703298,-35770.1075256037,17841.5327521780;17904.9725995474,-35782.8263107574,17847.8972294018;17911.2999207015,-35795.5088682906,17854.2436154599;17917.6091484969,-35808.1552275944,17860.5719250143;17923.9002976564,-35820.7654180957,17866.8821727449;17930.1733829214,-35833.3394692585,17873.1743733503;17936.4284190515,-35845.8774105837,17879.4485415472;17942.6654208245,-35858.3792716080,17885.7046920706;17948.8844030363,-35870.8450819049,17891.9428396736;17955.0853805009,-35883.2748710836,17898.1629991271;17961.2683680502,-35895.6686687894,17904.3651852203;17967.4333805340,-35908.0265047034,17910.5494127599;17973.5804328197,-35920.3484085421,17916.7156965706;17979.7095397927,-35932.6344100572,17922.8640514945;17985.8207163559,-35944.8845390365,17928.9944923918;17991.9139774297,-35957.0988253020,17935.1070341398;17997.9893379521,-35969.2772987112,17941.2016916334;18004.0468128780,-35981.4199891558,17947.2784797847;18010.0864171803,-35993.5269265628,17953.3374135235;18016.1081658485,-36005.5981408931,17959.3785077963;18022.1120738897,-36017.6336621419,17965.4017775669;18028.0981563277,-36029.6335203390,17971.4072378163;18034.0664282035,-36041.5977455477,17977.3949035424;18040.0169045749,-36053.5263678651,17983.3647897597;18045.9496005164,-36065.4194174222,17989.3169114999;18051.8645311195,-36077.2769243833,17995.2512838111;18057.7617114921,-36089.0989189459,18001.1679217582;18063.6411567586,-36100.8854313407,18007.0668404225;18069.5028820602,-36112.6364918317,18012.9480549021;18074.0022530920,-36121.6627122672,18017.4689675454;18078.4850299561,-36130.6557325032,18021.9733001026;18082.9512266794,-36139.6155805748,18026.4610665589;18087.4008573063,-36148.5422845524,18030.9322809175;18091.8339358990,-36157.4358725421,18035.3869571988;18096.2504765368,-36166.2963726843,18039.8251094410;18100.6504933170,-36175.1238131549,18044.2467516995;18105.0340003540,-36183.9182221645,18048.6518980473;18109.4010117795,-36192.6796279583,18053.0405625746;18113.7515417423,-36201.4080588154,18057.4127593887;18118.0856044086,-36210.1035430500,18061.7685026141;18122.4032139612,-36218.7661090095,18066.1078063922;18126.7043846004,-36227.3957850762,18070.4306848815;18130.9891305429,-36235.9925996652,18074.7371522574;18135.2574660226,-36244.5565812261,18079.0272227120;18139.5094052896,-36253.0877582411,18083.3009104539;18143.7449626112,-36261.5861592260,18087.5582297087;18147.9641522709,-36270.0518127304,18091.7991947183;18152.1669885686,-36278.4847473357,18096.0238197411;18156.3534858210,-36286.8849916568,18100.2321190519;18160.5236583608,-36295.2525743414,18104.4241069420;18164.6775205369,-36303.5875240690,18108.5997977186;18168.8150867144,-36311.8898695518,18112.7592057050;18172.9363712746,-36320.1596395343,18116.9023452410;18177.0413886147,-36328.3968627928,18121.0292306820;18181.1301531477,-36336.6015681356,18125.1398763995;18185.2026793027,-36344.7737844024,18129.2342967806;18189.2589815242,-36352.9135404645,18133.3125062284;18193.2990742727,-36361.0208652248,18137.3745191616;18197.3229720239,-36369.0957876170,18141.4203500143;18201.3306892694,-36377.1383366062,18145.4500132362;18205.3222405162,-36385.1485411884,18149.4635232926;18209.2976402864,-36393.1264303899,18153.4608946640;18213.2569031173,-36401.0720332678,18157.4421418461;18217.2000435619,-36408.9853789097,18161.4072793498;18221.1270761880,-36416.8664964337,18165.3563217014;18225.0380155782,-36424.7154149872,18169.2892834419;18228.9328763305,-36432.5321637483,18173.2061791273;18232.8116730575,-36440.3167719245,18177.1070233286;18236.6744203868,-36448.0692687530,18180.9918306316;18240.5211329605,-36455.7896835006,18184.8606156367;18244.3518254354,-36463.4780454631,18188.7133929589;18248.1665124830,-36471.1343839657,18192.5501772280;18251.9652087891,-36478.7587283623,18196.3709830881;18255.7479290542,-36486.3511080364,18200.1758251978;18259.5146879929,-36493.9115523994,18203.9647182299;18263.2655003339,-36501.4400908914,18207.7376768716;18267.0003808205,-36508.9367529810,18211.4947158243;18270.7193442097,-36516.4015681649,18215.2358498032;18274.4224052729,-36523.8345659682,18218.9610935379;18278.7684439965,-36532.5535643103,18223.3283284344;18283.0980811727,-36541.2397467233,18227.6791745600;18287.4113321681,-36549.8931439233,18232.0136472389;18291.7082123623,-36558.5137866519,18236.3317618081;18295.9887371479,-36567.1017056767,18240.6335336176;18300.2529219301,-36575.6569317911,18244.9189780300;18304.5007821271,-36584.1794958141,18249.1881104209;18308.7323331697,-36592.6694285900,18253.4409461788;18312.9475905012,-36601.1267609882,18257.6775007042;18317.1465695778,-36609.5515239036,18261.8977894107;18321.3292858679,-36617.9437482560,18266.1018277243;18325.4957548523,-36626.3034649895,18270.2896310831;18329.6459920241,-36634.6307050734,18274.4612149378;18333.7800128888,-36642.9254995016,18278.6165947513;18337.8978329640,-36651.1878792918,18282.7557859985;18341.9994677793,-36659.4178754862,18286.8788041667;18346.0849328765,-36667.6155191515,18290.9856647550;18350.1542438092,-36675.7808413776,18295.0763832745;18354.2074161429,-36683.9138732786,18299.1509752482;18358.2444654550,-36692.0146459921,18303.2094562110;18362.2654073345,-36700.0831906793,18307.2518417094;18366.2702573821,-36708.1195385246,18311.2781473015;18370.2590312102,-36716.1237207356,18315.2883885572;18374.2317444425,-36724.0957685428,18319.2825810578;18378.1884127142,-36732.0357132001,18323.2607403960;18382.1290516721,-36739.9435859837,18327.2228821760;18386.0536769738,-36747.8194181923,18331.1690220131;18389.9623042887,-36755.6632411474,18335.0991755339;18393.8549492967,-36763.4750861926,18339.0133583763;18397.7316276895,-36771.2549846939,18342.9115861891;18401.5923551691,-36779.0029680391,18346.7938746321;18405.4371474489,-36786.7190676379,18350.6602393763;18409.2660202529,-36794.4033149215,18354.5106961030;18413.0789893160,-36802.0557413434,18358.3452605050;18416.8760703837,-36809.6763783776,18362.1639482851;18420.6572792124,-36817.2652575203,18365.9667751575;18424.4226315687,-36824.8224102881,18369.7537568462;18428.1721432299,-36832.3478682190,18373.5249090863;18431.9058299837,-36839.8416628720,18377.2802476230;18435.6237076283,-36847.3038258266,18381.0197882122;18439.3257919717,-36854.7343886826,18384.7435466194;18443.0120988327,-36862.1333830609,18388.4515386212;18446.6826440398,-36869.5008406022,18392.1437800037;18450.3374434317,-36876.8367929673,18395.8202865633;18453.9765128572,-36884.1412718376,18399.4810741064;18457.5998681751,-36891.4143089139,18403.1261584495;18461.2075252535,-36898.6559359165,18406.7555554185;18464.7994999710,-36905.8661845859,18410.3692808495;18468.3758082155,-36913.0450866818,18413.9673505883;18471.9364658844,-36920.1926739827,18417.5497804901;18475.4814888853,-36927.3089782874,18421.1165864200;18479.0108931346,-36934.3940314125,18424.6677842524;18482.5246945584,-36941.4478651941,18428.2033898710;18486.0229090925,-36948.4705114874,18431.7234191694;18489.5055526813,-36955.4620021652,18435.2278880498;18492.9726412790,-36962.4223691198,18438.7168124243;18496.4241908488,-36969.3516442614,18442.1902082137;18499.8602173627,-36976.2498595180,18445.6480913482;18503.2807368022,-36983.1170468364,18449.0904777667;18506.6857651573,-36989.9532381808,18452.5173834175;18510.0753184271,-36996.7584655333,18455.9288242572;18513.4494126197,-37003.5327608938,18459.3248162519;18516.8080637513,-37010.2761562794,18462.7053753759;18520.1512878474,-37016.9886837247,18466.0705176123;18523.4791009418,-37023.6703752816,18469.4202589531;18526.7915190770,-37030.3212630191,18472.7546153985;18530.0885583039,-37036.9413790232,18476.0736029575;18533.3702346815,-37043.5307553964,18479.3772376471;18536.6365642776,-37050.0894242580,18482.6655354931;18539.8875631681,-37056.6174177444,18485.9385125292;18543.1232474367,-37063.1147680073,18489.1961847974;18546.3436331759,-37069.5815072158,18492.4385683480;18549.5487364858,-37076.0176675545,18495.6656792393;18552.7385734746,-37082.4232812241,18498.8775335374;18555.9131602583,-37088.7983804413,18502.0741473167;18559.0725129610,-37095.1429974383,18505.2555366591;18562.2166477145,-37101.4571644632,18508.4217176546;18565.3455806581,-37107.7409137794,18511.5727064007;18568.4593279390,-37113.9942776656,18514.7085190027;18571.5579057120,-37120.2172884157,18517.8291715735;18574.6413301392,-37126.4099783390,18520.9346802336;18577.7096173903,-37132.5723797590,18524.0250611107;18580.7627836423,-37138.7045250145,18527.1003303401;18583.8008450797,-37144.8064464593,18530.1605040646;18586.8238178942,-37150.8781764611,18533.2055984340;18589.8317182844,-37156.9197474020,18536.2356296052;18592.8245624564,-37162.9311916790,18539.2506137428;18595.8023666231,-37168.9125417026,18542.2505670178;18598.7651470043,-37174.8638298973,18545.2355056085;18601.7129198273,-37180.7850887023,18548.2054457005;18604.6457013257,-37186.6763505697,18551.1604034856;18607.5635077399,-37192.5376479652,18554.1003951628;18610.4663553173,-37198.3690133687,18557.0254369379;18613.3542603118,-37204.1704792726,18559.9355450231;18616.2272389840,-37209.9420781833,18562.8307356375;18619.0853076008,-37215.6838426197,18565.7110250067;18621.9284824358,-37221.3958051138,18568.5764293625;18624.7567797690,-37227.0779982106,18571.4269649435;18627.5702158867,-37232.7304544679,18574.2626479945;18630.3688070813,-37238.3532064556,18577.0834947665;18633.1525696515,-37243.9462867564,18579.8895215168;18635.9215199024,-37249.5097279655,18582.6807445091;18638.6756741447,-37255.0435626897,18585.4571800128;18641.4150486956,-37260.5478235483,18588.2188443036;18644.1396598780,-37266.0225431724,18590.9657536630;18646.8495240206,-37271.4677542051,18593.6979243786;18649.5446574580,-37276.8834893007,18596.4153727436;18652.2250765309,-37282.2697811257,18599.1181150574;18654.8907975851,-37287.6266623576,18601.8061676246;18657.5418369725,-37292.9541656851,18604.4795467558;18660.1782110504,-37298.2523238086,18607.1382687673;18662.7999361814,-37303.5211694387,18609.7823499803;18665.4070287340,-37308.7607352979,18612.4118067223;18667.9995050817,-37313.9710541188,18615.0266553256;18670.5773816035,-37319.1521586448,18617.6269121281;18673.1406746837,-37324.3040816302,18620.2125934729;18675.6894007116,-37329.4268558392,18622.7837157084;18678.2235760817,-37334.5205140466,18625.3402951881;18680.7432171936,-37339.5850890372,18627.8823482705;18683.2483404520,-37344.6206136063,18630.4098913193;18685.7389622664,-37349.6271205584,18632.9229407031;18688.2150990513,-37354.6046427083,18635.4215127953;18690.6767672258,-37359.5532128803,18637.9056239744;18693.1239832141,-37364.4728639084,18640.3752906234;18695.5567634448,-37369.3636286358,18642.8305291303;18697.9751243513,-37374.2255399151,18645.2713558874;18700.3790823714,-37379.0586306082,18647.6977872919;18702.7686539478,-37383.8629335860,18650.1098397456;18705.1438555272,-37388.6384817281,18652.5075296544;18707.5047035609,-37393.3853079233,18654.8908734291;18709.8512145044,-37398.1034450687,18657.2598874844;18712.1834048179,-37402.7929260706,18659.6145882396;18714.5012909652,-37407.4537838428,18661.9549921181;18716.8048894146,-37412.0860513082,18664.2811155475;18719.0942166386,-37416.6897613978,18666.5929749596;18721.3692891134,-37421.2649470504,18668.8905867902;18723.6301233192,-37425.8116412128,18671.1739674789;18725.8767357407,-37430.3298768402,18673.4431334698;18728.1091428654,-37434.8196868946,18675.6981012100;18730.3273611855,-37439.2811043463,18677.9388871512;18732.5314071966,-37443.7141621732,18680.1655077486;18734.7212973979,-37448.1188933598,18682.3779794609;18736.8970482923,-37452.4953308987,18684.5763187507;18739.0586763861,-37456.8435077889,18686.7605420840;18741.2061981894,-37461.1634570370,18688.9306659305;18743.3396302156,-37465.4552116564,18691.0867067632;18745.4589889811,-37469.7188046668,18693.2286810586;18747.5642910063,-37473.9542690951,18695.3566052964;18749.6555528142,-37478.1616379746,18697.4704959598;18751.7327909315,-37482.3409443447,18699.5703695351;18754.4171947465,-37487.7346198992,18702.2764723064;18757.0871307216,-37493.0993445555,18704.9681144624;18759.7426158723,-37498.4351523318,18707.6453129778;18762.3836672164,-37503.7420772508,18710.3080848297;18765.0103017745,-37509.0201533402,18712.9564469979;18767.6225365687,-37514.2694146316,18715.5904164640;18770.2203886240,-37519.4898951618,18718.2100102121;18772.8038749671,-37524.6816289711,18720.8152452283;18775.3730126271,-37529.8446501048,18723.4061385011;18777.9278186347,-37534.9789926115,18725.9827070207;18780.4683100228,-37540.0846905443,18728.5449677795;18782.9945038263,-37545.1617779600,18731.0929377717;18785.5064170820,-37550.2102889194,18733.6266339938;18788.0040668282,-37555.2302574861,18736.1460734435;18790.4874701052,-37560.2217177283,18738.6512731208;18792.9566439549,-37565.1847037170,18741.1422500271;18795.4116054207,-37570.1192495263,18743.6190211656;18797.8523715479,-37575.0253892341,18746.0816035412;18800.2789593830,-37579.9031569211,18748.5300141601;18802.6913859741,-37584.7525866706,18750.9642700302;18805.0896683707,-37589.5737125692,18753.3843881607;18807.4738236237,-37594.3665687062,18755.7903855624;18809.8438687851,-37599.1311891733,18758.1822792472;18812.1998209085,-37603.8676080650,18760.5600862284;18814.5416970485,-37608.5758594781,18762.9238235206;18816.8695142605,-37613.2559775114,18765.2735081392;18819.1832896016,-37617.9079962664,18767.6091571012;18821.4830401294,-37622.5319498464,18769.9307874244;18823.7687829029,-37627.1278723567,18772.2384161276;18826.0405349818,-37631.6957979046,18774.5320602306;18828.2983134265,-37636.2357605989,18776.8117367541;18830.5421352984,-37640.7477945503,18779.0774627197;18832.7720176597,-37645.2319338708,18781.3292551495;18834.9879775733,-37649.6882126743,18783.5671310669;18837.1900321026,-37654.1166650755,18785.7911074954;18839.3781983117,-37658.5173251905,18788.0012014594;18841.5524932651,-37662.8902271366,18790.1974299839;18843.7129340280,-37667.2354050321,18792.3798100942;18845.8595376659,-37671.5528929960,18794.5483588165;18847.9923212448,-37675.8427251485,18796.7030931769;18850.1113018309,-37680.1049356101,18798.8440302023;18852.2164964907,-37684.3395585021,18800.9711869196;18854.3079222908,-37688.5466279460,18803.0845803561;18856.3855962983,-37692.7261780641,18805.1842275394;18858.4495355802,-37696.8782429787,18807.2701454970;18860.4997572034,-37701.0028568121,18809.3423512566;18862.5362782352,-37705.1000536873,18811.4008618462;18864.5591157426,-37709.1698677264,18813.4456942933;18866.5682867926,-37713.2123330520,18815.4768656259;18868.5638084519,-37717.2274837862,18817.4943928715;18869.3268265579,-37718.7775088682,18818.2812734072;18870.0771525591,-37720.3021340307,18819.0554657049;18870.8148026055,-37721.8013915623,18819.8169858765;18871.5397928477,-37723.2753137527,18820.5658500353;18872.2521394374,-37724.7239328938,18821.3020742951;18872.9518585267,-37726.1472812782,18822.0256747704;18873.6389662683,-37727.5453912003,18822.7366675763;18874.3134788157,-37728.9182949553,18823.4350688288;18874.9754123227,-37730.2660248399,18824.1208946441;18875.6247829436,-37731.5886131510,18824.7941611391;18876.2616068332,-37732.8860921872,18825.4548844310;18876.8859001466,-37734.1584942474,18826.1030806376;18877.4976790391,-37735.4058516312,18826.7387658769;18878.0969596664,-37736.6281966387,18827.3619562671;18878.6837581844,-37737.8255615705,18827.9726679268;18879.2580907491,-37738.9979787277,18828.5709169748;18879.8199735165,-37740.1454804112,18829.1567195299;18880.3694226428,-37741.2680989225,18829.7300917111;18880.9064542842,-37742.3658665628,18830.2910496373;18881.4310845967,-37743.4388156334,18830.8396094276;18881.9433297362,-37744.4869784352,18831.3757872007;18882.4432058587,-37745.5103872692,18831.8995990755;18882.9307291197,-37746.5090744358,18832.4110611707;18883.4059156745,-37747.4830722345,18832.9101896044;18883.8687816782,-37748.4324129650,18833.3970004949;18884.3193432855,-37749.3571289260,18833.8715099600;18884.7576166505,-37750.2572524150,18834.3337341170;18885.1836179271,-37751.1328157291,18834.7836890829;18885.5973632686,-37751.9838511641,18835.2213909741;18885.9988688277,-37752.8103910153,18835.6468559069;18886.3881507563,-37753.6124675759,18836.0600999963;18886.7652252063,-37754.3901131387,18836.4611393575;18887.1301083279,-37755.1433599941,18836.8499901042;18887.4828162713,-37755.8722404323,18837.2266683500;18887.8233651857,-37756.5767867408,18837.5911902075;18888.1517712194,-37757.2570312059,18837.9435717884;18888.4680505196,-37757.9130061121,18838.2838292038;18888.7722192328,-37758.5447437418,18838.6119785634;18889.0642935045,-37759.1522763758,18838.9280359764;18889.3442894789,-37759.7356362925,18839.2320175509;18889.6122232994,-37760.2948557683,18839.5239393937;18889.8681111079,-37760.8299670770,18839.8038176106;18890.1119690454,-37761.3410024906,18840.0716683064;18890.3438132514,-37761.8279942780,18840.3275075843;18890.5636598644,-37762.2909747060,18840.5713515467;18890.7715250213,-37762.7299760385,18840.8032162944;18890.9674248576,-37763.1450305369,18841.0231179270;18891.1513755075,-37763.5361704592,18841.2310725424;18891.3233931037,-37763.9034280612,18841.4270962375;18891.4834937771,-37764.2468355948,18841.6112051072;18892.2297741672,-37765.7626361748,18842.3805866778;18892.9637232444,-37767.2537578269,18843.1376396186;18893.6853575723,-37768.7202336686,18843.8823804566;18894.3946937121,-37770.1620968132,18844.6148257167;18895.0917482231,-37771.5793803692,18845.3349919218;18895.7765376620,-37772.9721174407,18846.0428955923;18896.4490785831,-37774.3403411266,18846.7385532460;18897.1093875382,-37775.6840845213,18847.4219813988;18897.7574810768,-37777.0033807141,18848.0931965637;18898.3933757456,-37778.2982627892,18848.7522152513;18899.0170880889,-37779.5687638258,18849.3990539700;18899.6286346483,-37780.8149168977,18850.0337292250;18900.2280319629,-37782.0367550737,18850.6562575195;18900.8152965686,-37783.2343114167,18851.2666553535;18901.3904449992,-37784.4076189847,18851.8649392247;18901.9534937850,-37785.5567108296,18852.4511256277;18902.5044594539,-37786.6816199977,18853.0252310544;18903.0433585309,-37787.7823795299,18853.5872719939;18903.5702075378,-37788.8590224608,18854.1372649323;18904.0850229935,-37789.9115818192,18854.6752263528;18904.5878214139,-37790.9400906280,18855.2011727357;18905.0786193119,-37791.9445819038,18855.7151205580;18905.5574331970,-37792.9250886569,18856.2170862938;18906.0242795758,-37793.8816438915,18856.7070864141;18906.4791749516,-37794.8142806055,18857.1851373866;18906.9221358244,-37795.7230317900,18857.6512556760;18907.3531786909,-37796.6079304296,18858.1054577434;18907.7723200444,-37797.4690095024,18858.5477600469;18908.1795763751,-37798.3063019798,18858.9781790412;18908.5749641693,-37799.1198408261,18859.3967311774;18908.9584999103,-37799.9096589988,18859.8034329035;18909.3302000775,-37800.6757894486,18860.1983006637;18909.6900811470,-37801.4182651187,18860.5813508990;18910.0381595910,-37802.1371189455,18860.9526000464;18910.3744518782,-37802.8323838577,18861.3120645396;18910.6989744738,-37803.5040927772,18861.6597608088;18911.0117438390,-37804.1522786181,18861.9957052801;18911.3127764313,-37804.7769742869,18862.3199143761;18911.6020887045,-37805.3782126830,18862.6324045158;18911.8796971082,-37805.9560266974,18862.9331921138;18912.1456180883,-37806.5104492136,18863.2222935814;18912.3998680869,-37807.0415131077,18863.4997253259;18912.6424635420,-37807.5492512473,18863.7655037505;18912.8734208874,-37808.0336964921,18864.0196452544;18913.0927565530,-37808.4948816936,18864.2621662327;18913.3004869646,-37808.9328396955,18864.4930830769;18913.4966285436,-37809.3476033326,18864.7124121738;18913.6811977075,-37809.7392054319,18864.9201699063;18913.8542108693,-37810.1076788114,18865.1163726531;18914.0156844381,-37810.4530562812,18865.3010367887;18913.5785444381,-37809.6011415049,18864.8879812056;18913.1303300350,-37808.7270612409,18864.4638514961;18912.6710572061,-37807.8308474361,18864.0286636043;18912.2007419254,-37806.9125320307,18863.5824334704;18911.7194001626,-37805.9721469562,18863.1251770306;18911.2270478833,-37805.0097241362,18862.6569102168;18910.7237010493,-37804.0252954865,18862.1776489577;18910.2093756179,-37803.0188929141,18861.6874091769;18909.6840875427,-37801.9905483185,18861.1862067947;18909.1478527725,-37800.9402935900,18860.6740577267;18908.6006872527,-37799.8681606115,18860.1509778849;18908.0426069235,-37798.7741812561,18859.6169831764;18907.4736277215,-37797.6583873897,18859.0720895046;18906.8937655786,-37796.5208108683,18858.5163127682;18906.3030364224,-37795.3614835398,18857.9496688617;18905.7014561760,-37794.1804372431,18857.3721736752;18905.0890407581,-37792.9777038085,18856.7838430945;18904.4658060828,-37791.7533150565,18856.1846930005;18903.8317680596,-37790.5073027993,18855.5747392701;18903.1869425936,-37789.2396988395,18854.9539977754;18902.5313455851,-37787.9505349709,18854.3224843839;18901.8649929297,-37786.6398429773,18853.6802149584;18901.1879005185,-37785.3076546339,18853.0272053574;18900.5000842375,-37783.9540017057,18852.3634714341;18899.8015599680,-37782.5789159484,18851.6890290373;18899.0923435869,-37781.1824291084,18851.0038940112;18898.3724509655,-37779.7645729219,18850.3080821948;18897.6418979707,-37778.3253791154,18849.6016094224;18896.9007004643,-37776.8648794058,18848.8844915232;18896.1488743032,-37775.3831055001,18848.1567443219;18895.3864353390,-37773.8800890946,18847.4183836377;18894.6133994185,-37772.3558618762,18846.6694252851;18893.8297823832,-37770.8104555214,18845.9098850736;18893.0356000697,-37769.2439016964,18845.1397788072;18892.2308683091,-37767.6562320570,18844.3591222852;18891.4156029275,-37766.0474782487,18843.5679313014;18890.5898197457,-37764.4176719064,18842.7662216446;18889.7535345791,-37762.7668446548,18841.9540090982;18888.9067632379,-37761.0950281073,18841.1313094404;18888.0495215268,-37759.4022538674,18840.2981384442;18887.1818252452,-37757.6885535270,18839.4545118768;18886.3036901869,-37755.9539586676,18838.6004455005;18885.4151321405,-37754.1985008599,18837.7359550719;18884.5161668886,-37752.4222116631,18836.8610563421;18883.6068102087,-37750.6251226256,18835.9757650568;18882.6870778725,-37748.8072652848,18835.0800969561;18881.7569856461,-37746.9686711666,18834.1740677745;18880.8165492897,-37745.1093717855,18833.2576932408;18879.8657845583,-37743.2293986451,18832.3309890783;18878.9047072006,-37741.3287832369,18831.3939710045;18877.9333329599,-37739.4075570414,18830.4466547313;18876.9516775735,-37737.4657515270,18829.4890559644;18875.9597567728,-37735.5033981512,18828.5211904044;18874.9575862835,-37733.5205283587,18827.5430737453;18873.9451818252,-37731.5171735834,18826.5547216758;18872.9225591117,-37729.4933652467,18825.5561498784;18871.8897338505,-37727.4491347581,18824.5473740297;18870.8467217434,-37725.3845135150,18823.5284098001;18869.7935384859,-37723.2995329033,18822.4992728547;18868.7301997676,-37721.1942242959,18821.4599788516;18867.6567212717,-37719.0686190539,18820.4105434434;18866.5731186753,-37716.9227485259,18819.3509822764;18865.4794076495,-37714.7566440483,18818.2813109907;18864.3756038590,-37712.5703369450,18817.2015452204;18863.2617229620,-37710.3638585271,18816.1117005929;18862.1377806107,-37708.1372400935,18815.0117927299;18861.0037924508,-37705.8905129301,18813.9018372465;18859.8597741217,-37703.6237083101,18812.7818497513;18858.7057412562,-37701.3368574942,18811.6518458469;18857.5417094808,-37699.0299917296,18810.5118411292;18856.3676944155,-37696.7031422514,18809.3618511878;18855.1837116737,-37694.3563402811,18808.2018916059;18853.9897768622,-37691.9896170269,18807.0319779599;18852.7859055813,-37689.6030036845,18805.8521258198;18851.5721134246,-37687.1965314359,18804.6623507491;18850.3484159792,-37684.7702314501,18803.4626683046;18849.1148288253,-37682.3241348825,18802.2530940365;18847.8713675364,-37679.8582728752,18801.0336434884;18846.6180476794,-37677.3726765568,18799.8043321969;18845.3548848142,-37674.8673770422,18798.5651756921;18844.0818944939,-37672.3424054330,18797.3161894972;18842.7990922649,-37669.7977928169,18796.0573891289;18841.5064936664,-37667.2335702675,18794.7887900963;18840.2041142310,-37664.6497688453,18793.5104079024;18838.8919694842,-37662.0464195964,18792.2222580431;18837.5700749444,-37659.4235535529,18790.9243560069;18836.2384461230,-37656.7812017332,18789.6167172758;18834.8970985246,-37654.1193951415,18788.2993573248;18833.5460476463,-37651.4381647677,18786.9722916215;18832.1853089784,-37648.7375415875,18785.6355356267;18830.8148980038,-37646.0175565624,18784.2891047939;18829.4348301982,-37643.2782406396,18782.9330145697;18828.0451210305,-37640.5196247518,18781.5672803933;18826.6457859618,-37637.7417398173,18780.1919176968;18825.2368404462,-37634.9446167397,18778.8069419050;18823.8182999305,-37632.1282864082,18777.4123684356;18822.3901798539,-37629.2927796973,18776.0082126988;18820.9524956485,-37626.4381274664,18774.5944900975;18819.5052627387,-37623.5643605606,18773.1712160272;18818.0484965418,-37620.6715098099,18771.7384058762;18816.5822124674,-37617.7596060294,18770.2960750251;18815.1064259175,-37614.8286800192,18768.8442388473;18813.6211522868,-37611.8787625646,18767.3829127086;18812.1264069623,-37608.9098844353,18765.9121119672;18810.6222053235,-37605.9220763864,18764.4318519738;18809.1085627419,-37602.9153691572,18762.9421480716;18807.5854945818,-37599.8897934720,18761.4430155960;18806.0530161995,-37596.8453800400,18759.9344698750;18804.5111429439,-37593.7821595545,18758.4165262287;18802.9598901556,-37590.7001626934,18756.8891999696;18801.3992731681,-37587.5994201196,18755.3525064026;18799.8293073063,-37584.4799624795,18753.8064608244;18798.2500078881,-37581.3418204047,18752.2510785244;18796.6613902228,-37578.1850245106,18750.6863747839;18795.0634696122,-37575.0096053970,18749.1123648764;18793.4562613501,-37571.8155936478,18747.5290640675;18791.8397807221,-37568.6030198309,18745.9364876150;18790.2140430061,-37565.3719144983,18744.3346507684;18788.5790634719,-37562.1223081863,18742.7235687698;18786.9348573812,-37558.8542314147,18741.1032568528;18785.2814399874,-37555.5677146871,18739.4737302431;18783.6188265363,-37552.2627884915,18737.8350041585;18781.9470322650,-37548.9394832990,18736.1870938084;18780.2660724029,-37545.5978295649,18734.5300143945;18778.5759621709,-37542.2378577278,18732.8637811100;18776.8767167817,-37538.8595982100,18731.1884091400;18775.1683514398,-37535.4630814171,18729.5039136614;18773.4508813414,-37532.0483377386,18727.8103098430;18771.7243216745,-37528.6153975471,18726.1076128451;18769.9886876184,-37525.1642911984,18724.3958378198;18768.2439943446,-37521.6950490321,18722.6749999111;18766.4902570156,-37518.2077013706,18720.9451142543;18764.7274907859,-37514.7022785196,18719.2061959766;18762.9557108012,-37511.1788107678,18717.4582601965;18761.1749321990,-37507.6373283873,18715.7013220243;18759.3851701082,-37504.0778616329,18713.9353965618;18757.5864396491,-37500.5004407425,18712.1604989023;18755.7787559335,-37496.9050959367,18710.3766441305;18753.9621340645,-37493.2918574193,18708.5838473227;18752.1365891367,-37489.6607553764,18706.7821235465;18750.3021362359,-37486.0118199774,18704.9714878609;18748.4587904395,-37482.3450813739,18703.1519553164;18746.6065668159,-37478.6605697005,18701.3235409548;18744.7454804248,-37474.9583150740,18699.4862598091;18742.8755463172,-37471.2383475938,18697.6401269036;18740.9967795356,-37467.5006973421,18695.7851572541;18739.1091951132,-37463.7453943833,18693.9213658674;18737.2128080745,-37459.9724687639,18692.0487677415;18735.3076334353,-37456.1819505131,18690.1673778659;18733.3936862024,-37452.3738696419,18688.2772112207;18731.4709813737,-37448.5482561441,18686.3782827778;18729.5395339382,-37444.7051399951,18684.4706074997;18727.5993588759,-37440.8445511529,18682.5542003402;18725.6504711575,-37436.9665195568,18680.6290762440;18723.6928857452,-37433.0710751289,18678.6952501471;18721.7266175919,-37429.1582477725,18676.7527369761;18719.7516816412,-37425.2280673734,18674.8015516489;18717.7680928280,-37421.2805637989,18672.8417090743;18715.7758660779,-37417.3157668983,18670.8732241520;18713.7750163073,-37413.3337065023,18668.8961117725;18711.7655584233,-37409.3344124234,18666.9103868171;18709.7475073242,-37405.3179144559,18664.9160641584;18707.7208778987,-37401.2842423756,18662.9131586594;18705.6856850263,-37397.2334259397,18660.9016851739;18703.6419435774,-37393.1654948871,18658.8816585467;18701.5896684129,-37389.0804789376,18656.8530936130;18699.5288743846,-37384.9784077934,18654.8160051994;18697.4595763346,-37380.8593111368,18652.7704081224;18695.3817890958,-37376.7232186321,18650.7163171895;18693.2955274919,-37372.5701599250,18648.6537471992;18691.2008063368,-37368.4001646417,18646.5827129399;18689.0976404353,-37364.2132623901,18644.5032291912;18686.9860445824,-37360.0094827589,18642.4153107230;18684.8660335639,-37355.7888553182,18640.3189722960;18682.7376221558,-37351.5514096183,18638.2142286610;18680.6008251247,-37347.2971751913,18636.1010945597;18678.4556572276,-37343.0261815496,18633.9795847240;18676.3021332119,-37338.7384581868,18631.8497138764;18674.1402678154,-37334.4340345770,18629.7114967299;18671.9700757663,-37330.1129401756,18627.5649479878;18669.7915717830,-37325.7752044178,18625.4100823438;18667.6047705742,-37321.4208567201,18623.2469144818;18665.4096868390,-37317.0499264795,18621.0754590764;18663.2063352669,-37312.6624430737,18618.8957307922;18660.9947305372,-37308.2584358604,18616.7077442843;18658.7748873198,-37303.8379341782,18614.5115141979;18656.5468202747,-37299.4009673461,18612.3070551685;18654.3105440519,-37294.9475646630,18610.0943818217;18652.0660732918,-37290.4777554090,18607.8735087736;18649.8134226248,-37285.9915688439,18605.6444506305;18647.5526066713,-37281.4890342075,18603.4072219882;18645.2836400420,-37276.9701807204,18601.1618374334;18643.0065373375,-37272.4350375829,18598.9083115425;18640.7213131483,-37267.8836339755,18596.6466588821;18638.4279820553,-37263.3159990591,18594.3768940088;18636.1265586291,-37258.7321619740,18592.0990314693;18633.8170574303,-37254.1321518408,18589.8130858003;18631.4994930096,-37249.5159977605,18587.5190715286;18629.1738799073,-37244.8837288128,18585.2170031707;18626.8402326540,-37240.2353740584,18582.9068952334;18624.4985657698,-37235.5709625371,18580.5887622130;18622.1488937649,-37230.8905232689,18578.2626185963;18619.7912311393,-37226.1940852529,18575.9284788594;18617.4255923828,-37221.4816774686,18573.5863574686;18615.0519919750,-37216.7533288747,18571.2362688800;18612.6704443852,-37212.0090684092,18568.8782275394;18610.2809640724,-37207.2489249903,18566.5122478826;18607.8835654855,-37202.4729275152,18564.1383443349;18605.4782630632,-37197.6811048610,18561.7565313118;18603.0650712336,-37192.8734858836,18559.3668232180;18600.6440044144,-37188.0500994185,18556.9692344482;18598.2150770134,-37183.2109742810,18554.5637793870;18595.7783034277,-37178.3561392650,18552.1504724084;18593.3336980440,-37173.4856231440,18549.7293278759;18590.8812752385,-37168.5994546705,18547.3003601431;18588.4210493775,-37163.6976625766,18544.8635835528;18585.9530348161,-37158.7802755731,18542.4190124377;18583.4772458995,-37153.8473223499,18539.9666611199;18580.9936969620,-37148.8988315761,18537.5065439111;18578.5024023276,-37143.9348318995,18535.0386751123;18576.0033763098,-37138.9553519474,18532.5630690145;18573.4966332114,-37133.9604203256,18530.0797398980;18570.9821873247,-37128.9500656190,18527.5887020323;18568.4600529313,-37123.9243163909,18525.0899696765;18565.9302443024,-37118.8832011840,18522.5835570795;18563.3927756984,-37113.8267485193,18520.0694784791;18560.8476613690,-37108.7549868969,18517.5477481027;18558.2949155533,-37103.6679447952,18515.0183801671;18555.7345524798,-37098.5656506715,18512.4813888785;18553.1665863662,-37093.4481329617,18509.9367884324;18550.5910314193,-37088.3154200801,18507.3845930136;18548.0079018354,-37083.1675404196,18504.8248167960;18545.4172118001,-37078.0045223519,18502.2574739433;18542.8189754877,-37072.8263942264,18499.6825786079;18540.2132070623,-37067.6331843720,18497.1001449318;18537.5999206768,-37062.4249210948,18494.5101870461;18534.9791304733,-37057.2016326801,18491.9127190710;18532.3508505834,-37051.9633473913,18489.3077551162;18529.7150951271,-37046.7100934696,18486.6953092802;18527.0718782143,-37041.4418991354,18484.0753956509;18524.4212139433,-37036.1587925861,18481.4480283052;18521.7631164018,-37030.8608019981,18478.8132213093;18519.0975996666,-37025.5479555259,18476.1709887182;18516.4246778034,-37020.2202813017,18473.5213445763;18513.7443648669,-37014.8778074357,18470.8643029168;18511.0566749009,-37009.5205620168,18468.1998777621;18508.3616219380,-37004.1485731110,18465.5280831235;18505.6592199999,-36998.7618687630,18462.8489330015;18502.9494830972,-36993.3604769947,18460.1624413854;18500.2324252293,-36987.9444258065,18457.4686222534;18497.5080603847,-36982.5137431762,18454.7674895730;18494.7764025407,-36977.0684570596,18452.0590573003;18492.0374656633,-36971.6085953902,18449.3433393804;18489.2912637079,-36966.1341860797,18446.6203497476;18486.5378106180,-36960.6452570164,18443.8901023246;18483.7771203263,-36955.1418360674,18441.1526110232;18481.0092067544,-36949.6239510769,18438.4078897442;18478.2340838124,-36944.0916298666,18435.6559523770;18475.4517653993,-36938.5449002360,18432.8968127999;18472.6622654031,-36932.9837899624,18430.1304848801;18469.8655977000,-36927.4083267997,18427.3569824733;18467.0617761554,-36921.8185384801,18424.5763194243;18464.2508146231,-36916.2144527130,18421.7885095665;18461.4327269458,-36910.5960971851,18418.9935667220;18458.6075269545,-36904.9634995604,18416.1915047017;18455.7752284694,-36899.3166874806,18413.3823373052;18452.9358452989,-36893.6556885641,18410.5660783205;18450.0893912401,-36887.9805304073,18407.7427415249;18447.2358800790,-36882.2912405833,18404.9123406837;18444.3753255897,-36876.5878466426,18402.0748895513;18441.5077415352,-36870.8703761126,18399.2304018703;18438.6331416670,-36865.1388564985,18396.3788913724;18435.7515397250,-36859.3933152818,18393.5203717774;18432.8629494380,-36853.6337799217,18390.6548567941;18429.9673845227,-36847.8602778541,18387.7823601195;18427.0648586849,-36842.0728364922,18384.9028954395;18424.1553856186,-36836.2714832259,18382.0164764281;18421.2389790061,-36830.4562454221,18379.1231167483;18418.3156525185,-36824.6271504249,18376.2228300512;18415.3854198150,-36818.7842255549,18373.3156299765;18412.4482945436,-36812.9274981100,18370.4015301527;18409.5042903403,-36807.0569953646,18367.4805441961;18406.5534208297,-36801.1727445700,18364.5526857120;18403.5956996248,-36795.2747729543,18361.6179682938;18400.6311403268,-36789.3631077222,18358.6764055235;18397.6597565254,-36783.4377760556,18355.7280109715;18394.6815617985,-36777.4988051124,18352.7727981963;18391.6965697126,-36771.5462220277,18349.8107807453;18388.7047938220,-36765.5800539129,18346.8419721536;18385.7062476698,-36759.6003278564,18343.8663859451;18382.7009447869,-36753.6070709226,18340.8840356319;18379.6888986930,-36747.6003101530,18337.8949347144;18376.6701228956,-36741.5800725653,18334.8990966812;18373.6446308904,-36735.5463851537,18331.8965350094;18370.6124361617,-36729.4992748890,18328.8872631641;18367.5735521818,-36723.4387687184,18325.8712945988;18364.5279924111,-36717.3648935654,18322.8486427554;18361.4757702983,-36711.2776763301,18319.8193210637;18358.4168992801,-36705.1771438886,18316.7833429418;18355.3513927816,-36699.0633230937,18313.7407217962;18352.2792642158,-36692.9362407741,18310.6914710214;18349.2005269840,-36686.7959237354,18307.6356040001;18346.1151944755,-36680.6423987588,18304.5731341033;18343.0232800677,-36674.4756926019,18301.5040746899;18339.9247971261,-36668.2958319988,18298.4284391070;18336.8197590043,-36662.1028436594,18295.3462406900;18333.7081790438,-36655.8967542697,18292.2574927622;18330.5900705744,-36649.6775904922,18289.1622086351;18327.4654469138,-36643.4453789653,18286.0604016083;18324.3343213676,-36637.2001463032,18282.9520849693;18321.1967072296,-36630.9419190968,18279.8372719939;18318.0526177814,-36624.6707239120,18276.7159759457;18314.9020662929,-36618.3865872917,18273.5882100766;18311.7450660215,-36612.0895357544,18270.4539876262;18308.5816302130,-36605.7795957941,18267.3133218223;18305.4117721009,-36599.4567938815,18264.1662258807;18302.2355049066,-36593.1211564624,18261.0127130052;18299.0528418394,-36586.7727099590,18257.8527963873;18295.8637960969,-36580.4114807693,18254.6864892069;18292.6683808640,-36574.0374952668,18251.5138046314;18289.4666093139,-36567.6507798011,18248.3347558164;18286.2584946077,-36561.2513606976,18245.1493559056;18283.0440498939,-36554.8392642570,18241.9576180299;18279.8232883094,-36548.4145167563,18238.7595553090;18276.5962229784,-36541.9771444476,18235.5551808497;18273.3628670135,-36535.5271735594,18232.3445077472;18270.1232335146,-36529.0646302953,18229.1275490844;18266.8773355698,-36522.5895408346,18225.9043179320;18263.6251862547,-36516.1019313323,18222.6748273486;18260.3667986327,-36509.6018279190,18219.4390903804;18257.1021857551,-36503.0892567009,18216.1971200618;18253.8313606610,-36496.5642437595,18212.9489294148;18250.5543363771,-36490.0268151522,18209.6945314492;18247.2711259178,-36483.4769969115,18206.4339391625;18243.9817422854,-36476.9148150457,18203.1671655401;18240.6861984698,-36470.3402955385,18199.8942235553;18237.3845074485,-36463.7534643487,18196.6151261687;18234.0766821869,-36457.1543474109,18193.3298863292;18230.7627356380,-36450.5429706349,18190.0385169729;18227.4426807425,-36443.9193599060,18186.7410310241;18224.1165304285,-36437.2835410845,18183.4374413943;18220.7842976122,-36430.6355400065,18180.1277609832;18217.4459951970,-36423.9753824830,18176.8120026778;18214.1016360743,-36417.3030943008,18173.4901793531;18210.7512331227,-36410.6187012211,18170.1623038713;18207.3947992089,-36403.9222289815,18166.8283890829;18204.0323471867,-36397.2137032936,18163.4884478255;18200.6638898980,-36390.4931498452,18160.1424929247;18197.2894401718,-36383.7605942986,18156.7905371934;18193.9090108250,-36377.0160622916,18153.4325934322;18190.5226146618,-36370.2595794373,18150.0686744297;18187.1302644742,-36363.4911713235,18146.6987929616;18183.7319730416,-36356.7108635133,18143.3229617913;18180.3277531309,-36349.9186815450,18139.9411936700;18176.9176174966,-36343.1146509318,18136.5535013363;18173.5015788806,-36336.2987971619,18133.1598975163;18170.0796500125,-36329.4711456989,18129.7603949238;18166.6518436091,-36322.6317219809,18126.3550062600;18163.2181723750,-36315.7805514214,18122.9437442138;18159.7786490020,-36308.9176594085,18119.5266214613;18156.3332861697,-36302.0430713058,18116.1036506666;18152.8820965447,-36295.1568124511,18112.6748444808;18149.4250927814,-36288.2589081579,18109.2402155430;18145.9622875215,-36281.3493837140,18105.7997764793;18142.4936933942,-36274.4282643824,18102.3535399036;18139.0193230160,-36267.4955754009,18098.9015184171;18135.5391889909,-36260.5513419821,18095.4437246086;18132.0533039103,-36253.5955893134,18091.9801710541;18128.5616803529,-36246.6283425570,18088.5108703174;18125.0643308850,-36239.6496268502,18085.0358349495;18121.5612680599,-36232.6594673046,18081.5550774888;18118.0525044189,-36225.6578890071,18078.0686104614;18114.5380524899,-36218.6449170187,18074.5764463802;18111.0179247887,-36211.6205763759,18071.0785977464;18107.4921338181,-36204.5848920890,18067.5750770476;18103.9606920686,-36197.5378891440,18064.0658967596;18100.4236120178,-36190.4795925008,18060.5510693452;18096.8809061305,-36183.4100270944,18057.0306072546;18093.3325868590,-36176.3292178342,18053.5045229252;18089.7786666430,-36169.2371896045,18049.9728287823;18086.2191579092,-36162.1339672637,18046.4355372378;18082.6540730718,-36155.0195756456,18042.8926606916;18079.0834245322,-36147.8940395577,18039.3442115304;18075.5072246792,-36140.7573837830,18035.7902021287;18071.9254858888,-36133.6096330785,18032.2306448480;18068.3382205240,-36126.4508121756,18028.6655520371;18064.7454409354,-36119.2809457804,18025.0949360322;18061.1471594609,-36112.1000585739,18021.5188091569;18057.5433884251,-36104.9081752110,18017.9371837218;18053.9341401405,-36097.7053203216,18014.3500720250;18050.3194269064,-36090.4915185098,18010.7574863520;18046.6992610094,-36083.2667943539,18007.1594389751;18043.0736547233,-36076.0311724072,18003.5559421542;18039.4426203093,-36068.7846771972,17999.9470081365;18035.8061700155,-36061.5273332255,17996.3326491561;18032.1643160774,-36054.2591649689,17992.7128774349;18028.5170707175,-36046.9801968774,17989.0877051813;18024.8644461457,-36039.6904533767,17985.4571445916;18021.2064545588,-36032.3899588656,17981.8212078489;18017.5431081411,-36025.0787377184,17978.1799071236;18013.5340582780,-36017.0760672760,17974.1934139470;18009.5199034193,-36009.0631699092,17970.2018062640;18005.5006555129,-36001.0400695192,17966.2050960093;18001.4763264941,-35993.0067899825,17962.2032951050;17997.4469282855,-35984.9633551497,17958.1964154606;17993.4124727970,-35976.9097888466,17954.1844689729;17989.3729719260,-35968.8461148732,17950.1674675261;17985.3284375571,-35960.7723570049,17946.1454229920;17981.2788815622,-35952.6885389909,17942.1183472294;17977.2243158005,-35944.5946845557,17938.0862520847;17973.1647521188,-35936.4908173984,17934.0491493917;17969.1002023507,-35928.3769611921,17930.0070509712;17965.0306783175,-35920.2531395852,17925.9599686317;17960.9561918276,-35912.1193762007,17921.9079141691;17956.8767546767,-35903.9756946355,17917.8508993661;17952.7923786479,-35895.8221184621,17913.7889359935;17948.7030755115,-35887.6586712266,17909.7220358087;17944.6088570251,-35879.4853764503,17905.6502105568;17940.5097349334,-35871.3022576289,17901.5734719702;17936.4057209685,-35863.1093382323,17897.4918317684;17932.2968268497,-35854.9066417056,17893.4053016584;17928.1830642837,-35846.6941914675,17889.3138933344;17924.0644449642,-35838.4720109122,17885.2176184778;17919.9409805723,-35830.2401234077,17881.1164887576;17915.8126827763,-35821.9985522968,17877.0105158297;17911.6795632318,-35813.7473208967,17872.8997113375;17907.5416335813,-35805.4864524990,17868.7840869115;17903.3989054548,-35797.2159703697,17864.6636541696;17899.2513904695,-35788.9358977494,17860.5384247170;17895.0991002298,-35780.6462578531,17856.4084101460;17890.9420463272,-35772.3470738702,17852.2736220361;17886.7802403404,-35764.0383689644,17848.1340719543;17882.6136938354,-35755.7201662742,17843.9897714546;17878.4424183653,-35747.3924889120,17839.8407320783;17874.2664254705,-35739.0553599648,17835.6869653541;17870.0857266783,-35730.7088024939,17831.5284827975;17865.9003335034,-35722.3528395352,17827.3652959116;17861.7102574478,-35713.9874940988,17823.1974161867;17857.5155100003,-35705.6127891690,17819.0248551000;17853.3161026370,-35697.2287477047,17814.8476241162;17849.1120468215,-35688.8353926391,17810.6657346872;17844.9033540038,-35680.4327468794,17806.4791982518;17840.6900356218,-35672.0208333077,17802.2880262364;17836.4721031002,-35663.5996747797,17798.0922300542;17832.2495678508,-35655.1692941260,17793.8918211058;17828.0224412726,-35646.7297141512,17789.6868107789;17823.7907347518,-35638.2809576342,17785.4772104486;17819.5544596617,-35629.8230473284,17781.2630314768;17815.3136273625,-35621.3560059610,17777.0442852127;17811.0682492018,-35612.8798562339,17772.8209829928;17806.8183365143,-35604.3946208232,17768.5931361408;17802.5639006216,-35595.9003223790,17764.3607559673;17798.3049528326,-35587.3969835257,17760.1238537701;17794.0415044432,-35578.8846268621,17755.8824408343;17789.7735667365,-35570.3632749613,17751.6365284321;17785.5011509826,-35561.8329503702,17747.3861278228;17781.2242684387,-35553.2936756103,17743.1312502528;17776.9429303491,-35544.7454731770,17738.8719069557;17772.6571479454,-35536.1883655404,17734.6081091524;17768.3669324458,-35527.6223751440,17730.3398680504;17764.0722950561,-35519.0475244064,17726.0671948450;17759.7732469688,-35510.4638357194,17721.7901007179;17755.4697993637,-35501.8713314500,17717.5085968388;17751.1619634077,-35493.2700339387,17713.2226943637;17746.8497502543,-35484.6599654999,17708.9324044360;17742.5331710448,-35476.0411484231,17704.6377381865;17738.2122369071,-35467.4136049712,17700.3387067327;17733.8869589562,-35458.7773573815,17696.0353211793;17729.5573482941,-35450.1324278651,17691.7275926182;17725.2234160102,-35441.4788386079,17687.4155321284;17720.8851731807,-35432.8166117695,17683.0991507761;17716.5426308685,-35424.1457694834,17678.7784596140;17712.1958001244,-35415.4663338578,17674.4534696828;17707.8446919855,-35406.7783269746,17670.1241920097;17703.4893174762,-35398.0817708899,17665.7906376090;17699.1296876080,-35389.3766876338,17661.4528174822;17694.7658133793,-35380.6630992107,17657.1107426179;17690.3977057758,-35371.9410275989,17652.7644239918;17686.0253757699,-35363.2104947512,17648.4138725667;17681.6488343211,-35354.4715225937,17644.0590992923;17677.2680923762,-35345.7241330276,17639.7001151055;17672.8831608687,-35336.9683479271,17635.3369309302;17668.4940507193,-35328.2041891413,17630.9695576775;17664.1007728357,-35319.4316784929,17626.5980062453;17659.7033381126,-35310.6508377789,17622.2222875190;17655.3017574318,-35301.8616887705,17617.8424123708;17650.8960416619,-35293.0642532124,17613.4583916597;17646.4862016587,-35284.2585528239,17609.0702362323;17642.0722482650,-35275.4446092981,17604.6779569218;17637.6541923107,-35266.6224443024,17600.2815645489;17633.2320446123,-35257.7920794776,17595.8810699208;17628.8058159739,-35248.9535364393,17591.4764838321;17624.3755171862,-35240.1068367769,17587.0678170646;17619.9411590271,-35231.2520020536,17582.6550803868;17615.5027522614,-35222.3890538069,17578.2382845545;17611.0603076407,-35213.5180135479,17573.8174403102;17606.6138359043,-35204.6389027626,17569.3925583840;17602.1633477776,-35195.7517429100,17564.9636494926;17597.7088539737,-35186.8565554238,17560.5307243398;17593.2503651924,-35177.9533617114,17556.0937936166;17588.7878921205,-35169.0421831546,17551.6528680010;17584.3214454318,-35160.1230411086,17547.2079581579;17579.8510357873,-35151.1959569032,17542.7590747395;17575.3766738346,-35142.2609518419,17538.3062283846;17570.8983702087,-35133.3180472024,17533.8494297197;17566.4161355315,-35124.3672642363,17529.3886893577;17561.9299804115,-35115.4086241689,17524.9240178987;17557.4399154448,-35106.4421482001,17520.4554259301;17552.9459512141,-35097.4678575036,17515.9829240262;17548.4480982892,-35088.4857732268,17511.5065227482;17543.9463672269,-35079.4959164914,17507.0262326444;17539.4407685709,-35070.4983083931,17502.5420642502;17534.9313128521,-35061.4929700013,17498.0540280878;17530.4180105881,-35052.4799223599,17493.5621346669;17525.9008722839,-35043.4591864865,17489.0663944839;17521.3799084309,-35034.4307833725,17484.5668180222;17516.8551295082,-35025.3947339839,17480.0634157523;17512.3265459811,-35016.3510592599,17475.5561981318;17507.7941683027,-35007.2997801144,17471.0451756052;17503.2580069124,-34998.2409174349,17466.5303586041;17498.7180722370,-34989.1744920831,17462.0117575472;17494.1743746902,-34980.1005248946,17457.4893828402;17489.6269246727,-34971.0190366790,17452.9632448756;17485.0757325721,-34961.9300482200,17448.4333540334;17480.5208087629,-34952.8335802749,17443.8997206801;17475.9621636069,-34943.7296535756,17439.3623551697;17471.3998074527,-34934.6182888276,17434.8212678427;17466.8337506358,-34925.4995067104,17430.2764690272;17462.2640034789,-34916.3733278777,17425.7279690379;17457.6905762916,-34907.2397729573,17421.1757781770;17453.1134793705,-34898.0988625504,17416.6199067331;17448.5327229989,-34888.9506172327,17412.0603649823;17443.9483174477,-34879.7950575541,17407.4971631876;17439.3602729744,-34870.6322040381,17402.9303115991;17434.7685998234,-34861.4620771820,17398.3598204537;17430.1733082263,-34852.2846974577,17393.7856999755;17425.5744084017,-34843.1000853109,17389.2079603759;17420.9719105551,-34833.9082611609,17384.6266118528;17416.3658248790,-34824.7092454016,17380.0416645914;17411.7561615529,-34815.5030584007,17375.4531287641;17407.1429307434,-34806.2897204997,17370.8610145301;17402.5261426041,-34797.0692520145,17366.2653320357;17397.9058072753,-34787.8416732345,17361.6660914143;17393.2819348845,-34778.6070044236,17357.0633027862;17388.6545355466,-34769.3652658196,17352.4569762590;17384.0236193628,-34760.1164776343,17347.8471219270;17379.3891964217,-34750.8606600533,17343.2337498718;17374.7512767988,-34741.5978332366,17338.6168701620;17370.1098705567,-34732.3280173178,17333.9964928531;17365.4649877450,-34723.0512324052,17329.3726279879;17360.4114441273,-34712.9570809459,17324.3407117089;17355.3547026107,-34702.8565178862,17319.3055861498;17350.2947729868,-34692.7495628183,17314.2672610962;17345.2316650346,-34682.6362353088,17309.2257463203;17340.1653885201,-34672.5165548987,17304.1810515819;17335.0959531970,-34662.3905411041,17299.1331866283;17330.0233688056,-34652.2582134146,17294.0821611936;17324.9476450740,-34642.1195912955,17289.0279849996;17319.8687917173,-34631.9746941855,17283.9706677551;17314.7868184380,-34621.8235414988,17278.9102191565;17309.7017349257,-34611.6661526234,17273.8466488872;17304.6135508572,-34601.5025469221,17268.7799666180;17299.5222758967,-34591.3327437321,17263.7101820069;17294.4279196958,-34581.1567623656,17258.6373046995;17289.3304918931,-34570.9746221089,17253.5613443285;17284.2300021146,-34560.7863422229,17248.4823105138;17279.1264599733,-34550.5919419429,17243.4002128627;17274.0198750700,-34540.3914404791,17238.3150609698;17268.9102569921,-34530.1848570160,17233.2268644170;17263.7976153149,-34519.9722107130,17228.1356327736;17258.6819596007,-34509.7535207037,17223.0413755961;17253.5632993988,-34499.5288060959,17217.9441024282;17248.4416442462,-34489.2980859730,17212.8438228012;17243.3170036671,-34479.0613793922,17207.7405462336;17238.1893871727,-34468.8187053854,17202.6342822310;17233.0588042618,-34458.5700829592,17197.5250402866;17227.9252644204,-34448.3155310949,17192.4128298808;17222.7887771216,-34438.0550687480,17187.2976604814;17217.6493518261,-34427.7887148489,17182.1795415434;17212.5069979815,-34417.5164883024,17177.0584825091;17207.3617250232,-34407.2384079883,17171.9344928085;17202.2135423734,-34396.9544927605,17166.8075818584;17197.0624594418,-34386.6647614476,17161.6777590633;17191.9084856255,-34376.3692328532,17156.5450338148;17186.7516303089,-34366.0679257553,17151.4094154922;17181.5919028634,-34355.7608589061,17146.2709134616;17176.4293126479,-34345.4480510332,17141.1295370771;17171.2638690089,-34335.1295208384,17135.9852956795;17166.0955812797,-34324.8052869980,17130.8381985973;17160.9244587813,-34314.4753681634,17125.6882551465;17155.7505108218,-34304.1397829602,17120.5354746301;17150.5737466967,-34293.7985499890,17115.3798663385;17145.3941756888,-34283.4516878245,17110.2214395497;17140.2118070683,-34273.0992150170,17105.0602035289;17135.0266500927,-34262.7411500907,17099.8961675287;17129.8387140068,-34252.3775115450,17094.7293407892;17124.6480080425,-34242.0083178532,17089.5597325374;17119.4545414197,-34231.6335874643,17084.3873519884;17114.2583233449,-34221.2533388014,17079.2122083440;17109.0593630123,-34210.8675902621,17074.0343107937;17103.8576696036,-34200.4763602194,17068.8536685145;17098.6532522875,-34190.0796670204,17063.6702906705;17093.4461202202,-34179.6775289871,17058.4841864134;17088.2362825455,-34169.2699644166,17053.2953648822;17083.0237483941,-34158.8569915803,17048.1038352033;17077.8085268843,-34148.4386287243,17042.9096064904;17072.5906271218,-34138.0148940697,17037.7126878449;17067.3700581996,-34127.5858058121,17032.5130883553;17062.1468291983,-34117.1513821224,17027.3108170976;17056.9209491856,-34106.7116411458,17022.1058831355;17051.6924272164,-34096.2666010020,17016.8982955195;17046.4612723336,-34085.8162797863,17011.6880632881;17041.2274935669,-34075.3606955679,17006.4751954668;17035.9910999338,-34064.8998663918,17001.2597010690;17030.7521004389,-34054.4338102767,16996.0415890951;17025.5105040744,-34043.9625452169,16990.8208685330;17020.2663198197,-34033.4860891812,16985.5975483582;17015.0195566418,-34023.0044601134,16980.3716375336;17009.7702234951,-34012.5176759320,16975.1431450096;17004.5183293212,-34002.0257545302,16969.9120797237;16999.2638830494,-33991.5287137766,16964.6784506013;16994.0068935963,-33981.0265715139,16959.4422665550;16988.7473698658,-33970.5193455601,16954.2035364849;16983.4853207494,-33960.0070537082,16948.9622692786;16978.2207551260,-33949.4897137257,16943.7184738113;16972.9536818618,-33938.9673433552,16938.4721589453;16967.6841098108,-33928.4399603144,16933.2233335307;16962.4120478139,-33917.9075822954,16927.9720064050;16957.1375047000,-33907.3702269656,16922.7181863932;16951.8604892850,-33896.8279119671,16917.4618823076;16946.5810103726,-33886.2806549173,16912.2031029483;16941.2990767537,-33875.7284734081,16906.9418571026;16936.0146972069,-33865.1713850065,16901.6781535456;16930.7278804981,-33854.6094072545,16896.4120010396;16925.4386353808,-33844.0425576690,16891.1434083346;16920.1469705958,-33833.4708537420,16885.8723841681;16914.8528948716,-33822.8943129405,16880.5989372651;16909.5564169240,-33812.3129527061,16875.3230763381;16904.2575454565,-33801.7267904560,16870.0448100871;16898.9562891598,-33791.1358435818,16864.7641471995;16893.6526567125,-33780.5401294507,16859.4810963507;16888.3466567802,-33769.9396654043,16854.1956662032;16883.0382980166,-33759.3344687598,16848.9078654071;16877.7275890623,-33748.7245568091,16843.6177026003;16872.4145385460,-33738.1099468194,16838.3251864079;16867.0991550835,-33727.4906560327,16833.0303254429;16861.7814472784,-33716.8667016662,16827.7331283056;16856.4614237216,-33706.2381009122,16822.4336035840;16851.1390929916,-33695.6048709380,16817.1317598536;16845.8144636547,-33684.9670288863,16811.8276056777;16840.4875442645,-33674.3245918746,16806.5211496068;16835.1583433621,-33663.6775769953,16801.2124001793;16829.8268694764,-33653.0260013167,16795.9013659211;16824.4931311236,-33642.3698818815,16790.5880553455;16819.1571368077,-33631.7092357079,16785.2724769538;16813.8188950202,-33621.0440797893,16779.9546392347;16808.4784142399,-33610.3744310937,16774.6345506642;16803.1357029337,-33599.7003065652,16769.3122197065;16797.7907695559,-33589.0217231227,16763.9876548131;16792.4436225480,-33578.3386976598,16758.6608644230;16787.0942703396,-33567.6512470461,16753.3318569632;16781.7427213477,-33556.9593881258,16748.0006408480;16776.3889839770,-33546.2631377188,16742.6672244795;16771.0330666196,-33535.5625126198,16737.3316162475;16765.6749776556,-33524.8575295994,16731.9938245293;16760.3147254522,-33514.1482054026,16726.6538576899;16754.9523183648,-33503.4345567504,16721.3117240821;16749.5877647361,-33492.7166003389,16715.9674320462;16744.2210728963,-33481.9943528390,16710.6209899103;16738.8522511638,-33471.2678308977,16705.2724059900;16733.4813078440,-33460.5370511368,16699.9216885888;16728.1082512305,-33449.8020301537,16694.5688459978;16722.7330896041,-33439.0627845207,16689.2138864957;16717.3558312338,-33428.3193307861,16683.8568183492;16711.9764843757,-33417.5716854731,16678.4976498123;16706.5950572740,-33406.8198650802,16673.1363891269;16701.2115581606,-33396.0638860819,16667.7730445228;16695.8259952546,-33385.3037649274,16662.4076242173;16690.4383767634,-33374.5395180417,16657.0401364154;16685.0487108818,-33363.7711618249,16651.6705893100;16679.6570057922,-33352.9987126529,16646.2989910816;16674.2632696651,-33342.2221868770,16640.9253498986;16668.8675106583,-33331.4416008237,16635.5496739171;16663.4697369177,-33320.6569707952,16630.1719712807;16658.0699565767,-33309.8683130689,16624.7922501212;16652.6681777564,-33299.0756438980,16619.4105185579;16647.2644085658,-33288.2789795112,16614.0267846979;16641.8586571017,-33277.4783361124,16608.6410566362;16636.4509314484,-33266.6737298813,16603.2533424555;16631.0412396781,-33255.8651769730,16597.8636502261;16625.6295898510,-33245.0526935184,16592.4719880066;16620.2159900146,-33234.2362956234,16587.0783638428;16614.8004482047,-33223.4159993703,16581.6827857688;16609.3829724444,-33212.5918208163,16576.2852618064;16603.9635707450,-33201.7637759944,16570.8857999651;16598.5422511054,-33190.9318809134,16565.4844082422;16593.1190215123,-33180.0961515575,16560.0810946232;16587.6938899402,-33169.2566038865,16554.6758670808;16582.2668643516,-33158.4132538361,16549.2687335762;16576.8379526966,-33147.5661173175,16543.8597020581;16571.4071629132,-33136.7152102176,16538.4487804631;16565.9745029274,-33125.8605483989,16533.0359767157;16560.5399806530,-33115.0021477000,16527.6212987286;16555.1036039912,-33104.1400239344,16522.2047544016;16549.6653808317,-33093.2741928922,16516.7863516232;16544.2253190518,-33082.4046703388,16511.3660982693;16538.7834265166,-33071.5314720153,16505.9440022038;16533.3397110792,-33060.6546136390,16500.5200712789;16527.8941805803,-33049.7741109022,16495.0943133339;16522.4468428490,-33038.8899794740,16489.6667361968;16516.9977057020,-33028.0022349984,16484.2373476833;16511.5467769437,-33017.1108930956,16478.8061555967;16506.0940643668,-33006.2159693617,16473.3731677286;16500.6395757518,-32995.3174793687,16467.9383918585;16495.1833188669,-32984.4154386641,16462.5018357538;16489.7253014685,-32973.5098627716,16457.0635071698;16484.2655313009,-32962.6007671906,16451.6234138498;16478.8040160963,-32951.6881673967,16446.1815635253;16473.3407635747,-32940.7720788410,16440.7379639153;16467.8757814444,-32929.8525169509,16435.2926227274;16462.4090774014,-32918.9294971294,16429.8455476566;16456.9406591296,-32908.0030347556,16424.3967463862;16451.4705343012,-32897.0731451847,16418.9462265877;16445.9987105761,-32886.1398437478,16413.4939959201;16440.5251956024,-32875.2031457519,16408.0400620309;16435.0499970159,-32864.2630664799,16402.5844325553;16429.5731224410,-32853.3196211914,16397.1271151168;16424.0945794895,-32842.3728251212,16391.6681173269;16418.6143757613,-32831.4226934804,16386.2074467848;16413.1325188447,-32820.4692414566,16380.7451110784;16407.6490163158,-32809.5124842129,16375.2811177829;16402.1638757387,-32798.5524368888,16369.8154744623;16396.6771046657,-32787.5891146000,16364.3481886682;16391.1887106369,-32776.6225324380,16358.8792679405;16385.6987011807,-32765.6527054705,16353.4087198069;16380.2070838137,-32754.6796487419,16347.9365517837;16374.7138660402,-32743.7033772720,16342.4627713750;16369.2190553528,-32732.7239060571,16336.9873860728;16363.7226592323,-32721.7412500701,16331.5104033579;16358.2246851472,-32710.7554242594,16326.0318306984;16352.7251405547,-32699.7664435500,16320.5516755512;16347.2240328995,-32688.7743228432,16315.0699453609;16341.7213696150,-32677.7790770163,16309.5866475605;16336.2171581224,-32666.7807209233,16304.1017895712;16330.7114058309,-32655.7792693941,16298.6153788021;16325.2041201383,-32644.7747372350,16293.1274226508;16319.6953084301,-32633.7671392285,16287.6379285027;16314.1849780802,-32622.7564901337,16282.1469037317;16308.6731364509,-32611.7428046862,16276.6543557000;16303.1597908919,-32600.7260975971,16271.1602917575;16296.8073800091,-32588.0311892874,16264.8284360903;16290.4539893315,-32575.3343076965,16258.4955878974;16284.0996257617,-32562.6354666403,16252.1617540818;16277.7442961904,-32549.9346799119,16245.8269415353;16271.3880074973,-32537.2319612818,16239.4911571380;16265.0307665508,-32524.5273244979,16233.1544077592;16258.6725802077,-32511.8207832852,16226.8167002565;16252.3134553135,-32499.1123513460,16220.4780414763;16245.9533987025,-32486.4020423600,16214.1384382534;16239.5924171976,-32473.6898699846,16207.7978974120;16233.2305176102,-32460.9758478537,16201.4564257641;16226.8677067408,-32448.2599895795,16195.1140301112;16220.5039913782,-32435.5423087510,16188.7707172430;16214.1393783000,-32422.8228189348,16182.4264939382;16207.7738742725,-32410.1015336746,16176.0813669639;16201.4074860510,-32397.3784664926,16169.7353430765;16195.0402203790,-32384.6536308868,16163.3884290206;16188.6720839891,-32371.9270403342,16157.0406315298;16182.3030836026,-32359.1987082883,16150.6919573266;16175.9332259294,-32346.4686481805,16144.3424131218;16169.5625176683,-32333.7368734196,16137.9920056155;16163.1909655067,-32321.0033973919,16131.6407414962;16156.8185761209,-32308.2682334614,16125.2886274415;16150.4453561760,-32295.5313949695,16118.9356701177;16144.0713123256,-32282.7928952350,16112.5818761795;16137.6964512125,-32270.0527475548,16106.2272522711;16131.3207794681,-32257.3109652029,16099.8718050250;16124.9443037124,-32244.5675614312,16093.5155410628;16118.5670305547,-32231.8225494691,16087.1584669949;16112.1889665926,-32219.0759425237,16080.8005894204;16105.8101184128,-32206.3277537796,16074.4419149273;16099.4304925909,-32193.5779963994,16068.0824500927;16093.0500956911,-32180.8266835231,16061.7222014822;16086.6689342667,-32168.0738282687,16055.3611756505;16080.2870148596,-32155.3194437314,16048.9993791411;16073.9043440009,-32142.5635429847,16042.6368184864;16067.5209282103,-32129.8061390798,16036.2735002079;16061.1367739965,-32117.0472450452,16029.9094308156;16054.7518878570,-32104.2868738876,16023.5446168088;16048.3662762782,-32091.5250385913,16017.1790646754;16041.9799457356,-32078.7617521187,16010.8127808926;16035.5929026935,-32065.9970274099,16004.4457719262;16029.2051536050,-32053.2308773825,15998.0780442310;16022.8167049122,-32040.4633149325,15991.7096042510;16016.4275630463,-32027.6943529335,15985.3404584189;16010.0377344272,-32014.9240042370,15978.9706131565;16003.6472254640,-32002.1522816726,15972.6000748745;15997.2560425545,-31989.3791980474,15966.2288499727;15990.8641920857,-31976.6047661470,15959.8569448397;15984.4716804334,-31963.8289987344,15953.4843658532;15978.0785139625,-31951.0519085514,15947.1111193802;15971.6846990269,-31938.2735083168,15940.7372117761;15965.2902419695,-31925.4938107281,15934.3626493859;15958.8951491220,-31912.7128284605,15927.9874385433;15952.4994268055,-31899.9305741675,15921.6115855713;15946.1030813299,-31887.1470604804,15915.2350967817;15939.7061189941,-31874.3623000089,15908.8579784755;15933.3085460861,-31861.5763053403,15902.4802369426;15926.9103688830,-31848.7890890405,15896.1018784622;15920.5115936510,-31836.0006636534,15889.7229093027;15914.1122266452,-31823.2110417007,15883.3433357210;15907.7122741098,-31810.4202356828,15876.9631639637;15901.3117422782,-31797.6282580778,15870.5824002662;15894.9106373730,-31784.8351213425,15864.2010508533;15888.5089656057,-31772.0408379114,15857.8191219386;15882.1067331768,-31759.2454201974,15851.4366197249;15875.7039462762,-31746.4488805918,15845.0535504043;15869.3006110829,-31733.6512314643,15838.6699201580;15862.8967337648,-31720.8524851621,15832.2857351562;15856.4923204792,-31708.0526540116,15825.9010015585;15850.0873773725,-31695.2517503172,15819.5157255136;15843.6819105800,-31682.4497863613,15813.1299131591;15837.2759262266,-31669.6467744050,15806.7435706223;15830.8694304262,-31656.8427266879,15800.3567040194;15824.4624292817,-31644.0376554276,15793.9693194559;15818.0549288852,-31631.2315728200,15787.5814230262;15811.6469353186,-31618.4244910402,15781.1930208144;15805.2384546522,-31605.6164222408,15774.8041188937;15798.8294929461,-31592.8073785536,15768.4147233264;15792.4200562492,-31579.9973720881,15762.0248401640;15786.0101506001,-31567.1864149329,15755.6344754476;15779.5997820264,-31554.3745191552,15749.2436352074;15773.1889565448,-31541.5616968000,15742.8523254626;15766.7776801615,-31528.7479598915,15736.4605522221;15760.3659588719,-31515.9333204321,15730.0683214838;15753.9537986609,-31503.1177904030,15723.6756392352;15747.5412055022,-31490.3013817638,15717.2825114528;15741.1281853592,-31477.4841064528,15710.8889441027;15734.7147441846,-31464.6659763869,15704.4949431400;15728.3008879202,-31451.8470034618,15698.1005145096;15721.8866224973,-31439.0271995516,15691.7056641453;15715.4719538364,-31426.2065765091,15685.3103979705;15709.0568878475,-31413.3851461660,15678.9147218978;15702.6414304298,-31400.5629203325,15672.5186418295;15696.2255874721,-31387.7399107976,15666.1221636569;15689.8093648523,-31374.9161293293,15659.7252932609;15683.3927684378,-31362.0915876739,15653.3280365117;15676.9758040855,-31349.2662975567,15646.9303992691;15670.5584776414,-31336.4402706820,15640.5323873821;15664.1407949412,-31323.6135187326,15634.1340066893;15657.7227618100,-31310.7860533705,15627.7352630186;15651.3043840621,-31297.9578862361,15621.3361621874;15644.8856675014,-31285.1290289490,15614.9367100027;15638.4666179213,-31272.2994931075,15608.5369122605;15632.0472411044,-31259.4692902889,15602.1367747469;15625.6275428231,-31246.6384320495,15595.7363032370;15619.2075288390,-31233.8069299247,15589.3355034957;15612.7872049033,-31220.9747954282,15582.9343812772;15606.3665767567,-31208.1420400533,15576.5329423252;15599.9456501295,-31195.3086752724,15570.1311923732;15593.5244307410,-31182.4747125361,15563.7291371437;15587.1029243008,-31169.6401632751,15557.3267823494;15580.6811365074,-31156.8050388983,15550.9241336921;15574.2590730490,-31143.9693507940,15544.5211968631;15567.8367396037,-31131.1331103298,15538.1179775436;15561.4141418385,-31118.2963288520,15531.7144814040;15554.9912854105,-31105.4590176864,15525.3107141048;15548.5681759661,-31092.6211881376,15518.9066812955;15542.1448191414,-31079.7828514897,15512.5023886155;15535.7212205622,-31066.9440190056,15506.0978416938;15529.2973858434,-31054.1047019277,15499.6930461490;15522.8733205902,-31041.2649114777,15493.2880075893;15516.4490303970,-31028.4246588563,15486.8827316127;15510.0245208478,-31015.5839552434,15480.4772238065;15503.5997975165,-31002.7428117984,15474.0714897480;15497.1748659664,-30989.9012396602,15467.6655350040;15490.7497317505,-30977.0592499461,15461.2593651310;15484.3244004117,-30964.2168537539,15454.8529856751;15477.8988774820,-30951.3740621597,15448.4464021722;15471.4731684840,-30938.5308862201,15442.0396201480;15465.0472789290,-30925.6873369698,15435.6326451177;15458.6212143187,-30912.8434254240,15429.2254825863;15452.1949801442,-30899.9991625768,15422.8181380485;15445.7685818863,-30887.1545594014,15416.4106169888;15439.3420250158,-30874.3096268516,15410.0029248816;15432.9153149930,-30861.4643758595,15403.5950671906;15426.4884572680,-30848.6188173373,15397.1870493697;15420.0614572806,-30835.7729621766,15390.7788768625;15413.6343204606,-30822.9268212484,15384.3705551021;15407.2070522273,-30810.0804054036,15377.9620895119;15400.7796579899,-30797.2337254722,15371.5534855044;15394.3521431475,-30784.3867922643,15365.1447484828;15387.9245130887,-30771.5396165691,15358.7358838394;15381.4967731923,-30758.6922091559,15352.3268969565;15375.0689288268,-30745.8445807735,15345.9177932065;15368.6409853502,-30732.9967421500,15339.5085779515;15362.2129481109,-30720.1487039940,15333.0992565433;15355.7848224468,-30707.3004769928,15326.6898343238;15349.3566136856,-30694.4520718142,15320.2803166247;15342.9283271452,-30681.6034991056,15313.8707087675;15336.9076681346,-30669.5701959165,15307.8680891082;15330.8867024476,-30657.5362673949,15301.8651507540;15324.8654355594,-30645.5017245029,15295.8618991838;15318.8438729348,-30633.4665781820,15289.8583398660;15312.8220200282,-30621.4308393530,15283.8544782588;15306.7998822841,-30609.3945189167,15277.8503198103;15300.7774651365,-30597.3576277531,15271.8458699582;15294.7547740092,-30585.3201767216,15265.8411341301;15288.7318143158,-30573.2821766616,15259.8361177434;15282.7085914598,-30561.2436383914,15253.8308262053;15276.6851108342,-30549.2045727095,15247.8252649126;15270.6613778221,-30537.1649903938,15241.8194392522;15264.6373977963,-30525.1249022017,15235.8133546007;15258.6131761196,-30513.0843188707,15229.8070163247;15252.5887181443,-30501.0432511174,15223.8004297805;15246.5640292126,-30489.0017096383,15217.7936003141;15240.5391146569,-30476.9597051096,15211.7865332618;15234.5139797992,-30464.9172481877,15205.7792339495;15228.4886299513,-30452.8743495081,15199.7717076929;15222.4630704151,-30440.8310196860,15193.7639597979;15216.4373064824,-30428.7872693174,15187.7559955602;15210.4113434345,-30416.7431089767,15181.7478202651;15204.3851865433,-30404.6985492195,15175.7394391885;15198.3588410700,-30392.6536005803,15169.7308575956;15192.3323122660,-30380.6082735736,15163.7220807418;15186.3056053728,-30368.5625786944,15157.7131138727;15180.2787256216,-30356.5165264169,15151.7039622234;15174.2516782334,-30344.4701271955,15145.6946310193;15168.2244684198,-30332.4233914648,15139.6851254758;15162.1971013819,-30320.3763296390,15133.6754507982;15156.1695823109,-30308.3289521124,15127.6656121817;15150.1419163880,-30296.2812692596,15121.6556148120;15144.1141087844,-30284.2332914347,15115.6454638641;15138.0861646615,-30272.1850289723,15109.6351645036;15132.0580891705,-30260.1364921870,15103.6247218861;15126.0298874527,-30248.0876913732,15097.6141411570;15120.0015646396,-30236.0386368057,15091.6034274519;15113.9731258527,-30223.9893387394,15085.5925858966;15107.9445762034,-30211.9398074094,15079.5816216070;15101.9159207935,-30199.8900530307,15073.5705396888;15095.8871647147,-30187.8400857989,15067.5593452381;15089.8583130487,-30175.7899158894,15061.5480433411;15083.8293708677,-30163.7395534583,15055.5366390740;15077.8003432337,-30151.6890086416,15049.5251375034;15071.7712351989,-30139.6382915556,15043.5135436856;15065.7420518056,-30127.5874122969,15037.5018626675;15059.7127980865,-30115.5363809428,15031.4900994860;15053.6834790643,-30103.4852075504,15025.4782591683;15047.6540997517,-30091.4339021573,15019.4663467314;15041.6246651520,-30079.3824747820,15013.4543671832;15035.5951802583,-30067.3309354224,15007.4423255211;15029.5656500543,-30055.2792940579,15001.4302267332;15023.5360795135,-30043.2275606475,14995.4180757976;15017.5064735999,-30031.1757451310,14989.4058776828;15011.4768372679,-30019.1238574291,14983.3936373475;15005.4471754616,-30007.0719074420,14977.3813597404;14999.4174931158,-29995.0199050513,14971.3690498010;14993.3877951555,-29982.9678601188,14965.3567124587;14987.3580864961,-29970.9157824871,14959.3443526334;14981.3283720428,-29958.8636819787,14953.3319752351;14975.2986566918,-29946.8115683978,14947.3195851643;14969.2689453290,-29934.7594515282,14941.3071873116;14963.2392428310,-29922.7073411349,14935.2947865584;14957.2095540647,-29910.6552469635,14929.2823877759;14951.1798838870,-29898.6031787400,14923.2699958260;14945.1502371456,-29886.5511461716,14917.2576155608;14939.1206186784,-29874.4991589459,14911.2452518229;14933.0910333136,-29862.4472267313,14905.2329094454;14927.0614858698,-29850.3953591769,14899.2205932514;14921.0319811561,-29838.3435659125,14893.2083080546;14915.0025239720,-29826.2918565494,14887.1960586595;14908.9731191071,-29814.2402406787,14881.1838498605;14902.9437713420,-29802.1887278733,14875.1716864427;14896.9144854472,-29790.1373276861,14869.1595731815;14890.8852661840,-29778.0860496518,14863.1475148430;14884.8561183041,-29766.0349032852,14857.1355161835;14878.8270465493,-29753.9838980824,14851.1235819499;14872.7980556525,-29741.9330435207,14845.1117168798;14866.7691503366,-29729.8823490580,14839.0999257010;14860.7403353151,-29717.8318241332,14833.0882131319;14854.7116152923,-29705.7814781665,14827.0765838815;14848.6829949626,-29693.7313205589,14821.0650426492;14842.6544790112,-29681.6813606926,14815.0535941251;14836.6260721137,-29669.6316079307,14809.0422429897;14830.5977789365,-29657.5820716176,14803.0309939143;14824.5696041363,-29645.5327610788,14797.0198515604;14818.5415523603,-29633.4836856208,14791.0088205805;14812.5136282466,-29621.4348545314,14784.9979056175;14806.4858364238,-29609.3862770796,14778.9871113047;14800.4581815108,-29597.3379625155,14772.9764422665;14794.4306681176,-29585.2899200705,14766.9659031176;14788.4033008445,-29573.2421589570,14760.9554984633;14782.3760842824,-29561.1946883692,14754.9452328996;14776.3490230131,-29549.1475174823,14748.9351110134;14770.3221216089,-29537.1006554527,14742.9251373820;14764.2953846327,-29525.0541114181,14736.9153165734;14758.2688166382,-29513.0078944980,14730.9056531464;14752.2424221697,-29500.9620137925,14724.8961516503;14746.2162057625,-29488.9164783840,14718.8868166256;14740.1901719421,-29476.8712973357,14712.8776526028;14734.1643252249,-29464.8264796922,14706.8686641037;14728.1386701184,-29452.7820344802,14700.8598556407;14722.1132111204,-29440.7379707070,14694.8512317168;14716.0879527195,-29428.6942973622,14688.8427968259;14710.0628993953,-29416.6510234163,14682.8345554527;14704.0380556181,-29404.6081578220,14676.8265120726;14698.0134258488,-29392.5657095127,14670.8186711518;14691.9890145391,-29380.5236874041,14664.8110371474;14685.9648261318,-29368.4821003932,14658.8036145072;14679.9408650602,-29356.4409573587,14652.7964076699;14673.9171357487,-29344.4002671610,14646.7894210650;14667.8936426123,-29332.3600386421,14640.7826591128;14661.8703900569,-29320.3202806256,14634.7761262246;14655.8473824793,-29308.2810019170,14628.7698268025;14649.8246242673,-29296.2422113035,14622.7637652395;14643.8021197991,-29284.2039175537,14616.7579459193;14637.7798734445,-29272.1661294186,14610.7523732168;14631.7578895637,-29260.1288556306,14604.7470514977;14625.7361725079,-29248.0921049037,14598.7419851184;14619.7147266192,-29236.0558859344,14592.7371784266;14613.6935562307,-29224.0202074004,14586.7326357606;14607.6726656665,-29211.9850779617,14580.7283614501;14601.6520592416,-29199.9505062599,14574.7243598151;14595.6317412617,-29187.9165009189,14568.7206351673;14589.6117160240,-29175.8830705441,14562.7171918088;14583.5919878163,-29163.8502237233,14556.7140340331;14577.5725609174,-29151.8179690258,14550.7111661244;14571.5534395972,-29139.7863150033,14544.7085923582;14565.5346281168,-29127.7552701897,14538.7063170008;14559.5161307280,-29115.7248431002,14532.7043443096;14553.4979516737,-29103.6950422327,14526.7026785331;14547.4800951880,-29091.6658760670,14520.7013239108;14541.4625654960,-29079.6373530652,14514.7002846734;14535.4453668137,-29067.6094816711,14508.6995650425;14529.4285033485,-29055.5822703109,14502.6991692308;14523.4119792986,-29043.5557273931,14496.6991014421;14517.3957988535,-29031.5298613085,14490.6993658717;14511.3799661937,-29019.5046804297,14484.6999667055;14505.3644854908,-29007.4801931117,14478.7009081207;14499.3493609076,-28995.4564076918,14472.7021942857;14493.3345965979,-28983.4333324897,14466.7038293600;14487.3201967071,-28971.4109758074,14460.7058174944;14481.3061653711,-28959.3893459287,14454.7081628306;14475.2925067174,-28947.3684511206,14448.7108695019;14469.2792248647,-28935.3482996317,14442.7139416322;14463.2663239226,-28923.3288996936,14436.7173833373;14457.2538079923,-28911.3102595197,14430.7211987236;14451.2416811659,-28899.2923873066,14424.7253918893;14445.2299475269,-28887.2752912326,14418.7299669232;14439.2186111500,-28875.2589794588,14412.7349279059;14433.2076761010,-28863.2434601289,14406.7402789090;14427.1971464372,-28851.2287413689,14400.7460239954;14421.1870262070,-28839.2148312874,14394.7521672193;14415.1773194502,-28827.2017379757,14388.7587126262;14409.1680301977,-28815.1894695074,14382.7656642528;14403.1591624721,-28803.1780339391,14376.7730261274;14397.1507202868,-28791.1674393098,14370.7808022693;14391.1427076468,-28779.1576936408,14364.7889966892;14385.1351285485,-28767.1488049366,14358.7976133892;14379.1279869795,-28755.1407811843,14352.8066563629;14373.1212869188,-28743.1336303535,14346.8161295951;14367.1150323367,-28731.1273603965,14340.8260370618;14361.1092271951,-28719.1219792487,14334.8363827309;14355.1038754471,-28707.1174948278,14328.8471705611;14349.0989810371,-28695.1139150347,14322.8584045029;14343.0945479011,-28683.1112477528,14316.8700884981;14337.0905799664,-28671.1095008486,14310.8822264799;14331.0870811519,-28659.1086821712,14304.8948223730;14325.0840553680,-28647.1087995532,14298.9078800937;14319.0815065160,-28635.1098608089,14292.9214035493;14313.0794384892,-28623.1118737367,14286.9353966391;14307.0778551723,-28611.1148461173,14280.9498632534;14301.0767604413,-28599.1187857145,14274.9648072745;14295.0761581638,-28587.1237002752,14268.9802325757;14289.0760521989,-28575.1295975293,14262.9961430222;14283.0764463974,-28563.1364851897,14257.0125424706;14277.0773446010,-28551.1443709519,14251.0294347688;14271.0787506438,-28539.1532624953,14245.0468237567;14265.0806683509,-28527.1631674817,14239.0647132654;14259.0831015389,-28515.1740935563,14233.0831071176;14253.0860540163,-28503.1860483476,14227.1020091279;14247.0895295831,-28491.1990394669,14221.1214231020;14241.0935320306,-28479.2130745087,14215.1413528376;14235.0980651422,-28467.2281610511,14209.1618021238;14229.1031326923,-28455.2443066550,14203.1827747413;14223.1087384475,-28443.2615188647,14197.2042744626;14217.1148861656,-28431.2798052076,14191.2263050517;14211.1215795964,-28419.2991731948,14185.2488702643;14205.1288224811,-28407.3196303202,14179.2719738478;14199.1366185526,-28395.3411840615,14173.2956195413;14193.1449715355,-28383.3638418792,14167.3198110753;14187.1538851462,-28371.3876112176,14161.3445521724;14181.1633630926,-28359.4124995043,14155.3698465466;14175.1734090745,-28347.4385141502,14149.3956979039;14169.1840267833,-28335.4656625499,14143.4221099417;14163.1952199021,-28323.4939520808,14137.4490863493;14157.2069921058,-28311.5233901046,14131.4766308078;14151.2193470610,-28299.5539839659,14125.5047469900;14145.2322884261,-28287.5857409931,14119.5334385604;14139.2458198514,-28275.6186684981,14113.5627091754;14133.2599449787,-28263.6527737763,14107.5925624832;14127.2746674419,-28251.6880641067,14101.6230021235;14121.2899908664,-28239.7245467519,14095.6540317284;14115.3059188695,-28227.7622289580,14089.6856549212;14109.3224550607,-28215.8011179552,14083.7178753174;14103.3396030406,-28203.8412209567,14077.7506965243;14097.3573664024,-28191.8825451598,14071.7841221408;14091.3757487306,-28179.9250977455,14065.8181557581;14085.3947536019,-28167.9688858785,14059.8528009589;14079.4143845848,-28156.0139167070,14053.8880613180;14073.4346452395,-28144.0601973634,14047.9239404019;14067.4555391183,-28132.1077349634,14041.9604417692;14061.4770697654,-28120.1565366070,14035.9975689704;14055.4992407169,-28108.2066093777,14030.0353255477;14049.5220555007,-28096.2579603430,14024.0737150356;14043.5455176368,-28084.3105965543,14018.1127409602;14037.5696306371,-28072.3645250467,14012.1524068398;14031.5943980055,-28060.4197528395,14006.1927161846;14025.6198232379,-28048.4762869359,14000.2336724967;14019.6459098218,-28036.5341343226,13994.2752792702;14013.6726612374,-28024.5933019710,13988.3175399915;14007.7000809562,-28012.6537968359,13982.3604581384;14001.7281724423,-28000.7156258567,13976.4040371815;13995.7569391513,-27988.7787959561,13970.4482805827;13989.7863845312,-27976.8433140415,13964.4931917964;13983.8165120221,-27964.9091870043,13958.5387742690;13977.8473250557,-27952.9764217196,13952.5850314387;13971.8788270563,-27941.0450250473,13946.6319667361;13965.9110214398,-27929.1150038306,13940.6795835837;13959.9439116148,-27917.1863648979,13934.7278853962;13953.9775009814,-27905.2591150608,13928.7768755803;13948.0117929319,-27893.3332611156,13922.8265575348;13942.0467908511,-27881.4088098431,13916.8769346509;13936.0824981157,-27869.4857680078,13910.9280103116;13930.1189180944,-27857.5641423586,13904.9797878921;13924.1560541482,-27845.6439396292,13899.0322707601;13918.1939096304,-27833.7251665369,13893.0854622750;13912.2324878862,-27821.8078297840,13887.1393657886;13906.2717922532,-27809.8919360569,13881.1939846452;13900.3118260610,-27797.9774920259,13875.2493221806;13894.3525926315,-27786.0645043464,13869.3053817233;13888.3940952790,-27774.1529796580,13863.3621665941;13882.4363373098,-27762.2429245848,13857.4196801057;13876.4793220224,-27750.3343457353,13851.4779255633;13870.5230527077,-27738.4272497024,13845.5369062642;13864.5675326488,-27726.5216430634,13839.5966254980;13858.6127651211,-27714.6175323808,13833.6570865467;13852.6587533922,-27702.7149242007,13827.7182926844;13846.7055007221,-27690.8138250546,13821.7802471777;13840.7530103630,-27678.9142414582,13815.8429532853;13833.3371224467,-27664.0877662594,13808.4445098767;13825.9228166903,-27649.2644464392,13801.0476367473;13818.5100957178,-27634.4442872566,13793.6523365286;13811.0989621461,-27619.6272939569,13786.2586118450;13803.6894185852,-27604.8134717710,13778.8664653139;13796.2814676376,-27590.0028259152,13771.4758995453;13788.8751118991,-27575.1953615924,13764.0869171426;13781.4703539586,-27560.3910839912,13756.6995207019;13774.0671963975,-27545.5899982857,13749.3137128124;13766.6656417903,-27530.7921096362,13741.9294960560;13759.2656927048,-27515.9974231891,13734.5468730079;13751.8673517015,-27501.2059440767,13727.1658462361;13744.4706213338,-27486.4176774170,13719.7864183017;13737.0755041483,-27471.6326283141,13712.4085917587;13729.6820026845,-27456.8508018586,13705.0323691543;13722.2901194751,-27442.0722031264,13697.6577530285;13714.8998570458,-27427.2968371801,13690.2847459145;13707.5112179150,-27412.5247090680,13682.9133503384;13700.1242045947,-27397.7558238247,13675.5435688197;13692.7388195896,-27382.9901864710,13668.1754038707;13685.3550653974,-27368.2278020134,13660.8088579966;13677.9729445092,-27353.4686754450,13653.4439336961;13670.5924594092,-27338.7128117450,13646.0806334608;13663.2136125742,-27323.9602158786,13638.7189597753;13655.8364064746,-27309.2108927975,13631.3589151175;13648.4608435740,-27294.4648474396,13624.0005019584;13641.0869263287,-27279.7220847289,13616.6437227621;13633.7146571884,-27264.9826095757,13609.2885799859;13626.3440385959,-27250.2464268768,13601.9350760801;13618.9750729873,-27235.5135415150,13594.5832134884;13611.6077627915,-27220.7839583596,13587.2329946473;13604.2421104312,-27206.0576822667,13579.8844219872;13596.8781183216,-27191.3347180778,13572.5374979308;13589.5157888717,-27176.6150706217,13565.1922248947;13582.1551244833,-27161.8987447134,13557.8486052885;13574.7961275516,-27147.1857451539,13550.5066415147;13567.4388004651,-27132.4760767313,13543.1663359697;13560.0831456052,-27117.7697442194,13535.8276910426;13552.7291653470,-27103.0667523795,13528.4907091159;13545.3768620585,-27088.3671059584,13521.1553925654;13538.0262381014,-27073.6708096904,13513.8217437604;13530.6772958302,-27058.9778682956,13506.4897650630;13523.3300375929,-27044.2882864808,13499.1594588289;13515.9844657310,-27029.6020689399,13491.8308274073;13508.6405825789,-27014.9192203527,13484.5038731401;13501.2983904646,-27000.2397453862,13477.1785983632;13493.9578917094,-26985.5636486939,13469.8550054054;13486.6190886278,-26970.8909349157,13462.5330965891;13479.2819835279,-26956.2216086785,13455.2128742297;13471.9465787109,-26941.5556745959,13447.8943406365;13464.6128764717,-26926.8931372683,13440.5774981117;13457.2808790980,-26912.2340012823,13433.2623489511;13449.9505888716,-26897.5782712121,13425.9488954438;13442.6220080671,-26882.9259516179,13418.6371398724;13435.2951389530,-26868.2770470475,13411.3270845128;13427.9699837907,-26853.6315620346,13404.0187316345;13420.6465448355,-26838.9895011007,13396.7120835002;13413.3248243360,-26824.3508687536,13389.4071423663;13406.0048245340,-26809.7156694882,13382.1039104824;13398.6865476651,-26795.0839077860,13374.8023900916;13391.3699959581,-26780.4555881159,13367.5025834308;13384.0551716354,-26765.8307149332,13360.2044927298;13376.7420769130,-26751.2092926808,13352.9081202124;13369.4307140002,-26736.5913257881,13345.6134680957;13362.1210850998,-26721.9768186715,13338.3205385903;13354.8131924084,-26707.3657757349,13331.0293339003;13347.5070381157,-26692.7582013687,13323.7398562234;13340.2026244053,-26678.1540999508,13316.4521077509;13332.8999534541,-26663.5534758458,13309.1660906674;13325.5990274327,-26648.9563334054,13301.8818071512;13318.2998485052,-26634.3626769689,13294.5992593743;13311.0024188293,-26619.7725108624,13287.3184495021;13303.7067405563,-26605.1858393989,13280.0393796936;13296.4128158311,-26590.6026668793,13272.7620521015;13289.1206467921,-26576.0229975910,13265.4864688721;13281.8302355714,-26561.4468358090,13258.2126321451;13274.5415842947,-26546.8741857953,13250.9405440540;13267.2546950813,-26532.3050517993,13243.6702067261;13259.9695700443,-26517.7394380579,13236.4016222820;13252.6862112901,-26503.1773487947,13229.1347928361;13245.4046209192,-26488.6187882211,13221.8697204966;13238.1248010255,-26474.0637605358,13214.6064073651;13230.8467536966,-26459.5122699246,13207.3448555372;13223.5704810138,-26444.9643205609,13200.0850671019;13216.2959850523,-26430.4199166055,13192.8270441421;13209.0232678806,-26415.8790622064,13185.5707887343;13201.7523315613,-26401.3417614991,13178.3163029488;13194.4831781506,-26386.8080186069,13171.0635888496;13187.2158096982,-26372.2778376398,13163.8126484943;13179.9502282481,-26357.7512226962,13156.5634839345;13172.6864358374,-26343.2281778611,13149.3160972154;13165.4244344974,-26328.7087072080,13142.0704903761;13158.1642262532,-26314.1928147972,13134.8266654493;13150.9058131234,-26299.6805046767,13127.5846244616;13143.6491971206,-26285.1717808824,13120.3443694334;13136.3943802511,-26270.6666474372,13113.1059023787;13129.1413645151,-26256.1651083523,13105.8692253057;13121.8901519065,-26241.6671676263,13098.6343402162;13114.6407444132,-26227.1728292452,13091.4012491058;13107.3931440169,-26212.6820971830,13084.1699539640;13100.1473526931,-26198.1949754013,13076.9404567743;13092.9033724111,-26183.7114678493,13069.7127595137;13085.6612051341,-26169.2315784640,13062.4868641534;13078.4208528194,-26154.7553111702,13055.2627726584;13071.1823174178,-26140.2826698805,13048.0404869875;13063.9456008744,-26125.8136584952,13040.8200090935;13056.7107051279,-26111.3482809025,13033.6013409232;13049.4776321112,-26096.8865409785,13026.3844844170;13042.2463837509,-26082.4284425870,13019.1694415097;13035.0169619675,-26067.9739895794,13011.9562141295;13027.7893686756,-26053.5231857955,13004.7448041990;13020.5636057839,-26039.0760350630,12997.5352136345;13013.3396751946,-26024.6325411971,12990.3274443464;13006.1175788043,-26010.1927080011,12983.1214982389;12998.8973185035,-25995.7565392666,12975.9173772106;12991.6788961765,-25981.3240387725,12968.7150831535;12984.4623137018,-25966.8952102866,12961.5146179542;12977.2475729519,-25952.4700575639,12954.3159834928;12970.0346757933,-25938.0485843481,12947.1191816439;12962.8236240864,-25923.6307943702,12939.9242142756;12955.6144196858,-25909.2166913500,12932.7310832506;12948.4070644401,-25894.8062789950,12925.5397904252;12941.2015601918,-25880.3995610008,12918.3503376501;12933.9979087780,-25865.9965410516,12911.1627267699;12926.7961120292,-25851.5972228190,12903.9769596231;12919.5961717704,-25837.2016099635,12896.7930380428;12912.3980898207,-25822.8097061333,12889.6109638558;12905.2018679930,-25808.4215149649,12882.4307388830;12898.0075080947,-25794.0370400833,12875.2523649396;12890.8150119271,-25779.6562851013,12868.0758438349;12883.6243812856,-25765.2792536205,12860.9011773723;12876.4356179600,-25750.9059492302,12853.7283673492;12869.2487237339,-25736.5363755085,12846.5574155575;12862.0637003854,-25722.1705360214,12839.3883237828;12854.8805496865,-25707.8084343236,12832.2210938053;12847.6992734036,-25693.4500739579,12825.0557273992;12840.5198732973,-25679.0954584559,12817.8922263330;12833.3423511220,-25664.7445913369,12810.7305923691;12826.1667086268,-25650.3974761090,12803.5708272645;12818.9929475548,-25636.0541162689,12796.4129327702;12811.8210696435,-25621.7145153017,12789.2569106315;12804.6510766242,-25607.3786766805,12782.1027625878;12797.4829702230,-25593.0466038675,12774.9504903730;12790.3167521599,-25578.7183003130,12767.8000957152;12783.1524241493,-25564.3937694560,12760.6515803365;12775.9899878998,-25550.0730147241,12753.5049459535;12768.8294451144,-25535.7560395332,12746.3601942772;12761.6707974902,-25521.4428472881,12739.2173270126;12754.5140467188,-25507.1334413818,12732.0763458592;12747.3591944862,-25492.8278251967,12724.9372525109;12740.2062424723,-25478.5260021028,12717.8000486556;12733.0551923518,-25464.2279754595,12710.6647359759;12725.9060457934,-25449.9337486146,12703.5313161484;12718.7588044604,-25435.6433249045,12696.3997908444;12711.6134700101,-25421.3567076545,12689.2701617291;12704.4700440948,-25407.0739001788,12682.1424304628;12697.3285283605,-25392.7949057798,12675.0165986993;12690.1889244479,-25378.5197277492,12667.8926680874;12683.0512339921,-25364.2483693670,12660.7706402700;12675.9154586227,-25349.9808339025,12653.6505168847;12668.7815999636,-25335.7171246137,12646.5322995633;12661.6496596328,-25321.4572447469,12639.4159899318;12654.5196392434,-25307.2011975381,12632.3015896113;12647.3915404024,-25292.9489862115,12625.1891002166;12640.2653647115,-25278.7006139805,12618.0785233574;12633.1411137668,-25264.4560840476,12610.9698606378;12626.0187891590,-25250.2153996038,12603.8631136562;12618.8983924728,-25235.9785638290,12596.7582840057;12611.7799252881,-25221.7455798928,12589.6553732738;12604.6633891787,-25207.5164509530,12582.5543830423;12597.5487857133,-25193.2911801567,12575.4553148879;12590.4361164549,-25179.0697706403,12568.3581703815;12583.3253829609,-25164.8522255285,12561.2629510886;12576.2165867837,-25150.6385479360,12554.1696585693;12569.1097294698,-25136.4287409658,12547.0782943782;12562.0048125604,-25122.2228077104,12539.9888600645;12554.9018375914,-25108.0207512513,12532.9013571718;12547.8008060929,-25093.8225746591,12525.8157872385;12540.7017195900,-25079.6282809938,12518.7321517975;12533.6045796022,-25065.4378733040,12511.6504523761;12526.5093876435,-25051.2513546281,12504.5706904964;12519.4161452226,-25037.0687279932,12497.4928676751;12512.3248538429,-25022.8899964162,12490.4169854235;12505.2355150024,-25008.7151629028,12483.3430452475;12498.1481301934,-24994.5442304479,12476.2710486474;12491.0627009035,-24980.3772020360,12469.2009971187;12483.9792286143,-24966.2140806407,12462.1328921510;12476.8977148024,-24952.0548692250,12455.0667352290;12469.8181609390,-24937.8995707410,12448.0025278315;12462.7405684900,-24923.7481881304,12440.9402714326;12455.6649389159,-24909.6007243243,12433.8799675009;12448.5912736720,-24895.4571822429,12426.8216174993;12441.5195742083,-24881.3175647962,12419.7652228859;12434.4498419694,-24867.1818748832,12412.7107851133;12427.3820783948,-24853.0501153927,12405.6583056290;12420.3162849185,-24838.9222892026,12398.6077858748;12413.2524629694,-24824.7983991805,12391.5592272877;12406.1906139713,-24810.6784481837,12384.5126312994;12399.1307393423,-24796.5624390584,12377.4679993359;12392.0728404958,-24782.4503746408,12370.4253328186;12385.0169188396,-24768.3422577569,12363.3846331633;12377.9629757764,-24754.2380912213,12356.3459017806;12370.9110127038,-24740.1378778391,12349.3091400759;12363.8610310140,-24726.0416204048,12342.2743494497;12356.8130320941,-24711.9493217021,12335.2415312968;12349.7670173262,-24697.8609845049,12328.2106870073;12342.7229880870,-24683.7766115762,12321.1818179658;12335.6809457480,-24669.6962056691,12314.1549255520;12328.6408916758,-24655.6197695264,12307.1300111401;12321.6028272316,-24641.5473058801,12300.1070760995;12314.5667537717,-24627.4788174525,12293.0861217944;12307.5326726470,-24613.4143069552,12286.0671495836;12300.5005852037,-24599.3537770900,12279.0501608212;12293.4704927822,-24585.2972305479,12272.0351568558;12286.4423967187,-24571.2446700105,12265.0221390312;12279.4162983435,-24557.1960981483,12258.0111086859;12272.3921989822,-24543.1515176222,12251.0020671534;12265.3700999555,-24529.1109310829,12243.9950157622;12258.3500025786,-24515.0743411709,12236.9899558357;12251.3319081619,-24501.0417505162,12229.9868886920;12244.3158180108,-24487.0131617396,12222.9858156446;12237.3017334255,-24472.9885774508,12215.9867380017;12230.2896557014,-24458.9680002503,12208.9896570664;12223.2795861285,-24444.9514327278,12201.9945741368;12216.2715259921,-24430.9388774635,12195.0014905063;12209.2654765724,-24416.9303370272,12188.0104074627;12202.2614391447,-24402.9258139792,12181.0213262896;12195.2594149792,-24388.9253108695,12174.0342482649;12188.2594053412,-24374.9288302380,12167.0491746618;12181.2614114909,-24360.9363746149,12160.0661067487;12174.2654346836,-24346.9479465204,12153.0850457886;12167.2714761698,-24332.9635484648,12146.1059930401;12160.2795371949,-24318.9831829484,12139.1289497564;12153.2896189994,-24305.0068524619,12132.1539171860;12146.3017228188,-24291.0345594859,12125.1808965724;12139.3158498839,-24277.0663064910,12118.2098891541;12132.3320014203,-24263.1020959385,12111.2408961651;12125.3501786490,-24249.1419302795,12104.2739188338;12118.3703827859,-24235.1858119553,12097.3089583844;12111.3926150421,-24221.2337433977,12090.3460160357;12104.4168766239,-24207.2857270285,12083.3850930021;12097.4431687324,-24193.3417652597,12076.4261904926;12090.4714925643,-24179.4018604939,12069.4693097117;12083.5018493112,-24165.4660151238,12062.5144518591;12076.5342401600,-24151.5342315325,12055.5616181296;12069.5686662925,-24137.6065120932,12048.6108097128;12062.6051288860,-24123.6828591697,12041.6620277939;12055.6436291126,-24109.7632751159,12034.7152735532;12048.6841681403,-24095.8477622768,12027.7705481663;12041.7267471313,-24081.9363229866,12020.8278528036;12033.3269163316,-24065.1399789596,12012.4449732051;12024.9298885167,-24048.3492346446,12004.0648855484;12016.5356642964,-24031.5640912705,11995.6875904520;12008.1442442762,-24014.7845500574,11987.3130885300;11999.7556290575,-23998.0106122176,11978.9413803927;11991.3698192371,-23981.2422789540,11970.5724666456;11982.9868154078,-23964.4795514612,11962.2063478902;11974.6066181582,-23947.7224309260,11953.8430247237;11966.2292280725,-23930.9709185256,11945.4824977390;11957.8546457307,-23914.2250154293,11937.1247675248;11949.4828717087,-23897.4847227982,11928.7698346657;11941.1139065777,-23880.7500417843,11920.4176997418;11932.7477509055,-23864.0209735317,11912.0683633293;11924.3844052551,-23847.2975191759,11903.7218260000;11916.0238701853,-23830.5796798438,11895.3780883214;11907.6661462512,-23813.8674566545,11887.0371508572;11899.3112340030,-23797.1608507178,11878.6990141664;11890.9591339873,-23780.4598631361,11870.3636788043;11882.6098467465,-23763.7644950030,11862.0311453219;11874.2633728184,-23747.0747474036,11853.7014142656;11865.9197127372,-23730.3906214152,11845.3744861784;11857.5788670326,-23713.7121181064,11837.0503615986;11849.2408362303,-23697.0392385378,11828.7290410606;11840.9056208519,-23680.3719837614,11820.4105250947;11832.5732214147,-23663.7103548213,11812.0948142268;11824.2436384322,-23647.0543527532,11803.7819089790;11815.9168724135,-23630.4039785847,11795.4718098692;11807.5929238637,-23613.7592333350,11787.1645174112;11799.2717932841,-23597.1201180155,11778.8600321147;11790.9534811713,-23580.4866336288,11770.5583544853;11782.6379880186,-23563.8587811703,11762.2594850246;11774.3253143146,-23547.2365616263,11753.9634242300;11766.0154605441,-23530.6199759755,11745.6701725950;11757.7084271878,-23514.0090251883,11737.3797306089;11749.4042147225,-23497.4037102271,11729.0920987571;11741.1028236209,-23480.8040320466,11720.8072775210;11732.8042543516,-23464.2099915928,11712.5252673777;11724.5085073792,-23447.6215898040,11704.2460688007;11716.2155831644,-23431.0388276104,11695.9696822590;11707.9254821636,-23414.4617059341,11687.6961082180;11699.6382048299,-23397.8902256898,11679.4253471390;11691.3537516115,-23381.3243877831,11671.1573994791;11683.0721229532,-23364.7641931126,11662.8922656917;11674.7933192958,-23348.2096425689,11654.6299462261;11666.5173410760,-23331.6607370339,11646.3704415277;11658.2441887265,-23315.1174773824,11638.1137520379;11649.9738626764,-23298.5798644811,11629.8598781942;11641.7063633502,-23282.0478991883,11621.6088204299;11633.4416911693,-23265.5215823553,11613.3605791748;11625.1798465505,-23249.0009148248,11605.1151548545;11616.9208299070,-23232.4858974322,11596.8725478907;11608.6646416480,-23215.9765310043,11588.6327587012;11600.4112821789,-23199.4728163612,11580.3957877000;11592.1607519011,-23182.9747543145,11572.1616352971;11583.9130512122,-23166.4823456679,11563.9303018986;11575.6681805057,-23149.9955912177,11555.7017879068;11567.4261401717,-23133.5144917524,11547.4760937201;11559.1869305959,-23117.0390480527,11539.2532197331;11550.9505521606,-23100.5692608916,11531.0331663363;11542.7170052439,-23084.1051310343,11522.8159339167;11534.4862902202,-23067.6466592385,11514.6015228571;11526.2584074601,-23051.1938462540,11506.3899335368;11518.0333573305,-23034.7466928233,11498.1811663310;11509.8111401941,-23018.3051996809,11489.9752216113;11501.5917564102,-23001.8693675537,11481.7720997453;11493.3752063341,-22985.4391971613,11473.5718010969;11485.1614903173,-22969.0146892153,11465.3743260263;11476.9506087076,-22952.5958444201,11457.1796748896;11468.7425618488,-22936.1826634721,11448.9878480394;11460.5373500812,-22919.7751470606,11440.7988458245;11452.3349737415,-22903.3732958674,11432.6126685899;11444.1354331620,-22886.9771105661,11424.4293166767;11435.9387286717,-22870.5865918235,11416.2487904224;11427.7448605960,-22854.2017402987,11408.0710901608;11419.5538292561,-22837.8225566430,11399.8962162217;11411.3656349699,-22821.4490415007,11391.7241689316;11403.1802780514,-22805.0811955085,11383.5549486129;11394.9977588109,-22788.7190192957,11375.3885555845;11386.8180775549,-22772.3625134838,11367.2249901613;11378.6412345864,-22756.0116786877,11359.0642526549;11370.4672302045,-22739.6665155140,11350.9063433730;11362.2960647048,-22723.3270245625,11342.7512626196;11354.1277383793,-22706.9932064257,11334.5990106951;11345.9622515159,-22690.6650616882,11326.4495878961;11337.7996043993,-22674.3425909279,11318.3029945158;11329.6397973105,-22658.0257947153,11310.1592308435;11321.4828305265,-22641.7146736129,11302.0182971647;11313.3287043210,-22625.4092281768,11293.8801937618;11305.1774189639,-22609.1094589554,11285.7449209130;11297.0289747217,-22592.8153664901,11277.6124788934;11288.8833718570,-22576.5269513145,11269.4828679739;11280.7406106289,-22560.2442139557,11261.3560884223;11272.6006912930,-22543.9671549330,11253.2321405025;11264.4636141012,-22527.6957747590,11245.1110244750;11256.3293793019,-22511.4300739387,11236.9927405965;11248.1979871398,-22495.1700529702,11228.8772891203;11240.0694378560,-22478.9157123442,11220.7646702959;11231.9437316884,-22462.6670525447,11212.6548843696;11223.8208688709,-22446.4240740480,11204.5479315838;11215.7008496339,-22430.1867773238,11196.4438121774;11207.5836742045,-22413.9551628343,11188.3425263859;11199.4693428063,-22397.7292310351,11180.2440744413;11191.3578556589,-22381.5089823741,11172.1484565717;11183.2492129790,-22365.2944172928,11164.0556730022;11175.1434149794,-22349.0855362254,11155.9657239539;11167.0404618693,-22332.8823395986,11147.8786096447;11158.9403538548,-22316.6848278332,11139.7943302889;11150.8430911381,-22300.4930013418,11131.7128860972;11142.7486739183,-22284.3068605309,11123.6342772772;11134.6571023908,-22268.1264057996,11115.5585040325;11126.5683767474,-22251.9516375401,11107.4855665634;11118.4824971767,-22235.7825561378,11099.4154650670;11110.3994638638,-22219.6191619712,11091.3481997366;11102.3192769901,-22203.4614554117,11083.2837707623;11094.2419367340,-22187.3094368239,11075.2221783306;11086.1674432700,-22171.1631065655,11067.1634226246;11078.0957967694,-22155.0224649874,11059.1075038238;11070.0269974003,-22138.8875124338,11051.0544221048;11061.9610453269,-22122.7582492417,11043.0041776402;11053.8979407103,-22106.6346757413,11034.9567705993;11045.8376837083,-22090.5167922566,11026.9122011485;11037.7802744750,-22074.4045991041,11018.8704694501;11029.7257131614,-22058.2980965938,11010.8315756635;11021.6739999149,-22042.1972850290,11002.7955199445;11013.6251348797,-22026.1021647063,10994.7623024456;11005.5791181964,-22010.0127359151,10986.7319233159;10997.5359500026,-21993.9289989387,10978.7043827012;10989.4956304323,-21977.8509540534,10970.6796807439;10981.4581596162,-21961.7786015286,10962.6578175829;10973.4235376818,-21945.7119416276,10954.6387933542;10965.3917647529,-21929.6509746064,10946.6226081900;10957.3628409504,-21913.5957007147,10938.6092622193;10949.3367663917,-21897.5461201956,10930.5987555680;10941.3135411909,-21881.5022332853,10922.5910883585;10933.2931654589,-21865.4640402137,10914.5862607099;10925.2756393031,-21849.4315412041,10906.5842727381;10917.2609628278,-21833.4047364728,10898.5851245555;10909.2491361340,-21817.3836262299,10890.5888162715;10901.2401593192,-21801.3682106789,10882.5953479920;10893.2340324779,-21785.3584900167,10874.6047198197;10885.2307557014,-21769.3544644338,10866.6169318541;10877.2303290775,-21753.3561341141,10858.6319841915;10869.2327526908,-21737.3634992348,10850.6498769246;10861.2380266229,-21721.3765599671,10842.6706101434;10853.2461509517,-21705.3953164749,10834.6941839340;10845.2571257525,-21689.4197689169,10826.7205983801;10837.2709510968,-21673.4499174442,10818.7498535614;10829.2876270533,-21657.4857622019,10810.7819495547;10821.3071536873,-21641.5273033289,10802.8168864338;10813.3295310610,-21625.5745409575,10794.8546642691;10805.3547592332,-21609.6274752134,10786.8952831276;10797.3828382598,-21593.6861062162,10778.9387430735;10789.4137681933,-21577.7504340792,10770.9850441675;10781.4475490832,-21561.8204589090,10763.0341864673;10773.4841809758,-21545.8961808063,10755.0861700275;10765.5236639142,-21529.9775998653,10747.1409948995;10757.5659979383,-21514.0647161737,10739.1986611313;10749.6111830850,-21498.1575298133,10731.2591687681;10741.6592193879,-21482.2560408592,10723.3225178518;10733.7101068775,-21466.3602493803,10715.3887084209;10725.7638455815,-21450.4701554399,10707.4577405115;10717.8204355240,-21434.5857590941,10699.5296141558;10709.8798767262,-21418.7070603933,10691.6043293833;10701.9421692063,-21402.8340593816,10683.6818862203;10694.0073129794,-21386.9667560970,10675.7622846900;10686.0753080573,-21371.1051505714,10667.8455248128;10678.1461544489,-21355.2492428300,10659.9316066053;10670.2198521598,-21339.3990328923,10652.0205300817;10662.2964011930,-21323.5545207717,10644.1122952529;10654.3758015481,-21307.7157064754,10636.2069021267;10646.4580532216,-21291.8825900041,10628.3043507078;10638.5431562070,-21276.0551713528,10620.4046409980;10630.6311104949,-21260.2334505105,10612.5077729959;10622.7219160727,-21244.4174274597,10604.6137466971;10614.8155729248,-21228.6071021772,10596.7225620943;10606.9120810329,-21212.8024746337,10588.8342191770;10599.0114403751,-21197.0035447937,10580.9487179318;10591.1136509269,-21181.2103126158,10573.0660583423;10583.2187126609,-21165.4227780526,10565.1862403889;10575.3266255462,-21149.6409410505,10557.3092640492;10567.4373895494,-21133.8648015503,10549.4351292978;10559.5510046339,-21118.0943594864,10541.5638361061;10551.6674707601,-21102.3296147875,10533.6953844429;10543.7867878855,-21086.5705673762,10525.8297742735;10535.9089559648,-21070.8172171695,10517.9670055610;10528.0339749494,-21055.0695640781,10510.1070782647;10520.1618447880,-21039.3276080070,10502.2499923414;10512.2925654263,-21023.5913488552,10494.3957477451;10504.4261368072,-21007.8607865161,10486.5443444265;10496.5625588701,-20992.1359208765,10478.6957823334;10488.7018315524,-20976.4167518184,10470.8500614110;10480.8439547878,-20960.7032792172,10463.0071816012;10472.9889285074,-20944.9955029426,10455.1671428432;10465.1367526395,-20929.2934228587,10447.3299450734;10457.2874271092,-20913.5970388235,10439.4955882249;10449.4409518391,-20897.9063506898,10431.6640722283;10441.5973267485,-20882.2213583036,10423.8353970111;10433.7565517543,-20866.5420615063,10416.0095624981;10425.9186267700,-20850.8684601328,10408.1865686110;10418.0835517065,-20835.2005540123,10400.3664152687;10410.2513264721,-20819.5383429687,10392.5491023875;10402.4219509718,-20803.8818268197,10384.7346298803;10394.5954251079,-20788.2310053777,10376.9229976577;10386.7717487800,-20772.5858784491,10369.1142056272;10378.9509218849,-20756.9464458351,10361.3082536935;10371.1329443161,-20741.3127073305,10353.5051417584;10363.3178159650,-20725.6846627252,10345.7048697210;10355.5055367196,-20710.0623118029,10337.9074374775;10347.6961064654,-20694.4456543421,10330.1128449213;10339.8895250849,-20678.8346901152,10322.3210919430;10332.0857924581,-20663.2294188896,10314.5321784305;10324.2849084619,-20647.6298404268,10306.7461042687;10316.4868729706,-20632.0359544828,10298.9628693400;10308.6916858557,-20616.4477608078,10291.1824735236;10300.8993469858,-20600.8652591468,10283.4049166965;10293.1098562269,-20585.2884492391,10275.6301987323;10285.3232134423,-20569.7173308184,10267.8583195023;10277.5394184924,-20554.1519036133,10260.0892788751;10269.7584712348,-20538.5921673462,10252.3230767160;10261.9803715244,-20523.0381217346,10244.5597128880;10254.2051192137,-20507.4897664905,10236.7991872515;10246.4327141521,-20491.9471013200,10229.0414996638;10238.6631561863,-20476.4101259244,10221.2866499796;10230.8964451604,-20460.8788399990,10213.5346380510;10223.1325809159,-20445.3532432338,10205.7854637272;10215.3715632912,-20429.8333353135,10198.0391268547;10207.6133921226,-20414.3191159177,10190.2956272777;10199.8580672433,-20398.8105847201,10182.5549648372;10192.1055884838,-20383.3077413891,10174.8171393717;10184.3559556721,-20367.8105855882,10167.0821507172;10176.6091686336,-20352.3191169752,10159.3499987068;10168.8652271906,-20336.8333352023,10151.6206831709;10161.1241311634,-20321.3532399170,10143.8942039374;10153.3858803691,-20305.8788307610,10136.1705608316;10145.6504746225,-20290.4101073710,10128.4497536759;10137.9179137355,-20274.9470693784,10120.7317822903;10130.1881975175,-20259.4897164088,10113.0166464919;10122.4613257753,-20244.0380480834,10105.3043460955;10114.7372983131,-20228.5920640177,10097.5948809131;10107.0161149323,-20213.1517638217,10089.8882507540;10099.2977754321,-20197.7171471008,10082.1844554251;10091.5822796085,-20182.2882134547,10074.4834947304;10083.8696272554,-20166.8649624779,10066.7853684716;10076.1598181639,-20151.4473937602,10059.0900764476;10068.4528521226,-20136.0355068858,10051.3976184549;10060.7487289175,-20120.6293014336,10043.7079942872;10053.0474483320,-20105.2287769779,10036.0212037358;10045.3490101469,-20089.8339330874,10028.3372465894;10037.6534141406,-20074.4447693259,10020.6561226340;10029.9606600888,-20059.0612852520,10012.9778316533;10019.5257835653,-20038.1934166760,10002.5616712406;10009.0951221746,-20017.3339743417,9992.14971497477;9998.66867475719,-19996.4829559373,9981.74196170542;9988.24644015229,-19975.6403591483,9971.33841028091;9977.82841719712,-19954.8061816560,9960.93905954762;9967.41460472718,-19933.9804211383,9950.54390835018;9957.00500157624,-19913.1630752698,9940.15295553150;9946.59960657653,-19892.3541417219,9929.76619993292;9936.19841855843,-19871.5536181623,9919.38364039397;9925.80143635045,-19850.7615022548,9909.00527575224;9915.40865877970,-19829.9777916607,9898.63110484395;9905.02008467146,-19809.2024840374,9888.26112650349;9894.63571284921,-19788.4355770387,9877.89533956345;9884.25554213478,-19767.6770683153,9867.53374285472;9873.87957134857,-19746.9269555147,9857.17633520678;9863.50779930890,-19726.1852362805,9846.82311544706;9853.14022483274,-19705.4519082536,9836.47408240155;9842.77684673523,-19684.7269690710,9826.12923489451;9832.41766382976,-19664.0104163664,9815.78857174834;9822.06267492840,-19643.3022477707,9805.45209178419;9811.71187884116,-19622.6024609108,9795.11979382109;9801.36527437658,-19601.9110534106,9784.79167667663;9791.02286034173,-19581.2280228911,9774.46773916693;9780.68463554169,-19560.5533669692,9764.14798010608;9770.35059878011,-19539.8870832591,9753.83239830673;9760.02074885915,-19519.2291693717,9743.52099258009;9749.69508457897,-19498.5796229143,9733.21376173531;9739.37360473847,-19477.9384414913,9722.91070458029;9729.05630813466,-19457.3056227037,9712.61181992103;9718.74319356324,-19436.6811641495,9702.31710656224;9708.43425981801,-19416.0650634230,9692.02656330669;9698.12950569126,-19395.4573181157,9681.74018895562;9687.82892997386,-19374.8579258159,9671.45798230892;9677.53253145492,-19354.2668841086,9661.17994216463;9667.24030892188,-19333.6841905754,9650.90606731915;9656.95226116082,-19313.1098427952,9640.63635656752;9646.66838695611,-19292.5438383434,9630.37080870306;9636.38868509057,-19271.9861747923,9620.10942251751;9626.11315434556,-19251.4368497113,9609.85219680117;9615.84179350064,-19230.8958606662,9599.59913034254;9605.57460133408,-19210.3632052202,9589.35022192880;9595.31157662245,-19189.8388809332,9579.10547034542;9585.05271814085,-19169.3228853619,9568.86487437644;9574.79802466277,-19148.8152160599,9558.62843280421;9564.54749496022,-19128.3158705780,9548.39614440966;9554.30112780359,-19107.8248464635,9538.16800797206;9544.05892196183,-19087.3421412609,9527.94402226925;9533.82087620233,-19066.8677525116,9517.72418607749;9523.58698929105,-19046.4016777542,9507.50849817162;9513.35725999242,-19025.9439145239,9497.29695732490;9503.13168706918,-19005.4944603531,9487.08956230898;9492.91026928279,-18985.0533127710,9476.88631189412;9482.69300539303,-18964.6204693039,9466.68720484896;9472.47989415842,-18944.1959274753,9456.49223994088;9462.27093433587,-18923.7796848056,9446.30141593559;9452.06612468064,-18903.3717388118,9436.11473159719;9441.86546394682,-18882.9720870087,9425.93218568860;9431.66895088680,-18862.5807269076,9415.75377697099;9421.47658425157,-18842.1976560169,9405.57950420419;9411.28836279081,-18821.8228718425,9395.40936614666;9401.10428525246,-18801.4563718868,9385.24336155513;9390.92435038311,-18781.0981536494,9375.08148918499;9380.74855692816,-18760.7482146277,9364.92374779041;9370.57690363113,-18740.4065523151,9354.77013612370;9360.40938923437,-18720.0731642027,9344.62065293596;9350.24601247876,-18699.7480477789,9334.47529697685;9340.08677210377,-18679.4312005290,9324.33406699457;9329.93166684737,-18659.1226199354,9314.19696173586;9319.78069544618,-18638.8223034776,9304.06397994606;9309.63385663532,-18618.5302486325,9293.93512036906;9299.49114914861,-18598.2464528740,9283.81038174738;9289.35257171838,-18577.9709136733,9273.68976282206;9279.21812307557,-18557.7036284985,9263.57326233281;9269.08780194976,-18537.4445948152,9253.46087901788;9258.96160706911,-18517.1938100862,9243.35261161415;9248.83953716040,-18496.9512717713,9233.24845885707;9238.72159094905,-18476.7169773278,9223.14841948078;9228.60776715903,-18456.4909242099,9213.05249221793;9218.49806451303,-18436.2731098694,9202.96067579987;9208.39248173230,-18416.0635317551,9192.87296895655;9198.29101753677,-18395.8621873132,9182.78937041654;9188.19367064498,-18375.6690739871,9172.70987890706;9178.10043977413,-18355.4841892175,9162.63449315394;9168.01132364010,-18335.3075304425,9152.56321188172;9157.92632095733,-18315.1390950972,9142.49603381347;9147.84543043903,-18294.9788806144,9132.43295767105;9137.76865079701,-18274.8268844240,9122.37398217488;9127.69598074176,-18254.6831039532,9112.31910604408;9117.62741898245,-18234.5475366265,9102.26832799642;9107.56296422693,-18214.4201798660,9092.22164674837;9097.50261518169,-18194.3010310910,9082.17906101503;9087.44637055199,-18174.1900877180,9072.14056951023;9077.39422904170,-18154.0873471612,9062.10617094645;9067.34618935343,-18133.9928068319,9052.07586403485;9057.30225018845,-18113.9064641389,9042.04964748532;9047.26241024679,-18093.8283164886,9032.02752000642;9037.22666822716,-18073.7583612844,9022.00948030543;9027.19502282696,-18053.6965959273,9011.99552708833;9017.16747274236,-18033.6430178160,9001.98565905980;9007.14401666819,-18013.5976243463,8991.97987492325;9005.29710319599,-18009.9056983865,8990.13791761094;9003.45027175735,-18006.2139325913,8988.29603813169;9001.60352370060,-18002.5223296639,8986.45423783843;8999.75686037060,-17998.8308923004,8984.61251808063;8997.91028310870,-17995.1396231902,8982.77088020425;8996.06379325284,-17991.4485250154,8980.92932555183;8994.21739213748,-17987.7576004516,8979.08785546242;8992.37108109364,-17984.0668521672,8977.24647127165;8990.52486144890,-17980.3762828238,8975.40517431169;8988.67873452738,-17976.6858950761,8973.56396591125;8986.83270164982,-17972.9956915720,8971.72284739564;8984.98676413352,-17969.3056749526,8969.88182008676;8983.14092329233,-17965.6158478520,8968.04088530304;8981.29518043675,-17961.9262128975,8966.20004435955;8979.44953687383,-17958.2367727097,8964.35929856791;8977.60399390727,-17954.5475299024,8962.51864923640;8975.75855283736,-17950.8584870826,8960.67809766986;8973.91321496099,-17947.1696468503,8958.83764516976;8972.06798157170,-17943.4810117991,8956.99729303419;8970.22285395966,-17939.7925845156,8955.15704255788;8968.37783341167,-17936.1043675798,8953.31689503219;8966.53292121118,-17932.4163635649,8951.47685174509;8964.68811863828,-17928.7285750375,8949.63691398126;8962.84342696975,-17925.0410045575,8947.79708302200;8960.99884747897,-17921.3536546778,8945.95736014523;8959.15438143608,-17917.6665279452,8944.11774662561;8957.31003010782,-17913.9796268993,8942.27824373445;8955.46579475764,-17910.2929540735,8940.43885273970;8953.62167664568,-17906.6065119941,8938.59957490605;8951.77767702880,-17902.9203031814,8936.76041149486;8949.93379716053,-17899.2343301484,8934.92136376418;8948.09003829111,-17895.5485954021,8933.08243296879;8946.24640166752,-17891.8631014426,8931.24362036016;8944.40288853344,-17888.1778507636,8929.40492718649;8942.55950012929,-17884.4928458520,8927.56635469270;8940.71623769222,-17880.8080891885,8925.72790412046;8938.87310245613,-17877.1235832470,8923.88957670814;8937.03009565164,-17873.4393304950,8922.05137369087;8935.18721850616,-17869.7553333935,8920.21329630057;8933.34447224383,-17866.0715943970,8918.37534576584;8931.50185808559,-17862.3881159535,8916.53752331212;8929.65937724911,-17858.7049005046,8914.69983016156;8927.81703094888,-17855.0219504855,8912.86226753313;8925.97482039615,-17851.3392683247,8911.02483664255;8924.13274679896,-17847.6568564445,8909.18753870234;8922.29081136217,-17843.9747172608,8907.35037492182;8920.44901528743,-17840.2928531830,8905.51334650712;8918.60735977318,-17836.6112666142,8903.67645466112;8916.76584601473,-17832.9299599510,8901.83970058361;8914.92447520415,-17829.2489355837,8900.00308547110;8913.08324853039,-17825.5681958963,8898.16661051699;8911.24216717921,-17821.8877432664,8896.33027691149;8909.40123233321,-17818.2075800654,8894.49408584165;8907.56044517186,-17814.5277086582,8892.65803849138;8905.71980687144,-17810.8481314034,8890.82213604139;8903.87931860515,-17807.1688506536,8888.98637966933;8902.03898154300,-17803.4898687548,8887.15077054962;8900.19879685192,-17799.8111880468,8885.31530985362;8898.35876569567,-17796.1328108634,8883.47999874954;8896.51888923494,-17792.4547395318,8881.64483840244;8894.67916862729,-17788.7769763732,8879.80982997434;8892.83960502716,-17785.0995237025,8877.97497462408;8891.00019958592,-17781.4223838285,8876.14027350744;8889.16095345186,-17777.7455590537,8874.30572777710;8887.32186777014,-17774.0690516744,8872.47133858264;8885.48294368288,-17770.3928639809,8870.63710707057;8883.64418232911,-17766.7169982572,8868.80303438433;8881.80558484480,-17763.0414567812,8866.96912166426;8879.96715236286,-17759.3662418246,8865.13537004767;8878.12888601313,-17755.6913556531,8863.30178066879;8876.29078692243,-17752.0168005263,8861.46835465881;8874.45285621451,-17748.3425786976,8859.63509314586;8872.61509501011,-17744.6686924145,8857.80199725506;8870.77750442692,-17740.9951439181,8855.96906810847;8868.94008557961,-17737.3219354438,8854.13630682511;8867.10283957983,-17733.6490692208,8852.30371452102;8865.26576753622,-17729.9765474721,8850.47129230918;8863.42887055444,-17726.3043724151,8848.63904129960;8861.59214973710,-17722.6325462609,8846.80696259926;8859.75560618382,-17718.9610712144,8844.97505731213;8857.91924099129,-17715.2899494751,8843.14332653924;8856.08305525317,-17711.6191832360,8841.31177137859;8854.24705006013,-17707.9487746843,8839.48039292519;8852.41122649992,-17704.2787260013,8837.64919227112;8850.57558565728,-17700.6090393625,8835.81817050546;8848.74012861400,-17696.9397169371,8833.98732871432;8846.90485644896,-17693.2707608888,8832.15666798090;8845.06977023802,-17689.6021733750,8830.32618938539;8843.23487105415,-17685.9339565475,8828.49589400508;8841.40015996738,-17682.2661125522,8826.66578291430;8839.56563804478,-17678.5986435289,8824.83585718445;8837.73130635054,-17674.9315516119,8823.00611788400;8835.89716594590,-17671.2648389293,8821.17656607850;8834.06321788921,-17667.5985076036,8819.34720283061;8832.22946323587,-17663.9325597514,8817.51802920001;8830.39590303844,-17660.2669974836,8815.68904624357;8828.56253834655,-17656.6018229050,8813.86025501519;8826.72937020695,-17652.9370381150,8812.03165656591;8824.89639966349,-17649.2726452069,8810.20325194387;8823.06362775718,-17645.6086462686,8808.37504219434;8821.23105552612,-17641.9450433818,8806.54702835971;8819.39868400555,-17638.2818386227,8804.71921147948;8817.56651422789,-17634.6190340620,8802.89159259033;8815.73454722266,-17630.9566317642,8801.06417272606;8813.90278401655,-17627.2946337885,8799.23695291760;8812.07122563340,-17623.6330421882,8797.40993419305;8810.23987309422,-17619.9718590109,8795.58311757769;8808.40872741719,-17616.3110862987,8793.75650409391;8806.57778961765,-17612.6507260879,8791.93009476134;8804.74706070814,-17608.9907804092,8790.10389059672;8802.91654169837,-17605.3312512876,8788.27789261402;8801.08623359526,-17601.6721407426,8786.45210182438;8799.25613740289,-17598.0134507879,8784.62651923612;8797.42625412259,-17594.3551834319,8782.80114585481;8795.59658475286,-17590.6973406770,8780.97598268313;8793.76713028944,-17587.0399245204,8779.15103072106;8791.93789172526,-17583.3829369535,8777.32629096576;8790.10887005052,-17579.7263799623,8775.50176441162;8788.28006625260,-17576.0702555270,8773.67745205024;8786.45148131615,-17572.4145656226,8771.85335487046;8784.62311622305,-17568.7593122183,8770.02947385837;8782.79497195244,-17565.1044972780,8768.20580999731;8780.96704948068,-17561.4501227598,8766.38236426783;8779.13934978143,-17557.7961906167,8764.55913764776;8777.31187382558,-17554.1427027959,8762.73613111221;8775.48462258133,-17550.4896612394,8760.91334563352;8773.65759701409,-17546.8370678834,8759.09078218132;8771.83079808663,-17543.1849246589,8757.26844172252;8770.00422675894,-17539.5332334916,8755.44632522131;8768.17788398834,-17535.8819963013,8753.62443363915;8766.35177072943,-17532.2312150029,8751.80276793481;8764.52588793413,-17528.5808915056,8749.98132906438;8762.70023655164,-17524.9310277133,8748.16011798119;8760.87481752850,-17521.2816255244,8746.33913563597;8759.04963180854,-17517.6326868322,8744.51838297667;8757.22468033296,-17513.9842135244,8742.69786094865;8755.39996404026,-17510.3362074833,8740.87757049453;8753.57548386625,-17506.6886705862,8739.05751255428;8751.75124074415,-17503.0416047047,8737.23768806523;8749.92723560446,-17499.3950117054,8735.41809796203;8747.19167614096,-17493.9260129301,8732.68915431871;];
%   Derivative.theta       = [0,0.100000000000000,0.200000000000000,0.300000000000000,0.400000000000000,0.500000000000000,0.600000000000000,0.700000000000000,0.800000000000000,0.900000000000000,1,1.10000000000000,1.20000000000000,1.30000000000000,1.40000000000000,1.50000000000000,1.60000000000000,1.70000000000000,1.80000000000000,1.90000000000000,2,2.10000000000000,2.20000000000000,2.30000000000000,2.40000000000000,2.50000000000000,2.60000000000000,2.70000000000000,2.80000000000000,2.90000000000000,3,3.10000000000000,3.20000000000000,3.30000000000000,3.40000000000000,3.50000000000000,3.60000000000000,3.70000000000000,3.80000000000000,3.90000000000000,4,4.10000000000000,4.20000000000000,4.30000000000000,4.40000000000000,4.50000000000000,4.60000000000000,4.70000000000000,4.80000000000000,4.90000000000000,5,5.10000000000000,5.20000000000000,5.30000000000000,5.40000000000000,5.50000000000000,5.60000000000000,5.70000000000000,5.80000000000000,5.90000000000000,6,6.10000000000000,6.20000000000000,6.30000000000000,6.40000000000000,6.50000000000000,6.60000000000000,6.70000000000000,6.80000000000000,6.90000000000000,7,7.10000000000000,7.20000000000000,7.30000000000000,7.40000000000000,7.50000000000000,7.60000000000000,7.70000000000000,7.80000000000000,7.90000000000000,8,8.10000000000000,8.20000000000000,8.30000000000000,8.40000000000000,8.50000000000000,8.60000000000000,8.70000000000000,8.80000000000000,8.90000000000000,9,9.10000000000000,9.20000000000000,9.30000000000000,9.40000000000000,9.50000000000000,9.60000000000000,9.70000000000000,9.80000000000000,9.90000000000000,10,10.1000000000000,10.2000000000000,10.3000000000000,10.4000000000000,10.5000000000000,10.6000000000000,10.7000000000000,10.8000000000000,10.9000000000000,11,11.1000000000000,11.2000000000000,11.3000000000000,11.4000000000000,11.5000000000000,11.6000000000000,11.7000000000000,11.8000000000000,11.9000000000000,12,12.1000000000000,12.2000000000000,12.3000000000000,12.4000000000000,12.5000000000000,12.6000000000000,12.7000000000000,12.8000000000000,12.9000000000000,13,13.1000000000000,13.2000000000000,13.3000000000000,13.4000000000000,13.5000000000000,13.6000000000000,13.7000000000000,13.8000000000000,13.9000000000000,14,14.1000000000000,14.2000000000000,14.3000000000000,14.4000000000000,14.5000000000000,14.6000000000000,14.7000000000000,14.8000000000000,14.9000000000000,15,15.1000000000000,15.2000000000000,15.3000000000000,15.4000000000000,15.5000000000000,15.6000000000000,15.7000000000000,15.8000000000000,15.9000000000000,16,16.1000000000000,16.2000000000000,16.3000000000000,16.4000000000000,16.5000000000000,16.6000000000000,16.7000000000000,16.8000000000000,16.9000000000000,17,17.1000000000000,17.2000000000000,17.3000000000000,17.4000000000000,17.5000000000000,17.6000000000000,17.7000000000000,17.8000000000000,17.9000000000000,18,18.1000000000000,18.2000000000000,18.3000000000000,18.4000000000000,18.5000000000000,18.6000000000000,18.7000000000000,18.8000000000000,18.9000000000000,19,19.1000000000000,19.2000000000000,19.3000000000000,19.4000000000000,19.5000000000000,19.6000000000000,19.7000000000000,19.8000000000000,19.9000000000000,20,20.1000000000000,20.2000000000000,20.3000000000000,20.4000000000000,20.5000000000000,20.6000000000000,20.7000000000000,20.8000000000000,20.9000000000000,21,21.1000000000000,21.2000000000000,21.3000000000000,21.4000000000000,21.5000000000000,21.6000000000000,21.7000000000000,21.8000000000000,21.9000000000000,22,22.1000000000000,22.2000000000000,22.3000000000000,22.4000000000000,22.5000000000000,22.6000000000000,22.7000000000000,22.8000000000000,22.9000000000000,23,23.1000000000000,23.2000000000000,23.3000000000000,23.4000000000000,23.5000000000000,23.6000000000000,23.7000000000000,23.8000000000000,23.9000000000000,24,24.1000000000000,24.2000000000000,24.3000000000000,24.4000000000000,24.5000000000000,24.6000000000000,24.7000000000000,24.8000000000000,24.9000000000000,25,25.1000000000000,25.2000000000000,25.3000000000000,25.4000000000000,25.5000000000000,25.6000000000000,25.7000000000000,25.8000000000000,25.9000000000000,26,26.1000000000000,26.2000000000000,26.3000000000000,26.4000000000000,26.5000000000000,26.6000000000000,26.7000000000000,26.8000000000000,26.9000000000000,27,27.1000000000000,27.2000000000000,27.3000000000000,27.4000000000000,27.5000000000000,27.6000000000000,27.7000000000000,27.8000000000000,27.9000000000000,28,28.1000000000000,28.2000000000000,28.3000000000000,28.4000000000000,28.5000000000000,28.6000000000000,28.7000000000000,28.8000000000000,28.9000000000000,29,29.1000000000000,29.2000000000000,29.3000000000000,29.4000000000000,29.5000000000000,29.6000000000000,29.7000000000000,29.8000000000000,29.9000000000000,30,30.1000000000000,30.2000000000000,30.3000000000000,30.4000000000000,30.5000000000000,30.6000000000000,30.7000000000000,30.8000000000000,30.9000000000000,31,31.1000000000000,31.2000000000000,31.3000000000000,31.4000000000000,31.5000000000000,31.6000000000000,31.7000000000000,31.8000000000000,31.9000000000000,32,32.1000000000000,32.2000000000000,32.3000000000000,32.4000000000000,32.5000000000000,32.6000000000000,32.7000000000000,32.8000000000000,32.9000000000000,33,33.1000000000000,33.2000000000000,33.3000000000000,33.4000000000000,33.5000000000000,33.6000000000000,33.7000000000000,33.8000000000000,33.9000000000000,34,34.1000000000000,34.2000000000000,34.3000000000000,34.4000000000000,34.5000000000000,34.6000000000000,34.7000000000000,34.8000000000000,34.9000000000000,35,35.1000000000000,35.2000000000000,35.3000000000000,35.4000000000000,35.5000000000000,35.6000000000000,35.7000000000000,35.8000000000000,35.9000000000000,36,36.1000000000000,36.2000000000000,36.3000000000000,36.4000000000000,36.5000000000000,36.6000000000000,36.7000000000000,36.8000000000000,36.9000000000000,37,37.1000000000000,37.2000000000000,37.3000000000000,37.4000000000000,37.5000000000000,37.6000000000000,37.7000000000000,37.8000000000000,37.9000000000000,38,38.1000000000000,38.2000000000000,38.3000000000000,38.4000000000000,38.5000000000000,38.6000000000000,38.7000000000000,38.8000000000000,38.9000000000000,39,39.1000000000000,39.2000000000000,39.3000000000000,39.4000000000000,39.5000000000000,39.6000000000000,39.7000000000000,39.8000000000000,39.9000000000000,40,40.1000000000000,40.2000000000000,40.3000000000000,40.4000000000000,40.5000000000000,40.6000000000000,40.7000000000000,40.8000000000000,40.9000000000000,41,41.1000000000000,41.2000000000000,41.3000000000000,41.4000000000000,41.5000000000000,41.6000000000000,41.7000000000000,41.8000000000000,41.9000000000000,42,42.1000000000000,42.2000000000000,42.3000000000000,42.4000000000000,42.5000000000000,42.6000000000000,42.7000000000000,42.8000000000000,42.9000000000000,43,43.1000000000000,43.2000000000000,43.3000000000000,43.4000000000000,43.5000000000000,43.6000000000000,43.7000000000000,43.8000000000000,43.9000000000000,44,44.1000000000000,44.2000000000000,44.3000000000000,44.4000000000000,44.5000000000000,44.6000000000000,44.7000000000000,44.8000000000000,44.9000000000000,45,45.1000000000000,45.2000000000000,45.3000000000000,45.4000000000000,45.5000000000000,45.6000000000000,45.7000000000000,45.8000000000000,45.9000000000000,46,46.1000000000000,46.2000000000000,46.3000000000000,46.4000000000000,46.5000000000000,46.6000000000000,46.7000000000000,46.8000000000000,46.9000000000000,47,47.1000000000000,47.2000000000000,47.3000000000000,47.4000000000000,47.5000000000000,47.6000000000000,47.7000000000000,47.8000000000000,47.9000000000000,48,48.1000000000000,48.2000000000000,48.3000000000000,48.4000000000000,48.5000000000000,48.6000000000000,48.7000000000000,48.8000000000000,48.9000000000000,49,49.1000000000000,49.2000000000000,49.3000000000000,49.4000000000000,49.5000000000000,49.6000000000000,49.7000000000000,49.8000000000000,49.9000000000000,50,50.1000000000000,50.2000000000000,50.3000000000000,50.4000000000000,50.5000000000000,50.6000000000000,50.7000000000000,50.8000000000000,50.9000000000000,51,51.1000000000000,51.2000000000000,51.3000000000000,51.4000000000000,51.5000000000000,51.6000000000000,51.7000000000000,51.8000000000000,51.9000000000000,52,52.1000000000000,52.2000000000000,52.3000000000000,52.4000000000000,52.5000000000000,52.6000000000000,52.7000000000000,52.8000000000000,52.9000000000000,53,53.1000000000000,53.2000000000000,53.3000000000000,53.4000000000000,53.5000000000000,53.6000000000000,53.7000000000000,53.8000000000000,53.9000000000000,54,54.1000000000000,54.2000000000000,54.3000000000000,54.4000000000000,54.5000000000000,54.6000000000000,54.7000000000000,54.8000000000000,54.9000000000000,55,55.1000000000000,55.2000000000000,55.3000000000000,55.4000000000000,55.5000000000000,55.6000000000000,55.7000000000000,55.8000000000000,55.9000000000000,56,56.1000000000000,56.2000000000000,56.3000000000000,56.4000000000000,56.5000000000000,56.6000000000000,56.7000000000000,56.8000000000000,56.9000000000000,57,57.1000000000000,57.2000000000000,57.3000000000000,57.4000000000000,57.5000000000000,57.6000000000000,57.7000000000000,57.8000000000000,57.9000000000000,58,58.1000000000000,58.2000000000000,58.3000000000000,58.4000000000000,58.5000000000000,58.6000000000000,58.7000000000000,58.8000000000000,58.9000000000000,59,59.1000000000000,59.2000000000000,59.3000000000000,59.4000000000000,59.5000000000000,59.6000000000000,59.7000000000000,59.8000000000000,59.9000000000000,60,60.1000000000000,60.2000000000000,60.3000000000000,60.4000000000000,60.5000000000000,60.6000000000000,60.7000000000000,60.8000000000000,60.9000000000000,61,61.1000000000000,61.2000000000000,61.3000000000000,61.4000000000000,61.5000000000000,61.6000000000000,61.7000000000000,61.8000000000000,61.9000000000000,62,62.1000000000000,62.2000000000000,62.3000000000000,62.4000000000000,62.5000000000000,62.6000000000000,62.7000000000000,62.8000000000000,62.9000000000000,63,63.1000000000000,63.2000000000000,63.3000000000000,63.4000000000000,63.5000000000000,63.6000000000000,63.7000000000000,63.8000000000000,63.9000000000000,64,64.1000000000000,64.2000000000000,64.3000000000000,64.4000000000000,64.5000000000000,64.6000000000000,64.7000000000000,64.8000000000000,64.9000000000000,65,65.1000000000000,65.2000000000000,65.3000000000000,65.4000000000000,65.5000000000000,65.6000000000000,65.7000000000000,65.8000000000000,65.9000000000000,66,66.1000000000000,66.2000000000000,66.3000000000000,66.4000000000000,66.5000000000000,66.6000000000000,66.7000000000000,66.8000000000000,66.9000000000000,67,67.1000000000000,67.2000000000000,67.3000000000000,67.4000000000000,67.5000000000000,67.6000000000000,67.7000000000000,67.8000000000000,67.9000000000000,68,68.1000000000000,68.2000000000000,68.3000000000000,68.4000000000000,68.5000000000000,68.6000000000000,68.7000000000000,68.8000000000000,68.9000000000000,69,69.1000000000000,69.2000000000000,69.3000000000000,69.4000000000000,69.5000000000000,69.6000000000000,69.7000000000000,69.8000000000000,69.9000000000000,70,70.1000000000000,70.2000000000000,70.3000000000000,70.4000000000000,70.5000000000000,70.6000000000000,70.7000000000000,70.8000000000000,70.9000000000000,71,71.1000000000000,71.2000000000000,71.3000000000000,71.4000000000000,71.5000000000000,71.6000000000000,71.7000000000000,71.8000000000000,71.9000000000000,72,72.1000000000000,72.2000000000000,72.3000000000000,72.4000000000000,72.5000000000000,72.6000000000000,72.7000000000000,72.8000000000000,72.9000000000000,73,73.1000000000000,73.2000000000000,73.3000000000000,73.4000000000000,73.5000000000000,73.6000000000000,73.7000000000000,73.8000000000000,73.9000000000000,74,74.1000000000000,74.2000000000000,74.3000000000000,74.4000000000000,74.5000000000000,74.6000000000000,74.7000000000000,74.8000000000000,74.9000000000000,75,75.1000000000000,75.2000000000000,75.3000000000000,75.4000000000000,75.5000000000000,75.6000000000000,75.7000000000000,75.8000000000000,75.9000000000000,76,76.1000000000000,76.2000000000000,76.3000000000000,76.4000000000000,76.5000000000000,76.6000000000000,76.7000000000000,76.8000000000000,76.9000000000000,77,77.1000000000000,77.2000000000000,77.3000000000000,77.4000000000000,77.5000000000000,77.6000000000000,77.7000000000000,77.8000000000000,77.9000000000000,78,78.1000000000000,78.2000000000000,78.3000000000000,78.4000000000000,78.5000000000000,78.6000000000000,78.7000000000000,78.8000000000000,78.9000000000000,79,79.1000000000000,79.2000000000000,79.3000000000000,79.4000000000000,79.5000000000000,79.6000000000000,79.7000000000000,79.8000000000000,79.9000000000000,80,80.1000000000000,80.2000000000000,80.3000000000000,80.4000000000000,80.5000000000000,80.6000000000000,80.7000000000000,80.8000000000000,80.9000000000000,81,81.1000000000000,81.2000000000000,81.3000000000000,81.4000000000000,81.5000000000000,81.6000000000000,81.7000000000000,81.8000000000000,81.9000000000000,82,82.1000000000000,82.2000000000000,82.3000000000000,82.4000000000000,82.5000000000000,82.6000000000000,82.7000000000000,82.8000000000000,82.9000000000000,83,83.1000000000000,83.2000000000000,83.3000000000000,83.4000000000000,83.5000000000000,83.6000000000000,83.7000000000000,83.8000000000000,83.9000000000000,84,84.1000000000000,84.2000000000000,84.3000000000000,84.4000000000000,84.5000000000000,84.6000000000000,84.7000000000000,84.8000000000000,84.9000000000000,85,85.1000000000000,85.2000000000000,85.3000000000000,85.4000000000000,85.5000000000000,85.6000000000000,85.7000000000000,85.8000000000000,85.9000000000000,86,86.1000000000000,86.2000000000000,86.3000000000000,86.4000000000000,86.5000000000000,86.6000000000000,86.7000000000000,86.8000000000000,86.9000000000000,87,87.1000000000000,87.2000000000000,87.3000000000000,87.4000000000000,87.5000000000000,87.6000000000000,87.7000000000000,87.8000000000000,87.9000000000000,88,88.1000000000000,88.2000000000000,88.3000000000000,88.4000000000000,88.5000000000000,88.6000000000000,88.7000000000000,88.8000000000000,88.9000000000000,89,89.1000000000000,89.2000000000000,89.3000000000000,89.4000000000000,89.5000000000000,89.6000000000000,89.7000000000000,89.8000000000000,89.9000000000000,90,90.1000000000000,90.2000000000000,90.3000000000000,90.4000000000000,90.5000000000000,90.6000000000000,90.7000000000000,90.8000000000000,90.9000000000000,91,91.1000000000000,91.2000000000000,91.3000000000000,91.4000000000000,91.5000000000000,91.6000000000000,91.7000000000000,91.8000000000000,91.9000000000000,92,92.1000000000000,92.2000000000000,92.3000000000000,92.4000000000000,92.5000000000000,92.6000000000000,92.7000000000000,92.8000000000000,92.9000000000000,93,93.1000000000000,93.2000000000000,93.3000000000000,93.4000000000000,93.5000000000000,93.6000000000000,93.7000000000000,93.8000000000000,93.9000000000000,94,94.1000000000000,94.2000000000000,94.3000000000000,94.4000000000000,94.5000000000000,94.6000000000000,94.7000000000000,94.8000000000000,94.9000000000000,95,95.1000000000000,95.2000000000000,95.3000000000000,95.4000000000000,95.5000000000000,95.6000000000000,95.7000000000000,95.8000000000000,95.9000000000000,96,96.1000000000000,96.2000000000000,96.3000000000000,96.4000000000000,96.5000000000000,96.6000000000000,96.7000000000000,96.8000000000000,96.9000000000000,97,97.1000000000000,97.2000000000000,97.3000000000000,97.4000000000000,97.5000000000000,97.6000000000000,97.7000000000000,97.8000000000000,97.9000000000000,98,98.1000000000000,98.2000000000000,98.3000000000000,98.4000000000000,98.5000000000000,98.6000000000000,98.7000000000000,98.8000000000000,98.9000000000000,99,99.1000000000000,99.2000000000000,99.3000000000000,99.4000000000000,99.5000000000000,99.6000000000000,99.7000000000000,99.8000000000000,99.9000000000000,100,100.100000000000,100.200000000000,100.300000000000,100.400000000000,100.500000000000,100.600000000000,100.700000000000,100.800000000000,100.900000000000,101,101.100000000000,101.200000000000,101.300000000000,101.400000000000,101.500000000000,101.600000000000,101.700000000000,101.800000000000,101.900000000000,102,102.100000000000,102.200000000000,102.300000000000,102.400000000000,102.500000000000,102.600000000000,102.700000000000,102.800000000000,102.900000000000,103,103.100000000000,103.200000000000,103.300000000000,103.400000000000,103.500000000000,103.600000000000,103.700000000000,103.800000000000,103.900000000000,104,104.100000000000,104.200000000000,104.300000000000,104.400000000000,104.500000000000,104.600000000000,104.700000000000,104.800000000000,104.900000000000,105,105.100000000000,105.200000000000,105.300000000000,105.400000000000,105.500000000000,105.600000000000,105.700000000000,105.800000000000,105.900000000000,106,106.100000000000,106.200000000000,106.300000000000,106.400000000000,106.500000000000,106.600000000000,106.700000000000,106.800000000000,106.900000000000,107,107.100000000000,107.200000000000,107.300000000000,107.400000000000,107.500000000000,107.600000000000,107.700000000000,107.800000000000,107.900000000000,108,108.100000000000,108.200000000000,108.300000000000,108.400000000000,108.500000000000,108.600000000000,108.700000000000,108.800000000000,108.900000000000,109,109.100000000000,109.200000000000,109.300000000000,109.400000000000,109.500000000000,109.600000000000,109.700000000000,109.800000000000,109.900000000000,110,110.100000000000,110.200000000000,110.300000000000,110.400000000000,110.500000000000,110.600000000000,110.700000000000,110.800000000000,110.900000000000,111,111.100000000000,111.200000000000,111.300000000000,111.400000000000,111.500000000000,111.600000000000,111.700000000000,111.800000000000,111.900000000000,112,112.100000000000,112.200000000000,112.300000000000,112.400000000000,112.500000000000,112.600000000000,112.700000000000,112.800000000000,112.900000000000,113,113.100000000000,113.200000000000,113.300000000000,113.400000000000,113.500000000000,113.600000000000,113.700000000000,113.800000000000,113.900000000000,114,114.100000000000,114.200000000000,114.300000000000,114.400000000000,114.500000000000,114.600000000000,114.700000000000,114.800000000000,114.900000000000,115,115.100000000000,115.200000000000,115.300000000000,115.400000000000,115.500000000000,115.600000000000,115.700000000000,115.800000000000,115.900000000000,116,116.100000000000,116.200000000000,116.300000000000,116.400000000000,116.500000000000,116.600000000000,116.700000000000,116.800000000000,116.900000000000,117,117.100000000000,117.200000000000,117.300000000000,117.400000000000,117.500000000000,117.600000000000,117.700000000000,117.800000000000,117.900000000000,118,118.100000000000,118.200000000000,118.300000000000,118.400000000000,118.500000000000,118.600000000000,118.700000000000,118.800000000000,118.900000000000,119,119.100000000000,119.200000000000,119.300000000000,119.400000000000,119.500000000000,119.600000000000,119.700000000000,119.800000000000,119.900000000000,120,120.100000000000,120.200000000000,120.300000000000,120.400000000000,120.500000000000,120.600000000000,120.700000000000,120.800000000000,120.900000000000,121,121.100000000000,121.200000000000,121.300000000000,121.400000000000,121.500000000000,121.600000000000,121.700000000000,121.800000000000,121.900000000000,122,122.100000000000,122.200000000000,122.300000000000,122.400000000000,122.500000000000,122.600000000000,122.700000000000,122.800000000000,122.900000000000,123,123.100000000000,123.200000000000,123.300000000000,123.400000000000,123.500000000000,123.600000000000,123.700000000000,123.800000000000,123.900000000000,124,124.100000000000,124.200000000000,124.300000000000,124.400000000000,124.500000000000,124.600000000000,124.700000000000,124.800000000000,124.900000000000,125,125.100000000000,125.200000000000,125.300000000000,125.400000000000,125.500000000000,125.600000000000,125.700000000000,125.800000000000,125.900000000000,126,126.100000000000,126.200000000000,126.300000000000,126.400000000000,126.500000000000,126.600000000000,126.700000000000,126.800000000000,126.900000000000,127,127.100000000000,127.200000000000,127.300000000000,127.400000000000,127.500000000000,127.600000000000,127.700000000000,127.800000000000,127.900000000000,128,128.100000000000,128.200000000000,128.300000000000,128.400000000000,128.500000000000,128.600000000000,128.700000000000,128.800000000000,128.900000000000,129,129.100000000000,129.200000000000,129.300000000000,129.400000000000,129.500000000000,129.600000000000,129.700000000000,129.800000000000,129.900000000000,130,130.100000000000,130.200000000000,130.300000000000,130.400000000000,130.500000000000,130.600000000000,130.700000000000,130.800000000000,130.900000000000,131,131.100000000000,131.200000000000,131.300000000000,131.400000000000,131.500000000000,131.600000000000,131.700000000000,131.800000000000,131.900000000000,132,132.100000000000,132.200000000000,132.300000000000,132.400000000000,132.500000000000,132.600000000000,132.700000000000,132.800000000000,132.900000000000,133,133.100000000000,133.200000000000,133.300000000000,133.400000000000,133.500000000000,133.600000000000,133.700000000000,133.800000000000,133.900000000000,134,134.100000000000,134.200000000000,134.300000000000,134.400000000000,134.500000000000,134.600000000000,134.700000000000,134.800000000000,134.900000000000,135,135.100000000000,135.200000000000,135.300000000000,135.400000000000,135.500000000000,135.600000000000,135.700000000000,135.800000000000,135.900000000000,136,136.100000000000,136.200000000000,136.300000000000,136.400000000000,136.500000000000,136.600000000000,136.700000000000,136.800000000000,136.900000000000,137,137.100000000000,137.200000000000,137.300000000000,137.400000000000,137.500000000000,137.600000000000,137.700000000000,137.800000000000,137.900000000000,138,138.100000000000,138.200000000000,138.300000000000,138.400000000000,138.500000000000,138.600000000000,138.700000000000,138.800000000000,138.900000000000,139,139.100000000000,139.200000000000,139.300000000000,139.400000000000,139.500000000000,139.600000000000,139.700000000000,139.800000000000,139.900000000000,140,140.100000000000,140.200000000000,140.300000000000,140.400000000000,140.500000000000,140.600000000000,140.700000000000,140.800000000000,140.900000000000,141,141.100000000000,141.200000000000,141.300000000000,141.400000000000,141.500000000000,141.600000000000,141.700000000000,141.800000000000,141.900000000000,142,142.100000000000,142.200000000000,142.300000000000,142.400000000000,142.500000000000,142.600000000000,142.700000000000,142.800000000000,142.900000000000,143,143.100000000000,143.200000000000,143.300000000000,143.400000000000,143.500000000000,143.600000000000,143.700000000000,143.800000000000,143.900000000000,144,144.100000000000,144.200000000000,144.300000000000,144.400000000000,144.500000000000,144.600000000000,144.700000000000,144.800000000000,144.900000000000,145,145.100000000000,145.200000000000,145.300000000000,145.400000000000,145.500000000000,145.600000000000,145.700000000000,145.800000000000,145.900000000000,146,146.100000000000,146.200000000000,146.300000000000,146.400000000000,146.500000000000,146.600000000000,146.700000000000,146.800000000000,146.900000000000,147,147.100000000000,147.200000000000,147.300000000000,147.400000000000,147.500000000000,147.600000000000,147.700000000000,147.800000000000,147.900000000000,148,148.100000000000,148.200000000000,148.300000000000,148.400000000000,148.500000000000,148.600000000000,148.700000000000,148.800000000000,148.900000000000,149,149.100000000000,149.200000000000,149.300000000000,149.400000000000,149.500000000000,149.600000000000,149.700000000000,149.800000000000,149.900000000000,150,150.100000000000,150.200000000000,150.300000000000,150.400000000000,150.500000000000,150.600000000000,150.700000000000,150.800000000000,150.900000000000,151,151.100000000000,151.200000000000,151.300000000000,151.400000000000,151.500000000000,151.600000000000,151.700000000000,151.800000000000,151.900000000000,152,152.100000000000,152.200000000000,152.300000000000,152.400000000000,152.500000000000,152.600000000000,152.700000000000,152.800000000000,152.900000000000,153,153.100000000000,153.200000000000,153.300000000000,153.400000000000,153.500000000000,153.600000000000,153.700000000000,153.800000000000,153.900000000000,154,154.100000000000,154.200000000000,154.300000000000,154.400000000000,154.500000000000,154.600000000000,154.700000000000,154.800000000000,154.900000000000,155,155.100000000000,155.200000000000,155.300000000000,155.400000000000,155.500000000000,155.600000000000,155.700000000000,155.800000000000,155.900000000000,156,156.100000000000,156.200000000000,156.300000000000,156.400000000000,156.500000000000,156.600000000000,156.700000000000,156.800000000000,156.900000000000,157,157.100000000000,157.200000000000,157.300000000000,157.400000000000,157.500000000000,157.600000000000,157.700000000000,157.800000000000,157.900000000000,158,158.100000000000,158.200000000000,158.300000000000,158.400000000000,158.500000000000,158.600000000000,158.700000000000,158.800000000000,158.900000000000,159,159.100000000000,159.200000000000,159.300000000000,159.400000000000,159.500000000000,159.600000000000,159.700000000000,159.800000000000,159.900000000000,160,160.100000000000,160.200000000000,160.300000000000,160.400000000000,160.500000000000,160.600000000000,160.700000000000,160.800000000000,160.900000000000,161,161.100000000000,161.200000000000,161.300000000000,161.400000000000,161.500000000000,161.600000000000,161.700000000000,161.800000000000,161.900000000000,162,162.100000000000,162.200000000000,162.300000000000,162.400000000000,162.500000000000,162.600000000000,162.700000000000,162.800000000000,162.900000000000,163,163.100000000000,163.200000000000,163.300000000000,163.400000000000,163.500000000000,163.600000000000,163.700000000000,163.800000000000,163.900000000000,164,164.100000000000,164.200000000000,164.300000000000,164.400000000000,164.500000000000,164.600000000000,164.700000000000,164.800000000000,164.900000000000,165,165.100000000000,165.200000000000,165.300000000000,165.400000000000,165.500000000000,165.600000000000,165.700000000000,165.800000000000,165.900000000000,166,166.100000000000,166.200000000000,166.300000000000,166.400000000000,166.500000000000,166.600000000000,166.700000000000,166.800000000000,166.900000000000,167,167.100000000000,167.200000000000,167.300000000000,167.400000000000,167.500000000000,167.600000000000,167.700000000000,167.800000000000,167.900000000000,168,168.100000000000,168.200000000000,168.300000000000,168.400000000000,168.500000000000,168.600000000000,168.700000000000,168.800000000000,168.900000000000,169,169.100000000000,169.200000000000,169.300000000000,169.400000000000,169.500000000000,169.600000000000,169.700000000000,169.800000000000,169.900000000000,170,170.100000000000,170.200000000000,170.300000000000,170.400000000000,170.500000000000,170.600000000000,170.700000000000,170.800000000000,170.900000000000,171,171.100000000000,171.200000000000,171.300000000000,171.400000000000,171.500000000000,171.600000000000,171.700000000000,171.800000000000,171.900000000000,172,172.100000000000,172.200000000000,172.300000000000,172.400000000000,172.500000000000,172.600000000000,172.700000000000,172.800000000000,172.900000000000,173,173.100000000000,173.200000000000,173.300000000000,173.400000000000,173.500000000000,173.600000000000,173.700000000000,173.800000000000,173.900000000000,174,174.100000000000,174.200000000000,174.300000000000,174.400000000000,174.500000000000,174.600000000000,174.700000000000,174.800000000000,174.900000000000,175,175.100000000000,175.200000000000,175.300000000000,175.400000000000,175.500000000000,175.600000000000,175.700000000000,175.800000000000,175.900000000000,176,176.100000000000,176.200000000000,176.300000000000,176.400000000000,176.500000000000,176.600000000000,176.700000000000,176.800000000000,176.900000000000,177,177.100000000000,177.200000000000,177.300000000000,177.400000000000,177.500000000000,177.600000000000,177.700000000000,177.800000000000,177.900000000000,178,178.100000000000,178.200000000000,178.300000000000,178.400000000000,178.500000000000,178.600000000000,178.700000000000,178.800000000000,178.900000000000,179,179.100000000000,179.200000000000,179.300000000000,179.400000000000,179.500000000000,179.600000000000,179.700000000000,179.800000000000,179.900000000000,180,180.100000000000,180.200000000000,180.300000000000,180.400000000000,180.500000000000,180.600000000000,180.700000000000,180.800000000000,180.900000000000,181,181.100000000000,181.200000000000,181.300000000000,181.400000000000,181.500000000000,181.600000000000,181.700000000000,181.800000000000,181.900000000000,182,182.100000000000,182.200000000000,182.300000000000,182.400000000000,182.500000000000,182.600000000000,182.700000000000,182.800000000000,182.900000000000,183,183.100000000000,183.200000000000,183.300000000000,183.400000000000,183.500000000000,183.600000000000,183.700000000000,183.800000000000,183.900000000000,184,184.100000000000,184.200000000000,184.300000000000,184.400000000000,184.500000000000,184.600000000000,184.700000000000,184.800000000000,184.900000000000,185,185.100000000000,185.200000000000,185.300000000000,185.400000000000,185.500000000000,185.600000000000,185.700000000000,185.800000000000,185.900000000000,186,186.100000000000,186.200000000000,186.300000000000,186.400000000000,186.500000000000,186.600000000000,186.700000000000,186.800000000000,186.900000000000,187,187.100000000000,187.200000000000,187.300000000000,187.400000000000,187.500000000000,187.600000000000,187.700000000000,187.800000000000,187.900000000000,188,188.100000000000,188.200000000000,188.300000000000,188.400000000000,188.500000000000,188.600000000000,188.700000000000,188.800000000000,188.900000000000,189,189.100000000000,189.200000000000,189.300000000000,189.400000000000,189.500000000000,189.600000000000,189.700000000000,189.800000000000,189.900000000000,190,190.100000000000,190.200000000000,190.300000000000,190.400000000000,190.500000000000,190.600000000000,190.700000000000,190.800000000000,190.900000000000,191,191.100000000000,191.200000000000,191.300000000000,191.400000000000,191.500000000000,191.600000000000,191.700000000000,191.800000000000,191.900000000000,192,192.100000000000,192.200000000000,192.300000000000,192.400000000000,192.500000000000,192.600000000000,192.700000000000,192.800000000000,192.900000000000,193,193.100000000000,193.200000000000,193.300000000000,193.400000000000,193.500000000000,193.600000000000,193.700000000000,193.800000000000,193.900000000000,194,194.100000000000,194.200000000000,194.300000000000,194.400000000000,194.500000000000,194.600000000000,194.700000000000,194.800000000000,194.900000000000,195,195.100000000000,195.200000000000,195.300000000000,195.400000000000,195.500000000000,195.600000000000,195.700000000000,195.800000000000,195.900000000000,196,196.100000000000,196.200000000000,196.300000000000,196.400000000000,196.500000000000,196.600000000000,196.700000000000,196.800000000000,196.900000000000,197,197.100000000000,197.200000000000,197.300000000000,197.400000000000,197.500000000000,197.600000000000,197.700000000000,197.800000000000,197.900000000000,198,198.100000000000,198.200000000000,198.300000000000,198.400000000000,198.500000000000,198.600000000000,198.700000000000,198.800000000000,198.900000000000,199,199.100000000000,199.200000000000,199.300000000000,199.400000000000,199.500000000000,199.600000000000,199.700000000000,199.800000000000,199.900000000000,200,200.100000000000,200.200000000000,200.300000000000,200.400000000000,200.500000000000,200.600000000000,200.700000000000,200.800000000000,200.900000000000,201,201.100000000000,201.200000000000,201.300000000000,201.400000000000,201.500000000000,201.600000000000,201.700000000000,201.800000000000,201.900000000000,202,202.100000000000,202.200000000000,202.300000000000,202.400000000000,202.500000000000,202.600000000000,202.700000000000,202.800000000000,202.900000000000,203,203.100000000000,203.200000000000,203.300000000000,203.400000000000,203.500000000000,203.600000000000,203.700000000000,203.800000000000,203.900000000000,204,204.100000000000,204.200000000000,204.300000000000,204.400000000000,204.500000000000,204.600000000000,204.700000000000,204.800000000000,204.900000000000,205,205.100000000000,205.200000000000,205.300000000000,205.400000000000,205.500000000000,205.600000000000,205.700000000000,205.800000000000,205.900000000000,206,206.100000000000,206.200000000000,206.300000000000,206.400000000000,206.500000000000,206.600000000000,206.700000000000,206.800000000000,206.900000000000,207,207.100000000000,207.200000000000,207.300000000000,207.400000000000,207.500000000000,207.600000000000,207.700000000000,207.800000000000,207.900000000000,208,208.100000000000,208.200000000000,208.300000000000,208.400000000000,208.500000000000,208.600000000000,208.700000000000,208.800000000000,208.900000000000,209,209.100000000000,209.200000000000,209.300000000000,209.400000000000,209.500000000000,209.600000000000,209.700000000000,209.800000000000,209.900000000000,210,210.100000000000,210.200000000000,210.300000000000,210.400000000000,210.500000000000,210.600000000000,210.700000000000,210.800000000000,210.900000000000,211,211.100000000000,211.200000000000,211.300000000000,211.400000000000,211.500000000000,211.600000000000,211.700000000000,211.800000000000,211.900000000000,212,212.100000000000,212.200000000000,212.300000000000,212.400000000000,212.500000000000,212.600000000000,212.700000000000,212.800000000000,212.900000000000,213,213.100000000000,213.200000000000,213.300000000000,213.400000000000,213.500000000000,213.600000000000,213.700000000000,213.800000000000,213.900000000000,214,214.100000000000,214.200000000000,214.300000000000,214.400000000000,214.500000000000,214.600000000000,214.700000000000,214.800000000000,214.900000000000,215,215.100000000000,215.200000000000,215.300000000000,215.400000000000,215.500000000000,215.600000000000,215.700000000000,215.800000000000,215.900000000000,216,216.100000000000,216.200000000000,216.300000000000,216.400000000000,216.500000000000,216.600000000000,216.700000000000,216.800000000000,216.900000000000,217,217.100000000000,217.200000000000,217.300000000000,217.400000000000,217.500000000000,217.600000000000,217.700000000000,217.800000000000,217.900000000000,218,218.100000000000,218.200000000000,218.300000000000,218.400000000000,218.500000000000,218.600000000000,218.700000000000,218.800000000000,218.900000000000,219,219.100000000000,219.200000000000,219.300000000000,219.400000000000,219.500000000000,219.600000000000,219.700000000000,219.800000000000,219.900000000000,220,220.100000000000,220.200000000000,220.300000000000,220.400000000000,220.500000000000,220.600000000000,220.700000000000,220.800000000000,220.900000000000,221,221.100000000000,221.200000000000,221.300000000000,221.400000000000,221.500000000000,221.600000000000,221.700000000000,221.800000000000,221.900000000000,222,222.100000000000,222.200000000000,222.300000000000,222.400000000000,222.500000000000,222.600000000000,222.700000000000,222.800000000000,222.900000000000,223,223.100000000000,223.200000000000,223.300000000000,223.400000000000,223.500000000000,223.600000000000,223.700000000000,223.800000000000,223.900000000000,224,224.100000000000,224.200000000000,224.300000000000,224.400000000000,224.500000000000,224.600000000000,224.700000000000,224.800000000000,224.900000000000,225,225.100000000000,225.200000000000,225.300000000000,225.400000000000,225.500000000000,225.600000000000,225.700000000000,225.800000000000,225.900000000000,226,226.100000000000,226.200000000000,226.300000000000,226.400000000000,226.500000000000,226.600000000000,226.700000000000,226.800000000000,226.900000000000,227,227.100000000000,227.200000000000,227.300000000000,227.400000000000,227.500000000000,227.600000000000,227.700000000000,227.800000000000,227.900000000000,228,228.100000000000,228.200000000000,228.300000000000,228.400000000000,228.500000000000,228.600000000000,228.700000000000,228.800000000000,228.900000000000,229,229.100000000000,229.200000000000,229.300000000000,229.400000000000,229.500000000000,229.600000000000,229.700000000000,229.800000000000,229.900000000000,230,230.100000000000,230.200000000000,230.300000000000,230.400000000000,230.500000000000,230.600000000000,230.700000000000,230.800000000000,230.900000000000,231,231.100000000000,231.200000000000,231.300000000000,231.400000000000,231.500000000000,231.600000000000,231.700000000000,231.800000000000,231.900000000000,232,232.100000000000,232.200000000000,232.300000000000,232.400000000000,232.500000000000,232.600000000000,232.700000000000,232.800000000000,232.900000000000,233,233.100000000000,233.200000000000,233.300000000000,233.400000000000,233.500000000000,233.600000000000,233.700000000000,233.800000000000,233.900000000000,234,234.100000000000,234.200000000000,234.300000000000,234.400000000000,234.500000000000,234.600000000000,234.700000000000,234.800000000000,234.900000000000,235,235.100000000000,235.200000000000,235.300000000000,235.400000000000,235.500000000000,235.600000000000,235.700000000000,235.800000000000,235.900000000000,236,236.100000000000,236.200000000000,236.300000000000,236.400000000000,236.500000000000,236.600000000000,236.700000000000,236.800000000000,236.900000000000,237,237.100000000000,237.200000000000,237.300000000000,237.400000000000,237.500000000000,237.600000000000,237.700000000000,237.800000000000,237.900000000000,238,238.100000000000,238.200000000000,238.300000000000,238.400000000000,238.500000000000,238.600000000000,238.700000000000,238.800000000000,238.900000000000,239,239.100000000000,239.200000000000,239.300000000000,239.400000000000,239.500000000000,239.600000000000,239.700000000000,239.800000000000,239.900000000000,240,240.100000000000,240.200000000000,240.300000000000,240.400000000000,240.500000000000,240.600000000000,240.700000000000,240.800000000000,240.900000000000,241,241.100000000000,241.200000000000,241.300000000000,241.400000000000,241.500000000000,241.600000000000,241.700000000000,241.800000000000,241.900000000000,242,242.100000000000,242.200000000000,242.300000000000,242.400000000000,242.500000000000,242.600000000000,242.700000000000,242.800000000000,242.900000000000,243,243.100000000000,243.200000000000,243.300000000000,243.400000000000,243.500000000000,243.600000000000,243.700000000000,243.800000000000,243.900000000000,244,244.100000000000,244.200000000000,244.300000000000,244.400000000000,244.500000000000,244.600000000000,244.700000000000,244.800000000000,244.900000000000,245,245.100000000000,245.200000000000,245.300000000000,245.400000000000,245.500000000000,245.600000000000,245.700000000000,245.800000000000,245.900000000000,246,246.100000000000,246.200000000000,246.300000000000,246.400000000000,246.500000000000,246.600000000000,246.700000000000,246.800000000000,246.900000000000,247,247.100000000000,247.200000000000,247.300000000000,247.400000000000,247.500000000000,247.600000000000,247.700000000000,247.800000000000,247.900000000000,248,248.100000000000,248.200000000000,248.300000000000,248.400000000000,248.500000000000,248.600000000000,248.700000000000,248.800000000000,248.900000000000,249,249.100000000000,249.200000000000,249.300000000000,249.400000000000,249.500000000000,249.600000000000,249.700000000000,249.800000000000,249.900000000000,250,250.100000000000,250.200000000000,250.300000000000,250.400000000000,250.500000000000,250.600000000000,250.700000000000,250.800000000000,250.900000000000,251,251.100000000000,251.200000000000,251.300000000000,251.400000000000,251.500000000000,251.600000000000,251.700000000000,251.800000000000,251.900000000000,252,252.100000000000,252.200000000000,252.300000000000,252.400000000000,252.500000000000,252.600000000000,252.700000000000,252.800000000000,252.900000000000,253,253.100000000000,253.200000000000,253.300000000000,253.400000000000,253.500000000000,253.600000000000,253.700000000000,253.800000000000,253.900000000000,254,254.100000000000,254.200000000000,254.300000000000,254.400000000000,254.500000000000,254.600000000000,254.700000000000,254.800000000000,254.900000000000,255,255.100000000000,255.200000000000,255.300000000000,255.400000000000,255.500000000000,255.600000000000,255.700000000000,255.800000000000,255.900000000000,256,256.100000000000,256.200000000000,256.300000000000,256.400000000000,256.500000000000,256.600000000000,256.700000000000,256.800000000000,256.900000000000,257,257.100000000000,257.200000000000,257.300000000000,257.400000000000,257.500000000000,257.600000000000,257.700000000000,257.800000000000,257.900000000000,258,258.100000000000,258.200000000000,258.300000000000,258.400000000000,258.500000000000,258.600000000000,258.700000000000,258.800000000000,258.900000000000,259,259.100000000000,259.200000000000,259.300000000000,259.400000000000,259.500000000000,259.600000000000,259.700000000000,259.800000000000,259.900000000000,260,260.100000000000,260.200000000000,260.300000000000,260.400000000000,260.500000000000,260.600000000000,260.700000000000,260.800000000000,260.900000000000,261,261.100000000000,261.200000000000,261.300000000000,261.400000000000,261.500000000000,261.600000000000,261.700000000000,261.800000000000,261.900000000000,262,262.100000000000,262.200000000000,262.300000000000,262.400000000000,262.500000000000,262.600000000000,262.700000000000,262.800000000000,262.900000000000,263,263.100000000000,263.200000000000,263.300000000000,263.400000000000,263.500000000000,263.600000000000,263.700000000000,263.800000000000,263.900000000000,264,264.100000000000,264.200000000000,264.300000000000,264.400000000000,264.500000000000,264.600000000000,264.700000000000,264.800000000000,264.900000000000,265,265.100000000000,265.200000000000,265.300000000000,265.400000000000,265.500000000000,265.600000000000,265.700000000000,265.800000000000,265.900000000000,266,266.100000000000,266.200000000000,266.300000000000,266.400000000000,266.500000000000,266.600000000000,266.700000000000,266.800000000000,266.900000000000,267,267.100000000000,267.200000000000,267.300000000000,267.400000000000,267.500000000000,267.600000000000,267.700000000000,267.800000000000,267.900000000000,268,268.100000000000,268.200000000000,268.300000000000,268.400000000000,268.500000000000,268.600000000000,268.700000000000,268.800000000000,268.900000000000,269,269.100000000000,269.200000000000,269.300000000000,269.400000000000,269.500000000000,269.600000000000,269.700000000000,269.800000000000,269.900000000000,270,270.100000000000,270.200000000000,270.300000000000,270.400000000000,270.500000000000,270.600000000000,270.700000000000,270.800000000000,270.900000000000,271,271.100000000000,271.200000000000,271.300000000000,271.400000000000,271.500000000000,271.600000000000,271.700000000000,271.800000000000,271.900000000000,272,272.100000000000,272.200000000000,272.300000000000,272.400000000000,272.500000000000,272.600000000000,272.700000000000,272.800000000000,272.900000000000,273,273.100000000000,273.200000000000,273.300000000000,273.400000000000,273.500000000000,273.600000000000,273.700000000000,273.800000000000,273.900000000000,274,274.100000000000,274.200000000000,274.300000000000,274.400000000000,274.500000000000,274.600000000000,274.700000000000,274.800000000000,274.900000000000,275,275.100000000000,275.200000000000,275.300000000000,275.400000000000,275.500000000000,275.600000000000,275.700000000000,275.800000000000,275.900000000000,276,276.100000000000,276.200000000000,276.300000000000,276.400000000000,276.500000000000,276.600000000000,276.700000000000,276.800000000000,276.900000000000,277,277.100000000000,277.200000000000,277.300000000000,277.400000000000,277.500000000000,277.600000000000,277.700000000000,277.800000000000,277.900000000000,278,278.100000000000,278.200000000000,278.300000000000,278.400000000000,278.500000000000,278.600000000000,278.700000000000,278.800000000000,278.900000000000,279,279.100000000000,279.200000000000,279.300000000000,279.400000000000,279.500000000000,279.600000000000,279.700000000000,279.800000000000,279.900000000000,280,280.100000000000,280.200000000000,280.300000000000,280.400000000000,280.500000000000,280.600000000000,280.700000000000,280.800000000000,280.900000000000,281,281.100000000000,281.200000000000,281.300000000000,281.400000000000,281.500000000000,281.600000000000,281.700000000000,281.800000000000,281.900000000000,282,282.100000000000,282.200000000000,282.300000000000,282.400000000000,282.500000000000,282.600000000000,282.700000000000,282.800000000000,282.900000000000,283,283.100000000000,283.200000000000,283.300000000000,283.400000000000,283.500000000000,283.600000000000,283.700000000000,283.800000000000,283.900000000000,284,284.100000000000,284.200000000000,284.300000000000,284.400000000000,284.500000000000,284.600000000000,284.700000000000,284.800000000000,284.900000000000,285,285.100000000000,285.200000000000,285.300000000000,285.400000000000,285.500000000000,285.600000000000,285.700000000000,285.800000000000,285.900000000000,286,286.100000000000,286.200000000000,286.300000000000,286.400000000000,286.500000000000,286.600000000000,286.700000000000,286.800000000000,286.900000000000,287,287.100000000000,287.200000000000,287.300000000000,287.400000000000,287.500000000000,287.600000000000,287.700000000000,287.800000000000,287.900000000000,288,288.100000000000,288.200000000000,288.300000000000,288.400000000000,288.500000000000,288.600000000000,288.700000000000,288.800000000000,288.900000000000,289,289.100000000000,289.200000000000,289.300000000000,289.400000000000,289.500000000000,289.600000000000,289.700000000000,289.800000000000,289.900000000000,290,290.100000000000,290.200000000000,290.300000000000,290.400000000000,290.500000000000,290.600000000000,290.700000000000,290.800000000000,290.900000000000,291,291.100000000000,291.200000000000,291.300000000000,291.400000000000,291.500000000000,291.600000000000,291.700000000000,291.800000000000,291.900000000000,292,292.100000000000,292.200000000000,292.300000000000,292.400000000000,292.500000000000,292.600000000000,292.700000000000,292.800000000000,292.900000000000,293,293.100000000000,293.200000000000,293.300000000000,293.400000000000,293.500000000000,293.600000000000,293.700000000000,293.800000000000,293.900000000000,294,294.100000000000,294.200000000000,294.300000000000,294.400000000000,294.500000000000,294.600000000000,294.700000000000,294.800000000000,294.900000000000,295,295.100000000000,295.200000000000,295.300000000000,295.400000000000,295.500000000000,295.600000000000,295.700000000000,295.800000000000,295.900000000000,296,296.100000000000,296.200000000000,296.300000000000,296.400000000000,296.500000000000,296.600000000000,296.700000000000,296.800000000000,296.900000000000,297,297.100000000000,297.200000000000,297.300000000000,297.400000000000,297.500000000000,297.600000000000,297.700000000000,297.800000000000,297.900000000000,298,298.100000000000,298.200000000000,298.300000000000,298.400000000000,298.500000000000,298.600000000000,298.700000000000,298.800000000000,298.900000000000,299,299.100000000000,299.200000000000,299.300000000000,299.400000000000,299.500000000000,299.600000000000,299.700000000000,299.800000000000,299.900000000000,300,300.100000000000,300.200000000000,300.300000000000,300.400000000000,300.500000000000,300.600000000000,300.700000000000,300.800000000000,300.900000000000,301,301.100000000000,301.200000000000,301.300000000000,301.400000000000,301.500000000000,301.600000000000,301.700000000000,301.800000000000,301.900000000000,302,302.100000000000,302.200000000000,302.300000000000,302.400000000000,302.500000000000,302.600000000000,302.700000000000,302.800000000000,302.900000000000,303,303.100000000000,303.200000000000,303.300000000000,303.400000000000,303.500000000000,303.600000000000,303.700000000000,303.800000000000,303.900000000000,304,304.100000000000,304.200000000000,304.300000000000,304.400000000000,304.500000000000,304.600000000000,304.700000000000,304.800000000000,304.900000000000,305,305.100000000000,305.200000000000,305.300000000000,305.400000000000,305.500000000000,305.600000000000,305.700000000000,305.800000000000,305.900000000000,306,306.100000000000,306.200000000000,306.300000000000,306.400000000000,306.500000000000,306.600000000000,306.700000000000,306.800000000000,306.900000000000,307,307.100000000000,307.200000000000,307.300000000000,307.400000000000,307.500000000000,307.600000000000,307.700000000000,307.800000000000,307.900000000000,308,308.100000000000,308.200000000000,308.300000000000,308.400000000000,308.500000000000,308.600000000000,308.700000000000,308.800000000000,308.900000000000,309,309.100000000000,309.200000000000,309.300000000000,309.400000000000,309.500000000000,309.600000000000,309.700000000000,309.800000000000,309.900000000000,310,310.100000000000,310.200000000000,310.300000000000,310.400000000000,310.500000000000,310.600000000000,310.700000000000,310.800000000000,310.900000000000,311,311.100000000000,311.200000000000,311.300000000000,311.400000000000,311.500000000000,311.600000000000,311.700000000000,311.800000000000,311.900000000000,312,312.100000000000,312.200000000000,312.300000000000,312.400000000000,312.500000000000,312.600000000000,312.700000000000,312.800000000000,312.900000000000,313,313.100000000000,313.200000000000,313.300000000000,313.400000000000,313.500000000000,313.600000000000,313.700000000000,313.800000000000,313.900000000000,314,314.100000000000,314.200000000000,314.300000000000,314.400000000000,314.500000000000,314.600000000000,314.700000000000,314.800000000000,314.900000000000,315,315.100000000000,315.200000000000,315.300000000000,315.400000000000,315.500000000000,315.600000000000,315.700000000000,315.800000000000,315.900000000000,316,316.100000000000,316.200000000000,316.300000000000,316.400000000000,316.500000000000,316.600000000000,316.700000000000,316.800000000000,316.900000000000,317,317.100000000000,317.200000000000,317.300000000000,317.400000000000,317.500000000000,317.600000000000,317.700000000000,317.800000000000,317.900000000000,318,318.100000000000,318.200000000000,318.300000000000,318.400000000000,318.500000000000,318.600000000000,318.700000000000,318.800000000000,318.900000000000,319,319.100000000000,319.200000000000,319.300000000000,319.400000000000,319.500000000000,319.600000000000,319.700000000000,319.800000000000,319.900000000000,320,320.100000000000,320.200000000000,320.300000000000,320.400000000000,320.500000000000,320.600000000000,320.700000000000,320.800000000000,320.900000000000,321,321.100000000000,321.200000000000,321.300000000000,321.400000000000,321.500000000000,321.600000000000,321.700000000000,321.800000000000,321.900000000000,322,322.100000000000,322.200000000000,322.300000000000,322.400000000000,322.500000000000,322.600000000000,322.700000000000,322.800000000000,322.900000000000,323,323.100000000000,323.200000000000,323.300000000000,323.400000000000,323.500000000000,323.600000000000,323.700000000000,323.800000000000,323.900000000000,324,324.100000000000,324.200000000000,324.300000000000,324.400000000000,324.500000000000,324.600000000000,324.700000000000,324.800000000000,324.900000000000,325,325.100000000000,325.200000000000,325.300000000000,325.400000000000,325.500000000000,325.600000000000,325.700000000000,325.800000000000,325.900000000000,326,326.100000000000,326.200000000000,326.300000000000,326.400000000000,326.500000000000,326.600000000000,326.700000000000,326.800000000000,326.900000000000,327,327.100000000000,327.200000000000,327.300000000000,327.400000000000,327.500000000000,327.600000000000,327.700000000000,327.800000000000,327.900000000000,328,328.100000000000,328.200000000000,328.300000000000,328.400000000000,328.500000000000,328.600000000000,328.700000000000,328.800000000000,328.900000000000,329,329.100000000000,329.200000000000,329.300000000000,329.400000000000,329.500000000000,329.600000000000,329.700000000000,329.800000000000,329.900000000000,330,330.100000000000,330.200000000000,330.300000000000,330.400000000000,330.500000000000,330.600000000000,330.700000000000,330.800000000000,330.900000000000,331,331.100000000000,331.200000000000,331.300000000000,331.400000000000,331.500000000000,331.600000000000,331.700000000000,331.800000000000,331.900000000000,332,332.100000000000,332.200000000000,332.300000000000,332.400000000000,332.500000000000,332.600000000000,332.700000000000,332.800000000000,332.900000000000,333,333.100000000000,333.200000000000,333.300000000000,333.400000000000,333.500000000000,333.600000000000,333.700000000000,333.800000000000,333.900000000000,334,334.100000000000,334.200000000000,334.300000000000,334.400000000000,334.500000000000,334.600000000000,334.700000000000,334.800000000000,334.900000000000,335,335.100000000000,335.200000000000,335.300000000000,335.400000000000,335.500000000000,335.600000000000,335.700000000000,335.800000000000,335.900000000000,336,336.100000000000,336.200000000000,336.300000000000,336.400000000000,336.500000000000,336.600000000000,336.700000000000,336.800000000000,336.900000000000,337,337.100000000000,337.200000000000,337.300000000000,337.400000000000,337.500000000000,337.600000000000,337.700000000000,337.800000000000,337.900000000000,338,338.100000000000,338.200000000000,338.300000000000,338.400000000000,338.500000000000,338.600000000000,338.700000000000,338.800000000000,338.900000000000,339,339.100000000000,339.200000000000,339.300000000000,339.400000000000,339.500000000000,339.600000000000,339.700000000000,339.800000000000,339.900000000000,340,340.100000000000,340.200000000000,340.300000000000,340.400000000000,340.500000000000,340.600000000000,340.700000000000,340.800000000000,340.900000000000,341,341.100000000000,341.200000000000,341.300000000000,341.400000000000,341.500000000000,341.600000000000,341.700000000000,341.800000000000,341.900000000000,342,342.100000000000,342.200000000000,342.300000000000,342.400000000000,342.500000000000,342.600000000000,342.700000000000,342.800000000000,342.900000000000,343,343.100000000000,343.200000000000,343.300000000000,343.400000000000,343.500000000000,343.600000000000,343.700000000000,343.800000000000,343.900000000000,344,344.100000000000,344.200000000000,344.300000000000,344.400000000000,344.500000000000,344.600000000000,344.700000000000,344.800000000000,344.900000000000,345,345.100000000000,345.200000000000,345.300000000000,345.400000000000,345.500000000000,345.600000000000,345.700000000000,345.800000000000,345.900000000000,346,346.100000000000,346.200000000000,346.300000000000,346.400000000000,346.500000000000,346.600000000000,346.700000000000,346.800000000000,346.900000000000,347,347.100000000000,347.200000000000,347.300000000000,347.400000000000,347.500000000000,347.600000000000,347.700000000000,347.800000000000,347.900000000000,348,348.100000000000,348.200000000000,348.300000000000,348.400000000000,348.500000000000,348.600000000000,348.700000000000,348.800000000000,348.900000000000,349,349.100000000000,349.200000000000,349.300000000000,349.400000000000,349.500000000000,349.600000000000,349.700000000000,349.800000000000,349.900000000000,350,350.100000000000,350.200000000000,350.300000000000,350.400000000000,350.500000000000,350.600000000000,350.700000000000,350.800000000000,350.900000000000,351,351.100000000000,351.200000000000,351.300000000000,351.400000000000,351.500000000000,351.600000000000,351.700000000000,351.800000000000,351.900000000000,352,352.100000000000,352.200000000000,352.300000000000,352.400000000000,352.500000000000,352.600000000000,352.700000000000,352.800000000000,352.900000000000,353,353.100000000000,353.200000000000,353.300000000000,353.400000000000,353.500000000000,353.600000000000,353.700000000000,353.800000000000,353.900000000000,354,354.100000000000,354.200000000000,354.300000000000,354.400000000000,354.500000000000,354.600000000000,354.700000000000,354.800000000000,354.900000000000,355,355.100000000000,355.200000000000,355.300000000000,355.400000000000,355.500000000000,355.600000000000,355.700000000000,355.800000000000,355.900000000000,356,356.100000000000,356.200000000000,356.300000000000,356.400000000000,356.500000000000,356.600000000000,356.700000000000,356.800000000000,356.900000000000,357,357.100000000000,357.200000000000,357.300000000000,357.400000000000,357.500000000000,357.600000000000,357.700000000000,357.800000000000,357.900000000000,358,358.100000000000,358.200000000000,358.300000000000,358.400000000000,358.500000000000,358.600000000000,358.700000000000,358.800000000000,358.900000000000,359,359.100000000000,359.200000000000,359.300000000000,359.400000000000,359.500000000000,359.600000000000,359.700000000000,359.800000000000,359.900000000000,360,360.100000000000,360.200000000000,360.300000000000,360.400000000000,360.500000000000,360.600000000000,360.700000000000,360.800000000000,360.900000000000,361,361.100000000000,361.200000000000,361.300000000000,361.400000000000,361.500000000000,361.600000000000,361.700000000000,361.800000000000,361.900000000000,362,362.100000000000,362.200000000000,362.300000000000,362.400000000000,362.500000000000,362.600000000000,362.700000000000,362.800000000000,362.900000000000,363,363.100000000000,363.200000000000,363.300000000000,363.400000000000,363.500000000000,363.600000000000,363.700000000000,363.800000000000,363.900000000000,364,364.100000000000,364.200000000000,364.300000000000,364.400000000000,364.500000000000,364.600000000000,364.700000000000,364.800000000000,364.900000000000,365,365.100000000000,365.200000000000,365.300000000000,365.400000000000,365.500000000000,365.600000000000,365.700000000000,365.800000000000,365.900000000000,366,366.100000000000,366.200000000000,366.300000000000,366.400000000000,366.500000000000,366.600000000000,366.700000000000,366.800000000000,366.900000000000,367,367.100000000000,367.200000000000,367.300000000000,367.400000000000,367.500000000000,367.600000000000,367.700000000000,367.800000000000,367.900000000000,368,368.100000000000,368.200000000000,368.300000000000,368.400000000000,368.500000000000,368.600000000000,368.700000000000,368.800000000000,368.900000000000,369,369.100000000000,369.200000000000,369.300000000000,369.400000000000,369.500000000000,369.600000000000,369.700000000000,369.800000000000,369.900000000000,370,370.100000000000,370.200000000000,370.300000000000,370.400000000000,370.500000000000,370.600000000000,370.700000000000,370.800000000000,370.900000000000,371,371.100000000000,371.200000000000,371.300000000000,371.400000000000,371.500000000000,371.600000000000,371.700000000000,371.800000000000,371.900000000000,372,372.100000000000,372.200000000000,372.300000000000,372.400000000000,372.500000000000,372.600000000000,372.700000000000,372.800000000000,372.900000000000,373,373.100000000000,373.200000000000,373.300000000000,373.400000000000,373.500000000000,373.600000000000,373.700000000000,373.800000000000,373.900000000000,374,374.150000000000;];
  %% 2/2
  Derivative.dwdp_p2     = [131.176087262670,-265.289565756759,133.950466098440;45.9701654140950,-93.9958075987949,48.0330407654457;45.5523403736567,-93.1443837164126,47.5995560034777;45.1376716394287,-92.2993979047184,47.1693525362329;44.7261372030788,-91.4608050921326,46.7424072925262;44.3177151909961,-90.6285604859235,46.3186973455307;43.9123838637944,-89.8026195711244,45.8981999121879;43.5101216158067,-88.9829381094352,45.4808923526103;43.1109069745763,-88.1694721381175,45.0667521694816;42.7147186003464,-87.3621779688875,44.6557570074559;42.3215352855372,-86.5610121867862,44.2478846525465;41.9313359542309,-85.7659316490635,43.8431130315216;41.5440996616400,-84.9768934840321,43.4414202112859;41.1598055935817,-84.1938550899337,43.0427843982686;40.7784330659430,-83.4167741337865,42.6471839378023;40.3999615241449,-82.6456085502339,42.2545973135034;40.0243705426019,-81.8803165403818,41.8650031466467;39.6516398241790,-81.1208565706342,41.4783801955405;39.2817491996458,-80.3671873715219,41.0947073548976;38.9146786271260,-79.6192679365246,40.7139636552043;38.5504081915476,-78.8770575208927,40.3361282620891;38.1889181040868,-78.1405156404601,39.9611804756881;37.8301887016115,-77.4096020704550,39.5890997300087;37.4742004461209,-76.6842768443041,39.2198655922914;37.1209339241850,-75.9645002524377,38.8534577623725;36.7703698463804,-75.2502328410875,38.4898560720421;36.4224890467244,-74.5414354110825,38.1290404844042;36.0772724821074,-73.8380690166423,37.7709910932328;35.7347012317232,-73.1400949641647,37.4156881223283;35.3947564964975,-72.4474748110139,37.0631119248729;35.0574195985164,-71.7601703643070,36.7132429827860;34.7226719804510,-71.0781436796940,36.3660619060770;34.3904952049833,-70.4013570601406,36.0215494321997;34.0608709542280,-69.7297730547049,35.6796864254037;33.7337810291562,-69.0633544573170,35.3404538760886;33.4092073490158,-68.4020643055531,35.0038329001543;33.0871319507521,-67.7458658794118,34.6698047383544;32.7675369884271,-67.0947227000860,34.3383507556463;32.4504047326383,-66.4485985287373,34.0094524405446;32.1357175699364,-65.8074573652668,33.6830914044707;31.8234580022445,-65.1712634470900,33.3592493811076;31.5174251494690,-64.5476532370045,33.0417560459394;31.2137316784514,-63.9288117858224,32.7266915546521;30.9123610641535,-63.3147053034121,32.4140386394182;30.6132968873206,-62.7053002176571,32.1037801447664;30.3165228339810,-62.1005631733959,31.7958990270192;30.0220226949467,-61.5004610313647,31.4903783537323;29.7297803653112,-60.9049608671352,31.1872013031320;29.4397798439502,-60.3140299700569,30.8863511635559;29.1520052330156,-59.7276358421894,30.5878113328871;28.8664407374348,-59.1457461972435,30.2915653179953;28.5859099013750,-58.5740364341229,30.0004592690055;28.3075183820476,-58.0066877788573,29.7115745352101;28.0312511511175,-57.4436695013127,29.4248954122878;27.7570932757335,-56.8849510681491,29.1404062973395;27.4850299180841,-56.3305021418783,28.8580916883884;27.2150463349501,-55.7802925799156,28.5779361838777;26.9471278772601,-55.2342924336400,28.2999244821717;26.6812599896414,-54.6924719474429,28.0240413810530;26.4174282099718,-54.1548015577810,27.7502717772209;26.1556181689311,-53.6212518922290,27.4786006657906;25.8958155895504,-53.0917937685268,27.2090131397894;25.6380062867623,-52.5663981936311,26.9414943896558;25.3821761669493,-52.0450363627620,26.6760297027364;25.1283112274930,-51.5276796584535,26.4126044627850;24.8763975563222,-51.0142996496007,26.1512041494594;24.6264213314609,-50.5048680905080,25.8918143378206;24.3783688205761,-49.9993569199368,25.6344206978308;24.1322263805234,-49.4977382601510,25.3790089938510;23.8879804568978,-48.9999844159707,25.1255650841425;23.6456175835773,-48.5060678738136,24.8740749203634;23.4051243822726,-48.0159613007493,24.6245245470709;23.1664875620728,-47.5296375435448,24.3769001012199;22.9296939189938,-47.0470696277169,24.1311878116652;22.6947303355250,-46.5682307565811,23.8873739986622;22.4615837801771,-46.0930943103030,23.6454450733691;22.2302413070299,-45.6216338449510,23.4053875373499;22.0006900552809,-45.1538230915499,23.1671879820780;21.7729172487936,-44.6896359551348,22.9308330884407;21.5469101956455,-44.2290465138050,22.6963096262432;21.3226562876788,-43.7720290177834,22.4636044537162;21.1001430000498,-43.3185578884736,22.2327045170220;20.8793578907785,-42.8686077175185,22.0035968497621;20.6602886003003,-42.4221532658629,21.7762685724866;20.4429228510165,-41.9791694628136,21.5507068922030;20.2272484468482,-41.5396314051076,21.3268991018889;20.0132532727870,-41.1035143559743,21.1048325800019;19.8009252944501,-40.6707937442061,20.8844947899943;19.5902525576338,-40.2414451632268,20.6658732798263;19.3812231878686,-39.8154443701631,20.4489556814817;19.1738253899759,-39.3927672849203,20.2337297104851;18.9680474476234,-38.9733899892549,20.0201831654185;18.7638777228843,-38.5572887258561,19.8083039274421;18.5613046557950,-38.1444398974241,19.5980799598137;18.3603167639149,-37.7348200657523,19.3894993074103;18.1609026418867,-37.3284059508132,19.1825500962519;17.9630509609985,-36.9251744298453,18.9772205330261;17.7667504687464,-36.5251025364424,18.7734989046134;17.5719899883977,-36.1281674596464,18.5713735776152;17.3787584185562,-35.7343465430413,18.3708329978822;17.1870447327283,-35.3436172838514,18.1718656900452;17.0008710777647,-34.9640647248606,17.9785264502306;16.8161396127727,-34.5874509968120,17.7866834600196;16.6328401383439,-34.2137552685806,17.5963260875144;16.4509625215923,-33.8429568457177,17.4074437710234;16.2704966957998,-33.4750351697104,17.2200260186732;16.0914326600646,-33.1099698172454,17.0340624080236;15.9137604789470,-32.7477404994698,16.8495425856817;15.7374702821199,-32.3883270612609,16.6664562669191;15.5625522640158,-32.0317094804881,16.4847932352871;15.3889966834762,-31.6778678672819,16.3045433422345;15.2167938634021,-31.3267824633035,16.1256965067260;15.0459341904035,-30.9784336410149,15.9482427148617;14.8764081144506,-30.6328019029498,15.7721720194960;14.7082061485256,-30.2898678809892,15.5974745398601;14.5413188682749,-29.9496123356345,15.4241404611827;14.3757369116620,-29.6120161552862,15.2521600343142;14.2114509786209,-29.2770603555207,15.0815235753494;14.0484518307114,-28.9447260783724,14.9122214652535;13.8867302907733,-28.6149945916140,14.7442441494877;13.7262772425835,-28.2878472880428,14.5775821376368;13.5670836305117,-27.9632656847643,14.4122260030366;13.4091404591787,-27.6412314224808,14.2481663824038;13.2524387931152,-27.3217262647825,14.0853939754668;13.0969697564205,-27.0047320974373,13.9238995445966;12.9427245324234,-26.6902309276862,13.7636739144401;12.7896943633431,-26.3782048835385,13.6047079715539;12.6378705499519,-26.0686362130706,13.4469926640396;12.4872444512369,-25.7615072837245,13.2905190011793;12.3378074840666,-25.4568005816132,13.1352780530751;12.1895511228533,-25.1544987108220,12.9812609502857;12.0424668992208,-24.8545843927178,12.8284588834682;11.8965464016712,-24.5570404652575,12.6768631030186;11.7517812752533,-24.2618498822997,12.5264649187151;11.6081632212309,-23.9689957129176,12.3772556993609;11.4656839967542,-23.6784611407166,12.2292268724309;11.3243354145304,-23.3902294631520,12.0823699237172;11.1841093424969,-23.1042840908505,11.9366763969777;11.0449977034937,-22.8206085469327,11.7921378935845;10.9069924749396,-22.5391864663404,11.6487460721757;10.7700856885066,-22.2600015951636,11.5064926483060;10.6342694297979,-21.9830377899724,11.3653693941011;10.4995358380260,-21.7082790171512,11.2253681379126;10.3658771056910,-21.4357093522313,11.0864807639722;10.2332854782619,-21.1653129792332,10.9486992120514;10.1017532538589,-20.8970741900067,10.8120154771197;9.97127278293474,-20.6309773835731,10.6764216090043;9.84183646795985,-20.3670070654732,10.5419097120524;9.71343676310759,-20.1051478471161,10.4084719447946;9.58606617394040,-19.8453844451301,10.2761005196088;9.45971725709779,-19.5877016807174,10.1447877023868;9.33656067197931,-19.3364628301615,10.0167217365879;9.21438308676587,-19.0872184099998,9.88967090281423;9.09317751150581,-18.8399541584716,9.76362793002645;8.97293700288374,-18.5946559093928,9.63858559614706;8.85365466394961,-18.3513095915944,9.51453672776893;8.73532364384848,-18.1099012283621,9.39147419986485;8.61793713755108,-17.8704169368779,9.26939093549801;8.50148838558521,-17.6328429276636,9.14827990553353;8.38597067376859,-17.3971655040272,9.02813412835163;8.27137733294142,-17.1633710615090,8.90894666956064;8.15770173870135,-16.9314460873328,8.79071064171273;8.04493731113881,-16.7013771598579,8.67341920401995;7.93307751457271,-16.4731509480318,8.55706556207110;7.82211585728801,-16.2467542108471,8.44164296755043;7.71204589127392,-16.0221737967999,8.32714471795721;7.60286121196244,-15.7993966433484,8.21356415632587;7.49455545796951,-15.5784097763779,8.10089467094883;7.38712231083487,-15.3592003096625,7.98912969509828;7.28055549476564,-15.1417554443350,7.87826270675178;7.17484877637836,-14.9260624683532,7.76828722831658;7.06999596444358,-14.7121087559721,7.65919682635654;6.96599090963075,-14.4998817672169,7.55098511131961;6.86282750425509,-14.2893690473595,7.44364573726743;6.76049968202413,-14.0805582263947,7.33717240160466;6.65900141778666,-13.8734370185219,7.23155884481104;6.55832672728129,-13.6679932216256,7.12679885017313;6.45846966688744,-13.4642147167610,7.02288624351857;6.35942433337687,-13.2620894676410,6.91981489295119;6.26118486366562,-13.0616055201241,6.81757870858657;6.16374543456815,-12.8627510017068,6.71617164228994;6.06710026255162,-12.6655141210163,6.61558768741444;5.97124360349179,-12.4698831673070,6.51582087854110;5.87616975242973,-12.2758465099582,6.41686529121983;5.78187304332982,-12.0833925979750,6.31871504171173;5.68834784883851,-11.8925099594906,6.22136428673242;5.59558858004444,-11.7031872012715,6.12480722319684;5.50358968623971,-11.5154130082250,6.02903808796531;5.41234565468187,-11.3291761429090,5.93405115759046;5.32185101035736,-11.1444654450433,5.83984074806580;5.23210031574595,-10.9612698310250,5.74640121457531;5.14308817058602,-10.7795782934439,5.65372695124414;5.05480921164160,-10.5993799006029,5.56181239089114;4.96725811246947,-10.4206637960377,5.47065200478153;4.88042958318885,-10.2434191980426,5.38024030238239;4.79431837025011,-10.0676353991935,5.29057183111728;4.70891925620684,-9.89330176587890,5.20164117612424;4.62422705948755,-9.72040773782942,5.11344296001371;4.54023663416887,-9.54894282765066,5.02597184262797;4.45694286974991,-9.37889662035868,4.93922252080190;4.37434069092791,-9.21025877291794,4.85318972812511;4.29401377091994,-9.04621266838502,4.76946998472146;4.21434880323857,-8.88351507683668,4.68643659887047;4.13534102083709,-8.72215627841154,4.60408461868200;4.05698568889134,-8.56212661917237,4.52240912597523;3.97927810460280,-8.40341651069980,4.44140523606903;3.90221359700257,-8.24601642968805,4.36106809757341;3.82578752675531,-8.08991691754046,4.28139289218093;3.74999528596524,-7.93510857996950,4.20237483446040;3.67483229798231,-7.78158208659699,4.12400917165074;3.60029401720970,-7.62932817055726,4.04629118345637;3.52637592891157,-7.47833762810086,3.96921618184294;3.45307354902214,-7.32860131820103,3.89277951083450;3.38038242395587,-7.18011016216238,3.81697654631181;3.30829813041775,-7.03285514323017,3.74180269581100;3.23681627521557,-6.88682730620324,3.66725339832417;3.16593249507202,-6.74201775704714,3.59332412410005;3.09564245643830,-6.59841766251000,3.52001037444620;3.02594185530837,-6.45601824974004,3.44730768153193;2.95682641703430,-6.31481080590524,3.37521160819252;2.88829189614214,-6.17478667781423,3.30371774773398;2.82033407614942,-6.03593727154042,3.23282172373954;2.75294876938239,-5.89825405204590,3.16251918987605;2.68613181679533,-5.76172854280930,3.09280582970242;2.61987908779016,-5.62635232545463,3.02367735647862;2.55418648003676,-5.49211703938144,2.95512951297534;2.48904991929461,-5.35901438139780,2.88715807128516;2.42446535923518,-5.22703610535477,2.81975883263451;2.36042878126545,-5.09617402178338,2.75292762719688;2.29693619435125,-4.96641999753123,2.68666031390593;2.23398363484327,-4.83776595540450,2.62095278027138;2.17156716630222,-4.71020387380845,2.55580094219411;2.10968287932637,-4.58372578639259,2.49120074378374;2.04832689137847,-4.45832378169497,2.42714815717573;1.98749534661509,-4.33399000279113,2.36363918235089;1.92718441571569,-4.21071664694267,2.30066984695480;1.86739029571302,-4.08849596524870,2.23823620611856;1.80810920982472,-3.96732026229960,2.17633434228095;1.74933740728493,-3.84718189583090,2.11496036501051;1.69107116317769,-3.72807327638097,2.05411041082968;1.63330677827102,-3.60998686695000,1.99378064303955;1.57604057885132,-3.49291518265972,1.93396725154513;1.51926891655919,-3.37685079041611,1.87466645268201;1.46298816822601,-3.26178630857369,1.81587448904399;1.40719473571176,-3.14771440660223,1.75758762931189;1.35188504574247,-3.03462780475301,1.69980216808216;1.29705554975019,-2.92251927373010,1.64251442569810;1.24270272371279,-2.81138163436133,1.58572074808095;1.18882306799476,-2.70120775727134,1.52941750656199;1.13541310718909,-2.59199056255703,1.47360109771597;1.08246938996026,-2.48372301946500,1.41826794319555;1.03077050631421,-2.37797016864287,1.36420292397575;0.979521760720737,-2.27313441048579,1.31060472641641;0.928719866243535,-2.16920904696093,1.25746994030276;0.878361558476373,-2.06618742606033,1.20479517891586;0.828443595399415,-1.96406294150551,1.15257707888085;0.778962757236196,-1.86282903245369,1.10081230001599;0.729915846311585,-1.76247918320585,1.04949752518274;0.681299686910225,-1.66300692291596,0.998629460136349;0.633111125135831,-1.56440582530188,0.948204833377431;0.585347028771367,-1.46666950835819,0.898220396004439;0.538004287139771,-1.36979163407009,0.848672921566785;0.491079810965309,-1.27376590812865,0.799559205918636;0.444570532236322,-1.17858607964897,0.750876067074179;0.398473404068035,-1.08424594088844,0.702620345063026;0.352785400566246,-0.990739326966854,0.654788901786527;0.307503516692138,-0.898060115588874,0.607378620875316;0.262624768127191,-0.806202226766690,0.560386407546981;0.218146191139557,-0.715159622545721,0.513809188465292;0.174064842450642,-0.624926306730754,0.467643911599679;0.130377799102551,-0.535496324613887,0.421887546085636;0.0870821583264753,-0.446863762704422,0.376537082086145;0.0441750374114683,-0.359022748459574,0.331589530653528;0.00165357357417470,-0.271967450017162,0.287041923592325;-0.0404850761704965,-0.185692075930242,0.242891313323179;-0.0822437351388175,-0.100190874901556,0.199134772746650;-0.123625207105682,-0.0154581355220548,0.155769395109104;-0.164632276432550,0.0685118139915399,0.112792293868143;-0.205267708194106,0.151724606056530,0.0702006025594002;-0.245534248303733,0.234185833981632,0.0279914746645512;-0.285434623639304,0.315901052224923,-0.0138379165209131;-0.324971542167913,0.396875776649643,-0.0552903780188215;-0.364147693068710,0.477115484776113,-0.0963686972974729;-0.402965746857317,0.556625616036794,-0.137075642402348;-0.441428355507247,0.635411572025282,-0.177413962083740;-0.479538152572246,0.713478716747103,-0.217386385925280;-0.517297753307027,0.790832376867232,-0.256995624470774;-0.554709754787653,0.867477841956874,-0.296244369350663;-0.591776736031203,0.943420364738735,-0.335135293407689;-0.628501258114547,1.01866516133049,-0.373671050821640;-0.664885864292853,1.09321741148764,-0.411854277233751;-0.700933080117109,1.16708225884437,-0.449687589870100;-0.736645413550635,1.24026481115230,-0.487173587663909;-0.772025355085632,1.31277014051932,-0.524314851377859;-0.807075377858558,1.38460328364597,-0.561113943725165;-0.841797937764870,1.45576924206056,-0.597573409489982;-0.876195473573446,1.52627298235354,-0.633695775647426;-0.910270407039593,1.59611943640908,-0.669483551482153;-0.944025143018413,1.66531350163720,-0.704939228707222;-0.977462069576293,1.73386004120223,-0.740065281581055;-1.01058355810284,1.80176388425201,-0.774864167024800;-1.04280789556179,1.86785572461141,-0.808749464206046;-1.07472815618048,1.93332782971612,-0.842319178966718;-1.10634659738722,1.99818479817469,-0.875575651787154;-1.13766546098955,2.06243119671854,-0.908521206892672;-1.16868697327649,2.12607156041159,-0.941158152360978;-1.19941334511972,2.18911039285767,-0.973488780228440;-1.22984677207493,2.25155216640819,-1.00551536659648;-1.25998943448205,2.31340132236750,-1.03724017173677;-1.28984349756485,2.37466227119718,-1.06866544019589;-1.31941111153042,2.43533939271972,-1.09979340089965;-1.34869441166771,2.49543703632051,-1.13062626725653;-1.37769551844549,2.55495952114852,-1.16116623726049;-1.40641653760982,2.61391113631601,-1.19141549359321;-1.43485956028122,2.67229614109763,-1.22137620372607;-1.46302666305067,2.73011876512700,-1.25105052002079;-1.49091990807546,2.78738320859314,-1.28044057983001;-1.51854134317464,2.84409364243591,-1.30954850559737;-1.54589300192338,2.90025420853929,-1.33837640495643;-1.57297690374720,2.95586901992438,-1.36692637082945;-1.59979505401525,3.01094216094048,-1.39520048152530;-1.62634944413372,3.06547768745625,-1.42320080083717;-1.65264205163789,3.11947962704832,-1.45092937813920;-1.67867484028406,3.17295197918947,-1.47838824848276;-1.70444976014087,3.22589871543560,-1.50557943269213;-1.72996874768036,3.27832377961221,-1.53250493745992;-1.75523372586747,3.33023108799756,-1.55916675544081;-1.78024660425067,3.38162452950822,-1.58556686534647;-1.80500927905023,3.43250796587984,-1.61170723203807;-1.82952363324734,3.48288523184942,-1.63758980661951;-1.85379153667202,3.53276013533540,-1.66321652652957;-1.87781484609069,3.58213645761676,-1.68858931563350;-1.90159540529307,3.63101795351097,-1.71371008431407;-1.92513504517869,3.67940835155098,-1.73858072956211;-1.94843558384306,3.72731135416150,-1.76320313506661;-1.97149882666268,3.77473063783311,-1.78757917130385;-1.99432656638040,3.82166985329673,-1.81171069562655;-2.01692058318931,3.86813262569543,-1.83559955235177;-2.03928264481708,3.91412255475688,-1.85924757284911;-2.06141450660899,3.95964321496326,-1.88265657562751;-2.08331791161099,4.00469815572114,-1.90582836642221;-2.10499459065177,4.04929090152942,-1.92876473828055;-2.12644626242492,4.09342495214741,-1.95146747164789;-2.14767463356996,4.13710378276048,-1.97393833445236;-2.16868139875332,4.18033084414577,-1.99617908218949;-2.18946824074870,4.22310956283649,-2.01819145800624;-2.21003683051660,4.26544334128468,-2.03997719278420;-2.23038882728411,4.30733555802422,-2.06153800522287;-2.25052587862325,4.34878956783120,-2.08287560192166;-2.27044962052979,4.38980870188500,-2.10399167746216;-2.29016167750068,4.43039626792663,-2.12488791448913;-2.30922268423124,4.46966908939431,-2.14512138688474;-2.32808007057635,4.50852663767260,-2.16514324010780;-2.34673538164285,4.54697205995758,-2.18495507574741;-2.36519015176466,4.58500848147664,-2.20455848419884;-2.38344590457399,4.62263900563431,-2.22395504473806;-2.40150415307237,4.65986671415762,-2.24314632559616;-2.41936639970146,4.69669466724085,-2.26213388403331;-2.43703413641298,4.73312590368877,-2.28091926641202;-2.45450884473880,4.76916344105987,-2.29950400827039;-2.47179199585974,4.80481027580725,-2.31788963439411;-2.48888505067522,4.84006938342096,-2.33607765888929;-2.50578945987112,4.87494371856696,-2.35406958525345;-2.52250666398808,4.90943621522667,-2.37186690644688;-2.53903809348926,4.94354978683571,-2.38947110496358;-2.55538516882733,4.97728732642078,-2.40688365290119;-2.57154930051142,5.01065170673670,-2.42410601203106;-2.58753188917367,5.04364578040241,-2.44113963386779;-2.60333432563497,5.07627238003545,-2.45798595973787;-2.61895799097061,5.10853431838628,-2.47464642084845;-2.63440425657569,5.14043438847188,-2.49112243835549;-2.64967448422945,5.17197536370740,-2.50741542343115;-2.66477002616017,5.20315999803881,-2.52352677733149;-2.67969222510871,5.23399102607286,-2.53945789146291;-2.69444241439248,5.26447116320779,-2.55521014744893;-2.70902191796821,5.29460310576165,-2.57078491719574;-2.72343205049500,5.32438953110134,-2.58618356295817;-2.73767411739676,5.35383309777004,-2.60140743740472;-2.75174941492405,5.38293644561377,-2.61645788368227;-2.76565923021563,5.41170219590711,-2.63133623548029;-2.77940484135995,5.44013295147899,-2.64604381709507;-2.79298751745593,5.46823129683675,-2.66058194349312;-2.80640851867334,5.49599979828970,-2.67495192037427;-2.81966909631279,5.52344100407165,-2.68915504423421;-2.83277049286569,5.55055744446342,-2.70319260242713;-2.84571394207327,5.57735163191353,-2.71706587322731;-2.85850066898608,5.60382606115969,-2.73077612589117;-2.87113189002183,5.62998320934708,-2.74432462071767;-2.88360881302412,5.65582553614829,-2.75771260910955;-2.89593263732026,5.68135548388142,-2.77094133363366;-2.90810455377843,5.70657547762703,-2.78401202808063;-2.92012574486512,5.73148792534528,-2.79692591752471;-2.93199738470190,5.75609521799206,-2.80968421838306;-2.94372063912136,5.78039972963328,-2.82228813847408;-2.95529666572377,5.80440381756044,-2.83473887707641;-2.96672661393222,5.82810982240346,-2.84703762498656;-2.97801162504832,5.85152006824441,-2.85918556457692;-2.98915283230691,5.87463686272917,-2.87118386985279;-3.00015136093088,5.89746249717954,-2.88303370650957;-3.01100832818521,5.91999924670345,-2.89473623198908;-3.02172484343112,5.94224937030574,-2.90629259553601;-3.03179744885819,5.96320083866074,-2.91719523868119;-3.04173714658927,5.98388090404264,-2.92795938699496;-3.05154497426271,6.00429168064337,-2.93858611673597;-3.06122196225728,6.02443526785338,-2.94907649662237;-3.07076913374011,6.04431375035970,-2.95943158788199;-3.08018750471495,6.06392919824463,-2.96965244430273;-3.08947808406961,6.08328366708266,-2.97974011228210;-3.09864187362349,6.10237919803770,-2.98969563087684;-3.10767986817442,6.12121781795883,-2.99952003185194;-3.11659305554549,6.13980153947598,-3.00921433972946;-3.12538241663180,6.15813236109557,-3.01877957183736;-3.13404892544632,6.17621226729423,-3.02821673835744;-3.14259354916602,6.19404322861301,-3.03752684237343;-3.15101724817716,6.21162720175005,-3.04671087991836;-3.15932097612107,6.22896612965413,-3.05576984002228;-3.16750567993897,6.24606194161623,-3.06470470475908;-3.17557229991677,6.26291655336109,-3.07351644929323;-3.18352176972933,6.27953186713771,-3.08220604192603;-3.19135501648521,6.29590977181078,-3.09077444414223;-3.19907296077009,6.31205214294931,-3.09922261065540;-3.20667651669069,6.32796084291656,-3.10755148945374;-3.21416659191802,6.34363772095824,-3.11576202184521;-3.22154408773072,6.35908461329119,-3.12385514250275;-3.22880989905755,6.37430334319010,-3.13183177950860;-3.23596491452034,6.38929572107528,-3.13969285439909;-3.24301001647598,6.40406354459855,-3.14743928220847;-3.24994608105858,6.41860859872921,-3.15507197151288;-3.25677397822135,6.43293265583969,-3.16259182447399;-3.26349457177791,6.44703747578993,-3.16999973688211;-3.27010871944375,6.46092480601203,-3.17729659819943;-3.27661727287694,6.47459638159350,-3.18448329160245;-3.28302107771902,6.48805392536069,-3.19156069402463;-3.28932097363552,6.50129914796154,-3.19852967619860;-3.29551779435610,6.51433374794767,-3.20539110269807;-3.30161236771440,6.52715941185566,-3.21214583197928;-3.30760551568795,6.53977781428865,-3.21879471642270;-3.31349805443739,6.55219061799631,-3.22533860237380;-3.31929079434581,6.56439947395538,-3.23177833018417;-3.32498454005777,6.57640602144914,-3.23811473425207;-3.33058009051763,6.58821188814582,-3.24434864306246;-3.33607823900847,6.59981869017801,-3.25048087922748;-3.34147977319006,6.61122803222023,-3.25651225952609;-3.34678547513665,6.62244150756607,-3.26244359494338;-3.35199612137507,6.63346069820597,-3.26827569071027;-3.35711248292189,6.64428717490313,-3.27400934634224;-3.36213532532077,6.65492249726974,-3.27964535567825;-3.36706540867945,6.66536821384251,-3.28518450691922;-3.37190348770651,6.67562586215770,-3.29062758266637;-3.37665031174795,6.68569696882580,-3.29597535995924;-3.38130662482323,6.69558304960514,-3.30122861031333;-3.38574362522650,6.70502520544773,-3.30625749635568;-3.39009291159097,6.71428799763476,-3.31119471766218;-3.39435520060112,6.72337288654801,-3.31604101773461;-3.39853120385806,6.73228132221031,-3.32079713480054;-3.40262162791362,6.74101474435520,-3.32546380184886;-3.40662717430443,6.74957458249647,-3.33004174666524;-3.41054853958594,6.75796225599765,-3.33453169186764;-3.41438641536553,6.76617917413967,-3.33893435494079;-3.41814148833648,6.77422673619004,-3.34325044827151;-3.42181444031059,6.78210633146969,-3.34748067918275;-3.42540594825151,6.78981933942079,-3.35162574996829;-3.42891668430725,6.79736712967327,-3.35568635792658;-3.43234731584284,6.80475106211141,-3.35966319539478;-3.43569850547239,6.81197248693937,-3.36355694978215;-3.43897091109176,6.81903274474777,-3.36736830360401;-3.44216518590964,6.82593316657724,-3.37109793451419;-3.44528197848009,6.83267507398474,-3.37474651533880;-3.44832193273340,6.83925977910662,-3.37831471410846;-3.45128568800771,6.84568858472317,-3.38180319409120;-3.45417387907995,6.85196278432172,-3.38521261382459;-3.45698713619692,6.85808366216009,-3.38854362714818;-3.45972608510562,6.86405249332850,-3.39179688323504;-3.46239134708413,6.86987054381260,-3.39497302662388;-3.46498353897156,6.87553907055456,-3.39807269725025;-3.46750327319854,6.88105932151533,-3.40109653047824;-3.46995115781674,6.88643253573484,-3.40404515713123;-3.47232779652870,6.89165994339294,-3.40691920352292;-3.47463378871739,6.89674276586965,-3.40971929148808;-3.47686972947564,6.90168221580525,-3.41244603841317;-3.47903620963496,6.90647949715906,-3.41510005726633;-3.48113381579478,6.91113580526913,-3.41768195662778;-3.48316313035111,6.91565232691074,-3.42019234071971;-3.48512473152500,6.92003024035437,-3.42263180943575;-3.48701919339103,6.92427071542396,-3.42500095837075;-3.48884708590559,6.92837491355450,-3.42730037885008;-3.49060897493462,6.93234398784871,-3.42953065795857;-3.49230542228179,6.93617908313441,-3.43169237856974;-3.49393698571582,6.93988133602042,-3.43378611937427;-3.49550421899822,6.94345187495301,-3.43581245490882;-3.49700767191037,6.94689182027119,-3.43777195558419;-3.49844789028075,6.95020228426232,-3.43966518771365;-3.49982541601183,6.95338437121684,-3.44149271354087;-3.50114078710688,6.95643917748304,-3.44325509126781;-3.50239453769650,6.95936779152121,-3.44495287508235;-3.50358719806499,6.96217129395730,-3.44658661518560;-3.50471929467674,6.96485075763687,-3.44815685781941;-3.50579135020205,6.96740724767772,-3.44966414529321;-3.50680388354326,6.96984182152313,-3.45110901601113;-3.50775740986033,6.97215552899412,-3.45249200449864;-3.50865244059654,6.97434941234176,-3.45381364142917;-3.50969087366021,6.97682934366063,-3.45527749634964;-3.51066983511654,6.97918751682217,-3.45667904543335;-3.51158984220709,6.98142498544199,-3.45801882488993;-3.51245140841637,6.98354279548759,-3.45929736703944;-3.51325504349783,6.98554198533131,-3.46051520033934;-3.51400125349956,6.98742358580276,-3.46167284941118;-3.51469054078994,6.98918862024098,-3.46277083506717;-3.51532340408298,6.99083810454623,-3.46380967433653;-3.51590033846378,6.99237304723171,-3.46478988049183;-3.51642183541329,6.99379444947413,-3.46571196307475;-3.51688838283354,6.99510330516508,-3.46657642792221;-3.51730046507221,6.99630060096108,-3.46738377719186;-3.51765856294726,6.99738731633380,-3.46813450938767;-3.51796315377130,6.99836442361971,-3.46882911938518;-3.51821471137599,6.99923288806973,-3.46946809845674;-3.51841370613586,6.99999366789789,-3.47005193429637;-3.51856060499260,7.00064771433069,-3.47058111104482;-3.51865587147843,7.00119597165482,-3.47105610931388;-3.51869996574001,7.00163937726576,-3.47147740621112;-3.51869334456184,7.00197886171561,-3.47184547536423;-3.51863646138938,7.00221534876004,-3.47216078694493;-3.51852976635231,7.00234975540577,-3.47242380769313;-3.51837370628757,7.00238299195742,-3.47263500094077;-3.51816872476203,7.00231596206385,-3.47279482663543;-3.51791526209523,7.00214956276432,-3.47290374136380;-3.51761375538204,7.00188468453474,-3.47296219837522;-3.51726463851468,7.00152221133250,-3.47297064760452;-3.51686834220525,7.00106302064237,-3.47292953569535;-3.51642529400774,7.00050798352137,-3.47283930602304;-3.51593591833973,6.99985796464287,-3.47270039871704;-3.51540063650438,6.99911382234156,-3.47251325068379;-3.51481986671208,6.99827640865732,-3.47227829562908;-3.51419402410174,6.99734656937882,-3.47199596408017;-3.51352352076207,6.99632514408667,-3.47166668340785;-3.51280876575317,6.99521296619756,-3.47129087784881;-3.51205016512709,6.99401086300597,-3.47086896852691;-3.51124812194899,6.99271965572743,-3.47040137347519;-3.51040303631782,6.99134015954054,-3.46988850765726;-3.50951530538711,6.98987318362928,-3.46933078298878;-3.50858532338497,6.98831953122391,-3.46872860835836;-3.50761348163512,6.98667999964363,-3.46808238964917;-3.50660016857653,6.98495538033660,-3.46739252975937;-3.50554576978359,6.98314645892118,-3.46665942862307;-3.50445066798635,6.98125401522692,-3.46588348323119;-3.50331524308997,6.97927882333431,-3.46506508765169;-3.50213987219440,6.97722165161487,-3.46420463304996;-3.50092492961419,6.97508326277141,-3.46330250770928;-3.49967078689751,6.97286441387684,-3.46235909705062;-3.49837781284572,6.97056585641392,-3.46137478365282;-3.49704637353236,6.96818833631408,-3.46034994727236;-3.49488725832200,6.96414538109146,-3.45848891187317;-3.49269792914147,6.96004006998402,-3.45659569363372;-3.49047868242952,6.95587300874150,-3.45467060189082;-3.48822981247266,6.95164479872129,-3.45271394374126;-3.48595161141933,6.94735603691735,-3.45072602405663;-3.48364436929411,6.94300731598919,-3.44870714549809;-3.48130837401199,6.93859922429111,-3.44665760853137;-3.47894391139234,6.93413234590072,-3.44457771144123;-3.47655126517264,6.92960726064700,-3.44246775034590;-3.47413071702274,6.92502454413943,-3.44032801921188;-3.47168254655814,6.92038476779517,-3.43815880986787;-3.46920703135421,6.91568849886810,-3.43596041201955;-3.46670444695926,6.91093630047544,-3.43373311326325;-3.46417506690854,6.90612873162656,-3.43147719910057;-3.46161916273720,6.90126634724921,-3.42919295295185;-3.45903700399404,6.89634969821785,-3.42688065617059;-3.45642885825453,6.89137933138005,-3.42454058805697;-3.45379499113398,6.88635578958358,-3.42217302587162;-3.45113566630086,6.88127961170350,-3.41977824484953;-3.44845114548957,6.87615133266827,-3.41735651821332;-3.44574168851341,6.87097148348629,-3.41490811718682;-3.44300755327750,6.86574059127230,-3.41243331100855;-3.44024899579165,6.86045917927358,-3.40993236694506;-3.43746627018273,6.85512776689532,-3.40740555030394;-3.43465962870757,6.84974686972694,-3.40485312444721;-3.43182932176535,6.84431699956740,-3.40227535080426;-3.42897559791012,6.83883866445076,-3.39967248888489;-3.42609870386305,6.83331236867124,-3.39704479629211;-3.42319888452488,6.82773861280859,-3.39439252873509;-3.42027638298809,6.82211789375299,-3.39171594004186;-3.41733144054883,6.81645070472945,-3.38901528217178;-3.41436429671938,6.81073753532316,-3.38629080522847;-3.41137518923977,6.80497887150336,-3.38354275747198;-3.40836435408979,6.79917519564775,-3.38077138533129;-3.40533202550098,6.79332698656699,-3.37797693341675;-3.40227843596818,6.78743471952839,-3.37515964453225;-3.39920381626129,6.78149886627981,-3.37231975968735;-3.39610839543690,6.77551989507348,-3.36945751810946;-3.39299240084984,6.76949827068955,-3.36657315725586;-3.38985605816452,6.76343445445929,-3.36366691282557;-3.38669959136651,6.75732890428870,-3.36073901877133;-3.38352322277369,6.75118207468124,-3.35778970731126;-3.38032717304752,6.74499441676100,-3.35481920894065;-3.37711166120434,6.73876637829555,-3.35182775244364;-3.37387690462627,6.73249840371840,-3.34881556490466;-3.37062311907243,6.72619093415179,-3.34578287172008;-3.36735051868976,6.71984440742883,-3.34272989660948;-3.36405931602398,6.71345925811583,-3.33965686162708;-3.36074972203038,6.70703591753445,-3.33656398717302;-3.35742194608460,6.70057481378349,-3.33345149200446;-3.35407619599326,6.69407637176088,-3.33031959324683;-3.35071267800465,6.68754101318524,-3.32716850640483;-3.34733159681920,6.68096915661742,-3.32399844537338;-3.34393315560000,6.67436121748192,-3.32080962244859;-3.34051755598317,6.66771760808806,-3.31760224833855;-3.33708499808829,6.66103873765128,-3.31437653217418;-3.33363568052856,6.65432501231388,-3.31113268151982;-3.33016980042110,6.64757683516606,-3.30787090238396;-3.32668755339705,6.64079460626650,-3.30459139922977;-3.32318913361170,6.63397872266308,-3.30129437498561;-3.31967473375442,6.62712957841312,-3.29798003105539;-3.31614454505869,6.62024756460392,-3.29464856732904;-3.31259875731198,6.61333306937278,-3.29130018219276;-3.30903755886553,6.60638647792710,-3.28793507253917;-3.30546113664410,6.59940817256428,-3.28455343377760;-3.30186967615577,6.59239853269164,-3.28115545984411;-3.29826336150146,6.58535793484585,-3.27774134321152;-3.29464237538455,6.57828675271272,-3.27431127489940;-3.29100689912041,6.57118535714640,-3.27086544448395;-3.28735711264581,6.56405411618882,-3.26740404010788;-3.28369319452833,6.55689339508876,-3.26392724849008;-3.28001532197567,6.54970355632089,-3.26043525493544;-3.27632367084497,6.54248495960481,-3.25692824334447;-3.27261841565196,6.53523796192364,-3.25340639622281;-3.26889972958008,6.52796291754278,-3.24986989469083;-3.26516778448970,6.52066017802856,-3.24631891849308;-3.26142275092699,6.51333009226648,-3.24275364600762;-3.25766479813302,6.50597300647971,-3.23917425425547;-3.25389409405260,6.49858926424707,-3.23558091890975;-3.25011080534314,6.49117920652129,-3.23197381430500;-3.24631509738349,6.48374317164685,-3.22835311344631;-3.24250713428262,6.47628149537785,-3.22471898801836;-3.23868707888839,6.46879451089576,-3.22107160839454;-3.23485509279607,6.46128254882697,-3.21741114364585;-3.23101133635701,6.45374593726030,-3.21373776154989;-3.22715596868708,6.44618500176437,-3.21005162859962;-3.22328914767520,6.43860006540493,-3.20635291001228;-3.21941102999167,6.43099144876191,-3.20264176973804;-3.21552177109661,6.42335946994652,-3.19891837046877;-3.21162152524815,6.41570444461811,-3.19518287364654;-3.20771044551077,6.40802668600113,-3.19143543947236;-3.20378868376343,6.40032650490167,-3.18767622691456;-3.19985639070775,6.39260420972417,-3.18390539371733;-3.19591371587603,6.38486010648787,-3.18012309640911;-3.19196080763934,6.37709449884317,-3.17632949031091;-3.18799781321547,6.36930768808794,-3.17252472954462;-3.18402487867685,6.36149997318370,-3.16870896704132;-3.18004214895845,6.35367165077165,-3.16488235454933;-3.17604976786557,6.34582301518863,-3.16104504264250;-3.17204787808161,6.33795435848293,-3.15719718072814;-3.16853407065272,6.33106595045600,-3.15384044844207;-3.16500660510155,6.32414919040999,-3.15046899366947;-3.16146565480936,6.31720443200403,-3.14708299666275;-3.15791139180588,6.31023202614801,-3.14368263627730;-3.15434398677893,6.30323232102218,-3.14026808998142;-3.15076360908384,6.29620566209631,-3.13683953386606;-3.14717042675302,6.28915239214904,-3.13339714265468;-3.14356460650527,6.28207285128696,-3.12994108971288;-3.13994631375508,6.27496737696341,-3.12647154705800;-3.13631571262192,6.26783630399744,-3.12298868536876;-3.13267296593944,6.26067996459247,-3.11949267399465;-3.12901823526453,6.25349868835478,-3.11598368096546;-3.12535168088643,6.24629280231191,-3.11246187300050;-3.12167346183573,6.23906263093112,-3.10892741551804;-3.11798373589328,6.23180849613736,-3.10538047264446;-3.11428265959909,6.22453071733148,-3.10182120722341;-3.11057038826109,6.21722961140798,-3.09824978082493;-3.10684707596397,6.20990549277298,-3.09466635375450;-3.10311287557779,6.20255867336176,-3.09107108506199;-3.09936793876664,6.19518946265637,-3.08746413255060;-3.09561241599721,6.18779816770305,-3.08384565278568;-3.09184645654734,6.18038509312953,-3.08021580110356;-3.08807020851435,6.17295054116217,-3.07657473162022;-3.08428381882362,6.16549481164314,-3.07292259724004;-3.08048743323675,6.15801820204726,-3.06925954966433;-3.07668119635992,6.15052100749885,-3.06558573939992;-3.07286525165216,6.14300352078854,-3.06190131576765;-3.06903974143339,6.13546603238972,-3.05820642691078;-3.06520480689261,6.12790883047511,-3.05450121980338;-3.06136058809595,6.12033220093316,-3.05078584025864;-3.05750722399464,6.11273642738422,-3.04706043293713;-3.05364485243295,6.10512179119675,-3.04332514135496;-3.04977361015611,6.09748857150330,-3.03958010789200;-3.04589363281807,6.08983704521650,-3.03582547379989;-3.04200505498936,6.08216748704477,-3.03206137921010;-3.03810801016475,6.07448016950811,-3.02828796314192;-3.03420263077093,6.06677536295365,-3.02450536351035;-3.03028904817417,6.05905333557116,-3.02071371713398;-3.02636739268781,6.05131435340835,-3.01691315974279;-3.02243779357981,6.04355868038624,-3.01310382598590;-3.01850037908023,6.03578657831426,-3.00928584943929;-3.01455527638859,6.02799830690533,-3.00545936261344;-3.01060261168126,6.02019412379082,-3.00162449696092;-3.00664251011870,6.01237428453530,-2.99778138288389;-3.00267509585284,6.00453904265149,-2.99393014974169;-2.99870049203414,5.99668864961471,-2.99007092585818;-2.99471882081885,5.98882335487753,-2.98620383852918;-2.99073020337605,5.98094340588416,-2.98232901402978;-2.98673475989471,5.97304904808481,-2.97844657762162;-2.98273260959074,5.96514052494995,-2.97455665356015;-2.97832450333465,5.95641526398865,-2.97025672064258;-2.97391336781540,5.94768323794594,-2.96595301585592;-2.96949929375245,5.93894463293833,-2.96164563465093;-2.96508237110999,5.93019963354112,-2.95733467169248;-2.96066268910224,5.92144842279912,-2.95302022086498;-2.95624033619873,5.91269118223746,-2.94870237527792;-2.95181540012950,5.90392809187220,-2.94438122727126;-2.94738796789039,5.89515933022108,-2.94005686842090;-2.94295812574807,5.88638507431381,-2.93572938954395;-2.93852595924528,5.87760549970274,-2.93139888070416;-2.93409155320587,5.86882078047314,-2.92706543121710;-2.92965499173985,5.86003108925352,-2.92272912965551;-2.92521635824848,5.85123659722597,-2.91839006385452;-2.92077573542920,5.84243747413622,-2.91404832091676;-2.91633320528061,5.83363388830385,-2.90970398721760;-2.91188884910741,5.82482600663228,-2.90535714841022;-2.90744274752529,5.81601399461879,-2.90100788943072;-2.90299498046579,5.80719801636445,-2.89665629450315;-2.89854562718111,5.79837823458385,-2.89230244714453;-2.89409476624896,5.78955481061508,-2.88794643016989;-2.88964247557726,5.78072790442926,-2.88358832569712;-2.88518883240893,5.77189767464030,-2.87922821515196;-2.88073391332654,5.76306427851447,-2.87486617927288;-2.87627779425706,5.75422787197988,-2.87050229811591;-2.87182055047639,5.74538860963600,-2.86613665105946;-2.86736225661408,5.73654664476304,-2.86176931680913;-2.86290298665782,5.72770212933124,-2.85740037340245;-2.85844281395805,5.71885521401024,-2.85302989821360;-2.85398181123245,5.71000604817819,-2.84865796795812;-2.84952005057042,5.70115477993091,-2.84428465869755;-2.84505760343754,5.69230155609108,-2.83991004584408;-2.84059454068003,5.68344652221713,-2.83553420416511;-2.83613093252911,5.67458982261234,-2.83115720778790;-2.83166684860538,5.66573160033360,-2.82677913020400;-2.82720235792315,5.65687199720037,-2.82240004427383;-2.82273752889479,5.64801115380347,-2.81802002223116;-2.81827242933495,5.63914920951370,-2.81363913568750;-2.81380712646487,5.63028630249067,-2.80925745563657;-2.80934168691656,5.62142256969124,-2.80487505245866;-2.80487617673705,5.61255814687823,-2.80049199592501;-2.80041066139248,5.60369316862880,-2.79610835520212;-2.79594520577230,5.59482776834294,-2.79172419885603;-2.79147987419340,5.58596207825193,-2.78733959485668;-2.78701473040411,5.57709622942650,-2.78295461058201;-2.78254983758834,5.56823035178523,-2.77856931282231;-2.77808525836957,5.55936457410271,-2.77418376778431;-2.77362105481488,5.55049902401781,-2.76979804109543;-2.76915728843887,5.54163382804156,-2.76541219780777;-2.76469402020771,5.53276911156546,-2.76102630240238;-2.76023131054293,5.52390499886929,-2.75664041879320;-2.75576921932545,5.51504161312915,-2.75225461033117;-2.75130780589936,5.50617907642531,-2.74786893980824;-2.74684712907580,5.49731750975010,-2.74348346946136;-2.74238724713678,5.48845703301561,-2.73909826097644;-2.73792821783896,5.47959776506152,-2.73471337549229;-2.73347009841744,5.47073982366271,-2.73032887360457;-2.72901294558946,5.46188332553689,-2.72594481536958;-2.72455681555818,5.45302838635225,-2.72156126030825;-2.72010176401632,5.44417512073492,-2.71717826740986;-2.71564784614984,5.43532364227642,-2.71279589513590;-2.71119511664161,5.42647406354122,-2.70841420142389;-2.70674362967498,5.41762649607395,-2.70403324369103;-2.70229343893742,5.40878105040684,-2.69965307883805;-2.69784459762406,5.39993783606698,-2.69527376325285;-2.69339715844127,5.39109696158348,-2.69089535281416;-2.68895117361013,5.38225853449474,-2.68651790289529;-2.68450669486997,5.37342266135553,-2.68214146836766;-2.68006377348184,5.36458944774410,-2.67776610360448;-2.67562246023194,5.35575899826918,-2.67339186248428;-2.67118280543507,5.34693141657698,-2.66901879839450;-2.66674485893802,5.33810680535815,-2.66464696423503;-2.66230867012296,5.32928526635469,-2.66027641242172;-2.65787428791082,5.32046690036675,-2.65590719488983;-2.65344176076458,5.31165180725944,-2.65153936309756;-2.64901113669260,5.30284008596961,-2.64717296802940;-2.64458246325194,5.29403183451253,-2.64280806019965;-2.64015578755161,5.28522714998862,-2.63844468965575;-2.63573115625581,5.27642612858998,-2.63408290598166;-2.63130861558715,5.26762886560699,-2.62972275830121;-2.62688821132990,5.25883545543493,-2.62536429528145;-2.62246998883311,5.25004599158033,-2.62100756513593;-2.61805399301380,5.24126056666748,-2.61665261562798;-2.61364026836011,5.23247927244487,-2.61229949407397;-2.60922885893440,5.22370219979142,-2.60794824734654;-2.60481980837636,5.21492943872297,-2.60359892187788;-2.60041315990606,5.20616107839837,-2.59925156366281;-2.59600895632704,5.19739720712584,-2.59490621826204;-2.59160724002933,5.18863791236911,-2.59056293080529;-2.58720805299246,5.17988328075351,-2.58622174599442;-2.58281143678845,5.17113339807215,-2.58188270810654;-2.57841743258477,5.16238834929196,-2.57754586099707;-2.57402608114737,5.15364821855971,-2.57321124810289;-2.56963742284350,5.14491308920793,-2.56887891244525;-2.56525149764470,5.13618304376096,-2.56454889663294;-2.56086834512967,5.12745816394072,-2.56022124286516;-2.55648800448714,5.11873853067269,-2.55589599293461;-2.55211051451876,5.11002422409166,-2.55157318823042;-2.54773591364185,5.10131532354751,-2.54725286974103;-2.54336423989234,5.09261190761094,-2.54293507805721;-2.53899553092742,5.08391405407922,-2.53861985337490;-2.53436696428264,5.07469343557568,-2.53404221880999;-2.52974356054754,5.06548280233917,-2.52946937182940;-2.52512534137489,5.05628219995819,-2.52490133645465;-2.52051232815415,5.04709167348000,-2.52033813642909;-2.51590454201349,5.03791126741475,-2.51577979522001;-2.51130200382172,5.02874102573937,-2.51122633602063;-2.50670473419014,5.01958099190146,-2.50667778175211;-2.50211275347455,5.01043120882329,-2.50213415506558;-2.49752608177705,5.00129171890558,-2.49759547834410;-2.49294473894797,4.99216256403147,-2.49306177370466;-2.48836874458773,4.98304378557022,-2.48853306300012;-2.48379811804868,4.97393542438110,-2.48400936782116;-2.47923287843699,4.96483752081719,-2.47949070949823;-2.47467304461443,4.95575011472904,-2.47497710910347;-2.47011863520022,4.94667324546849,-2.47046858745261;-2.46556966857283,4.93760695189235,-2.46596516510689;-2.46102616287179,4.92855127236608,-2.46146686237493;-2.45648813599947,4.91950624476744,-2.45697369931461;-2.45195560562284,4.91047190649014,-2.45248569573492;-2.44742858917525,4.90144829444744,-2.44800287119783;-2.44290710385818,4.89243544507576,-2.44352524502012;-2.43839116664296,4.88343339433822,-2.43905283627521;-2.43388079427252,4.87444217772819,-2.43458566379496;-2.42937600326312,4.86546183027282,-2.43012374617147;-2.42487680990600,4.85649238653652,-2.42566710175891;-2.42038323026914,4.84753388062442,-2.42121574867523;-2.41589528019891,4.83858634618588,-2.41676970480402;-2.41141297532175,4.82964981641784,-2.41232898779615;-2.40693633104580,4.82072432406828,-2.40789361507161;-2.40246536256263,4.81180990143955,-2.40346360382122;-2.39800008484878,4.80290658039181,-2.39903897100831;-2.39354051266747,4.79401439234626,-2.39461973337046;-2.38908666057019,4.78513336828859,-2.39020590742122;-2.38463854289829,4.77626353877215,-2.38579750945176;-2.38019617378459,4.76740493392129,-2.38139455553255;-2.37575956715499,4.75855758343459,-2.37699706151506;-2.37132873673000,4.74972151658808,-2.37260504303335;-2.36690369602637,4.74089676223851,-2.36821851550581;-2.36248445835857,4.73208334882645,-2.36383749413668;-2.35807103684040,4.72328130437953,-2.35946199391776;-2.35366344438648,4.71449065651552,-2.35509202962997;-2.34926169371381,4.70571143244552,-2.35072761584499;-2.34486579734326,4.69694365897701,-2.34636876692681;-2.34047576760109,4.68818736251697,-2.34201549703333;-2.33609161662044,4.67944256907494,-2.33766782011794;-2.33171335634280,4.67070930426601,-2.33332574993103;-2.32734099851952,4.66198759331395,-2.32898930002163;-2.32297455471326,4.65327746105411,-2.32465848373883;-2.31861403629942,4.64457893193644,-2.32033331423342;-2.31425945446764,4.63589203002849,-2.31601380445932;-2.31012618110398,4.62764970052926,-2.31191709523793;-2.30599717997137,4.61941565565896,-2.30782437105637;-2.30187247318620,4.61118994142380,-2.30373565585686;-2.29775208260654,4.60297260330188,-2.29965097331182;-2.29363602983400,4.59476368624711,-2.29557034682588;-2.28952433621572,4.58656323469324,-2.29149379953798;-2.28541702284626,4.57837129255772,-2.28742135432328;-2.28131411056957,4.57018790324567,-2.28335303379519;-2.27721561998082,4.56201310965366,-2.27928886030734;-2.27312157142834,4.55384695417364,-2.27522885595552;-2.26903198501548,4.54568947869673,-2.27117304257964;-2.26494688060247,4.53754072461700,-2.26712144176567;-2.26086627780824,4.52940073283527,-2.26307407484753;-2.25679019601234,4.52126954376282,-2.25903096290903;-2.25271865435664,4.51314719732508,-2.25499212678571;-2.24865167174725,4.50503373296541,-2.25095758706679;-2.24458926685626,4.49692918964870,-2.24692736409698;-2.24053145812357,4.48883360586503,-2.24290147797835;-2.23647826375858,4.48074701963323,-2.23887994857219;-2.23242970174207,4.47266946850456,-2.23486279550079;-2.22838578982784,4.46460098956623,-2.23085003814931;-2.22434654554451,4.45654161944490,-2.22684169566755;-2.22031198619723,4.44849139431031,-2.22283778697175;-2.21628212886940,4.44045034987863,-2.21883833074637;-2.21225699042435,4.43241852141604,-2.21484334544583;-2.20823658750705,4.42439594374210,-2.21085284929632;-2.20422093654578,4.41638265123324,-2.20686686029749;-2.20021005375381,4.40837867782609,-2.20288539622419;-2.19620395513102,4.40038405702089,-2.19890847462820;-2.19220265646559,4.39239882188481,-2.19493611283994;-2.18820617333561,4.38442300505537,-2.19096832797015;-2.18421452111068,4.37645663874357,-2.18700513691157;-2.18022771495356,4.36849975473735,-2.18304655634062;-2.17624576982175,4.36055238440473,-2.17909260271906;-2.17226870046907,4.35261455869711,-2.17514329229563;-2.16829652144724,4.34468630815246,-2.17119864110769;-2.16432924710746,4.33676766289850,-2.16725866498286;-2.16036689160196,4.32885865265588,-2.16332337954060;-2.15640946888552,4.32095930674134,-2.15939280019384;-2.15245699271703,4.31306965407082,-2.15546694215056;-2.14850947666103,4.30518972316257,-2.15154582041539;-2.14456693408916,4.29731954214022,-2.14762944979115;-2.14062937818173,4.28945913873587,-2.14371784488042;-2.13669682192917,4.28160854029309,-2.13981102008710;-2.13276927813352,4.27376777376998,-2.13590898961794;-2.12884675940991,4.26593686574216,-2.13201176748406;-2.12492927818802,4.25811584240569,-2.12811936750248;-2.12101684671350,4.25030472958010,-2.12423180329759;-2.11710947704948,4.24250355271133,-2.12034908830271;-2.11320718107791,4.23471233687454,-2.11647123576150;-2.10930997050106,4.22693110677717,-2.11259825872952;-2.10541785684289,4.21915988676164,-2.10873017007559;-2.10153085145045,4.21139870080836,-2.10486698248334;-2.09764896549529,4.20364757253847,-2.10100870845259;-2.09377220997484,4.19590652521667,-2.09715536030085;-2.08990059571374,4.18817558175405,-2.09330695016464;-2.08603413336528,4.18045476471082,-2.08946349000101;-2.08217283341269,4.17274409629916,-2.08562499158891;-2.07831670617050,4.16504359838580,-2.08179146653054;-2.07446576178587,4.15735329249492,-2.07796292625280;-2.07062001023994,4.14967319981069,-2.07413938200862;-2.06677946134913,4.14200334118009,-2.07032084487836;-2.06294412476644,4.13434373711547,-2.06650732577114;-2.05911400998273,4.12669440779725,-2.06269883542618;-2.05528912632807,4.11905537307653,-2.05889538441419;-2.05146948297295,4.11142665247769,-2.05509698313863;-2.04765508892961,4.10380826520100,-2.05130364183708;-2.04384595305323,4.09620023012517,-2.04751537058253;-2.04004208404328,4.08860256580992,-2.04373217928467;-2.03624349044466,4.08101529049852,-2.03995407769121;-2.03245018064902,4.07343842212030,-2.03618107538914;-2.02866216289594,4.06587197829312,-2.03241318180600;-2.02487944527417,4.05831597632593,-2.02865040621117;-2.02110203572280,4.05077043322116,-2.02489275771712;-2.01732994203254,4.04323536567721,-2.02114024528061;-2.01356317184683,4.03571079009088,-2.01739287770403;-2.00980173266306,4.02819672255976,-2.01365066363650;-2.00604563183378,4.02069317888464,-2.00991361157521;-2.00229487656781,4.01320017457195,-2.00618172986657;-1.99854947393141,4.00571772483601,-2.00245502670741;-1.99480943084948,3.99824584460147,-1.99873351014621;-1.99107475410666,3.99078454850560,-1.99501718808428;-1.98734545034846,3.98333385090064,-1.99130606827691;-1.98362152608241,3.97589376585603,-1.98760015833455;-1.97990298767920,3.96846430716080,-1.98389946572404;-1.97618984137375,3.96104548832576,-1.98020399776966;-1.97248209326630,3.95363732258571,-1.97651376165434;-1.96877974932359,3.94623982290182,-1.97282876442078;-1.96508281537988,3.93885300196374,-1.96914901297262;-1.96139129713802,3.93147687219179,-1.96547451407549;-1.95770520017059,3.92411144573924,-1.96180527435818;-1.95402452992091,3.91675673449441,-1.95814130031373;-1.95034929170410,3.90941275008284,-1.95448259830053;-1.94667949070820,3.90207950386947,-1.95082917454344;-1.94301513199510,3.89475700696072,-1.94718103513479;-1.93935622050167,3.88744527020665,-1.94353818603558;-1.93570276104078,3.88014430420303,-1.93990063307646;-1.93205475830225,3.87285411929340,-1.93626838195877;-1.92841221685396,3.86557472557120,-1.93264143825572;-1.92477514114277,3.85830613288178,-1.92901980741329;-1.92099632514829,3.85075242648692,-1.92525507644341;-1.91722406721005,3.84321171871812,-1.92149676152632;-1.91345836445239,3.83568400468634,-1.91774486070998;-1.90969921392762,3.82816927935300,-1.91399937196468;-1.90594661261667,3.82066753753130,-1.91026029318370;-1.90220055742984,3.81317877388772,-1.90652762218410;-1.89846104520738,3.80570298294322,-1.90280135670730;-1.89472807272018,3.79824015907472,-1.89908149441988;-1.89100163667042,3.79079029651633,-1.89536803291419;-1.88728173369221,3.78335338936075,-1.89166096970907;-1.88356836035223,3.77592943156057,-1.88796030225051;-1.87986151315040,3.76851841692955,-1.88426602791233;-1.87616118852047,3.76112033914397,-1.88057814399686;-1.87246738283067,3.75373519174389,-1.87689664773556;-1.86878009238432,3.74636296813442,-1.87322153628971;-1.86509931342049,3.73900366158703,-1.86955280675107;-1.86142504211456,3.73165726524077,-1.86589045614252;-1.85775727457888,3.72432377210357,-1.86223448141866;-1.85409600686333,3.71700317505347,-1.85858487946654;-1.85044123495597,3.70969546683979,-1.85494164710619;-1.84679295478363,3.70240064008450,-1.85130478109136;-1.84315116221244,3.69511868728329,-1.84767427811004;-1.83951585304853,3.68784960080691,-1.84405013478516;-1.83588702303851,3.68059337290226,-1.84043234767517;-1.83226466787013,3.67334999569366,-1.83682091327465;-1.82864878317281,3.66611946118400,-1.83321582801494;-1.82503936451824,3.65890176125593,-1.82961708826472;-1.82143640742092,3.65169688767304,-1.82602469033064;-1.81783990733877,3.64450483208099,-1.82243863045787;-1.81424985967363,3.63732558600866,-1.81885890483075;-1.81066625977189,3.63015914086935,-1.81528550957332;-1.80708910292497,3.62300548796185,-1.81171844074993;-1.80351838436992,3.61586461847160,-1.80815769436582;-1.79995409928996,3.60873652347180,-1.80460326636771;-1.79639624281499,3.60162119392452,-1.80105515264432;-1.79284481002216,3.59451862068184,-1.79751334902698;-1.78929979593638,3.58742879448686,-1.79397785129017;-1.78576119553087,3.58035170597488,-1.79044865515212;-1.78222900372768,3.57328734567444,-1.78692575627530;-1.77870321539821,3.56623570400835,-1.78340915026701;-1.77518382536371,3.55919677129486,-1.77989883267992;-1.77167082839582,3.55217053774859,-1.77639479901261;-1.76816421921709,3.54515699348168,-1.77289704471010;-1.76466399250146,3.53815612850482,-1.76940556516442;-1.76117014287474,3.53116793272817,-1.76592035571509;-1.75768266491521,3.52419239596257,-1.76244141164969;-1.75420155315400,3.51722950792041,-1.75896872820435;-1.75072680207564,3.51027925821670,-1.75550230056429;-1.74725840611856,3.50334163637009,-1.75204212386434;-1.74379635967554,3.49641663180382,-1.74858819318941;-1.74104618094572,3.49092248794498,-1.74585181672782;-1.73829718271125,3.48543057191047,-1.74311647632201;-1.73554939199047,3.47994093869706,-1.74038219993868;-1.73280283554934,3.47445364279066,-1.73764901528628;-1.73005753990330,3.46896873816996,-1.73491694981692;-1.72731353131909,3.46348627831020,-1.73218603072818;-1.72457083581657,3.45800631618689,-1.72945628496508;-1.72182947917054,3.45252890427938,-1.72672773922180;-1.71908948691254,3.44705409457454,-1.72400041994362;-1.71635088433264,3.44158193857040,-1.72127435332865;-1.71361369648118,3.43611248727965,-1.71854956532972;-1.71087794817057,3.43064579123331,-1.71582608165614;-1.70814366397702,3.42518190048415,-1.71310392777544;-1.70541086824227,3.41972086461024,-1.71038312891521;-1.70267958507532,3.41426273271848,-1.70766371006483;-1.69994983835413,3.40880755344801,-1.70494569597722;-1.69722165172736,3.40335537497363,-1.70222911117053;-1.69449504861600,3.39790624500924,-1.69951397992994;-1.69177005221507,3.39246021081124,-1.69680032630931;-1.68904668549529,3.38701731918184,-1.69408817413288;-1.68632497120474,3.38157761647245,-1.69137754699698;-1.68360493187046,3.37614114858698,-1.68866846827169;-1.68088658980013,3.37070796098510,-1.68596096110252;-1.67816996708365,3.36527809868558,-1.68325504841201;-1.67545508559475,3.35985160626944,-1.68055075290141;-1.67274196699260,3.35442852788328,-1.67784809705232;-1.67003063272341,3.34900890724239,-1.67514710312826;-1.66732110402193,3.34359278763396,-1.67244779317629;-1.66461340191309,3.33818021192027,-1.66975018902863;-1.66190754721353,3.33277122254179,-1.66705431230422;-1.65920356053308,3.32736586152024,-1.66436018441026;-1.65650146227639,3.32196417046182,-1.66166782654383;-1.65380127264437,3.31656619056015,-1.65897725969340;-1.65110301163571,3.31117196259934,-1.65628850464038;-1.64840669904842,3.30578152695708,-1.65360158196064;-1.64571235448127,3.30039492360756,-1.65091651202601;-1.64301999733526,3.29501219212453,-1.64823331500585;-1.64032964681513,3.28963337168420,-1.64555201086845;-1.63764132193079,3.28425850106821,-1.64287261938260;-1.63495504149874,3.27888761866654,-1.64019516011901;-1.63227082414356,3.27352076248045,-1.63751965245179;-1.62958868829929,3.26815797012527,-1.63484611555991;-1.62690865221085,3.26279927883336,-1.63217456842866;-1.62423073393546,3.25744472545691,-1.62950502985102;-1.62155495134404,3.25209434647072,-1.62683751842916;-1.61888132212256,3.24674817797505,-1.62417205257579;-1.61620986377347,3.24140625569842,-1.62150865051563;-1.61354059361699,3.23606861500029,-1.61884733028672;-1.61087352879254,3.23073529087386,-1.61618810974188;-1.60820868626005,3.22540631794878,-1.61353100655003;-1.60564962075710,3.22028986396779,-1.61098042575249;-1.60309211747207,3.21517643536285,-1.60843129794853;-1.60053619694487,3.21006607395200,-1.60588364440776;-1.59798187951652,3.20495882115079,-1.60333748619645;-1.59542918533063,3.19985471797523,-1.60079284417896;-1.59287813433482,3.19475380504470,-1.59824973901926;-1.59032874628217,3.18965612258490,-1.59570819118236;-1.58778104073264,3.18456171043062,-1.59316822093576;-1.58523503705448,3.17947060802874,-1.59062984835092;-1.58269075442565,3.17438285444096,-1.58809309330469;-1.58014821183520,3.16929848834666,-1.58555797548068;-1.57760742808465,3.16421754804568,-1.58302451437073;-1.57506842178938,3.15914007146116,-1.58049272927632;-1.57253121138002,3.15406609614222,-1.57796263930989;-1.56999581510375,3.14899565926675,-1.57543426339631;-1.56746225102567,3.14392879764411,-1.57290762027417;-1.56493053703016,3.13886554771784,-1.57038272849722;-1.56240069082222,3.13380594556839,-1.56785960643567;-1.55987272992870,3.12875002691569,-1.56533827227757;-1.55734667169972,3.12369782712189,-1.56281874403012;-1.55482253330992,3.11864938119392,-1.56030103952101;-1.55230033175973,3.11360472378615,-1.55778517639973;-1.54978008387670,3.10856388920296,-1.55527117213887;-1.54726180631675,3.10352691140132,-1.55275904403546;-1.54474551556543,3.09849382399332,-1.55024880921219;-1.54223122793919,3.09346466024879,-1.54774048461877;-1.53971895958661,3.08843945309769,-1.54523408703312;-1.53720872648967,3.08341823513274,-1.54272963306271;-1.53470054446494,3.07840103861183,-1.54022713914577;-1.53219442916484,3.07338789546053,-1.53772662155253;-1.52969039607883,3.06837883727451,-1.53522809638648;-1.52718846053460,3.06337389532196,-1.53273157958558;-1.52468863769932,3.05837310054610,-1.53023708692350;-1.52219094258076,3.05337648356746,-1.52774463401082;-1.51969539002853,3.04838407468635,-1.52525423629623;-1.51720199473523,3.04339590388518,-1.52276590906772;-1.51471077123757,3.03841200083084,-1.52027966745377;-1.51222173391760,3.03343239487701,-1.51779552642455;-1.50973489700381,3.02845711506651,-1.51531350079305;-1.50725027457229,3.02348619013357,-1.51283360521626;-1.50476788054783,3.01851964850614,-1.51035585419635;-1.50228772870508,3.01355751830812,-1.50788026208176;-1.49980983266965,3.00859982736169,-1.50540684306839;-1.49733420591923,3.00364660318947,-1.50293561120069;-1.49486086178464,2.99869787301679,-1.50046658037282;-1.49238981345100,2.99375366377387,-1.49799976432971;-1.48992107395877,2.98881400209805,-1.49553517666823;-1.48745465620481,2.98387891433593,-1.49307283083825;-1.48499057294351,2.97894842654556,-1.49061274014374;-1.48252883678778,2.97402256449853,-1.48815491774383;-1.47998169451463,2.96892492583062,-1.48561089078140;-1.47743749457863,2.96383311027672,-1.48306973310829;-1.47489624588540,2.95874713614984,-1.48053145413935;-1.47235795722258,2.95366702152368,-1.47799606316831;-1.46982263726065,2.94859278423450,-1.47546356936864;-1.46729029455390,2.94352444188293,-1.47293398179452;-1.46476093754131,2.93846201183576,-1.47040730938173;-1.46223457454742,2.93340551122783,-1.46788356094858;-1.45971121378325,2.92835495696370,-1.46536274519679;-1.45719086334711,2.92331036571946,-1.46284487071238;-1.45467353122556,2.91827175394455,-1.46032994596658;-1.45215922529419,2.91323913786342,-1.45781797931671;-1.44964795331854,2.90821253347731,-1.45530897900704;-1.44713972295491,2.90319195656599,-1.45280295316968;-1.44463454175122,2.89817742268943,-1.45029990982542;-1.44213241714789,2.89316894718953,-1.44779985688463;-1.43963335647859,2.88816654519178,-1.44530280214804;-1.43713736697114,2.88317023160697,-1.44280875330768;-1.43464445574833,2.87818002113286,-1.44031771794764;-1.43215462982866,2.87319592825574,-1.43782970354494;-1.42966789612726,2.86821796725222,-1.43534471747038;-1.42718426145661,2.86324615219070,-1.43286276698929;-1.42470373252739,2.85828049693312,-1.43038385926243;-1.42222631594924,2.85332101513651,-1.42790800134675;-1.41975201823159,2.84836772025455,-1.42543520019622;-1.41728084578438,2.84342062553922,-1.42296546266261;-1.41481280491892,2.83847974404235,-1.42049879549630;-1.41234790184857,2.83354508861715,-1.41803520534706;-1.40988614268960,2.82861667191981,-1.41557469876485;-1.40742753346185,2.82369450641098,-1.41311728220055;-1.40497208008960,2.81877860435738,-1.41066296200680;-1.40251978840223,2.81386897783324,-1.40821174443871;-1.40007066413498,2.80896563872184,-1.40576363565466;-1.39762471292974,2.80406859871704,-1.40331864171705;-1.39518194033573,2.79917786932469,-1.40087676859299;-1.39274235181026,2.79429346186417,-1.39843802215516;-1.39030595271945,2.78941538746986,-1.39600240818244;-1.38787274833892,2.78454365709250,-1.39356993236071;-1.38544274385457,2.77967828150079,-1.39114060028357;-1.38301594436320,2.77481927128266,-1.38871441745302;-1.38059235487330,2.76996663684686,-1.38629138928027;-1.37817198030569,2.76512038842419,-1.38387152108636;-1.37575482549425,2.76028053606910,-1.38145481810291;-1.37334089518659,2.75544708966092,-1.37904128547285;-1.37093019404475,2.75062005890535,-1.37663092825106;-1.36852272664585,2.74579945333580,-1.37422375140514;-1.36611849748280,2.74098528231474,-1.37181975981602;-1.36371751096495,2.73617755503506,-1.36941895827869;-1.36131977141878,2.73137628052147,-1.36702135150291;-1.35892528308850,2.72658146763176,-1.36462694411380;-1.35653405013679,2.72179312505817,-1.36223574065258;-1.35414607664541,2.71701126132872,-1.35984774557723;-1.35176136661580,2.71223588480848,-1.35746296326311;-1.34937992396983,2.70746700370088,-1.35508139800366;-1.34700175255034,2.70270462604905,-1.35270305401105;-1.34462685612182,2.69794875973703,-1.35032793541676;-1.34225523837103,2.69319941249107,-1.34795604627234;-1.33988690290762,2.68845659188094,-1.34558739054993;-1.33752185326478,2.68372030532110,-1.34322197214300;-1.33516009289979,2.67899056007201,-1.34085979486688;-1.33280162519470,2.67426736324133,-1.33850086245945;-1.33044645345691,2.66955072178520,-1.33614517858175;-1.32809458091976,2.66484064250938,-1.33379274681858;-1.32574601074314,2.66013713207054,-1.33144357067913;-1.32340074601409,2.65544019697741,-1.32909765359756;-1.32105878974738,2.65074984359199,-1.32675499893364;-1.31872014488612,2.64606607813077,-1.32441560997332;-1.31638481430229,2.64138890666582,-1.32207948992934;-1.31405280079739,2.63671833512606,-1.31974664194181;-1.31172410710294,2.63205436929836,-1.31741706907881;-1.30939873588110,2.62739701482871,-1.31509077433697;-1.30707668972520,2.62274627722335,-1.31276776064201;-1.30475797116037,2.61810216184994,-1.31044803084939;-1.30244258264399,2.61346467393865,-1.30813158774482;-1.30013052656635,2.60883381858331,-1.30581843404483;-1.29782180525111,2.60420960074250,-1.30350857239735;-1.29551642095591,2.59959202524065,-1.30120200538228;-1.29321437587291,2.59498109676919,-1.29889873551202;-1.29091567212928,2.59037681988758,-1.29659876523202;-1.28862031178775,2.58577919902439,-1.29430209692133;-1.28632829684720,2.58118823847844,-1.29200873289317;-1.28403962924309,2.57660394241978,-1.28971867539541;-1.28175431084808,2.57202631489083,-1.28743192661118;-1.27947234347246,2.56745535980734,-1.28514848865933;-1.27719372886474,2.56289108095954,-1.28286836359501;-1.27491846871212,2.55833348201310,-1.28059155341015;-1.27264656464099,2.55378256651015,-1.27831806003402;-1.27037801821749,2.54923833787038,-1.27604788533373;-1.26811283094796,2.54470079939200,-1.27378103111474;-1.26585100427943,2.54016995425272,-1.27151749912134;-1.26359253960017,2.53564580551081,-1.26925729103724;-1.26133743824012,2.53112835610605,-1.26700040848597;-1.25908570147144,2.52661760886079,-1.26474685303145;-1.25683733050892,2.52211356648078,-1.26249662617845;-1.25459232651054,2.51761623155632,-1.26024972937312;-1.25235069057786,2.51312560656308,-1.25800616400339;-1.25011242375657,2.50864169386316,-1.25576593139958;-1.24787752703694,2.50416449570598,-1.25352903283478;-1.24564600135423,2.49969401422924,-1.25129546952536;-1.24341784758926,2.49523025145989,-1.24906524263145;-1.24119306656876,2.49077320931501,-1.24683835325744;-1.23897165906591,2.48632288960276,-1.24461480245235;-1.23675362580075,2.48187929402330,-1.24239459121042;-1.23453896744064,2.47744242416974,-1.24017772047149;-1.23232768460070,2.47301228152894,-1.23796419112146;-1.23011977784429,2.46858886748252,-1.23575400399278;-1.22791524768340,2.46417218330769,-1.23354715986487;-1.22571409457911,2.45976223017816,-1.23134365946461;-1.22351631894207,2.45535900916502,-1.22914350346672;-1.22132192113283,2.45096252123759,-1.22694669249426;-1.21913090146235,2.44657276726431,-1.22475322711903;-1.21694326019242,2.44218974801361,-1.22256310786203;-1.21475899753604,2.43781346415473,-1.22037633519389;-1.21257811365789,2.43344391625861,-1.21819290953528;-1.21040060867469,2.42908110479871,-1.21601283125735;-1.20822648265567,2.42472503015184,-1.21383610068216;-1.20605573562293,2.42037569259899,-1.21166271808308;-1.20388836755191,2.41603309232623,-1.20949268368525;-1.20172437837174,2.41169722942540,-1.20732599766592;-1.19956376796563,2.40736810389499,-1.20516266015492;-1.19740653617134,2.40304571564101,-1.20300267123506;-1.19525268278153,2.39873006447767,-1.20084603094254;-1.19310220754413,2.39442115012827,-1.19869273926732;-1.19095511016277,2.39011897222592,-1.19654279615354;-1.18881139029718,2.38582353031441,-1.19439620149992;-1.18667104756353,2.38153482384891,-1.19225295516017;-1.18453408153483,2.37725285219678,-1.19011305694333;-1.18240049174132,2.37297761463832,-1.18797650661422;-1.18027027767084,2.36870911036759,-1.18584330389378;-1.17814343876921,2.36444733849309,-1.18371344845948;-1.17601997444057,2.36019229803854,-1.18158693994568;-1.17389988404781,2.35594398794365,-1.17946377794401;-1.17178316691288,2.35170240706484,-1.17734396200378;-1.16966982231716,2.34746755417596,-1.17522749163228;-1.16755984950187,2.34323942796907,-1.17311436629524;-1.16545324766836,2.33901802705513,-1.17100458541712;-1.16335001597851,2.33480334996470,-1.16889814838152;-1.16125015355508,2.33059539514870,-1.16679505453151;-1.15915365948205,2.32639416097912,-1.16469530317002;-1.15706053280495,2.32219964574966,-1.16259889356017;-1.15497077253125,2.31801184767652,-1.16050582492564;-1.15288437763067,2.31383076489904,-1.15841609645101;-1.15080134703553,2.30965639548036,-1.15632970728213;-1.14872167964110,2.30548873740822,-1.15424665652643;-1.14664537430590,2.30132778859550,-1.15216694325332;-1.14457242985208,2.29717354688101,-1.15009056649445;-1.14250284506572,2.29302601003006,-1.14801752524414;-1.14043661869716,2.28888517573524,-1.14594781845964;-1.13837374946135,2.28475104161695,-1.14388144506151;-1.13631423603814,2.28062360522417,-1.14181840393394;-1.13425807707263,2.27650286403505,-1.13975869392507;-1.13220527117548,2.27238881545759,-1.13770231384735;-1.13015581692322,2.26828145683022,-1.13564926247779;-1.12810971285857,2.26418078542253,-1.13359953855838;-1.12606695749075,2.26008679843584,-1.13155314079633;-1.12402754929581,2.25599949300381,-1.12951006786444;-1.12199148671690,2.25191886619314,-1.12747031840138;-1.11995876816461,2.24784491500413,-1.12543389101203;-1.11792939201724,2.24377763637129,-1.12340078426776;-1.11590335662115,2.23971702716400,-1.12137099670679;-1.11388066029102,2.23566308418707,-1.11934452683442;-1.11186130131015,2.23161580418137,-1.11732137312341;-1.10984527793076,2.22757518382439,-1.11530153401425;-1.10783258837431,2.22354121973089,-1.11328500791546;-1.10582323083173,2.21951390845343,-1.11127179320385;-1.10381720346378,2.21549324648301,-1.10926188822490;-1.10181450440128,2.21147923024959,-1.10725529129300;-1.09981513174541,2.20747185612272,-1.10525200069173;-1.09781908356802,2.20347112041207,-1.10325201467417;-1.09582635791187,2.19947701936805,-1.10125533146321;-1.09383695279093,2.19548954918230,-1.09926194925177;-1.09185086619066,2.19150870598832,-1.09727186620315;-1.08986809606828,2.18753448586200,-1.09528508045129;-1.08788864035301,2.18356688482213,-1.09330159010101;-1.08591249694640,2.17960589883102,-1.09132139322836;-1.08393966372256,2.17565152379499,-1.08934448788082;-1.08197013852842,2.17170375556495,-1.08737087207763;-1.08000391918403,2.16776258993689,-1.08540054381003;-1.07804100348278,2.16382802265244,-1.08343350104154;-1.07608138919170,2.15990004939939,-1.08146974170822;-1.07412507405169,2.15597866581224,-1.07950926371895;-1.07217205577779,2.15206386747269,-1.07755206495568;-1.07022233205943,2.14815564991015,-1.07559814327368;-1.06827590056067,2.14425400860227,-1.07364749650183;-1.06633275892051,2.14035893897545,-1.07170012244285;-1.06439290475304,2.13647043640535,-1.06975601887359;-1.06245633564779,2.13258849621737,-1.06781518354523;-1.06052304916990,2.12871311368717,-1.06587761418358;-1.05859304286041,2.12484428404116,-1.06394330848932;-1.05666631423647,2.12098200245696,-1.06201226413822;-1.05474286079161,2.11712626406395,-1.06008447878143;-1.05282267999596,2.11327706394370,-1.05815995004568;-1.05090576929648,2.10943439713047,-1.05623867553358;-1.04899212611723,2.10559825861168,-1.05432065282378;-1.04708174785956,2.10176864332837,-1.05240587947129;-1.04517463190237,2.09794554617574,-1.05049435300768;-1.04327077560232,2.09412896200351,-1.04858607094130;-1.04137017629411,2.09031888561647,-1.04668103075758;-1.03947283129061,2.08651531177487,-1.04477922991915;-1.03757873788319,2.08271823519497,-1.04288066586620;-1.03568789334186,2.07892765054936,-1.04098533601660;-1.03380029491557,2.07514355246755,-1.03909323776620;-1.03191593983234,2.07136593553632,-1.03720436848902;-1.03003482529955,2.06759479430018,-1.03531872553750;-1.02815694850415,2.06383012326186,-1.03343630624268;-1.02628230661282,2.06007191688269,-1.03155710791446;-1.02441089677226,2.05632016958303,-1.02968112784182;-1.02254271610933,2.05257487574276,-1.02780836329300;-1.02067776173133,2.04883602970166,-1.02593881151576;-1.01881603072615,2.04510362575982,-1.02407246973755;-1.01695752016251,2.04137765817811,-1.02220933516579;-1.01510222709015,2.03765812117857,-1.02034940498799;-1.01325014854006,2.03394500894481,-1.01849267637206;-1.01140128152465,2.03023831562244,-1.01663914646640;-1.00955562303796,2.02653803531950,-1.01478881240025;-1.00771317005590,2.02284416210682,-1.01294167128377;-1.00587391953638,2.01915669001843,-1.01109772020830;-1.00403786841955,2.01547561305201,-1.00925695624657;-1.00220501362800,2.01180092516921,-1.00741937645286;-1.00037535206694,2.00813262029612,-1.00558497786326;-0.998548880624391,2.00447069232361,-1.00375375749580;-0.996725596171372,2.00081513510771,-1.00192571235070;-0.994905495562107,1.99716594247005,-1.00010083941053;-0.993088575634197,1.99352310819818,-0.998279135640418;-0.991274833208834,1.98988662604600,-0.996460597988264;-0.989464265090940,1.98625648973410,-0.994645223384873;-0.987656868069394,1.98263269295014,-0.992833008744201;-0.985852638917204,1.97901522934927,-0.991023950963524;-0.984051574391669,1.97540409255441,-0.989218046923602;-0.982253671234583,1.97179927615667,-0.987415293488898;-0.980458926172403,1.96820077371573,-0.985615687507742;-0.978667335916426,1.96460857876014,-0.983819225812514;-0.976878897162979,1.96102268478776,-0.982025905219844;-0.975093606593560,1.95744308526599,-0.980235722530749;-0.973311460875056,1.95386977363229,-0.978448674530867;-0.971532456659887,1.95030274329437,-0.976664757990592;-0.969756590586171,1.94674198763062,-0.974883969665255;-0.967983859277925,1.94318749999045,-0.973106306295325;-0.966214259345200,1.93963927369463,-0.971331764606549;-0.964447787384274,1.93609730203558,-0.969560341310147;-0.962684439977791,1.93256157827778,-0.967792033102961;-0.960924213694956,1.92903209565806,-0.966026836667648;-0.959167105091682,1.92550884738594,-0.964264748672837;-0.957413110710749,1.92199182664397,-0.962505765773291;-0.955662227081962,1.91848102658800,-0.960749884610066;-0.953914450722335,1.91497644034762,-0.958997101810703;-0.952169778136229,1.91147806102637,-0.957247413989369;-0.950428205815502,1.90798588170211,-0.955500817747013;-0.948689730239694,1.90449989542733,-0.953757309671550;-0.946954347876155,1.90102009522946,-0.952016886337999;-0.945180899576985,1.89746374253123,-0.950238050995818;-0.943410768946169,1.89391402737064,-0.948462526964952;-0.941643951245064,1.89037094034913,-0.946690309602724;-0.939880441729510,1.88683447205646,-0.944921394260297;-0.938120235649941,1.88330461307099,-0.943155776282797;-0.936363328251492,1.87978135395983,-0.941393451009407;-0.934609714774130,1.87626468527919,-0.939634413773522;-0.932859390452746,1.87275459757451,-0.937878659902827;-0.931112350517301,1.86925108138077,-0.936126184719458;-0.929368590192893,1.86575412722263,-0.934376983540068;-0.927628104699904,1.86226372561472,-0.932631051675978;-0.925890889254105,1.85877986706188,-0.930888384433289;-0.924156939066737,1.85530254205928,-0.929148977112962;-0.922426249344661,1.85183174109277,-0.927412825010977;-0.920698815290431,1.84836745463900,-0.925679923418400;-0.918974632102411,1.84490967316568,-0.923950267621517;-0.917253694974903,1.84145838713181,-0.922223852901954;-0.915535999098207,1.83801358698783,-0.920500674536749;-0.913821539658763,1.83457526317589,-0.918780727798490;-0.912110311839234,1.83114340613005,-0.917064007955408;-0.910402310818623,1.82771800627646,-0.915350510271494;-0.908697531772357,1.82429905403360,-0.913640230006585;-0.906995969872398,1.82088653981246,-0.911933162416485;-0.905297620287347,1.81748045401676,-0.910229302753065;-0.903602478182525,1.81408078704312,-0.908528646264351;-0.901910538720089,1.81068752928129,-0.906831188194644;-0.900221797059121,1.80730067111436,-0.905136923784610;-0.898536248355736,1.80392020291893,-0.903445848271394;-0.896853887763146,1.80054611506527,-0.901757956888686;-0.895174710431795,1.79717839791760,-0.900073244866857;-0.893498711509424,1.79381704183421,-0.898391707433033;-0.891825886141176,1.79046203716768,-0.896713339811198;-0.890156229469696,1.78711337426507,-0.895038137222298;-0.888489736635201,1.78377104346808,-0.893366094884317;-0.886826402775580,1.78043503511325,-0.891697208012381;-0.885166223026504,1.77710533953218,-0.890031471818864;-0.883509192521484,1.77378194705164,-0.888368881513456;-0.881855306391979,1.77046484799381,-0.886709432303274;-0.880204559767488,1.76715403267645,-0.885053119392952;-0.878556947775605,1.76384949141301,-0.883399937984706;-0.876912465542152,1.76055121451293,-0.881749883278462;-0.875271108191235,1.75725919228171,-0.880102950471925;-0.873632870845326,1.75397341502112,-0.878459134760654;-0.871997748625360,1.75069387302935,-0.876818431338170;-0.870365736650825,1.74742055660125,-0.875180835396043;-0.868736830039820,1.74415345602841,-0.873546342123958;-0.867111023909164,1.74089256159938,-0.871914946709825;-0.865488313374457,1.73763786359981,-0.870286644339839;-0.863868693550177,1.73438935231265,-0.868661430198588;-0.862252159549733,1.73114701801824,-0.867039299469104;-0.860674522871191,1.72798284960322,-0.865456357616302;-0.859099766234996,1.72482444472160,-0.863876291923216;-0.857527885717884,1.72167179558891,-0.862299098542688;-0.855958877390994,1.71852489440893,-0.860724773621449;-0.854392737319924,1.71538373337391,-0.859153313300180;-0.852829461564899,1.71224830466485,-0.857584713713677;-0.851269046180815,1.70911860045157,-0.856018970990901;-0.849711487217366,1.70599461289305,-0.854456081255111;-0.848156780719148,1.70287633413755,-0.852896040623967;-0.846604922725733,1.69976375632283,-0.851338845209609;-0.845055909271802,1.69665687157637,-0.849784491118791;-0.843509736387207,1.69355567201553,-0.848232974452949;-0.841966400097084,1.69046014974776,-0.846684291308313;-0.840425896421954,1.68737029687082,-0.845138437776016;-0.838888221377813,1.68428610547294,-0.843595409942183;-0.837353370976211,1.68120756763302,-0.842055203888012;-0.835821341224369,1.67813467542082,-0.840517815689898;-0.834292128125261,1.67506742089716,-0.838983241419514;-0.832765727677701,1.67200579611407,-0.837451477143903;-0.831242135876440,1.66894979311504,-0.835922518925579;-0.829721348712250,1.66589940393512,-0.834396362822608;-0.828203362172035,1.66285462060118,-0.832873004888731;-0.826688172238884,1.65981543513205,-0.831352441173411;-0.825175774892190,1.65678183953869,-0.829834667721957;-0.823666166107718,1.65375382582439,-0.828319680575599;-0.822159341857715,1.65073138598496,-0.826807475771599;-0.820655298110959,1.64771451200885,-0.825298049343296;-0.819154030832888,1.64470319587739,-0.823791397320248;-0.817655535985651,1.64169742956492,-0.822287515728279;-0.816159809528205,1.63869720503896,-0.820786400589580;-0.814666847416396,1.63570251426040,-0.819288047922793;-0.813176645603048,1.63271334918365,-0.817792453743104;-0.811689200038045,1.62972970175685,-0.816299614062324;-0.810204506668385,1.62675156392193,-0.814809524888951;-0.808722561438309,1.62377892761492,-0.813322182228296;-0.807243360289345,1.62081178476601,-0.811837582082533;-0.805766899160389,1.61785012729970,-0.810355720450779;-0.804293173987807,1.61489394713505,-0.808876593329204;-0.802822180705483,1.61194323618576,-0.807400196711079;-0.801353915244926,1.60899798636037,-0.805926526586883;-0.799888373535329,1.60605818956239,-0.804455578944366;-0.798425551503639,1.60312383769047,-0.802987349768624;-0.796965445074653,1.60019492263855,-0.801521835042193;-0.795508050171077,1.59727143629600,-0.800059030745118;-0.794053362713601,1.59435337054779,-0.798598932855017;-0.792601378620997,1.59144071727466,-0.797141537347198;-0.791152093810147,1.58853346835318,-0.795686840194675;-0.789705504196163,1.58563161565603,-0.794234837368300;-0.788261605692413,1.58273515105201,-0.792785524836788;-0.786820394210636,1.57984406640629,-0.791338898566831;-0.785381865660986,1.57695835358050,-0.789894954523148;-0.783946015952108,1.57407800443290,-0.788453688668568;-0.782512840991218,1.57120301081850,-0.787015096964100;-0.781082336684142,1.56833336458918,-0.785579175368986;-0.779654498935421,1.56546905759390,-0.784145919840804;-0.778229323648366,1.56261008167879,-0.782715326335522;-0.776806806725108,1.55975642868727,-0.781287390807555;-0.775386944066688,1.55690809046021,-0.779862109209854;-0.773969731573114,1.55406505883609,-0.778439477493972;-0.772555165143426,1.55122732565107,-0.777019491610117;-0.771143240675757,1.54839488273920,-0.775602147507233;-0.769733954067406,1.54556772193246,-0.774187441133060;-0.768327301214904,1.54274583506099,-0.772775368434213;-0.766923278014060,1.53992921395313,-0.771365925356222;-0.765521880360040,1.53711785043560,-0.769959107843619;-0.764123104147434,1.53431173633363,-0.768554911840006;-0.762726945270289,1.53151086347104,-0.767153333288086;-0.761333399622214,1.52871522367042,-0.765754368129775;-0.759942463096400,1.52592480875323,-0.764358012306223;-0.758554131585698,1.52313961053988,-0.762964261757891;-0.757168400982691,1.52035962084995,-0.761573112424631;-0.755785267179728,1.51758483150223,-0.760184560245715;-0.754404726068995,1.51481523431483,-0.758798601159914;-0.753026773542577,1.51205082110537,-0.757415231105560;-0.751651405492518,1.50929158369107,-0.756034446020605;-0.750278617810859,1.50653751388881,-0.754656241842667;-0.748908406389717,1.50378860351533,-0.753280614509104;-0.747540767121338,1.50104484438730,-0.751907559957076;-0.746175695898130,1.49830622832141,-0.750537074123575;-0.744813188612747,1.49557274713455,-0.749169152945514;-0.743453241158134,1.49284439264386,-0.747803792359771;-0.742095849427577,1.49012115666688,-0.746440988303243;-0.740741009314754,1.48740303102162,-0.745080736712899;-0.739388716713804,1.48469000752674,-0.743723033525852;-0.738038967519360,1.48198207800155,-0.742367874679387;-0.736691757626623,1.47927923426623,-0.741015256111049;-0.735347082931395,1.47658146814185,-0.739665173758667;-0.734004939330137,1.47388877145054,-0.738317623560420;-0.732665322720026,1.47120113601552,-0.736972601454890;-0.731328228998996,1.46851855366129,-0.735630103381115;-0.729993654065799,1.46584101621366,-0.734290125278641;-0.728661593820047,1.46316851549990,-0.732952663087571;-0.727332044162264,1.46050104334881,-0.731617712748620;-0.726005000993931,1.45783859159083,-0.730285270203158;-0.724680460217542,1.45518115205815,-0.728955331393272;-0.723358417736648,1.45252871658478,-0.727627892261809;-0.722038869455901,1.44988127700668,-0.726302948752421;-0.720721811281109,1.44723882516184,-0.724980496809625;-0.719407239119274,1.44460135289036,-0.723660532378840;-0.718095148878647,1.44196885203458,-0.722343051406445;-0.716730673333213,1.43923102778239,-0.720972736515066;-0.715368955865993,1.43649873021506,-0.719605183647654;-0.714009991055494,1.43377194850101,-0.718240387409041;-0.712653773488074,1.43105067182417,-0.716878342411682;-0.711300297757944,1.42833488938399,-0.715519043275658;-0.709949558467204,1.42562459039548,-0.714162484628710;-0.708601550225831,1.42291976408924,-0.712808661106230;-0.707256267651704,1.42022039971147,-0.711457567351293;-0.705913705370607,1.41752648652397,-0.710109198014651;-0.704573858016233,1.41483801380421,-0.708763547754746;-0.703236720230225,1.41215497084534,-0.707420611237752;-0.701902286662144,1.40947734695617,-0.706080383137539;-0.700570551969509,1.40680513146124,-0.704742858135720;-0.699241510817799,1.40413831370083,-0.703408030921654;-0.697915157880454,1.40147688303096,-0.702075896192443;-0.696591487838893,1.39882082882343,-0.700746448652958;-0.695270495382529,1.39617014046584,-0.699419683015852;-0.693952175208763,1.39352480736158,-0.698095594001554;-0.692636522022997,1.39088481892990,-0.696774176338287;-0.691323530538654,1.38825016460587,-0.695455424762087;-0.690013195477167,1.38562083384044,-0.694139334016792;-0.688705511568005,1.38299681610044,-0.692825898854072;-0.687400473548678,1.38037810086863,-0.691515114033436;-0.686098076164731,1.37776467764364,-0.690206974322223;-0.684798314169760,1.37515653594006,-0.688901474495621;-0.683501182325428,1.37255366528843,-0.687598609336691;-0.682206675401464,1.36995605523525,-0.686298373636354;-0.680914788175658,1.36736369534300,-0.685000762193399;-0.679625515433904,1.36477657519017,-0.683705769814520;-0.678338851970150,1.36219468437124,-0.682413391314273;-0.677054792586470,1.35961801249672,-0.681123621515144;-0.675773332093014,1.35704654919316,-0.679836455247505;-0.674494465308045,1.35448028410316,-0.678551887349646;-0.673218187057946,1.35191920688539,-0.677269912667791;-0.671944492177203,1.34936330721459,-0.675990526056075;-0.670673375508430,1.34681257478157,-0.674713722376574;-0.669404831902370,1.34426699929328,-0.673439496499309;-0.668138856217896,1.34172657047273,-0.672167843302242;-0.666875443322031,1.33919127805913,-0.670898757671304;-0.665614588089918,1.33666111180772,-0.669632234500360;-0.664356285404867,1.33413606148998,-0.668368268691263;-0.663100530158338,1.33161611689349,-0.667106855153834;-0.661847317249938,1.32910126782201,-0.665847988805861;-0.660596641587437,1.32659150409546,-0.664591664573119;-0.659348498086785,1.32408681554998,-0.663337877389381;-0.658102881672068,1.32158719203784,-0.662086622196387;-0.656859787275585,1.31909262342758,-0.660837893943908;-0.655619209837777,1.31660309960388,-0.659591687589687;-0.654381144307278,1.31411861046769,-0.658347998099485;-0.653145585640911,1.31163914593616,-0.657106820447084;-0.651936663454117,1.30921321176085,-0.655892482305869;-0.650730116284606,1.30679203725919,-0.654680523189679;-0.649525939671362,1.30437561351794,-0.653470938658521;-0.648324129158947,1.30196393163485,-0.652263724277791;-0.647124680297489,1.29955698271867,-0.651058875618267;-0.645927588642720,1.29715475788915,-0.649856388256138;-0.644732849755995,1.29475724827717,-0.648656257773036;-0.643540459204293,1.29236444502465,-0.647458479756029;-0.642350412560238,1.28997633928469,-0.646263049797651;-0.641162705402104,1.28759292222149,-0.645069963495901;-0.639977333313847,1.28521418501050,-0.643879216454280;-0.638794291885108,1.28284011883835,-0.642690804281793;-0.637613576711231,1.28047071490294,-0.641504722592972;-0.636435183393268,1.27810596441342,-0.640320967007878;-0.635259107537996,1.27574585859025,-0.639139533152121;-0.634085344757945,1.27339038866525,-0.637960416656888;-0.632913890671391,1.27103954588155,-0.636783613158939;-0.631744740902379,1.26869332149371,-0.635609118300629;-0.630577891080730,1.26635170676767,-0.634436927729918;-0.629413336842059,1.26401469298083,-0.633267037100388;-0.628251073827788,1.26168227142202,-0.632099442071258;-0.627091097685157,1.25935443339161,-0.630934138307398;-0.625933404067224,1.25703117020143,-0.629771121479327;-0.624777988632899,1.25471247317488,-0.628610387263249;-0.623624847046931,1.25239833364690,-0.627451931341042;-0.622473974979953,1.25008874296406,-0.626295749400305;-0.621325368108446,1.24778369248447,-0.625141837134316;-0.620179022114795,1.24548317357792,-0.623990190242101;-0.619034932687270,1.24318717762585,-0.622840804428405;-0.617893095520055,1.24089569602136,-0.621693675403729;-0.616753506313248,1.23860872016926,-0.620548798884328;-0.615616160772870,1.23632624148606,-0.619406170592221;-0.614481054610886,1.23404825140005,-0.618265786255213;-0.613348183545209,1.23177474135126,-0.617127641606901;-0.612217543299702,1.22950570279148,-0.615991732386678;-0.611089129604198,1.22724112718434,-0.614858054339750;-0.609962938194506,1.22498100600526,-0.613726603217146;-0.608838964812417,1.22272533074152,-0.612597374775726;-0.607717205205728,1.22047409289227,-0.611470364778203;-0.606597655128223,1.21822728396852,-0.610345568993126;-0.605480310339707,1.21598489549317,-0.609222983194917;-0.604365166606008,1.21374691900107,-0.608102603163870;-0.603252219698976,1.21151334603897,-0.606984424686156;-0.602141465396506,1.20928416816560,-0.605868443553838;-0.601032899482519,1.20705937695161,-0.604754655564869;-0.599926517747017,1.20483896397969,-0.603643056523129;-0.598822315986051,1.20262292084451,-0.602533642238405;-0.597720290001731,1.20041123915274,-0.601426408526403;-0.596620435602258,1.19820391052311,-0.600321351208776;-0.595522748601899,1.19600092658637,-0.599218466113100;-0.594427224821033,1.19380227898537,-0.598117749072924;-0.593333860086129,1.19160795937502,-0.597019195927746;-0.592242650229746,1.18941795942230,-0.595922802523018;-0.591153591090571,1.18723227080633,-0.594828564710179;-0.590066678513399,1.18505088521835,-0.593736478346641;-0.588981908349162,1.18287379436172,-0.592646539295816;-0.587899276454908,1.18070098995195,-0.591558743427096;-0.586818778693829,1.17853246371673,-0.590473086615886;-0.585740410935265,1.17636820739591,-0.589389564743600;-0.584664169054681,1.17420821274151,-0.588308173697650;-0.583590048933730,1.17205247151779,-0.587228909371501;-0.582518046460198,1.16990097550118,-0.586151767664619;-0.581448157528053,1.16775371648038,-0.585076744482524;-0.580380378037417,1.16561068625627,-0.584003835736762;-0.579314703894603,1.16347187664201,-0.582933037344936;-0.578251131012100,1.16133727946302,-0.581864345230704;-0.577189655308579,1.15920688655697,-0.580797755323774;-0.576130272708902,1.15708068977380,-0.579733263559922;-0.575072979144132,1.15495868097577,-0.578670865880998;-0.574017770551527,1.15284085203741,-0.577610558234923;-0.572964642874544,1.15072719484555,-0.576552336575694;-0.571913592062862,1.14861770129937,-0.575496196863406;-0.570864614072358,1.14651236331036,-0.574442135064232;-0.569817704865130,1.14441117280231,-0.573390147150441;-0.568772860409497,1.14231412171140,-0.572340229100407;-0.567730076680008,1.14022120198614,-0.571292376898610;-0.566689349657430,1.13813240558740,-0.570246586535632;-0.565650675328766,1.13604772448842,-0.569202854008172;-0.564614049687245,1.13396715067479,-0.568161175319038;-0.563579468732351,1.13189067614452,-0.567121546477175;-0.562546928469796,1.12981829290798,-0.566083963497640;-0.561516424911534,1.12774999298795,-0.565048422401620;-0.560487954075772,1.12568576841959,-0.564014919216435;-0.559461511986968,1.12362561125049,-0.562983449975547;-0.558437094675822,1.12156951354064,-0.561954010718546;-0.557414698179307,1.11951746736246,-0.560926597491182;-0.556394318540635,1.11746946480079,-0.559901206345332;-0.555375951809282,1.11542549795289,-0.558877833339028;-0.554359594040998,1.11338555892848,-0.557856474536463;-0.553345241297777,1.11134963984968,-0.556837126007968;-0.552332889647898,1.10931773285111,-0.555819783830050;-0.551322535165899,1.10728983007980,-0.554804444085364;-0.550314173932579,1.10526592369522,-0.553791102862721;-0.549307802035030,1.10324600586936,-0.552779756257118;-0.548303415566597,1.10123006878660,-0.551770400369698;-0.547301010626910,1.09921810464384,-0.550763031307788;-0.546300583321868,1.09721010565042,-0.549757645184875;-0.545302129763654,1.09520606402815,-0.548754238120629;-0.544305646070723,1.09320597201133,-0.547752806240886;-0.543311128367819,1.09120982184674,-0.546753345677670;-0.542318572785953,1.08921760579363,-0.545755852569173;-0.541327975462428,1.08722931612372,-0.544760323059772;-0.540339332540824,1.08524494512124,-0.543766753300026;-0.539352640170999,1.08326448508289,-0.542775139446670;-0.538367894509113,1.08128792831787,-0.541785477662641;-0.537385091717579,1.07931526714786,-0.540797764117032;-0.536404227965127,1.07734649390704,-0.539811994985154;-0.535425299426744,1.07538160094207,-0.538828166448480;-0.534448302283723,1.07342058061213,-0.537846274694689;-0.533473232723624,1.07146342528885,-0.536866315917633;-0.532500086940303,1.06951012735640,-0.535888286317364;-0.531528861133902,1.06756067921143,-0.534912182100129;-0.530559551510829,1.06561507326306,-0.533937999478340;-0.529592154283805,1.06367330193295,-0.532965734670635;-0.528626665671810,1.06173535765522,-0.531995383901813;-0.527663081900123,1.05980123287652,-0.531026943402885;-0.526701399200292,1.05787092005595,-0.530060409411036;-0.525741613810160,1.05594441166513,-0.529095778169654;-0.524783721973849,1.05402170018819,-0.528133045928318;-0.523827719941754,1.05210277812173,-0.527172208942792;-0.522873603970557,1.05018763797482,-0.526213263475033;-0.521921370323221,1.04827627226909,-0.525256205793193;-0.520971015268978,1.04636867353858,-0.524301032171606;-0.520022535083343,1.04446483432986,-0.523347738890797;-0.519075926048108,1.04256474720197,-0.522396322237489;-0.518131184451337,1.04066840472646,-0.521446778504583;-0.517188306587361,1.03877579948731,-0.520499103991166;-0.516247288756794,1.03688692408103,-0.519553295002520;-0.515308127266511,1.03500177111657,-0.518609347850105;-0.514370818429664,1.03312033321538,-0.517667258851575;-0.513435358565661,1.03124260301134,-0.516727024330754;-0.512501744000187,1.02936857315087,-0.515788640617663;-0.511569971065179,1.02749823629277,-0.514852104048488;-0.510640036098838,1.02563158510835,-0.513917410965604;-0.509711935445633,1.02376861228137,-0.512984557717567;-0.508785665456283,1.02190931050805,-0.512053540659106;-0.507861222487760,1.02005367249704,-0.511124356151119;-0.506938602903295,1.01820169096945,-0.510197000560687;-0.506017803072361,1.01635335865884,-0.509271470261053;-0.505098819370691,1.01450866831118,-0.508347761631640;-0.504181648180261,1.01266761268492,-0.507425871058037;-0.503266285889279,1.01083018455089,-0.506505794931989;-0.502352728892214,1.00899637669239,-0.505587529651423;-0.501440973589752,1.00716618190509,-0.504671071620406;-0.500531016388834,1.00533959299713,-0.503756417249187;-0.499622853702614,1.00351660278901,-0.502843562954150;-0.498716481950500,1.00169720411367,-0.501932505157858;-0.497811897558106,0.999881389816446,-0.501023240289009;-0.496909096957287,0.998069152755060,-0.500115764782463;-0.496008076586101,0.996260485799608,-0.499210075079213;-0.495125595711213,0.994489078696957,-0.498323067999102;-0.494244809738488,0.992721070234112,-0.497437760758602;-0.493365715458352,0.990956453989147,-0.496554150153592;-0.492488309665956,0.989195223549522,-0.495672232984597;-0.491612589161195,0.987437372512120,-0.494792006056800;-0.490738550748715,0.985682894483261,-0.493913466180054;-0.489866191237902,0.983931783078675,-0.493036610168870;-0.488995507442907,0.982184031923559,-0.492161434842442;-0.488126496182623,0.980439634652533,-0.491287937024625;-0.487259154280706,0.978698584909672,-0.490416113543957;-0.486393478565578,0.976960876348530,-0.489545961233665;-0.485529465870421,0.975226502632108,-0.488677476931653;-0.484667113033185,0.973495457432883,-0.487810657480514;-0.483806416896586,0.971767734432808,-0.486945499727533;-0.482947374308110,0.970043327323309,-0.486082000524684;-0.482089982120031,0.968322229805327,-0.485220156728652;-0.481234237189392,0.966604435589282,-0.484359965200816;-0.480380136378012,0.964889938395086,-0.483501422807253;-0.479527676552498,0.963178731952169,-0.482644526418754;-0.478676854584241,0.961470809999467,-0.481789272910818;-0.477827667349408,0.959766166285412,-0.480935659163645;-0.476980111728967,0.958064794567977,-0.480083682062162;-0.476134184608672,0.956366688614654,-0.479233338496010;-0.475289882879069,0.954671842202456,-0.478384625359546;-0.474447203435495,0.952980249117927,-0.477537539551847;-0.473606143178087,0.951291903157150,-0.476692077976718;-0.472766699011777,0.949606798125745,-0.475848237542686;-0.471928867846293,0.947924927838870,-0.475006015163005;-0.471092646596169,0.946246286121234,-0.474165407755660;-0.470258032180735,0.944570866807094,-0.473326412243368;-0.469425021524127,0.942898663740253,-0.472489025553575;-0.468593611555285,0.941229670774076,-0.471653244618467;-0.467763799207952,0.939563881771481,-0.470819066374963;-0.466935581420680,0.937901290604947,-0.469986487764719;-0.466108955136825,0.936241891156514,-0.469155505734133;-0.465283917304555,0.934585677317788,-0.468326117234342;-0.464460464876846,0.932932642989944,-0.467498319221225;-0.463638594811480,0.931282782083720,-0.466672108655405;-0.462818304071055,0.929636088519430,-0.465847482502249;-0.461999589622977,0.927992556226956,-0.465024437731867;-0.461182448439463,0.926352179145754,-0.464202971319119;-0.460366877497546,0.924714951224861,-0.463383080243612;-0.459552873779068,0.923080866422883,-0.462564761489698;-0.458740434270684,0.921449918708007,-0.461748012046480;-0.457929555963866,0.919822102057999,-0.460932828907812;-0.457120235854893,0.918197410460199,-0.460119209072294;-0.456312470944865,0.916575837911535,-0.459307149543281;-0.455506258239691,0.914957378418514,-0.458496647328881;-0.454701594750095,0.913342025997216,-0.457687699441947;-0.453898477491614,0.911729774673310,-0.456880302900089;-0.453067030228419,0.910060566836855,-0.456044336339183;-0.452237259137996,0.908394721358227,-0.455210052184088;-0.451409160683730,0.906732231152870,-0.454377446895434;-0.450582731336262,0.905073089150711,-0.453546516941059;-0.449757967573479,0.903417288296156,-0.452717258796013;-0.448934865880499,0.901764821548050,-0.451889668942535;-0.448113422749662,0.900115681879668,-0.451063743870050;-0.447293634680521,0.898469862278687,-0.450239480075153;-0.446475498179821,0.896827355747153,-0.449416874061597;-0.445659009761497,0.895188155301474,-0.448595922340285;-0.444844165946658,0.893552253972389,-0.447776621429257;-0.444030963263578,0.891919644804944,-0.446958967853681;-0.443219398247680,0.890290320858475,-0.446142958145836;-0.442409467441528,0.888664275206576,-0.445328588845106;-0.441601167394815,0.887041500937083,-0.444515856497967;-0.440794494664350,0.885421991152052,-0.443704757657977;-0.439989445814048,0.883805738967728,-0.442895288885759;-0.439186017414916,0.882192737514531,-0.442087446749000;-0.438384206045044,0.880582979937025,-0.441281227822427;-0.437584008289590,0.878976459393900,-0.440476628687806;-0.436785420740773,0.877373169057951,-0.439673645933927;-0.435988439997857,0.875773102116046,-0.438872276156590;-0.435193062667144,0.874176251769113,-0.438072515958599;-0.434399285361955,0.872582611232110,-0.437274361949745;-0.433607104702624,0.870992173734002,-0.436477810746796;-0.432816517316488,0.869404932517746,-0.435682858973492;-0.432027519837868,0.867820880840254,-0.434889503260522;-0.431240108908064,0.866240011972383,-0.434097740245522;-0.430454281175343,0.864662319198908,-0.433307566573064;-0.429670033294920,0.863087795818489,-0.432518978894632;-0.428887361928955,0.861516435143666,-0.431731973868629;-0.428106263746538,0.859948230500817,-0.430946548160349;-0.427326735423675,0.858383175230152,-0.430162698441978;-0.426548773643280,0.856821262685676,-0.429380421392574;-0.425772375095161,0.855262486235171,-0.428599713698058;-0.424997536476009,0.853706839260177,-0.427820572051209;-0.424224254489386,0.852154315155959,-0.427042993151639;-0.423452525845716,0.850604907331499,-0.426266973705796;-0.422682347262266,0.849058609209453,-0.425492510426943;-0.421913715463143,0.847515414226142,-0.424719600035147;-0.421146627179274,0.845975315831525,-0.423948239257275;-0.420381079148406,0.844438307489180,-0.423178424826976;-0.419617068115080,0.842904382676269,-0.422410153484669;-0.418854590830630,0.841373534883530,-0.421643421977536;-0.418093644053162,0.839845757615234,-0.420878227059505;-0.417334224547557,0.838321044389187,-0.420114565491246;-0.416576329085441,0.836799388736687,-0.419352434040151;-0.415819954445189,0.835280784202507,-0.418591829480330;-0.415065097411901,0.833765224344873,-0.417832748592594;-0.414311754777399,0.832252702735438,-0.417075188164446;-0.413573271207797,0.830770045032857,-0.416332602385953;-0.412836236429422,0.829290293734555,-0.415591470964903;-0.412100647495519,0.827813442937474,-0.414851790952125;-0.411366501464988,0.826339486749849,-0.414113559404066;-0.410633795402376,0.824868419291183,-0.413376773382786;-0.409902526377867,0.823400234692244,-0.412641429955950;-0.409172691467277,0.821934927095043,-0.411907526196820;-0.408444287752049,0.820472490652822,-0.411175059184250;-0.407717312319239,0.819012919530042,-0.410444026002677;-0.406991762261517,0.817556207902363,-0.409714423742115;-0.406267634677153,0.816102349956637,-0.408986249498149;-0.405544926670012,0.814651339890886,-0.408259500371926;-0.404823635349551,0.813203171914299,-0.407534173470150;-0.404103757830803,0.811757840247204,-0.406810265905073;-0.403385291234379,0.810315339121062,-0.406087774794489;-0.402668232686451,0.808875662778447,-0.405366697261726;-0.401952579318755,0.807438805473041,-0.404647030435642;-0.401238328268576,0.806004761469612,-0.403928771450615;-0.400525476678742,0.804573525043998,-0.403211917446533;-0.399814021697619,0.803145090483095,-0.402496465568793;-0.399103960479102,0.801719452084844,-0.401782412968290;-0.398395290182607,0.800296604158215,-0.401069756801413;-0.397688007973067,0.798876541023195,-0.400358494230033;-0.396982111020917,0.797459257010763,-0.399648622421498;-0.396277596502094,0.796044746462888,-0.398940138548628;-0.395574461598027,0.794633003732509,-0.398233039789705;-0.394872703495629,0.793224023183515,-0.397527323328466;-0.394172319387289,0.791817799190744,-0.396822986354097;-0.393473306470867,0.790414326139949,-0.396120026061224;-0.392775661949680,0.789013598427797,-0.395418439649906;-0.392079383032504,0.787615610461854,-0.394718224325631;-0.391384466933560,0.786220356660560,-0.394019377299302;-0.390690910872508,0.784827831453230,-0.393321895787238;-0.389998712074436,0.783438029280016,-0.392625777011157;-0.389307867769860,0.782050944591913,-0.391931018198176;-0.388618375194709,0.780666571850738,-0.391237616580803;-0.387930231590322,0.779284905529106,-0.390545569396925;-0.387243434203437,0.777905940110428,-0.389854873889805;-0.386557980286187,0.776529670088887,-0.389165527308072;-0.385873867096087,0.775156089969424,-0.388477526905713;-0.385191091896033,0.773785194267726,-0.387790869942071;-0.384509651954288,0.772416977510209,-0.387105553681830;-0.383829544544479,0.771051434234002,-0.386421575395013;-0.383150766945587,0.769688558986933,-0.385738932356969;-0.382473316441938,0.768328346327512,-0.385057621848373;-0.381797190323198,0.766970790824918,-0.384377641155212;-0.381122385884365,0.765615887058979,-0.383698987568779;-0.380448900425759,0.764263629620167,-0.383021658385670;-0.379776731253016,0.762914013109569,-0.382345650907768;-0.379105875677079,0.761567032138879,-0.381670962442242;-0.378424369671761,0.760198636469414,-0.380985530808188;-0.377744223657516,0.758832969636636,-0.380301464997855;-0.377065434754876,0.757470025869281,-0.379618762126238;-0.376388000090502,0.756109799408349,-0.378937419314443;-0.375711916797171,0.754752284507067,-0.378257433689681;-0.375037182013769,0.753397475430884,-0.377578802385252;-0.374363792885276,0.752045366457434,-0.376901522540536;-0.373691746562752,0.750695951876517,-0.376225591300980;-0.373021040203332,0.749349225990078,-0.375551005818086;-0.372351670970206,0.748005183112177,-0.374877763249402;-0.371683636032618,0.746663817568979,-0.374205860758510;-0.371016932565846,0.745325123698723,-0.373535295515015;-0.370351557751192,0.743989095851694,-0.372866064694531;-0.369687508775973,0.742655728390211,-0.372198165478671;-0.369024782833509,0.741325015688596,-0.371531595055037;-0.368363377123108,0.739996952133154,-0.370866350617208;-0.367703288850061,0.738671532122155,-0.370202429364730;-0.367044515225625,0.737348750065801,-0.369539828503100;-0.366387053467012,0.736028600386210,-0.368878545243759;-0.365730900797380,0.734711077517393,-0.368218576804080;-0.365076054445822,0.733396175905231,-0.367559920407358;-0.364422511647350,0.732083890007449,-0.366902573282794;-0.363770269642889,0.730774214293598,-0.366246532665487;-0.363119325679263,0.729467143245026,-0.365591795796425;-0.362469677009183,0.728162671354867,-0.364938359922469;-0.361821320891236,0.726860793128002,-0.364286222296345;-0.361174254589876,0.725561503081051,-0.363635380176632;-0.360528475375409,0.724264795742344,-0.362985830827749;-0.359883980523984,0.722970665651894,-0.362337571519948;-0.359240767317583,0.721679107361387,-0.361690599529299;-0.358598833044003,0.720390115434145,-0.361044912137678;-0.357958174996854,0.719103684445115,-0.360400506632762;-0.357318790475542,0.717819808980840,-0.359757380308011;-0.356680676785257,0.716538483639436,-0.359115530462659;-0.356043831236966,0.715259703030579,-0.358474954401705;-0.355408251147397,0.713983461775465,-0.357835649435900;-0.354773933839032,0.712709754506808,-0.357197612881736;-0.354140876640094,0.711438575868803,-0.356560842061436;-0.353509076884535,0.710169920517109,-0.355925334302940;-0.352878531912022,0.708903783118823,-0.355291086939895;-0.352249239067936,0.707640158352468,-0.354658097311651;-0.351621195703348,0.706379040907957,-0.354026362763238;-0.350994399175017,0.705120425486579,-0.353395880645361;-0.350368846845374,0.703864306800976,-0.352766648314391;-0.349744536082514,0.702610679575118,-0.352138663132350;-0.349121464260183,0.701359538544285,-0.351511922466904;-0.348499628757765,0.700110878455038,-0.350886423691347;-0.347879026960277,0.698864694065208,-0.350262164184594;-0.347259656258351,0.697620980143859,-0.349639141331168;-0.346641514048226,0.696379731471281,-0.349017352521190;-0.346024597731738,0.695140942838956,-0.348396795150369;-0.345408904716309,0.693904609049545,-0.347777466619988;-0.344794432414931,0.692670724916858,-0.347159364336896;-0.344181178246160,0.691439285265838,-0.346542485713495;-0.343569139634107,0.690210284932536,-0.345926828167730;-0.342958314008419,0.688983718764092,-0.345312389123081;-0.342348698804276,0.687759581618709,-0.344699166008547;-0.341740291462373,0.686537868365633,-0.344087156258635;-0.341133089428917,0.685318573885132,-0.343476357313356;-0.340527090155609,0.684101693068474,-0.342866766618208;-0.339922291099636,0.682887220817904,-0.342258381624166;-0.339318689723660,0.681675152046623,-0.341651199787674;-0.338716283495807,0.680465481678766,-0.341045218570630;-0.338115069889656,0.679258204649380,-0.340440435440380;-0.337515046384227,0.678053315904401,-0.339836847869701;-0.336916210463972,0.676850810400638,-0.339234453336797;-0.336318559618767,0.675650683105747,-0.338633249325287;-0.335722091343891,0.674452928998205,-0.338033233324186;-0.335126803140025,0.673257543067296,-0.337434402827907;-0.334532692513236,0.672064520313085,-0.336836755336240;-0.333939756974972,0.670873855746403,-0.336240288354348;-0.333347994042044,0.669685544388816,-0.335644999392752;-0.332757401236618,0.668499581272606,-0.335050885967322;-0.332167976086206,0.667315961440756,-0.334457945599266;-0.331579716123653,0.666134679946919,-0.333866175815120;-0.330992618887128,0.664955731855408,-0.333275574146738;-0.330406681920112,0.663779112241164,-0.332686138131279;-0.329821902771389,0.662604816189739,-0.332097865311198;-0.329238278995030,0.661432838797274,-0.331510753234234;-0.328655808150390,0.660263175170481,-0.330924799453404;-0.328074487802093,0.659095820426615,-0.330340001526984;-0.327494315520023,0.657930769693463,-0.329756357018509;-0.326915288879307,0.656768018109308,-0.329173863496751;-0.326337405460317,0.655607560822922,-0.328592518535719;-0.325760662848647,0.654449392993537,-0.328012319714641;-0.325185058635109,0.653293509790827,-0.327433264617959;-0.324610590415721,0.652139906394887,-0.326855350835313;-0.324037255791697,0.650988577996206,-0.326278575961534;-0.323465052369433,0.649839519795654,-0.325702937596633;-0.322893977760505,0.648692727004463,-0.325128433345794;-0.322324029581644,0.647548194844187,-0.324555060819354;-0.321755205454742,0.646405918546709,-0.323982817632801;-0.321187503006830,0.645265893354198,-0.323411701406764;-0.320620919870072,0.644128114519096,-0.322841709766995;-0.320055453681753,0.642992577304100,-0.322272840344368;-0.319491102084270,0.641859276982137,-0.321705090774860;-0.318927862725121,0.640728208836344,-0.321138458699547;-0.318365733256893,0.639599368160048,-0.320572941764592;-0.317804711337255,0.638472750256743,-0.320008537621232;-0.317244794628943,0.637348350440072,-0.319445243925770;-0.316685980799755,0.636226164033808,-0.318883058339566;-0.316128267522536,0.635106186371827,-0.318321978529024;-0.315571652475171,0.633988412798094,-0.317762002165584;-0.315016133340569,0.632872838666634,-0.317203126925708;-0.314461707806663,0.631759459341525,-0.316645350490876;-0.313908373566390,0.630648270196863,-0.316088670547570;-0.313356128317683,0.629539266616749,-0.315533084787266;-0.312804969763466,0.628432443995270,-0.314978590906425;-0.312254895611634,0.627327797736469,-0.314425186606479;-0.311705903575053,0.626225323254341,-0.313872869593827;-0.311157991371545,0.625125015972795,-0.313321637579819;-0.310611156723876,0.624026871325646,-0.312771488280750;-0.310065397359749,0.622930884756588,-0.312222419417845;-0.309520711011791,0.621837051719174,-0.311674428717255;-0.308977095417546,0.620745367676802,-0.311127513910042;-0.308434548319464,0.619655828102689,-0.310581672732171;-0.307893067464888,0.618568428479851,-0.310036902924503;-0.307352650606047,0.617483164301084,-0.309493202232775;-0.306813295500045,0.616400031068944,-0.308950568407604;-0.306274999908850,0.615319024295723,-0.308408999204464;-0.305737761599288,0.614240139503442,-0.307868492383684;-0.305201578343024,0.613163372223812,-0.307329045710437;-0.304666447916562,0.612088717998227,-0.306790656954726;-0.304132368101230,0.611016172377741,-0.306253323891378;-0.303599336683168,0.609945730923045,-0.305717044300033;-0.303067351453324,0.608877389204452,-0.305181815965133;-0.302536410207438,0.607811142801873,-0.304647636675915;-0.302006510746037,0.606746987304799,-0.304114504226397;-0.301477650874420,0.605684918312280,-0.303582416415370;-0.300949828402651,0.604624931432906,-0.303051371046389;-0.300423041145552,0.603567022284788,-0.302521365927763;-0.299897286922687,0.602511186495539,-0.301992398872546;-0.299372563558355,0.601457419702247,-0.301464467698522;-0.298848868881580,0.600405717551465,-0.300937570228200;-0.298326200726103,0.599356075699187,-0.300411704288807;-0.297804556930370,0.598308489810828,-0.299886867712270;-0.297283935337521,0.597262955561204,-0.299363058335213;-0.296764333795384,0.596219468634516,-0.298840273998945;-0.296245750156460,0.595178024724324,-0.298318512549447;-0.295728182277918,0.594138619533532,-0.297797771837370;-0.295211628021585,0.593101248774371,-0.297278049718018;-0.294696085253932,0.592065908168375,-0.296759344051344;-0.294181551846068,0.591032593446360,-0.296241652701933;-0.293668025673728,0.590001300348409,-0.295724973538999;-0.293155504617267,0.588972024623852,-0.295209304436374;-0.292643986561647,0.587944762031246,-0.294694643272497;-0.292133469396427,0.586919508338355,-0.294180987930405;-0.291623951015754,0.585896259322131,-0.293668336297723;-0.291115429318356,0.584875010768693,-0.293156686266654;-0.290607902207530,0.583855758473312,-0.292646035733972;-0.290101367591130,0.582838498240390,-0.292136382601009;-0.289595823381564,0.581823225883439,-0.291627724773648;-0.289091267495776,0.580809937225063,-0.291120060162313;-0.288587697855245,0.579798628096941,-0.290613386681957;-0.288085112385969,0.578789294339803,-0.290107702252058;-0.287583509018458,0.577781931803418,-0.289603004796602;-0.287082885687725,0.576776536346568,-0.289099292244083;-0.286583240333276,0.575773103837034,-0.288596562527483;-0.286084570899098,0.574771630151572,-0.288094813584270;-0.285586875333655,0.573772111175902,-0.287594043356387;-0.285090151589875,0.572774542804682,-0.287094249790242;-0.284594397625138,0.571778920941491,-0.286595430836697;-0.284099611401274,0.570785241498813,-0.286097584451064;-0.283605790884543,0.569793500398012,-0.285600708593086;-0.283112934045640,0.568803693569323,-0.285104801226941;-0.282621038859669,0.567815816951819,-0.284609860321217;-0.282130103306148,0.566829866493413,-0.284115883848920;-0.281640125368993,0.565845838150817,-0.283622869787448;-0.281151103036504,0.564863727889536,-0.283130816118593;-0.280663034301368,0.563883531683849,-0.282639720828529;-0.280175917160640,0.562905245516789,-0.282149581907801;-0.279689749615736,0.561928865380123,-0.281660397351315;-0.279204529672424,0.560954387274332,-0.281172165158334;-0.278720255340816,0.559981807208597,-0.280684883332461;-0.278236924635357,0.559011121200779,-0.280198549881639;-0.277754535574818,0.558042325277401,-0.279713162818134;-0.277273086182284,0.557075415473628,-0.279228720158531;-0.276792574485146,0.556110387833247,-0.278745219923719;-0.276312998515094,0.555147238408655,-0.278262660138889;-0.275834356308103,0.554185963260835,-0.277781038833521;-0.275356645904428,0.553226558459339,-0.277300354041375;-0.274879865348596,0.552269020082274,-0.276820603800483;-0.274404012689391,0.551313344216277,-0.276341786153138;-0.273929085979850,0.550359526956498,-0.275863899145887;-0.273455083277252,0.549407564406590,-0.275386940829522;-0.272982002643111,0.548457452678682,-0.274910909259071;-0.272509842143162,0.547509187893363,-0.274435802493785;-0.272038599847358,0.546562766179667,-0.273961618597136;-0.271568273829859,0.545618183675051,-0.273488355636802;-0.271098862169018,0.544675436525378,-0.273016011684661;-0.270630362947382,0.543734520884905,-0.272544584816784;-0.270162774251672,0.542795432916256,-0.272074073113420;-0.269696094172784,0.541858168790409,-0.271604474658992;-0.269230320805772,0.540922724686680,-0.271135787542088;-0.268765452249844,0.539989096792695,-0.270668009855448;-0.268301486608353,0.539057281304391,-0.270201139695963;-0.267838421988785,0.538127274425981,-0.269735175164658;-0.267376256502752,0.537199072369941,-0.269270114366685;-0.266914988265984,0.536272671356998,-0.268805955411320;-0.266454615398319,0.535348067616105,-0.268342696411946;-0.265995136023695,0.534425257384427,-0.267880335486051;-0.265536548270140,0.533504236907329,-0.267418870755215;-0.265078850269763,0.532585002438341,-0.266958300345102;-0.264622040158747,0.531667550239160,-0.266498622385453;-0.264166116077342,0.530751876579625,-0.266039835010077;-0.263711076169849,0.529837977737696,-0.265581936356840;-0.263256918584620,0.528925849999439,-0.265124924567657;-0.262803641474041,0.528015489659013,-0.264668797788488;-0.262351242994533,0.527106893018645,-0.264213554169321;-0.261899721306532,0.526200056388619,-0.263759191864172;-0.261449074574492,0.525294976087256,-0.263305709031069;-0.260999300966866,0.524391648440895,-0.262853103832049;-0.260550398656104,0.523490069783881,-0.262401374433146;-0.260102365818643,0.522590236458541,-0.261950519004383;-0.259655200634896,0.521692144815175,-0.261500535719766;-0.259208901289247,0.520795791212031,-0.261051422757273;-0.258763465970039,0.519901172015291,-0.260603178298843;-0.258318892869568,0.519008283599054,-0.260155800530374;-0.257875180184074,0.518117122345322,-0.259709287641710;-0.257432326113732,0.517227684643979,-0.259263637826634;-0.256990328862642,0.516339966892772,-0.258818849282856;-0.256549186638825,0.515453965497301,-0.258374920212012;-0.256108897654208,0.514569676870998,-0.257931848819649;-0.255669460124623,0.513687097435107,-0.257489633315217;-0.255230872269791,0.512806223618673,-0.257048271912066;-0.254793132313321,0.511927051858524,-0.256607762827432;-0.254356238482695,0.511049578599250,-0.256168104282430;-0.253920189009265,0.510173800293191,-0.255729294502047;-0.253484982128240,0.509299713400420,-0.255291331715135;-0.253050616078682,0.508427314388719,-0.254854214154397;-0.252617089103492,0.507556599733573,-0.254417940056383;-0.252184399449409,0.506687565918150,-0.253982507661484;-0.251752545366998,0.505820209433279,-0.253547915213919;-0.251321525110637,0.504954526777435,-0.253114160961727;-0.250891336938518,0.504090514456732,-0.252681243156761;-0.250461979112633,0.503228168984896,-0.252249160054682;-0.250033449898765,0.502367486883249,-0.251817909914944;-0.249605747566483,0.501508464680698,-0.251387491000790;-0.249178870389132,0.500651098913717,-0.250957901579247;-0.248752816643825,0.499795386126325,-0.250529139921109;-0.248327584611437,0.498941322870080,-0.250101204300939;-0.247903172576591,0.498088905704053,-0.249674092997053;-0.247479578827658,0.497238131194818,-0.249247804291517;-0.247056801656741,0.496388995916429,-0.248822336470134;-0.246634839359672,0.495541496450414,-0.248397687822441;-0.246213690236002,0.494695629385748,-0.247973856641698;-0.245793352588994,0.493851391318843,-0.247550841224880;-0.245373824725614,0.493008778853535,-0.247128639872672;-0.244955104956521,0.492167788601055,-0.246707250889454;-0.244537191596065,0.491328417180030,-0.246286672583301;-0.244120082962271,0.490490661216452,-0.245866903265971;-0.243703777376837,0.489654517343671,-0.245447941252896;-0.243288273165125,0.488819982202376,-0.245029784863177;-0.242873568656150,0.487987052440582,-0.244612432419574;-0.242459662182575,0.487155724713606,-0.244195882248500;-0.242046552080703,0.486325995684061,-0.243780132680008;-0.241634236690468,0.485497862021835,-0.243365182047793;-0.241222714355425,0.484671320404074,-0.242951028689170;-0.240811983422747,0.483846367515171,-0.242537670945082;-0.240402042243214,0.483023000046744,-0.242125107160079;-0.239992889171204,0.482201214697627,-0.241713335682317;-0.239584522564690,0.481381008173848,-0.241302354863548;-0.239176940785227,0.480562377188620,-0.240892163059114;-0.238770142197945,0.479745318462318,-0.240482758627937;-0.238364125171543,0.478929828722465,-0.240074139932511;-0.237958888078282,0.478115904703726,-0.239666305338899;-0.237554429293976,0.477303543147880,-0.239259253216718;-0.237150747197981,0.476492740803808,-0.238852981939135;-0.236747840173192,0.475683494427480,-0.238447489882862;-0.236345706606034,0.474875800781940,-0.238042775428142;-0.235944344886453,0.474069656637288,-0.237638836958748;-0.235543753407910,0.473265058770666,-0.237235672861970;-0.235143930567371,0.472462003966240,-0.236833281528609;-0.234744874765301,0.471660489015188,-0.236431661352971;-0.234346584405658,0.470860510715685,-0.236030810732858;-0.233949057895881,0.470062065872884,-0.235630728069560;-0.233552293646885,0.469265151298906,-0.235231411767850;-0.233156290073055,0.468469763812818,-0.234832860235969;-0.232761045592235,0.467675900240623,-0.234435071885630;-0.232366558625722,0.466883557415244,-0.234038045132000;-0.231972827598258,0.466092732176506,-0.233641778393697;-0.231579850938027,0.465303421371131,-0.233246270092786;-0.231187627076637,0.464515621852702,-0.232851518654762;-0.230796154449123,0.463729330481673,-0.232457522508552;-0.230405431493934,0.462944544125334,-0.232064280086502;-0.230015456652926,0.462161259657809,-0.231671789824370;-0.229626228371357,0.461379473960033,-0.231280050161323;-0.229237745097879,0.460599183919743,-0.230889059539924;-0.228850005284526,0.459820386431458,-0.230498816406127;-0.228463007386711,0.459043078396466,-0.230109319209268;-0.228076749863218,0.458267256722812,-0.229720566402062;-0.227691231176197,0.457492918325279,-0.229332556440591;-0.227306449791148,0.456720060125376,-0.228945287784298;-0.226922404176924,0.455948679051320,-0.228558758895979;-0.226539092805718,0.455178772038025,-0.228172968241778;-0.226156514153056,0.454410336027089,-0.227787914291180;-0.225774666697790,0.453643367966770,-0.227403595516998;-0.225393548922093,0.452877864811982,-0.227020010395372;-0.225013159311448,0.452113823524275,-0.226637157405758;-0.224633496354642,0.451351241071820,-0.226255035030924;-0.224254558543762,0.450590114429398,-0.225873641756938;-0.223876344374182,0.449830440578381,-0.225492976073167;-0.223498852344561,0.449072216506722,-0.225113036472263;-0.223122080956831,0.448315439208937,-0.224733821450162;-0.222746028716195,0.447560105686092,-0.224355329506071;-0.222370694131114,0.446806212945789,-0.223977559142466;-0.221996075713307,0.446053758002153,-0.223600508865083;-0.221622171977736,0.445302737875812,-0.223224177182909;-0.221248981442605,0.444553149593889,-0.222848562608175;-0.220876502629348,0.443804990189984,-0.222473663656355;-0.220504734062627,0.443058256704165,-0.222099478846149;-0.220133674270320,0.442312946182943,-0.221726006699483;-0.219763321783519,0.441569055679272,-0.221353245741501;-0.219393675136515,0.440826582252520,-0.220981194500554;-0.219024732866802,0.440085522968468,-0.220609851508200;-0.218656493515059,0.439345874899288,-0.220239215299189;-0.218288955625152,0.438607635123533,-0.219869284411461;-0.217922117744119,0.437870800726119,-0.219500057386139;-0.217555978422170,0.437135368798313,-0.219131532767518;-0.217190536212673,0.436401336437718,-0.218763709103062;-0.216825789672156,0.435668700748264,-0.218396584943398;-0.216461737360292,0.434937458840189,-0.218030158842305;-0.216098377839893,0.434207607830023,-0.217664429356707;-0.215735709676910,0.433479144840581,-0.217299395046672;-0.215373731440417,0.432752067000943,-0.216935054475397;-0.215012441702609,0.432026371446445,-0.216571406209208;-0.214651839038797,0.431302055318664,-0.216208448817551;-0.214291922027393,0.430579115765398,-0.215846180872980;-0.213932689249914,0.429857549940660,-0.215484600951159;-0.213574139290968,0.429137355004666,-0.215123707630850;-0.213216270738247,0.428418528123810,-0.214763499493904;-0.212859082182524,0.427701066470662,-0.214403975125261;-0.212502572217644,0.426984967223949,-0.214045133112938;-0.212146739440516,0.426270227568541,-0.213686972048021;-0.211791582451110,0.425556844695439,-0.213329490524665;-0.211437099852447,0.424844815801763,-0.212972687140080;-0.211083290250591,0.424134138090734,-0.212616560494528;-0.210730152254647,0.423424808771663,-0.212261109191316;-0.210377684476751,0.422716825059939,-0.211906331836788;-0.210025885532065,0.422010184177017,-0.211552227040322;-0.209674754038765,0.421304883350394,-0.211198793414314;-0.209324288618046,0.420600919813613,-0.210846029574186;-0.208974487894099,0.419898290806230,-0.210493934138363;-0.208625350494121,0.419196993573820,-0.210142505728283;-0.208276875048297,0.418497025367949,-0.209791742968373;-0.207929060189796,0.417798383446168,-0.209441644486059;-0.207581904554768,0.417101065071997,-0.209092208911746;-0.207235406782334,0.416405067514916,-0.208743434878820;-0.206889565514579,0.415710388050341,-0.208395321023638;-0.206544379396548,0.415017023959629,-0.208047865985521;-0.206199847076236,0.414324972530046,-0.207701068406749;-0.205855967204587,0.413634231054766,-0.207354926932555;-0.205512738435481,0.412944796832852,-0.207009440211113;-0.205170159425732,0.412256667169248,-0.206664606893542;-0.204828228835078,0.411569839374760,-0.206320425633889;-0.204486945326180,0.410884310766049,-0.205976895089127;-0.204146307564607,0.410200078665612,-0.205634013919150;-0.203806314218841,0.409517140401777,-0.205291780786765;-0.203466963960257,0.408835493308678,-0.204950194357682;-0.203128255463130,0.408155134726257,-0.204609253300517;-0.202790187404617,0.407476062000241,-0.204268956286774;-0.202452758464759,0.406798272482127,-0.203929301990846;-0.202115967326472,0.406121763529183,-0.203590289090010;-0.201779812675537,0.405446532504417,-0.203251916264411;-0.201444293200598,0.404772576776581,-0.202914182197069;-0.201109407593156,0.404099893720145,-0.202577085573861;-0.200775154547559,0.403428480715293,-0.202240625083521;-0.200441532760998,0.402758335147909,-0.201904799417632;-0.200108540933500,0.402089454409556,-0.201569607270619;-0.199776177767924,0.401421835897480,-0.201235047339747;-0.199444441969950,0.400755477014578,-0.200901118325106;-0.199113332248078,0.400090375169402,-0.200567818929613;-0.198782847313617,0.399426527776136,-0.200235147859002;-0.198452985880682,0.398763932254586,-0.199903103821819;-0.198123746666187,0.398102586030172,-0.199571685529415;-0.197795128389838,0.397442486533909,-0.199240891695939;-0.197467129774128,0.396783631202400,-0.198910721038334;-0.197139749544329,0.396126017477819,-0.198581172276330;-0.196812986428488,0.395469642807900,-0.198252244132434;-0.196486839157418,0.394814504645931,-0.197923935331933;-0.196161306464696,0.394160600450728,-0.197596244602877;-0.195836387086652,0.393507927686638,-0.197269170676081;-0.195512079762368,0.392856483823517,-0.196942712285115;-0.195188383233668,0.392206266336719,-0.196616868166298;-0.194865296245111,0.391557272707086,-0.196291637058693;-0.194542817543989,0.390909500420935,-0.195967017704101;-0.194220945880320,0.390262946970046,-0.195643008847056;-0.193899680006839,0.389617609851651,-0.195319609234813;-0.193579018678995,0.388973486568417,-0.194996817617352;-0.193258960654942,0.388330574628441,-0.194674632747361;-0.192939504695537,0.387688871545231,-0.194353053380239;-0.192620649564330,0.387048374837701,-0.194032078274086;-0.192302394027562,0.386409082030154,-0.193711706189696;-0.191984736854152,0.385770990652268,-0.193391935890552;-0.191667676815702,0.385134098239092,-0.193072766142823;-0.191351212686479,0.384498402331028,-0.192754195715352;-0.191035343243420,0.383863900473820,-0.192436223379656;-0.190720067266118,0.383230590218542,-0.192118847909916;-0.190405383536818,0.382598469121587,-0.191802068082975;-0.190091290840414,0.381967534744658,-0.191485882678327;-0.189774162406188,0.381330496505889,-0.191166635169698;-0.189457635560940,0.380694666215740,-0.190847992735164;-0.189141709053800,0.380060041363974,-0.190529954118117;-0.188826381636676,0.379426619445927,-0.190212518064737;-0.188511652064248,0.378794397962493,-0.189895683323983;-0.188197519093960,0.378163374420107,-0.189579448647583;-0.187883981486012,0.377533546330737,-0.189263812790037;-0.187571038003361,0.376904911211868,-0.188948774508600;-0.187258687411706,0.376277466586493,-0.188634332563284;-0.186946928479485,0.375651209983093,-0.188320485716845;-0.186635759977871,0.375026138935634,-0.188007232734784;-0.186325180680763,0.374402250983547,-0.187694572385332;-0.186015189364779,0.373779543671717,-0.187382503439452;-0.185705784809252,0.373158014550473,-0.187071024670825;-0.185396965796223,0.372537661175572,-0.186760134855851;-0.185088731110433,0.371918481108188,-0.186449832773638;-0.184781079539320,0.371300471914901,-0.186140117205997;-0.184474009873011,0.370683631167683,-0.185830986937437;-0.184167520904314,0.370067956443883,-0.185522440755156;-0.183861611428714,0.369453445326219,-0.185214477449037;-0.183556280244367,0.368840095402764,-0.184907095811641;-0.183251526152093,0.368227904266932,-0.184600294638202;-0.182947347955370,0.367616869517469,-0.184294072726620;-0.182643744460327,0.367006988758434,-0.183988428877452;-0.182340714475739,0.366398259599197,-0.183683361893911;-0.182038256813022,0.365790679654418,-0.183378870581858;-0.181736370286224,0.365184246544040,-0.183074953749794;-0.181435053712020,0.364578957893270,-0.182771610208856;-0.181134305909708,0.363974811332577,-0.182468838772809;-0.180834125701200,0.363371804497672,-0.182166638258042;-0.180534511911016,0.362769935029496,-0.181865007483560;-0.180235463366282,0.362169200574215,-0.181563945270982;-0.179936978896719,0.361569598783198,-0.181263450444529;-0.179639057334639,0.360971127313012,-0.180963521831021;-0.179341697514941,0.360373783825410,-0.180664158259873;-0.179044898275102,0.359777565987314,-0.180365358563084;-0.178748658455171,0.359182471470808,-0.180067121575239;-0.178452976897765,0.358588497953123,-0.179769446133492;-0.178157852448064,0.357995643116627,-0.179472331077570;-0.177863283953800,0.357403904648810,-0.179175775249761;-0.177569270265257,0.356813280242280,-0.178879777494914;-0.177275810235263,0.356223767594740,-0.178584336660425;-0.176982902719181,0.355635364408986,-0.178289451596238;-0.176690546574907,0.355048068392888,-0.177995121154836;-0.176398740662864,0.354461877259382,-0.177701344191235;-0.176107483845994,0.353876788726462,-0.177408119562981;-0.175816774989752,0.353292800517156,-0.177115446130138;-0.175526612962105,0.352709910359531,-0.176823322755292;-0.175236996633519,0.352128115986667,-0.176531748303534;-0.174947924876958,0.351547415136654,-0.176240721642464;-0.174659396567879,0.350967805552577,-0.175950241642178;-0.174371410584222,0.350389284982504,-0.175660307175266;-0.174083965806406,0.349811851179476,-0.175370917116805;-0.173797061117326,0.349235501901497,-0.175082070344355;-0.173510695402343,0.348660234911517,-0.174793765737950;-0.173224867549284,0.348086047977429,-0.174506002180096;-0.172939576448428,0.347512938872049,-0.174218778555762;-0.172654820992508,0.346940905373110,-0.173932093752377;-0.172370600076701,0.346369945263248,-0.173645946659822;-0.172086912598625,0.345800056329991,-0.173360336170426;-0.171803757458330,0.345231236365753,-0.173075261178960;-0.171521133558298,0.344663483167814,-0.172790720582633;-0.171239039803430,0.344096794538314,-0.172506713281080;-0.170957475101045,0.343531168284239,-0.172223238176364;-0.170676438360876,0.342966602217416,-0.171940294172969;-0.170395928495059,0.342403094154491,-0.171657880177788;-0.170115944418133,0.341840641916932,-0.171375995100128;-0.169836485047031,0.341279243331003,-0.171094637851694;-0.169557549301074,0.340718896227763,-0.170813807346590;-0.169279136101969,0.340159598443052,-0.170533502501312;-0.169001244373800,0.339601347817479,-0.170253722234742;-0.168723873043025,0.339044142196416,-0.169974465468142;-0.168447021038468,0.338487979429976,-0.169695731125149;-0.168170687291316,0.337932857373013,-0.169417518131770;-0.167894870735112,0.337378773885106,-0.169139825416377;-0.167619570305750,0.336825726830551,-0.168862651909699;-0.167344784941470,0.336273714078346,-0.168585996544821;-0.167070513582851,0.335722733502183,-0.168309858257171;-0.166796755172809,0.335172782980436,-0.168034235984525;-0.166523508656587,0.334623860396151,-0.167759128666993;-0.166250772981753,0.334075963637037,-0.167484535247017;-0.165978547098195,0.333529090595451,-0.167210454669366;-0.165706829958111,0.332983239168390,-0.166936885881129;-0.165435620516008,0.332438407257477,-0.166663827831711;-0.165164917728699,0.331894592768958,-0.166391279472828;-0.164894720555289,0.331351793613684,-0.166119239758499;-0.164625027957179,0.330810007707103,-0.165847707645046;-0.164355838898054,0.330269232969248,-0.165576682091081;-0.164087152343883,0.329729467324729,-0.165306162057508;-0.163818967262908,0.329190708702720,-0.165036146507514;-0.163551282625644,0.328652955036952,-0.164766634406565;-0.163284097404872,0.328116204265697,-0.164497624722398;-0.163017410575631,0.327580454331761,-0.164229116425022;-0.162751221115217,0.327045703182474,-0.163961108486704;-0.162485528003177,0.326511948769679,-0.163693599881973;-0.162220330221299,0.325979189049721,-0.163426589587608;-0.161955626753614,0.325447421983434,-0.163160076582634;-0.161691416586386,0.324916645536138,-0.162894059848321;-0.161427698708109,0.324386857677621,-0.162628538368174;-0.161164472109500,0.323858056382133,-0.162363511127930;-0.160901735783496,0.323330239628374,-0.162098977115553;-0.160639488725247,0.322803405399486,-0.161834935321228;-0.160377729932112,0.322277551683039,-0.161571384737356;-0.160116458403654,0.321752676471022,-0.161308324358549;-0.159855673141635,0.321228777759837,-0.161045753181627;-0.159595373150008,0.320705853550283,-0.160783670205608;-0.159335557434917,0.320183901847547,-0.160522074431709;-0.159076225004689,0.319662920661201,-0.160260964863336;-0.158817374869828,0.319142908005180,-0.160000340506081;-0.158559006043013,0.318623861897779,-0.159740200367718;-0.158301117539089,0.318105780361646,-0.159480543458195;-0.158043708375067,0.317588661423763,-0.159221368789632;-0.157786777570114,0.317072503115444,-0.158962675376315;-0.157530324145552,0.316557303472322,-0.158704462234691;-0.157274347124851,0.316043060534338,-0.158446728383361;-0.157018845533622,0.315529772345731,-0.158189472843078;-0.156763818399619,0.315017436955033,-0.157932694636743;-0.156509264752725,0.314506052415050,-0.157676392789394;-0.156255183624953,0.313995616782863,-0.157420566328207;-0.156001574050443,0.313486128119809,-0.157165214282491;-0.155748435065448,0.312977584491475,-0.156910335683677;-0.155495765708339,0.312469983967691,-0.156655929565323;-0.155243565019596,0.311963324622513,-0.156401994963098;-0.154991832041799,0.311457604534221,-0.156148530914785;-0.154740565819634,0.310952821785304,-0.155895536460275;-0.154489765399875,0.310448974462452,-0.155643010641558;-0.154239429831390,0.309946060656548,-0.155390952502723;-0.153989558165129,0.309444078462655,-0.155139361089952;-0.153740149454125,0.308943025980010,-0.154888235451512;-0.153491202753482,0.308442901312010,-0.154637574637754;-0.153242717120379,0.307943702566207,-0.154387377701106;-0.152994691614057,0.307445427854296,-0.154137643696072;-0.152747125295822,0.306948075292106,-0.153888371679221;-0.152500017229031,0.306451642999588,-0.153639560709185;-0.152253366479095,0.305956129100813,-0.153391209846659;-0.152007172113474,0.305461531723951,-0.153143318154388;-0.151761433201666,0.304967849001274,-0.152895884697168;-0.151516148815208,0.304475079069134,-0.152648908541838;-0.151271318027671,0.303983220067967,-0.152402388757281;-0.151026939914650,0.303492270142273,-0.152156324414411;-0.150783013553768,0.303002227440609,-0.151910714586174;-0.150539538024662,0.302513090115583,-0.151665558347542;-0.150296512408987,0.302024856323844,-0.151420854775509;-0.150053935790405,0.301537524226068,-0.151176602949084;-0.149811807254582,0.301051091986955,-0.150932801949289;-0.149570125889186,0.300565557775215,-0.150689450859152;-0.149328890783880,0.300080919763564,-0.150446548763708;-0.149088101030316,0.299597176128705,-0.150204094749983;-0.148847755722134,0.299114325051332,-0.149962087907003;-0.148607853954956,0.298632364716110,-0.149720527325779;-0.148364900125536,0.298144268214245,-0.149475888722077;-0.148122399732086,0.297657082350830,-0.149231706361889;-0.147880351839056,0.297170805247847,-0.148987979304776;-0.147638755512987,0.296685435031470,-0.148744706612394;-0.147397609822499,0.296200969832045,-0.148501887348489;-0.147156913838293,0.295717407784094,-0.148259520578896;-0.146916666633140,0.295234747026287,-0.148017605371525;-0.146676867281878,0.294752985701448,-0.147776140796366;-0.146437514861409,0.294272121956536,-0.147535125925478;-0.146198608450690,0.293792153942639,-0.147294559832986;-0.145960147130736,0.293313079814965,-0.147054441595076;-0.145722129984606,0.292834897732829,-0.146814770289991;-0.145484556097400,0.292357605859642,-0.146575544998023;-0.145247424556262,0.291881202362909,-0.146336764801512;-0.145010734450365,0.291405685414213,-0.146098428784841;-0.144774484870911,0.290931053189203,-0.145860536034424;-0.144538674911128,0.290457303867594,-0.145623085638714;-0.144303303666259,0.289984435633145,-0.145386076688186;-0.144068370233565,0.289512446673660,-0.145149508275338;-0.143833873712314,0.289041335180974,-0.144913379494687;-0.143599813203781,0.288571099350944,-0.144677689442762;-0.143366187811236,0.288101737383434,-0.144442437218099;-0.143132996639949,0.287633247482318,-0.144207621921238;-0.142900238797177,0.287165627855457,-0.143973242654717;-0.142667913392165,0.286698876714700,-0.143739298523066;-0.142436019536138,0.286232992275869,-0.143505788632808;-0.142204556342297,0.285767972758750,-0.143272712092447;-0.141973522925813,0.285303816387082,-0.143040068012466;-0.141742918403827,0.284840521388556,-0.142807855505325;-0.141512741895439,0.284378085994794,-0.142576073685452;-0.141282992521709,0.283916508441349,-0.142344721669243;-0.141053669405648,0.283455786967690,-0.142113798575053;-0.140824771672218,0.282995919817197,-0.141883303523193;-0.140596298448321,0.282536905237146,-0.141653235635927;-0.140368248862799,0.282078741478706,-0.141423594037464;-0.140140622046431,0.281621426796926,-0.141194377853958;-0.139913417131924,0.281164959450730,-0.140965586213498;-0.139686633253909,0.280709337702899,-0.140737218246107;-0.139460269548940,0.280254559820073,-0.140509273083739;-0.139234325155486,0.279800624072732,-0.140281749860267;-0.139008799213928,0.279347528735196,-0.140054647711490;-0.138783690866553,0.278895272085607,-0.139827965775115;-0.138558999257553,0.278443852405928,-0.139601703190766;-0.138334723533015,0.277993267981926,-0.139375859099967;-0.138110862840924,0.277543517103172,-0.139150432646148;-0.137887416331148,0.277094598063024,-0.138925422974633;-0.137664383155446,0.276646509158623,-0.138700829232641;-0.137441762467453,0.276199248690882,-0.138476650569278;-0.137219553422681,0.275752814964475,-0.138252886135530;-0.136997755178514,0.275307206287836,-0.138029535084269;-0.136776366894201,0.274862420973138,-0.137806596570235;-0.136555387730856,0.274418457336297,-0.137584069750042;-0.136334816851449,0.273975313696953,-0.137361953782169;-0.136114653420805,0.273532988378467,-0.137140247826957;-0.135894896605599,0.273091479707911,-0.136918951046602;-0.135675545574347,0.272650786016056,-0.136698062605154;-0.135456599497411,0.272210905637369,-0.136477581668512;-0.135238057546985,0.271771836909999,-0.136257507404418;-0.135019918897097,0.271333578175771,-0.136037838982453;-0.134802182723603,0.270896127780180,-0.135818575574034;-0.134584848204180,0.270459484072373,-0.135599716352410;-0.134367914518326,0.270023645405154,-0.135381260492653;-0.134151380847353,0.269588610134959,-0.135163207171662;-0.133935246374384,0.269154376621867,-0.134945555568150;-0.133719510284346,0.268720943229572,-0.134728304862646;-0.133504171763969,0.268288308325386,-0.134511454237487;-0.133289230001783,0.267856470280231,-0.134295002876817;-0.133074684188108,0.267425427468623,-0.134078949966579;-0.132860533515055,0.266995178268669,-0.133863294694513;-0.132646777176519,0.266565721062060,-0.133648036250153;-0.132433414368175,0.266137054234054,-0.133433173824820;-0.132220444287476,0.265709176173481,-0.133218706611619;-0.132007866133648,0.265282085272719,-0.133004633805433;-0.131795679107682,0.264855779927701,-0.132790954602926;-0.131583882412337,0.264430258537895,-0.132577668202528;-0.131372475252128,0.264005519506300,-0.132364773804438;-0.131161456833328,0.263581561239442,-0.132152270610619;-0.130950826363961,0.263158382147354,-0.131940157824793;-0.130740583053797,0.262735980643582,-0.131728434652434;-0.130530726114353,0.262314355145166,-0.131517100300772;-0.130321254758880,0.261893504072637,-0.131306153978777;-0.130112168202368,0.261473425850007,-0.131095594897168;-0.129903465661537,0.261054118904763,-0.130885422268398;-0.129695146354834,0.260635581667853,-0.130675635306656;-0.129487209502427,0.260217812573686,-0.130466233227861;-0.129279654326206,0.259800810060117,-0.130257215249657;-0.129072480049774,0.259384572568446,-0.130048580591413;-0.128865685898443,0.258969098543397,-0.129840328474212;-0.128659271099236,0.258554386433128,-0.129632458120855;-0.128453234880874,0.258140434689209,-0.129424968755850;-0.128247576473780,0.257727241766615,-0.129217859605412;-0.128042295110071,0.257314806123731,-0.129011129897460;-0.127837390023552,0.256903126222323,-0.128804778861608;-0.127632860449720,0.256492200527552,-0.128598805729165;-0.127428705625750,0.256082027507947,-0.128393209733131;-0.127224924790498,0.255672605635411,-0.128187990108190;-0.127021517184493,0.255263933385205,-0.127983146090709;-0.126818482049938,0.254856009235942,-0.127778676918735;-0.126615818630701,0.254448831669586,-0.127574581831987;-0.126413526172312,0.254042399171429,-0.127370860071855;-0.126211603921963,0.253636710230100,-0.127167510881395;-0.126010051128499,0.253231763337543,-0.126964533505326;-0.125808867042417,0.252827556989019,-0.126761927190024;-0.125608050915862,0.252424089683098,-0.126559691183523;-0.125407602002622,0.252021359921641,-0.126357824735506;-0.125207519558126,0.251619366209805,-0.126156327097300;-0.125007802839437,0.251218107056027,-0.125955197521881;-0.124808451105251,0.250817580972019,-0.125754435263858;-0.124609463615892,0.250417786472760,-0.125554039579480;-0.124410839633310,0.250018722076490,-0.125354009726625;-0.124212578421074,0.249620386304702,-0.125154344964801;-0.124014679244369,0.249222777682129,-0.124955044555137;-0.123817141369996,0.248825894736745,-0.124756107760384;-0.123619964066363,0.248429735999749,-0.124557533844910;-0.123423146603483,0.248034300005566,-0.124359322074692;-0.123226688252972,0.247639585291833,-0.124161471717320;-0.123030588288044,0.247245590399392,-0.123963982041988;-0.122834845983508,0.246852313872287,-0.123766852319488;-0.122639460615760,0.246459754257751,-0.123570081822213;-0.122444431462786,0.246067910106199,-0.123373669824149;-0.122249757804155,0.245676779971231,-0.123177615600871;-0.122055438921014,0.245286362409607,-0.122981918429541;-0.121861474096085,0.244896655981252,-0.122786577588903;-0.121667862613664,0.244507659249247,-0.122591592359281;-0.121474603759614,0.244119370779818,-0.122396962022574;-0.121281696821363,0.243731789142330,-0.122202685862252;-0.121089141087900,0.243344912909283,-0.122008763163352;-0.120896935849769,0.242958740656298,-0.121815193212476;-0.120705080399072,0.242573270962117,-0.121621975297787;-0.120513574029457,0.242188502408589,-0.121429108709005;-0.120322416036122,0.241804433580671,-0.121236592737402;-0.120131605715804,0.241421063066410,-0.121044426675801;-0.119941142366780,0.241038389456945,-0.120852609818569;-0.119751025288865,0.240656411346496,-0.120661141461618;-0.119561253783404,0.240275127332355,-0.120470020902396;-0.119371827153270,0.239894536014885,-0.120279247439889;-0.119182744702862,0.239514635997504,-0.120088820374613;-0.118994005738099,0.239135425886686,-0.119898739008611;-0.118805609566419,0.238756904291949,-0.119709002645453;-0.118617555496773,0.238379069825848,-0.119519610590227;-0.118429842839623,0.238001921103974,-0.119330562149542;-0.118242470906938,0.237625456744937,-0.119141856631517;-0.118055439012190,0.237249675370366,-0.118953493345783;-0.117868746470352,0.236874575604901,-0.118765471603479;-0.117682392597894,0.236500156076183,-0.118577790717244;-0.117496376712777,0.236126415414853,-0.118390450001221;-0.117310698134453,0.235753352254538,-0.118203448771045;-0.117125356183859,0.235380965231844,-0.118016786343846;-0.116940350183416,0.235009252986359,-0.117830462038245;-0.116755679457023,0.234638214160635,-0.117644475174343;-0.116571343330055,0.234267847400185,-0.117458825073730;-0.116387341129359,0.233898151353478,-0.117273511059471;-0.116203672183252,0.233529124671931,-0.117088532456108;-0.116020335821515,0.233160766009900,-0.116903888589653;-0.115837331375391,0.232793074024674,-0.116719578787589;-0.115654658177582,0.232426047376471,-0.116535602378863;-0.115472315562245,0.232059684728428,-0.116351958693883;-0.115290302864989,0.231693984746597,-0.116168647064518;-0.115108619422870,0.231328946099932,-0.115985666824088;-0.114927264574392,0.230964567460291,-0.115803017307367;-0.114746237659497,0.230600847502425,-0.115620697850578;-0.114565538019569,0.230237784903969,-0.115438707791387;-0.114385164997423,0.229875378345437,-0.115257046468902;-0.114205117937308,0.229513626510220,-0.115075713223669;-0.114025396184902,0.229152528084570,-0.114894707397669;-0.113845999087304,0.228792081757602,-0.114714028334315;-0.113666925993039,0.228432286221282,-0.114533675378446;-0.113488176252048,0.228073140170424,-0.114353647876329;-0.113309749215686,0.227714642302678,-0.114173945175649;-0.113131644236724,0.227356791318531,-0.113994566625511;-0.112953860669336,0.226999585921294,-0.113815511576435;-0.112776397869105,0.226643024817099,-0.113636779380352;-0.112599255193013,0.226287106714889,-0.113458369390601;-0.112422431999444,0.225931830326418,-0.113280280961928;-0.112245927648173,0.225577194366233,-0.113102513450477;-0.112069741500371,0.225223197551682,-0.112925066213794;-0.111893872918597,0.224869838602898,-0.112747938610819;-0.111718321266792,0.224517116242790,-0.112571130001883;-0.111543085910285,0.224165029197050,-0.112394639748707;-0.111368166215780,0.223813576194129,-0.112218467214398;-0.111193561551358,0.223462755965243,-0.112042611763443;-0.111019271286475,0.223112567244366,-0.111867072761711;-0.110845294791952,0.222763008768214,-0.111691849576445;-0.110671631439983,0.222414079276252,-0.111516941576262;-0.110498280604118,0.222065777510675,-0.111342348131146;-0.110325241659273,0.221718102216411,-0.111168068612451;-0.110152513981716,0.221371052141109,-0.110994102392891;-0.109980096949072,0.221024626035137,-0.110820448846543;-0.109807989940317,0.220678822651572,-0.110647107348839;-0.109636192335772,0.220333640746195,-0.110474077276564;-0.109464703517104,0.219989079077484,-0.110301358007855;-0.109293522867320,0.219645136406611,-0.110128948922196;-0.109122649770767,0.219301811497434,-0.109956849400417;-0.108952083613125,0.218959103116485,-0.109785058824686;-0.108781823781407,0.218617010032975,-0.109613576578510;-0.108611869663956,0.218275531018779,-0.109442402046735;-0.108442220650437,0.217934664848433,-0.109271534615533;-0.108272876131841,0.217594410299124,-0.109100973672408;-0.108103835500479,0.217254766150696,-0.108930718606191;-0.107935098149976,0.216915731185625,-0.108760768807032;-0.107761085628347,0.216566091521672,-0.108585500049467;-0.107587392302705,0.216217093036725,-0.108410552607672;-0.107414017520304,0.215868734420035,-0.108235925825033;-0.107240960629861,0.215521014363785,-0.108061619046406;-0.107068220981546,0.215173931563080,-0.107887631618107;-0.106895797926987,0.214827484715948,-0.107713962887918;-0.106723690819257,0.214481672523322,-0.107540612205075;-0.106551899012881,0.214136493689042,-0.107367578920269;-0.106380421863825,0.213791946919845,-0.107194862385641;-0.106209258729493,0.213448030925356,-0.107022461954780;-0.106038408968725,0.213104744418082,-0.106850376982717;-0.105867871941798,0.212762086113408,-0.106678606825923;-0.105697647010412,0.212420054729585,-0.106507150842307;-0.105527733537697,0.212078648987728,-0.106336008391210;-0.105358130888204,0.211737867611805,-0.106165178833401;-0.105188838427902,0.211397709328633,-0.105994661531077;-0.105019855524175,0.211058172867868,-0.105824455847856;-0.104851181545821,0.210719256962003,-0.105654561148776;-0.104682815863045,0.210380960346356,-0.105484976800291;-0.104514757847458,0.210043281759066,-0.105315702170267;-0.104347006872070,0.209706219941086,-0.105146736627978;-0.104179562311294,0.209369773636176,-0.104978079544105;-0.104012423540932,0.209033941590893,-0.104809730290728;-0.103845589938183,0.208698722554591,-0.104641688241330;-0.103679060881631,0.208364115279410,-0.104473952770785;-0.103512835751245,0.208030118520266,-0.104306523255362;-0.103346913928377,0.207696731034852,-0.104139399072718;-0.103181294795757,0.207363951583628,-0.103972579601893;-0.103015977737487,0.207031778929808,-0.103806064223311;-0.102850962139043,0.206700211839364,-0.103639852318775;-0.102686247387270,0.206369249081013,-0.103473943271460;-0.102521832870374,0.206038889426212,-0.103308336465917;-0.102357717977928,0.205709131649150,-0.103143031288062;-0.102193902100858,0.205379974526742,-0.102978027125179;-0.102030384631448,0.205051416838626,-0.102813323365912;-0.101867164963333,0.204723457367151,-0.102648919400265;-0.101704242491497,0.204396094897372,-0.102484814619597;-0.101541616612268,0.204069328217046,-0.102321008416618;-0.101379286723317,0.203743156116623,-0.102157500185388;-0.101217252223653,0.203417577389240,-0.101994289321313;-0.101055512513621,0.203092590830715,-0.101831375221141;-0.100894066994899,0.202768195239544,-0.101668757282959;-0.100732915070493,0.202444389416884,-0.101506434906190;-0.100572056144735,0.202121172166558,-0.101344407491589;-0.100411489623278,0.201798542295043,-0.101182674441242;-0.100251214913100,0.201476498611466,-0.101021235158562;-0.100091231422489,0.201155039927593,-0.100860089048281;-0.0999315385610497,0.200834165057830,-0.100699235516456;-0.0997721357396962,0.200513872819211,-0.100538673970458;-0.0996130223706484,0.200194162031390,-0.100378403818971;-0.0994541978674309,0.199875031516644,-0.100218424471991;-0.0992956616448694,0.199556480099857,-0.100058735340821;-0.0991374131190858,0.199238506608519,-0.0998993358380688;-0.0989794517074964,0.198921109872715,-0.0997402253776414;-0.0988217768288097,0.198604288725126,-0.0995814033747456;-0.0986643879030219,0.198288042001018,-0.0994228692458822;-0.0985072843514133,0.197972368538232,-0.0992646224088429;-0.0983504655965475,0.197657267177189,-0.0991066622827097;-0.0981939310622660,0.197342736760872,-0.0989489882878485;-0.0980376801736864,0.197028776134828,-0.0987915998459086;-0.0978817123571990,0.196715384147157,-0.0986344963798183;-0.0977260270404643,0.196402559648509,-0.0984776773137826;-0.0975706236524082,0.196090301492075,-0.0983211420732788;-0.0974155016232210,0.195778608533584,-0.0981648900850550;-0.0972606603843536,0.195467479631294,-0.0980089207771266;-0.0971060993685139,0.195156913645989,-0.0978532335787723;-0.0969518180096649,0.194846909440970,-0.0976978279205328;-0.0967978157430208,0.194537465882051,-0.0975427032342063;-0.0966440920050441,0.194228581837552,-0.0973878589528460;-0.0964906462334429,0.193920256178292,-0.0972332945107569;-0.0963374778671681,0.193612487777585,-0.0970790093434937;-0.0961845863464102,0.193305275511236,-0.0969250028878570;-0.0960319711125959,0.192998618257527,-0.0967712745818900;-0.0958796316083856,0.192692514897222,-0.0966178238648761;-0.0957275672776696,0.192386964313549,-0.0964646501773352;-0.0955757775655680,0.192081965392208,-0.0963117529610232;-0.0954242619184233,0.191777517021350,-0.0961591316589251;-0.0952730197838020,0.191473618091586,-0.0960067857152560;-0.0951220506104876,0.191170267495969,-0.0958547145754547;-0.0949713538484809,0.190867464129994,-0.0957029176861833;-0.0948209289489945,0.190565206891591,-0.0955513944953225;-0.0946707753644532,0.190263494681122,-0.0954001444519714;-0.0945208925484875,0.189962326401370,-0.0952491670064411;-0.0943712799559326,0.189661700957535,-0.0950984616102538;-0.0942219370428251,0.189361617257231,-0.0949480277161393;-0.0940728632664009,0.189062074210478,-0.0947978647780331;-0.0939240580850910,0.188763070729695,-0.0946479722510722;-0.0937755209585207,0.188464605729698,-0.0944983495915940;-0.0936272513475031,0.188166678127690,-0.0943489962571302;-0.0934792487140409,0.187869286843260,-0.0941999117064080;-0.0933315125213191,0.187572430798370,-0.0940510953993436;-0.0931840422337067,0.187276108917359,-0.0939025467970431;-0.0930368373167488,0.186980320126930,-0.0937542653617951;-0.0928898972371689,0.186685063356146,-0.0936062505570727;-0.0927432214628619,0.186390337536427,-0.0934585018475267;-0.0925968094628936,0.186096141601540,-0.0933110186989851;-0.0924506607074983,0.185802474487599,-0.0931638005784500;-0.0923047746680733,0.185509335133053,-0.0930168469540937;-0.0921591508171798,0.185216722478686,-0.0928701572952574;-0.0920137886285371,0.184924635467609,-0.0927237310724475;-0.0918686875770208,0.184633073045252,-0.0925775677573322;-0.0917238471386610,0.184342034159365,-0.0924316668227407;-0.0915792667906380,0.184051517760004,-0.0922860277426581;-0.0914349460112819,0.183761522799537,-0.0921406499922258;-0.0912908842800657,0.183472048232623,-0.0919955330477341;-0.0911470810776076,0.183183093016221,-0.0918506763866245;-0.0910035358856644,0.182894656109576,-0.0917060794874831;-0.0908602481871316,0.182606736474220,-0.0915617418300406;-0.0907172174660377,0.182319333073956,-0.0914176628951673;-0.0905744432075435,0.182032444874865,-0.0912738421648712;-0.0904319248979408,0.181746070845294,-0.0911302791222977;-0.0902896620246459,0.181460209955850,-0.0909869732517225;-0.0901476540761997,0.181174861179397,-0.0908439240385520;-0.0900059005422648,0.180890023491051,-0.0907011309693203;-0.0898644009136210,0.180605695868169,-0.0905585935316844;-0.0897231546821663,0.180321877290356,-0.0904163112144259;-0.0895821613409088,0.180038566739443,-0.0902742835074422;-0.0894414203839705,0.179755763199497,-0.0901325099017502;-0.0893009313065794,0.179473465656808,-0.0899909898894794;-0.0891606936050685,0.179191673099882,-0.0898497229638697;-0.0890207067768754,0.178910384519442,-0.0897087086192718;-0.0888809703205354,0.178629598908417,-0.0895679463511395;-0.0887414837356840,0.178349315261943,-0.0894274356560333;-0.0886022465230488,0.178069532577348,-0.0892871760316114;-0.0884632581844516,0.177790249854158,-0.0891471669766317;-0.0883245182228035,0.177511466094085,-0.0890074079909478;-0.0881860261421022,0.177233180301023,-0.0888678985755055;-0.0880477814474303,0.176955391481043,-0.0887286382323411;-0.0879097836449518,0.176678098642387,-0.0885896264645785;-0.0877720322419114,0.176401300795467,-0.0884508627764279;-0.0876345267466296,0.176124996952856,-0.0883123466731808;-0.0874972666685015,0.175849186129282,-0.0881740776612096;-0.0873602515179934,0.175573867341624,-0.0880360552479633;-0.0872234808066420,0.175299039608911,-0.0878982789419673;-0.0870869540470498,0.175024701952311,-0.0877607482528180;-0.0869506707528833,0.174750853395128,-0.0876234626911824;-0.0868146304388712,0.174477492962797,-0.0874864217687946;-0.0866788326208008,0.174204619682881,-0.0873496249984534;-0.0865432768155169,0.173932232585064,-0.0872130718940206;-0.0864079625409174,0.173660330701145,-0.0870767619704172;-0.0862728893159519,0.173388913065033,-0.0869406947436210;-0.0861380566606203,0.173117978712748,-0.0868048697306661;-0.0860034640959683,0.172847526682407,-0.0866692864496380;-0.0858691111440856,0.172577556014225,-0.0865339444196717;-0.0857349973281038,0.172308065750506,-0.0863988431609501;-0.0856011221721941,0.172039054935644,-0.0862639821947007;-0.0854674852015640,0.171770522616112,-0.0861293610431935;-0.0853340859424559,0.171502467840460,-0.0859949792297386;-0.0852009239221434,0.171234889659309,-0.0858608362786830;-0.0850679986689309,0.170967787125350,-0.0857269317154103;-0.0849375809368087,0.170705724941503,-0.0855955549279324;-0.0848073924828933,0.170444123352359,-0.0854644089797830;-0.0846774328567675,0.170182981453374,-0.0853334934177902;-0.0845477016089825,0.169922298341949,-0.0852028077897553;-0.0844181982910506,0.169662073117413,-0.0850723516444456;-0.0842889224554475,0.169402304881030,-0.0849421245315973;-0.0841598736556085,0.169142992735989,-0.0848121260019108;-0.0840310514459242,0.168884135787400,-0.0846823556070472;-0.0839024553817430,0.168625733142291,-0.0845528128996302;-0.0837740850193629,0.168367783909600,-0.0844234974332383;-0.0836459399160346,0.168110287200177,-0.0842944087624076;-0.0835180196299567,0.167853242126772,-0.0841655464426273;-0.0833903237202730,0.167596647804036,-0.0840369100303365;-0.0832628517470728,0.167340503348516,-0.0839084990829250;-0.0831356032713858,0.167084807878647,-0.0837803131587280;-0.0830085778551824,0.166829560514753,-0.0836523518170263;-0.0828817750613691,0.166574760379038,-0.0835246146180418;-0.0827551944537892,0.166320406595585,-0.0833971011229380;-0.0826288355972186,0.166066498290348,-0.0832698108938163;-0.0825026980573634,0.165813034591153,-0.0831427434937128;-0.0823767814008594,0.165560014627687,-0.0830158984865984;-0.0822510851952689,0.165307437531500,-0.0828892754373758;-0.0821256090090789,0.165055302435999,-0.0827628739118767;-0.0820003524116982,0.164803608476438,-0.0826366934768598;-0.0818753149734564,0.164552354789923,-0.0825107337000095;-0.0817504962656014,0.164301540515402,-0.0823849941499334;-0.0816258958602967,0.164051164793660,-0.0822594743961595;-0.0815015133306197,0.163801226767319,-0.0821341740091345;-0.0813773482505599,0.163551725580831,-0.0820090925602222;-0.0812534001950169,0.163302660380473,-0.0818842296217013;-0.0811296687397974,0.163054030314346,-0.0817595847667622;-0.0810061534616141,0.162805834532370,-0.0816351575695068;-0.0808828539380828,0.162558072186274,-0.0815109476049441;-0.0807597697477202,0.162310742429600,-0.0813869544489894;-0.0806369004699440,0.162063844417695,-0.0812631776784633;-0.0805142456850668,0.161817377307707,-0.0811396168710867;-0.0803918049742986,0.161571340258581,-0.0810162716054822;-0.0802695779197417,0.161325732431055,-0.0808931414611696;-0.0801475641043884,0.161080552987655,-0.0807702260185634;-0.0800257631121216,0.160835801092694,-0.0806475248589739;-0.0799041745277106,0.160591475912263,-0.0805250375646018;-0.0797827979368102,0.160347576614234,-0.0804027637185387;-0.0796616329259560,0.160104102368242,-0.0802807029047614;-0.0795406790825671,0.159861052345702,-0.0801588547081350;-0.0794199359949401,0.159618425719785,-0.0800372187144069;-0.0792994032522482,0.159376221665426,-0.0799157945102054;-0.0791790804445411,0.159134439359316,-0.0797945816830405;-0.0790589671627396,0.158893077979898,-0.0796735798212979;-0.0789390629986351,0.158652136707361,-0.0795527885142383;-0.0788193675448899,0.158411614723642,-0.0794322073519982;-0.0786998803950306,0.158171511212414,-0.0793118359255829;-0.0785806011434506,0.157931825359090,-0.0791916738268695;-0.0784615293854051,0.157692556350813,-0.0790717206486010;-0.0783426647170101,0.157453703376455,-0.0789519759843863;-0.0782240067352420,0.157215265626613,-0.0788324394286991;-0.0781055550379312,0.156977242293600,-0.0787131105768718;-0.0779873092237664,0.156739632571453,-0.0785939890250996;-0.0778692688922871,0.156502435655915,-0.0784750743704332;-0.0777514336438848,0.156265650744440,-0.0783563662107800;-0.0776338030797994,0.156029277036187,-0.0782378641449000;-0.0775163768021181,0.155793313732014,-0.0781195677724056;-0.0773991544137741,0.155557760034477,-0.0780014766937592;-0.0772821355185435,0.155322615147826,-0.0778835905102713;-0.0771653197210426,0.155087878277997,-0.0777659088240964;-0.0770487066267289,0.154853548632615,-0.0776484312382354;-0.0769322958418960,0.154619625420982,-0.0775311573565295;-0.0768160869736743,0.154386107854082,-0.0774140867836612;-0.0767000796300271,0.154152995144570,-0.0772972191251508;-0.0765842734197492,0.153920286506771,-0.0771805539873540;-0.0764686679524660,0.153687981156676,-0.0770640909774620;-0.0763532628386299,0.153456078311938,-0.0769478297034974;-0.0762380576895207,0.153224577191870,-0.0768317697743146;-0.0761230521172408,0.152993477017438,-0.0767159107995954;-0.0760082457347167,0.152762777011260,-0.0766002523898497;-0.0758936381556939,0.152532476397600,-0.0764847941564111;-0.0757792289947366,0.152302574402365,-0.0763695357114364;-0.0756650178672266,0.152073070253104,-0.0762544766679043;-0.0755510043893589,0.151843963178997,-0.0761396166396112;-0.0754371881781433,0.151615252410861,-0.0760249552411727;-0.0753235688513995,0.151386937181140,-0.0759104920880188;-0.0752101460277561,0.151159016723899,-0.0757962267963926;-0.0750969193266504,0.150931490274830,-0.0756821589833506;-0.0749838883683245,0.150704357071239,-0.0755682882667582;-0.0748710527738238,0.150477616352043,-0.0754546142652887;-0.0747584121649963,0.150251267357774,-0.0753411365984221;-0.0746459661644893,0.150025309330566,-0.0752278548864425;-0.0745337143957495,0.149799741514158,-0.0751147687504372;-0.0744216564830185,0.149574563153886,-0.0750018778122935;-0.0743097920513337,0.149349773496684,-0.0748891816946979;-0.0741981207265241,0.149125371791073,-0.0747766800211336;-0.0740866421352111,0.148901357287167,-0.0746643724158801;-0.0739753559048039,0.148677729236660,-0.0745522585040093;-0.0738642616634998,0.148454486892830,-0.0744403379113854;-0.0737533590402816,0.148231629510531,-0.0743286102646621;-0.0736426476649160,0.148009156346190,-0.0742170751912820;-0.0735321271679506,0.147787066657803,-0.0741057323194720;-0.0734217971807150,0.147565359704936,-0.0739945812782460;-0.0733116573353156,0.147344034748713,-0.0738836216973987;-0.0732017072646364,0.147123091051821,-0.0737728532075065;-0.0730919466023356,0.146902527878500,-0.0736622754399245;-0.0729823749828454,0.146682344494546,-0.0735518880267859;-0.0728729920413687,0.146462540167298,-0.0734416906009991;-0.0727637974138784,0.146243114165646,-0.0733316827962462;-0.0726547907371150,0.146024065760018,-0.0732218642469816;-0.0725459716485852,0.145805394222381,-0.0731122345884300;-0.0724373397865594,0.145587098826234,-0.0730027934565839;-0.0723288947900718,0.145369178846613,-0.0728935404882039;-0.0722206362989170,0.145151633560076,-0.0727844753208149;-0.0721125639536484,0.144934462244707,-0.0726755975927053;-0.0720046773955778,0.144717664180114,-0.0725669069429257;-0.0718969762667707,0.144501238647415,-0.0724584030112847;-0.0717894602100497,0.144285184929249,-0.0723500854383521;-0.0716821288689864,0.144069502309761,-0.0722419538654508;-0.0715749818879059,0.143854190074606,-0.0721340079346615;-0.0714680189118800,0.143639247510939,-0.0720262472888156;-0.0713612395867284,0.143424673907416,-0.0719186715714966;-0.0712546435590166,0.143210468554193,-0.0718112804270378;-0.0711482304760537,0.142996630742915,-0.0717040735005204;-0.0710419999858912,0.142783159766720,-0.0715970504377720;-0.0709359517373197,0.142570054920230,-0.0714902108853634;-0.0708300853798700,0.142357315499552,-0.0713835544906097;-0.0707244005638096,0.142144940802271,-0.0712770809015667;-0.0706188969401414,0.141932930127452,-0.0711707897670297;-0.0705135741606011,0.141721282775627,-0.0710646807365311;-0.0704084318776579,0.141509998048805,-0.0709587534603406;-0.0703034697445105,0.141299075250456,-0.0708530075894613;-0.0701986874150861,0.141088513685515,-0.0707474427756294;-0.0700940845440398,0.140878312660375,-0.0706420586713124;-0.0699896607867517,0.140668471482890,-0.0705368549297073;-0.0698854157993264,0.140458989462364,-0.0704318312047394;-0.0697813492385889,0.140249865909549,-0.0703269871510584;-0.0696774607620863,0.140041100136646,-0.0702223224240402;-0.0695737500280842,0.139832691457301,-0.0701178366797831;-0.0694702166955653,0.139624639186597,-0.0700135295751067;-0.0693668604242284,0.139416942641055,-0.0699094007675502;-0.0692636808744852,0.139209601138628,-0.0698054499153703;-0.0691606777074607,0.139002613998702,-0.0697016766775407;-0.0690578505849912,0.138795980542090,-0.0695980807137500;-0.0689551991696205,0.138589700091025,-0.0694946616843989;-0.0688527231246024,0.138383771969167,-0.0693914192506015;-0.0687504221138936,0.138178195501585,-0.0692883530741791;-0.0686482958021582,0.137972970014771,-0.0691854628176642;-0.0685463438547609,0.137768094836622,-0.0690827481442937;-0.0684445659377686,0.137563569296443,-0.0689802087180107;-0.0683429617179479,0.137359392724949,-0.0688778442034621;-0.0682415308627629,0.137155564454250,-0.0687756542659959;-0.0681402730403745,0.136952083817858,-0.0686736385716611;-0.0680391879196387,0.136748950150680,-0.0685717967872054;-0.0679382751701044,0.136546162789014,-0.0684701285800732;-0.0678375344620120,0.136343721070546,-0.0683686336184049;-0.0677369654662928,0.136141624334349,-0.0682673115710347;-0.0676365678545665,0.135939871920879,-0.0681661621074900;-0.0675363412991397,0.135738463171972,-0.0680651848979884;-0.0674362854730042,0.135537397430837,-0.0679643796134367;-0.0673364000498373,0.135336674042061,-0.0678637459254309;-0.0672366847039961,0.135136292351595,-0.0677632835062509;-0.0671371391105210,0.134936251706765,-0.0676629920288635;-0.0670377629451305,0.134736551456253,-0.0675628711669174;-0.0669385558842212,0.134537190950108,-0.0674629205947434;-0.0668395176048668,0.134338169539734,-0.0673631399873529;-0.0667406477848140,0.134139486577889,-0.0672635290204344;-0.0666419461024845,0.133941141418685,-0.0671640873703552;-0.0665434122369709,0.133743133417582,-0.0670648147141567;-0.0664450458680361,0.133545461931385,-0.0669657107295553;-0.0663468466761118,0.133348126318242,-0.0668667750949392;-0.0662488143422966,0.133151125937639,-0.0667680074893675;-0.0661509485483559,0.132954460150404,-0.0666694075925700;-0.0660532489767174,0.132758128318690,-0.0665709750849422;-0.0659557153104727,0.132562129805988,-0.0664727096475478;-0.0658583472333753,0.132366463977114,-0.0663746109621155;-0.0657611444298373,0.132171130198207,-0.0662766787110367;-0.0656641065849288,0.131976127836730,-0.0661789125773644;-0.0655672333843776,0.131781456261462,-0.0660813122448129;-0.0654705245145666,0.131587114842502,-0.0659838773977556;-0.0653739796625326,0.131393102951259,-0.0658866077212233;-0.0652775985159630,0.131199419960448,-0.0657895029009010;-0.0651813807631994,0.131006065244099,-0.0656925626231317;-0.0650853260932294,0.130813038177538,-0.0655957865749082;-0.0649894341956911,0.130620338137399,-0.0654991744438770;-0.0648937047608681,0.130427964501609,-0.0654027259183345;-0.0647981374796877,0.130235916649389,-0.0653064406872237;-0.0647027320437240,0.130044193961259,-0.0652103184401384;-0.0646074881451898,0.129852795819022,-0.0651143588673148;-0.0645124054769405,0.129661721605768,-0.0650185616596353;-0.0644174837324711,0.129470970705876,-0.0649229265086253;-0.0643227226059133,0.129280542504999,-0.0648274531064509;-0.0642281217920354,0.129090436390070,-0.0647321411459179;-0.0641336809862415,0.128900651749300,-0.0646369903204721;-0.0640393998845682,0.128711187972167,-0.0645420003241950;-0.0639452781836847,0.128522044449421,-0.0644471708518042;-0.0638513155808912,0.128333220573079,-0.0643525015986522;-0.0637575117741165,0.128144715736420,-0.0642579922607237;-0.0636638664619178,0.127956529333983,-0.0641636425346350;-0.0635703793434783,0.127768660761566,-0.0640694521176323;-0.0634770501186074,0.127581109416225,-0.0639754207075913;-0.0633838784877362,0.127393874696261,-0.0638815480030133;-0.0632908641519203,0.127206956001231,-0.0637878337030272;-0.0631980068128341,0.127020352731936,-0.0636942775073846;-0.0631053061727733,0.126834064290420,-0.0636008791164618;-0.0630127619346504,0.126648090079971,-0.0635076382312553;-0.0629203738019949,0.126462429505110,-0.0634145545533824;-0.0628281414789524,0.126277081971601,-0.0633216277850798;-0.0627360646702814,0.126092046886434,-0.0632288576292006;-0.0626441430813525,0.125907323657829,-0.0631362437892135;-0.0625523764181506,0.125722911695242,-0.0630437859692050;-0.0624607643872660,0.125538810409340,-0.0629514838738707;-0.0623693066959008,0.125355019212024,-0.0628593372085212;-0.0622780030518632,0.125171537516407,-0.0627673456790767;-0.0621868531635667,0.124988364736819,-0.0626755089920664;-0.0620958567400296,0.124805500288807,-0.0625838268546275;-0.0620050134908729,0.124622943589123,-0.0624922989745033;-0.0619143231263201,0.124440694055734,-0.0624009250600434;-0.0618237853571947,0.124258751107807,-0.0623097048202005;-0.0617333998949184,0.124077114165714,-0.0622186379645291;-0.0616431664515111,0.123895782651027,-0.0621277242031852;-0.0615530847395898,0.123714755986514,-0.0620369632469254;-0.0614631544723658,0.123534033596141,-0.0619463548071042;-0.0613733753636434,0.123353614905061,-0.0618558985956720;-0.0612837471278209,0.123173499339622,-0.0617655943251772;-0.0611942694798857,0.122993686327353,-0.0616754417087603;-0.0611049421354163,0.122814175296971,-0.0615854404601562;-0.0610157648105796,0.122634965678375,-0.0614955902936921;-0.0609267372221287,0.122456056902639,-0.0614058909242842;-0.0608378590874028,0.122277448402015,-0.0613163420674384;-0.0607491301243257,0.122099139609930,-0.0612269434392488;-0.0606605500514046,0.121921129960980,-0.0611376947563959;-0.0605721185877277,0.121743418890929,-0.0610485957361446;-0.0604838354529648,0.121566005836710,-0.0609596460963449;-0.0603957003673642,0.121388890236414,-0.0608708455554285;-0.0603077130517528,0.121212071529297,-0.0607821938324091;-0.0602198732275328,0.121035549155770,-0.0606936906468791;-0.0601321806166838,0.120859322557401,-0.0606053357190114;-0.0600446349417580,0.120683391176910,-0.0605171287695550;-0.0599572359258817,0.120507754458168,-0.0604290695198361;-0.0598699832927508,0.120332411846192,-0.0603411576917541;-0.0597828767666333,0.120157362787145,-0.0602533930077835;-0.0596959160723656,0.119982606728333,-0.0601657751909707;-0.0596091009353516,0.119808143118202,-0.0600783039649329;-0.0595224310815617,0.119633971406334,-0.0599909790538567;-0.0594359062375325,0.119460091043448,-0.0599038001824985;-0.0593495261303630,0.119286501481393,-0.0598167670761804;-0.0592632904877158,0.119113202173151,-0.0597298794607912;-0.0591771990378148,0.118940192572827,-0.0596431370627842;-0.0590912515094447,0.118767472135655,-0.0595565396091769;-0.0590054476319485,0.118595040317991,-0.0594700868275484;-0.0589197871352258,0.118422896577306,-0.0593837784460374;-0.0588342697497350,0.118251040372194,-0.0592976141933447;-0.0587488952064882,0.118079471162362,-0.0592115937987279;-0.0586636632370522,0.117908188408629,-0.0591257169920030;-0.0585785735735461,0.117737191572923,-0.0590399835035409;-0.0584874092504587,0.117553983223025,-0.0589481253538650;-0.0583964029039700,0.117371092293405,-0.0588564263226057;-0.0583055542265923,0.117188518166372,-0.0587648861001982;-0.0582148629114984,0.117006260225559,-0.0586735043777429;-0.0581243286525205,0.116824317855922,-0.0585822808470029;-0.0580339511441456,0.116642690443735,-0.0584912152004008;-0.0579437300815193,0.116461377376594,-0.0584003071310216;-0.0578536651604380,0.116280378043400,-0.0583095563326052;-0.0577637560773528,0.116099691834370,-0.0582189624995502;-0.0576740025293640,0.115919318141027,-0.0581285253269088;-0.0575844042142222,0.115739256356196,-0.0580382445103870;-0.0574949608303261,0.115559505874007,-0.0579481197463433;-0.0574056720767189,0.115380066089883,-0.0578581507317847;-0.0573165376530908,0.115200936400546,-0.0577683371643691;-0.0572275572597740,0.115022116204008,-0.0576786787424004;-0.0571387305977432,0.114843604899571,-0.0575891751648290;-0.0570500573686121,0.114665401887821,-0.0574998261312486;-0.0569615372746341,0.114487506570628,-0.0574106313418961;-0.0568731700187004,0.114309918351143,-0.0573215904976505;-0.0567849553043368,0.114132636633792,-0.0572327033000293;-0.0566968928357043,0.113955660824275,-0.0571439694511889;-0.0566089823175957,0.113778990329565,-0.0570553886539220;-0.0565212234554367,0.113602624557901,-0.0569669606116575;-0.0564336159552813,0.113426562918787,-0.0568786850284572;-0.0563461595238131,0.113250804822990,-0.0567905616090157;-0.0562588538683415,0.113075349682536,-0.0567025900586578;-0.0561716986968023,0.112900196910706,-0.0566147700833386;-0.0560846937177543,0.112725345922035,-0.0565271013896399;-0.0559978386403804,0.112550796132309,-0.0564395836847715;-0.0559111331744833,0.112376546958561,-0.0563522166765672;-0.0558245770304861,0.112202597819068,-0.0562650000734846;-0.0557381699194290,0.112028948133347,-0.0561779335846025;-0.0556519115529705,0.111855597322159,-0.0560910169196221;-0.0555658016433830,0.111682544807493,-0.0560042497888618;-0.0554798399035538,0.111509790012579,-0.0559176319032592;-0.0553940260469815,0.111337332361869,-0.0558311629743669;-0.0553083597877781,0.111165171281052,-0.0557448427143547;-0.0552228408406623,0.110993306197031,-0.0556586708360028;-0.0551374689209628,0.110821736537937,-0.0555726470527054;-0.0550522437446144,0.110650461733118,-0.0554867710784666;-0.0549671650281577,0.110479481213138,-0.0554010426279000;-0.0548822324887375,0.110308794409773,-0.0553154614162271;-0.0547974458440989,0.110138400756008,-0.0552300271592737;-0.0547128048125922,0.109968299686041,-0.0551447395734744;-0.0546283091131636,0.109798490635268,-0.0550595983758635;-0.0545439584653599,0.109628973040290,-0.0549746032840798;-0.0544597525893237,0.109459746338905,-0.0548897540163612;-0.0543756912057948,0.109290809970112,-0.0548050502915472;-0.0542917740361045,0.109122163374096,-0.0547204918290719;-0.0542080008021799,0.108953805992238,-0.0546360783489694;-0.0541243712265369,0.108785737267106,-0.0545518095718661;-0.0540408850322837,0.108617956642451,-0.0544676852189842;-0.0539575419431158,0.108450463563208,-0.0543837050121373;-0.0538743416833166,0.108283257475493,-0.0542998686737304;-0.0537912839777549,0.108116337826595,-0.0542161759267575;-0.0537083685518847,0.107949704064980,-0.0541326264948016;-0.0536255951317433,0.107783355640285,-0.0540492201020326;-0.0535429634439497,0.107617292003316,-0.0539659564732059;-0.0534604732157025,0.107451512606041,-0.0538828353336599;-0.0533781241747814,0.107286016901599,-0.0537998564093179;-0.0532959160495425,0.107120804344282,-0.0537170194266833;-0.0532138485689195,0.106955874389546,-0.0536343241128405;-0.0531319214624195,0.106791226493996,-0.0535517701954513;-0.0530501344601255,0.106626860115394,-0.0534693574027565;-0.0529684872926921,0.106462774712652,-0.0533870854635726;-0.0528869796913449,0.106298969745826,-0.0533049541072903;-0.0528056113878802,0.106135444676121,-0.0532229630638749;-0.0527243821146613,0.105972198965878,-0.0531411120638620;-0.0526432916046206,0.105809232078583,-0.0530594008383603;-0.0525623395912551,0.105646543478854,-0.0529778291190461;-0.0524815258086267,0.105484132632447,-0.0528963966381646;-0.0524008499913618,0.105321999006248,-0.0528151031285290;-0.0523203118746468,0.105160142068270,-0.0527339483235156;-0.0522399111942304,0.104998561287654,-0.0526529319570672;-0.0521596476864195,0.104837256134664,-0.0525720537636880;-0.0520795210880803,0.104676226080684,-0.0524913134784450;-0.0519995311366357,0.104515470598219,-0.0524107108369653;-0.0519196775700630,0.104354989160888,-0.0523302455754343;-0.0518399601268945,0.104194781243421,-0.0522499174305955;-0.0517603785462164,0.104034846321664,-0.0521697261397501;-0.0516809325676648,0.103875183872565,-0.0520896714407524;-0.0516016219314275,0.103715793374183,-0.0520097530720120;-0.0515224463782418,0.103556674305678,-0.0519299707724917;-0.0514434056493908,0.103397826147306,-0.0518503242817032;-0.0513644994867071,0.103239248380429,-0.0517708133397112;-0.0512857276325665,0.103080940487499,-0.0516914376871275;-0.0512070898298899,0.102922901952061,-0.0516121970651117;-0.0511285858221409,0.102765132258752,-0.0515330912153702;-0.0510502153533240,0.102607630893295,-0.0514541198801535;-0.0509719781679858,0.102450397342501,-0.0513752828022574;-0.0508938740112102,0.102293431094261,-0.0512965797250186;-0.0508159026286203,0.102136731637549,-0.0512180103923166;-0.0507380637663744,0.101980298462414,-0.0511395745485692;-0.0506603571711676,0.101824131059981,-0.0510612719387345;-0.0505827825902288,0.101668228922450,-0.0509831023083077;-0.0505053397713196,0.101512591543090,-0.0509050654033203;-0.0504280284627332,0.101357218416236,-0.0508271609703385;-0.0503508484132939,0.101202109037292,-0.0507493887564631;-0.0502737993723543,0.101047262902723,-0.0506717485093268;-0.0501968810897961,0.100892679510054,-0.0505942399770941;-0.0501200933160272,0.100738358357870,-0.0505168629084597;-0.0500434358019811,0.100584298945810,-0.0504396170526469;-0.0499669082991166,0.100430500774567,-0.0503625021594077;-0.0498905105594145,0.100276963345886,-0.0502855179790194;-0.0498142423353784,0.100123686162558,-0.0502086642622856;-0.0497381033800319,0.0999706687284210,-0.0501319407605328;-0.0496620934469201,0.0998179105483592,-0.0500553472256127;-0.0495862122901039,0.0996654111282935,-0.0499788834098959;-0.0495104596641635,0.0995131699751872,-0.0499025490662757;-0.0494348353241943,0.0993611865970387,-0.0498263439481638;-0.0493593390258066,0.0992094605028803,-0.0497502678094899;-0.0492839705251247,0.0990579912027769,-0.0496743204047013;-0.0492087295787852,0.0989067782078222,-0.0495985014887607;-0.0491336159439358,0.0987558210301364,-0.0495228108171451;-0.0490586293782350,0.0986051191828659,-0.0494472481458457;-0.0489837696398494,0.0984546721801770,-0.0493718132313648;-0.0489090364874543,0.0983044795372586,-0.0492965058307170;-0.0488344296802311,0.0981545407703152,-0.0492213257014257;-0.0487599489778668,0.0980048553965674,-0.0491462726015237;-0.0486855941405533,0.0978554229342495,-0.0490713462895515;-0.0486113649289847,0.0977062429026045,-0.0489965465245551;-0.0485372611043578,0.0975573148218855,-0.0489218730660865;-0.0484632824283703,0.0974086382133512,-0.0488473256742018;-0.0483894286632193,0.0972602125992631,-0.0487729041094594;-0.0483156995716009,0.0971120375028857,-0.0486986081329203;-0.0482420949167081,0.0969641124484811,-0.0486244375061453;-0.0481686144622310,0.0968164369613094,-0.0485503919911954;-0.0480952579723541,0.0966690105676243,-0.0484764713506294;-0.0480220252117563,0.0965218327946727,-0.0484026753475037;-0.0479489159456099,0.0963749031706914,-0.0483290037453707;-0.0478759299395777,0.0962282212249036,-0.0482554563082772;-0.0478030669598148,0.0960817864875203,-0.0481820328007648;-0.0477303267729646,0.0959355984897339,-0.0481087329878670;-0.0476577091461593,0.0957896567637185,-0.0480355566351088;-0.0475852138470191,0.0956439608426277,-0.0479625035085066;-0.0475128406436490,0.0954985102605897,-0.0478895733745646;-0.0474405893046406,0.0953533045527093,-0.0478167660002768;-0.0473684595990682,0.0952083432550614,-0.0477440811531228;-0.0472964512964900,0.0950636259046924,-0.0476715186010694;-0.0472245641669455,0.0949191520396155,-0.0475990781125677;-0.0471527979809547,0.0947749211988090,-0.0475267594565522;-0.0470811525095178,0.0946309329222156,-0.0474545624024409;-0.0470096275241128,0.0944871867507379,-0.0473824867201326;-0.0469382227966955,0.0943436822262380,-0.0473105321800070;-0.0468669380996981,0.0942004188915349,-0.0472386985529232;-0.0467957732060278,0.0940573962904013,-0.0471669856102181;-0.0467247278890660,0.0939146139675629,-0.0470953931237063;-0.0466538019226672,0.0937720714686953,-0.0470239208656783;-0.0465829950811578,0.0936297683404220,-0.0469525686088994;-0.0465123071393355,0.0934877041303130,-0.0468813361266093;-0.0464417378724671,0.0933458783868808,-0.0468102231925201;-0.0463712870562890,0.0932042906595805,-0.0467392295808160;-0.0463009544670047,0.0930629404988061,-0.0466683550661517;-0.0462307398812847,0.0929218274558889,-0.0465975994236516;-0.0461606430762649,0.0927809510830957,-0.0465269624289088;-0.0460906638295458,0.0926403109336256,-0.0464564438579836;-0.0460208019191913,0.0924999065616093,-0.0463860434874032;-0.0459510571237278,0.0923597375221057,-0.0463157610941596;-0.0458814292221430,0.0922198033711006,-0.0462455964557096;-0.0458119179938850,0.0920801036655048,-0.0461755493499732;-0.0457425232188609,0.0919406379631504,-0.0461056195553322;-0.0456732446774366,0.0918014058227915,-0.0460358068506303;-0.0456040821504344,0.0916624068040986,-0.0459661110151706;-0.0455350354191335,0.0915236404676598,-0.0458965318287157;-0.0454661042652677,0.0913851063749769,-0.0458270690714861;-0.0453972884710249,0.0912468040884630,-0.0457577225241592;-0.0453285878190467,0.0911087331714429,-0.0456884919678688;-0.0452600020924257,0.0909708931881473,-0.0456193771842030;-0.0451915310747062,0.0908332837037139,-0.0455503779552043;-0.0451231745498824,0.0906959042841842,-0.0454814940633677;-0.0450549323023971,0.0905587544965006,-0.0454127252916402;-0.0449868041171415,0.0904218339085065,-0.0453440714234200;-0.0449187897794534,0.0902851420889416,-0.0452755322425542;-0.0448508890751165,0.0901486786074419,-0.0452071075333394;-0.0447831017903598,0.0900124430345373,-0.0451387970805199;-0.0447154277118552,0.0898764349416481,-0.0450706006692862;-0.0446478666267190,0.0897406539010860,-0.0450025180852755;-0.0445804183225081,0.0896050994860483,-0.0449345491145687;-0.0445130825872206,0.0894697712706188,-0.0448666935436910;-0.0444458592092948,0.0893346688297651,-0.0447989511596102;-0.0443787479776076,0.0891997917393354,-0.0447313217497358;-0.0443117486814740,0.0890651395760587,-0.0446638051019182;-0.0442448611106456,0.0889307119175400,-0.0445964010044470;-0.0441780850553101,0.0887965083422608,-0.0445291092460511;-0.0441114203060902,0.0886625284295764,-0.0444619296158968;-0.0440448666540423,0.0885287717597127,-0.0443948619035872;-0.0439784238906564,0.0883952379137667,-0.0443279058991615;-0.0439120918078534,0.0882619264737015,-0.0442610613930930;-0.0438458701979860,0.0881288370223466,-0.0441943281762892;-0.0437797588538370,0.0879959691433959,-0.0441277060400907;-0.0437137575686176,0.0878633224214035,-0.0440611947762691;-0.0436478661359680,0.0877308964417853,-0.0439947941770279;-0.0435820843499547,0.0875986907908137,-0.0439285040349997;-0.0435164120050706,0.0874667050556172,-0.0438623241432461;-0.0434508488962342,0.0873349388241790,-0.0437962542952570;-0.0433853948187877,0.0872033916853339,-0.0437302942849491;-0.0433200495684971,0.0870720632287674,-0.0436644439066653;-0.0432548129415502,0.0869409530450125,-0.0435987029551731;-0.0431896847345564,0.0868100607254492,-0.0435330712256645;-0.0431246647445459,0.0866793858623019,-0.0434675485137547;-0.0430597527689676,0.0865489280486369,-0.0434021346154806;-0.0429949486056898,0.0864186868783623,-0.0433368293273010;-0.0429302520529977,0.0862886619462240,-0.0432716324460945;-0.0428656629095934,0.0861588528478050,-0.0432065437691591;-0.0428011809745949,0.0860292591795238,-0.0431415630942117;-0.0427368060475346,0.0858998805386309,-0.0430766902193858;-0.0426725379283592,0.0857707165232096,-0.0430119249432324;-0.0426083764174279,0.0856417667321712,-0.0429472670647173;-0.0425443213155119,0.0855130307652549,-0.0428827163832212;-0.0424803724237939,0.0853845082230261,-0.0428182726985389;-0.0424165295438660,0.0852561987068725,-0.0427539358108770;-0.0423527924777305,0.0851281018190060,-0.0426897055208554;-0.0422891610277969,0.0850002171624565,-0.0426255816295035;-0.0422256349968828,0.0848725443410731,-0.0425615639382617;-0.0421622141882120,0.0847450829595212,-0.0424976522489791;-0.0420988984054137,0.0846178326232803,-0.0424338463639127;-0.0420356874525222,0.0844907929386437,-0.0423701460857275;-0.0419725811339749,0.0843639635127143,-0.0423065512174942;-0.0419095792546125,0.0842373439534050,-0.0422430615626891;-0.0418466816196774,0.0841109338694355,-0.0421796769251930;-0.0417838880348128,0.0839847328703308,-0.0421163971092901;-0.0417211983060625,0.0838587405664205,-0.0420532219196681;-0.0416586122398691,0.0837329565688348,-0.0419901511614156;-0.0415961296430737,0.0836073804895049,-0.0419271846400224;-0.0415337503229148,0.0834820119411598,-0.0418643221613786;-0.0414714740870271,0.0833568505373246,-0.0418015635317727;-0.0414093007434414,0.0832318958923199,-0.0417389085578923;-0.0413472301005831,0.0831071476212588,-0.0416763570468215;-0.0412852619672712,0.0829826053400451,-0.0416139088060413;-0.0412233961527181,0.0828582686653728,-0.0415515636434283;-0.0411616324665278,0.0827341372147223,-0.0414893213672530;-0.0410999707186962,0.0826102106063613,-0.0414271817861809;-0.0410384107196087,0.0824864884593400,-0.0413651447092691;-0.0409769522800409,0.0823629703934919,-0.0413032099459677;-0.0409155952111567,0.0822396560294309,-0.0412413773061174;-0.0408543393245075,0.0821165449885491,-0.0411796465999492;-0.0407931844320319,0.0819936368930165,-0.0411180176380837;-0.0407321303460545,0.0818709313657777,-0.0410564902315297;-0.0406711768792847,0.0817484280305513,-0.0409950641916839;-0.0406103238448163,0.0816261265118274,-0.0409337393303295;-0.0405495710561268,0.0815040264348664,-0.0408725154596359;-0.0404889183270759,0.0813821274256972,-0.0408113923921575;-0.0404283654719049,0.0812604291111151,-0.0407503699408325;-0.0403679123052364,0.0811389311186807,-0.0406894479189829;-0.0403075586420728,0.0810176330767178,-0.0406286261403132;-0.0402473042977952,0.0808965346143109,-0.0405679044189087;-0.0401871490881636,0.0807756353613057,-0.0405072825692365;-0.0401270928293150,0.0806549349483049,-0.0404467604061429;-0.0400671353377634,0.0805344330066686,-0.0403863377448536;-0.0400072764303984,0.0804141291685112,-0.0403260144009726;-0.0399427065446850,0.0802843551829058,-0.0402609413464617;-0.0398782462601955,0.0801548014477943,-0.0401959787172305;-0.0398138953682881,0.0800254675439656,-0.0401311263031398;-0.0397496536607610,0.0798963530530929,-0.0400663838944940;-0.0396855209298510,0.0797674575577300,-0.0400017512820384;-0.0396214969682314,0.0796387806413084,-0.0399372282569585;-0.0395575815690132,0.0795103218881380,-0.0398728146108799;-0.0394937745257419,0.0793820808834019,-0.0398085101358658;-0.0394300756323977,0.0792540572131569,-0.0397443146244172;-0.0393664846833945,0.0791262504643304,-0.0396802278694717;-0.0393030014735781,0.0789986602247176,-0.0396162496644016;-0.0392396257982264,0.0788712860829818,-0.0395523798030143;-0.0391763574530471,0.0787441276286497,-0.0394886180795498;-0.0391131962341775,0.0786171844521115,-0.0394249642886812;-0.0390501419381838,0.0784904561446181,-0.0393614182255126;-0.0389871943620591,0.0783639422982786,-0.0392979796855784;-0.0389243533032233,0.0782376425060593,-0.0392346484648426;-0.0388616185595217,0.0781115563617809,-0.0391714243596974;-0.0387989899292240,0.0779856834601175,-0.0391083071669626;-0.0387364672110237,0.0778600233965935,-0.0390452966838842;-0.0386740502040367,0.0777345757675825,-0.0389823927081339;-0.0386117387078007,0.0776093401703051,-0.0389195950378077;-0.0385495325222736,0.0774843162028263,-0.0388569034714251;-0.0384874314478333,0.0773595034640548,-0.0387943178079281;-0.0384254352852766,0.0772349015537406,-0.0387318378466805;-0.0383635438358174,0.0771105100724719,-0.0386694633874663;-0.0383017569010871,0.0769863286216753,-0.0386071942304894;-0.0382400742831322,0.0768623568036117,-0.0385450301763721;-0.0381784957844147,0.0767385942213762,-0.0384829710261547;-0.0381170212078100,0.0766150404788949,-0.0384210165812939;-0.0380556503566067,0.0764916951809238,-0.0383591666436624;-0.0379943830345057,0.0763685579330467,-0.0382974210155478;-0.0379332190456184,0.0762456283416726,-0.0382357794996512;-0.0378721581944665,0.0761229060140347,-0.0381742418990868;-0.0378112002859813,0.0760003905581888,-0.0381128080173811;-0.0377503451255016,0.0758780815830096,-0.0380514776584711;-0.0376895925187742,0.0757559786981913,-0.0379902506267042;-0.0376289422719519,0.0756340815142436,-0.0379291267268368;-0.0375683941915930,0.0755123896424909,-0.0378681057640335;-0.0375079480846604,0.0753909026950704,-0.0378071875438665;-0.0374476037585204,0.0752696202849298,-0.0377463718723138;-0.0373873610209423,0.0751485420258264,-0.0376856585557593;-0.0373272196800967,0.0750276675323234,-0.0376250474009911;-0.0372671795445553,0.0749069964197901,-0.0375645382152009;-0.0372072404232897,0.0747865283043988,-0.0375041308059830;-0.0371474021256703,0.0746662628031233,-0.0374438249813334;-0.0370876644614660,0.0745461995337379,-0.0373836205496493;-0.0370280272408422,0.0744263381148130,-0.0373235173197271;-0.0369684902743611,0.0743066781657169,-0.0372635151007626;-0.0369090533729801,0.0741872193066112,-0.0372036137023496;-0.0368497163480508,0.0740679611584496,-0.0371438129344787;-0.0367904790113189,0.0739489033429775,-0.0370841126075375;-0.0367313411749220,0.0738300454827278,-0.0370245125323080;-0.0366723026513900,0.0737113872010213,-0.0369650125199673;-0.0366133632536436,0.0735929281219637,-0.0369056123820857;-0.0365545227949931,0.0734746678704437,-0.0368463119306260;-0.0364957810891384,0.0733566060721326,-0.0367871109779433;-0.0364371379501670,0.0732387423534803,-0.0367280093367829;-0.0363785931925541,0.0731210763417155,-0.0366690068202804;-0.0363201466311613,0.0730036076648432,-0.0366101032419603;-0.0362617980812353,0.0728863359516422,-0.0365512984157353;-0.0362035473584081,0.0727692608316652,-0.0364925921559057;-0.0361453942786950,0.0726523819352347,-0.0364339842771574;-0.0360873386584943,0.0725356988934428,-0.0363754745945627;-0.0360293803145864,0.0724192113381496,-0.0363170629235780;-0.0359715190641326,0.0723029189019798,-0.0362587490800435;-0.0359137547246750,0.0721868212183232,-0.0362005328801826;-0.0358560871141346,0.0720709179213313,-0.0361424141406005;-0.0357985160508112,0.0719552086459157,-0.0360843926782833;-0.0357410413533822,0.0718396930277476,-0.0360264683105979;-0.0356836628409018,0.0717243707032543,-0.0359686408552901;-0.0356263803328006,0.0716092413096195,-0.0359109101304849;-0.0355691936488835,0.0714943044847794,-0.0358532759546842;-0.0355121026093303,0.0713795598674226,-0.0357957381467671;-0.0354551070346941,0.0712650070969880,-0.0357382965259890;-0.0353982067459004,0.0711506458136623,-0.0356809509119797;-0.0353414015642466,0.0710364756583798,-0.0356237011247439;-0.0352846913114008,0.0709224962728194,-0.0355665469846594;-0.0352280758094011,0.0708087072994032,-0.0355094883124766;-0.0351715548806551,0.0706951083812953,-0.0354525249293177;-0.0351151283479384,0.0705816991623994,-0.0353956566566756;-0.0350587960343943,0.0704684792873582,-0.0353388833164135;-0.0350025577635327,0.0703554484015504,-0.0352822047307636;-0.0349464133592292,0.0702426061510895,-0.0352256207223263;-0.0348903626457250,0.0701299521828233,-0.0351691311140702;-0.0348344054476244,0.0700174861443297,-0.0351127357293294;-0.0347785415898963,0.0699052076839181,-0.0350564343918051;-0.0347227708978713,0.0697931164506254,-0.0350002269255627;-0.0346670931972418,0.0696812120942150,-0.0349441131550321;-0.0346115083140616,0.0695694942651758,-0.0348880929050066;-0.0345560160747438,0.0694579626147195,-0.0348321660006418;-0.0345006163060615,0.0693466167947804,-0.0347763322674555;-0.0344453088351457,0.0692354564580119,-0.0347205915313257;-0.0343900934894854,0.0691244812577866,-0.0346649436184911;-0.0343349700969260,0.0690136908481933,-0.0346093883555494;-0.0342799384856692,0.0689030848840364,-0.0345539255694567;-0.0342249984842721,0.0687926630208342,-0.0344985550875270;-0.0341701499216457,0.0686824249148160,-0.0344432767374309;-0.0341153926270551,0.0685723702229226,-0.0343880903471952;-0.0340607264301177,0.0684624986028028,-0.0343329957452017;-0.0340061511608031,0.0683528097128122,-0.0342779927601866;-0.0339516666494324,0.0682433032120133,-0.0342230812212402;-0.0338972727266766,0.0681339787601712,-0.0341682609578050;-0.0338429692235568,0.0680248360177542,-0.0341135317996760;-0.0337887559714425,0.0679158746459309,-0.0340588935769990;-0.0337346328020514,0.0678070943065691,-0.0340043461202706;-0.0336805995474486,0.0676984946622347,-0.0339498892603369;-0.0336266560400454,0.0675900753761889,-0.0338955228283927;-0.0335728021125991,0.0674818361123881,-0.0338412466559811;-0.0335190375982115,0.0673737765354810,-0.0337870605749923;-0.0334653623303287,0.0672658963108078,-0.0337329644176630;-0.0334117761427405,0.0671581951043988,-0.0336789580165759;-0.0333582788695785,0.0670506725829720,-0.0336250412046581;-0.0333048703453170,0.0669433284139326,-0.0335712138151814;-0.0332515504047705,0.0668361622653702,-0.0335174756817605;-0.0331983188830940,0.0667291738060581,-0.0334638266383529;-0.0331451756157826,0.0666223627054527,-0.0334102665192582;-0.0330921204386691,0.0665157286336893,-0.0333567951591165;-0.0330391531879251,0.0664092712615833,-0.0333034123929086;-0.0329862737000591,0.0663029902606271,-0.0332501180559548;-0.0329334818119156,0.0661968853029886,-0.0331969119839137;-0.0328807773606757,0.0660909560615109,-0.0331437940127828;-0.0328281601838546,0.0659852022097092,-0.0330907639788957;-0.0327756301193019,0.0658796234217705,-0.0330378217189234;-0.0327231870052011,0.0657742193725517,-0.0329849670698724;-0.0326708306800674,0.0656689897375770,-0.0329321998690835;-0.0326185609827488,0.0655639341930390,-0.0328795199542327;-0.0325663777524241,0.0654590524157943,-0.0328269271633287;-0.0325142808286024,0.0653543440833641,-0.0327744213347133;-0.0324622700511229,0.0652498088739315,-0.0327220023070603;-0.0324103452601531,0.0651454464663403,-0.0326696699193741;-0.0323585062961895,0.0650412565400943,-0.0326174240109904;-0.0323067530000552,0.0649372387753544,-0.0325652644215740;-0.0322550852129006,0.0648333928529383,-0.0325131909911190;-0.0322035027762022,0.0647297184543189,-0.0324612035599478;-0.0321520055317609,0.0646262152616214,-0.0324093019687098;-0.0321005933217033,0.0645228829576245,-0.0323574860583818;-0.0320492659884789,0.0644197212257561,-0.0323057556702662;-0.0319980233748607,0.0643167297500940,-0.0322541106459910;-0.0319468653239439,0.0642139082153632,-0.0322025508275085;-0.0318957916791453,0.0641112563069348,-0.0321510760570950;-0.0318448022842027,0.0640087737108247,-0.0320996861773499;-0.0317938969831739,0.0639064601136919,-0.0320483810311948;-0.0317430756204365,0.0638043152028375,-0.0319971604618735;-0.0316923380406865,0.0637023386662027,-0.0319460243129502;-0.0316416840889380,0.0636005301923676,-0.0318949724283094;-0.0315911136105225,0.0634988894705500,-0.0318440046521555;-0.0315406264510881,0.0633974161906034,-0.0317931208290112;-0.0314902224565989,0.0632961100430163,-0.0317423208037176;-0.0314399014733339,0.0631949707189103,-0.0316916044214332;-0.0313896633478867,0.0630939979100386,-0.0316409715276328;-0.0313395079271648,0.0629931913087849,-0.0315904219681075;-0.0312894350583887,0.0628925506081620,-0.0315399555889636;-0.0312394445890912,0.0627920755018101,-0.0314895722366217;-0.0311895363671168,0.0626917656839955,-0.0314392717578164;-0.0311397102406211,0.0625916208496095,-0.0313890539995956;-0.0310899660580699,0.0624916406941665,-0.0313389188093194;-0.0310403036682386,0.0623918249138031,-0.0312888660346596;-0.0309907229202112,0.0622921732052759,-0.0312388955235990;-0.0309412236633805,0.0621926852659616,-0.0311890071244311;-0.0308918057474463,0.0620933607938539,-0.0311392006857586;-0.0308424690224155,0.0619941994875633,-0.0310894760564935;-0.0307932133386009,0.0618952010463152,-0.0310398330858558;-0.0307440385466210,0.0617963651699488,-0.0309902716233732;-0.0306949444973992,0.0616976915589156,-0.0309407915188804;-0.0306459310421623,0.0615991799142774,-0.0308913926225179;-0.0305969980324414,0.0615008299377068,-0.0308420747847323;-0.0305481453200697,0.0614026413314835,-0.0307928378562745;-0.0304993727571827,0.0613046137984942,-0.0307436816881998;-0.0304506801962173,0.0612067470422318,-0.0306946061318671;-0.0304020674899110,0.0611090407667926,-0.0306456110389377;-0.0303535344913018,0.0610114946768762,-0.0305966962613758;-0.0303050810537262,0.0609141084777831,-0.0305478616514460;-0.0302567070308201,0.0608168818754142,-0.0304991070617143;-0.0302084122765173,0.0607198145762694,-0.0304504323450470;-0.0301601966450488,0.0606229062874453,-0.0304018373546092;-0.0301120599909426,0.0605261567166359,-0.0303533219438656;-0.0300640021690224,0.0604295655721285,-0.0303048859665781;-0.0300160230344075,0.0603331325628047,-0.0302565292768066;-0.0299681224425121,0.0602368573981382,-0.0302082517289079;-0.0299203002490439,0.0601407397881930,-0.0301600531775343;-0.0298725563100048,0.0600447794436234,-0.0301119334776343;-0.0298248904816889,0.0599489760756712,-0.0300638924844507;-0.0297773026206826,0.0598533293961651,-0.0300159300535206;-0.0297297925838638,0.0597578391175200,-0.0299680460406746;-0.0296823602284010,0.0596625049527340,-0.0299202403020360;-0.0296350054117534,0.0595673266153896,-0.0298725126940208;-0.0295877279916691,0.0594723038196494,-0.0298248630733358;-0.0295405278261854,0.0593774362802575,-0.0297772912969792;-0.0294934047736279,0.0592827237125367,-0.0297297972222393;-0.0294463586926095,0.0591881658323873,-0.0296823807066939;-0.0293993894420306,0.0590937623562871,-0.0296350416082102;-0.0293524968810773,0.0589995130012878,-0.0295877797849429;-0.0293056808692218,0.0589054174850159,-0.0295405950953352;-0.0292589412662213,0.0588114755256707,-0.0294934873981169;-0.0292122779321170,0.0587176868420219,-0.0294464565523040;-0.0291656907272347,0.0586240511534109,-0.0293995024171991;-0.0291191795121826,0.0585305681797465,-0.0293526248523890;-0.0290727441478518,0.0584372376415059,-0.0293058237177454;-0.0290263844954153,0.0583440592597328,-0.0292590988734241;-0.0289801004163271,0.0582510327560350,-0.0292124501798635;-0.0289338917723223,0.0581581578525854,-0.0291658774977853;-0.0288877584254157,0.0580654342721188,-0.0291193806881928;-0.0288417002379016,0.0579728617379314,-0.0290729596123707;-0.0287957170723531,0.0578804399738796,-0.0290266141318844;-0.0287498087916213,0.0577881687043784,-0.0289803441085795;-0.0287039752588353,0.0576960476544011,-0.0289341494045812;-0.0286582163374009,0.0576040765494769,-0.0288880298822934;-0.0286125318909999,0.0575122551156898,-0.0288419854043982;-0.0285669217835903,0.0574205830796785,-0.0287960158338556;-0.0285213858794049,0.0573290601686337,-0.0287501210339022;-0.0284759240429514,0.0572376861102985,-0.0287043008680517;-0.0284305361390108,0.0571464606329652,-0.0286585552000928;-0.0283852220326378,0.0570553834654756,-0.0286128838940898;-0.0283399815891598,0.0569644543372198,-0.0285672868143818;-0.0282948146741759,0.0568736729781333,-0.0285217638255813;-0.0282497211535572,0.0567830391186986,-0.0284763147925749;-0.0282047008934452,0.0566925524899410,-0.0284309395805211;-0.0281597537602520,0.0566022128234298,-0.0283856380548514;-0.0281148796206592,0.0565120198512752,-0.0283404100812683;-0.0280700783416175,0.0564219733061286,-0.0282952555257454;-0.0280253497903462,0.0563320729211810,-0.0282501742545269;-0.0279806938343323,0.0562423184301609,-0.0282051661341264;-0.0279361103413305,0.0561527095673345,-0.0281602310313270;-0.0278915991793616,0.0560632460675034,-0.0281153688131801;-0.0278471602167130,0.0559739276660040,-0.0280705793470051;-0.0278027933219377,0.0558847540987065,-0.0280258625003893;-0.0277584983638531,0.0557957251020126,-0.0279812181411859;-0.0277142752115416,0.0557068404128559,-0.0279366461375151;-0.0276701237343490,0.0556180997686999,-0.0278921463577625;-0.0276260438018842,0.0555295029075362,-0.0278477186705785;-0.0275820352840193,0.0554410495678850,-0.0278033629448782;-0.0275380980508879,0.0553527394887922,-0.0277590790498406;-0.0274942319728851,0.0552645724098291,-0.0277148668549078;-0.0274504369206673,0.0551765480710918,-0.0276707262297848;-0.0274067127651506,0.0550886662131983,-0.0276266570444385;-0.0273630593775114,0.0550009265772894,-0.0275826591690978;-0.0273194766291850,0.0549133289050262,-0.0275387324742520;-0.0272759643918654,0.0548258729385894,-0.0274948768306514;-0.0272325225375045,0.0547385584206778,-0.0274510921093056;-0.0271891509383117,0.0546513850945078,-0.0274073781814837;-0.0271458494667534,0.0545643527038120,-0.0273637349187137;-0.0271026179955521,0.0544774609928376,-0.0273201621927813;-0.0270594563976865,0.0543907097063459,-0.0272766598757300;-0.0270163645463900,0.0543040985896112,-0.0272332278398605;-0.0269733423151508,0.0542176273884183,-0.0271898659577293;-0.0269303895777116,0.0541312958490642,-0.0271465741021495;-0.0268875062080678,0.0540451037183536,-0.0271033521461889;-0.0268446920804685,0.0539590507436003,-0.0270601999631703;-0.0268019470694151,0.0538731366726253,-0.0270171174266710;-0.0267519252520493,0.0537725946267383,-0.0269666983356635;-0.0267019881468478,0.0536722228353633,-0.0269163646149763;-0.0266521355948019,0.0535720209789584,-0.0268661161044008;-0.0266023674372336,0.0534719887386453,-0.0268159526440609;-0.0265526835157943,0.0533721257962084,-0.0267658740744130;-0.0265030836724638,0.0532724318340917,-0.0267158802362438;-0.0264535677495505,0.0531729065353992,-0.0266659709706711;-0.0264041355896895,0.0530735495838918,-0.0266161461191420;-0.0263547870358429,0.0529743606639871,-0.0265664055234327;-0.0263055219312981,0.0528753394607565,-0.0265167490256472;-0.0262563401196677,0.0527764856599250,-0.0264671764682173;-0.0262072414448887,0.0526777989478690,-0.0264176876939011;-0.0261582257512215,0.0525792790116152,-0.0263682825457828;-0.0261092928832493,0.0524809255388388,-0.0263189608672718;-0.0260604426858776,0.0523827382178621,-0.0262697225021017;-0.0260116750043326,0.0522847167376529,-0.0262205672943299;-0.0259629896841620,0.0521868607878238,-0.0261714950883370;-0.0259143865712326,0.0520891700586294,-0.0261225057288252;-0.0258658655117309,0.0519916442409662,-0.0260735990608188;-0.0258174263521614,0.0518942830263703,-0.0260247749296626;-0.0257690689393465,0.0517970861070158,-0.0259760331810213;-0.0257207931204257,0.0517000531757144,-0.0259273736608790;-0.0256725987428545,0.0516031839259128,-0.0258787962155385;-0.0256244856544038,0.0515064780516917,-0.0258303006916201;-0.0255764537031600,0.0514099352477648,-0.0257818869360617;-0.0255285027375228,0.0513135552094765,-0.0257335547961171;-0.0254806326062059,0.0512173376328012,-0.0256853041193561;-0.0254328431582352,0.0511212822143412,-0.0256371347536634;-0.0253851342429490,0.0510253886513262,-0.0255890465472378;-0.0253375057099965,0.0509296566416111,-0.0255410393485920;-0.0252899574093377,0.0508340858836747,-0.0254931130065510;-0.0252424891912424,0.0507386760766185,-0.0254452673702525;-0.0251951009062893,0.0506434269201650,-0.0253975022891450;-0.0251477924053659,0.0505483381146569,-0.0253498176129882;-0.0251005635396673,0.0504534093610551,-0.0253022131918517;-0.0250534141606956,0.0503586403609371,-0.0252546888761141;-0.0250063441202593,0.0502640308164965,-0.0252072445164629;-0.0249593532704726,0.0501695804305410,-0.0251598799638934;-0.0249124414637546,0.0500752889064907,-0.0251125950697081;-0.0248656085528287,0.0499811559483776,-0.0250653896855161;-0.0248188543907219,0.0498871812608432,-0.0250182636632319;-0.0247721788307641,0.0497933645491383,-0.0249712168550758;-0.0247255817265873,0.0496997055191204,-0.0249242491135720;-0.0246790629321252,0.0496062038772530,-0.0248773602915485;-0.0246326223016124,0.0495128593306045,-0.0248305502421366;-0.0245862596895834,0.0494196715868458,-0.0247838188187697;-0.0245399749508724,0.0493266403542503,-0.0247371658751831;-0.0244937679406123,0.0492337653416911,-0.0246905912654129;-0.0244476385142342,0.0491410462586408,-0.0246440948437956;-0.0244015865274667,0.0490484828151700,-0.0245976764649675;-0.0243556118363350,0.0489560747219449,-0.0245513359838636;-0.0243097142971609,0.0488638216902276,-0.0245050732557175;-0.0242638937665609,0.0487717234318729,-0.0244588881360599;-0.0242181501014469,0.0486797796593287,-0.0244127804807190;-0.0241724831590248,0.0485879900856336,-0.0243667501458191;-0.0241268927967936,0.0484963544244158,-0.0243207969877798;-0.0240813788725457,0.0484048723898924,-0.0242749208633162;-0.0240359412443650,0.0483135436968663,-0.0242291216294370;-0.0239905797706273,0.0482223680607273,-0.0241833991434452;-0.0239452943099993,0.0481313451974493,-0.0241377532629364;-0.0239000847214371,0.0480404748235884,-0.0240921838457983;-0.0238549508641874,0.0479497566562837,-0.0240466907502107;-0.0238098925977849,0.0478591904132536,-0.0240012738346438;-0.0237649097820529,0.0477687758127962,-0.0239559329578587;-0.0237200022771021,0.0476785125737875,-0.0239106679789057;-0.0236751699433302,0.0475884004156794,-0.0238654787571244;-0.0236304126414213,0.0474984390585001,-0.0238203651521428;-0.0235857302323446,0.0474086282228501,-0.0237753270238762;-0.0235411225773548,0.0473189676299041,-0.0237303642325273;-0.0234965895379908,0.0472294570014073,-0.0236854766385852;-0.0234521309760751,0.0471400960596750,-0.0236406641028248;-0.0234077467537132,0.0470508845275917,-0.0235959264863059;-0.0233634367332932,0.0469618221286087,-0.0235512636503731;-0.0233192007774848,0.0468729085867439,-0.0235066754566544;-0.0232750387492390,0.0467841436265803,-0.0234621617670617;-0.0232309505117871,0.0466955269732641,-0.0234177224437886;-0.0231869359286408,0.0466070583525047,-0.0233733573493116;-0.0231429948635903,0.0465187374905716,-0.0233290663463878;-0.0230991271807050,0.0464305641142949,-0.0232848492980551;-0.0230553327443321,0.0463425379510632,-0.0232407060676317;-0.0230116114190961,0.0462546587288219,-0.0231966365187149;-0.0229679630698986,0.0461669261760735,-0.0231526405151810;-0.0229243875619169,0.0460793400218747,-0.0231087179211846;-0.0228808847606040,0.0459918999958359,-0.0230648686011574;-0.0228374545316879,0.0459046058281199,-0.0230210924198083;-0.0227940967411707,0.0458174572494408,-0.0229773892421225;-0.0227508112553283,0.0457304539910625,-0.0229337589333609;-0.0227075979407097,0.0456435957847976,-0.0228902013590594;-0.0226644566641360,0.0455568823630057,-0.0228467163850280;-0.0226213872927007,0.0454703134585937,-0.0228033038773514;-0.0225783896937678,0.0453838888050121,-0.0227599637023865;-0.0225354637349727,0.0452976081362563,-0.0227166957267636;-0.0224926092842202,0.0452114711868639,-0.0226734998173845;-0.0224498262096846,0.0451254776919133,-0.0226303758414225;-0.0224071143798095,0.0450396273870240,-0.0225873236663220;-0.0223644736633059,0.0449539200083536,-0.0225443431597969;-0.0223219039291531,0.0448683552925979,-0.0225014341898314;-0.0222794050465969,0.0447829329769887,-0.0224585966246780;-0.0222369768851498,0.0446976527992939,-0.0224158303328582;-0.0221946193145901,0.0446125144978147,-0.0223731351831607;-0.0221724962933104,0.0445680519490723,-0.0223508405929982;-0.0221504016473684,0.0445236464143963,-0.0223285745831593;-0.0221283353353023,0.0444792978105139,-0.0223063371119204;-0.0221062973157141,0.0444350060542807,-0.0222841281376221;-0.0220842875472693,0.0443907710626798,-0.0222619476186691;-0.0220623059886969,0.0443465927528214,-0.0222397955135296;-0.0220403525987895,0.0443024710419438,-0.0222176717807358;-0.0220184273364030,0.0442584058474119,-0.0221955763788834;-0.0219965301604566,0.0442143970867177,-0.0221735092666318;-0.0219746610299324,0.0441704446774798,-0.0221514704027036;-0.0219528199038758,0.0441265485374434,-0.0221294597458850;-0.0219310067413952,0.0440827085844806,-0.0221074772550254;-0.0219092215016618,0.0440389247365889,-0.0220855228890374;-0.0218874641439096,0.0439951969118924,-0.0220635966068966;-0.0218657346274352,0.0439515250286406,-0.0220416983676417;-0.0218440329115979,0.0439079090052090,-0.0220198281303742;-0.0218223589558197,0.0438643487600986,-0.0219979858542587;-0.0218007127195847,0.0438208442119352,-0.0219761714985220;-0.0217790941624396,0.0437773952794703,-0.0219543850224540;-0.0217575032439932,0.0437340018815800,-0.0219326263854070;-0.0217359399239163,0.0436906639372650,-0.0219108955467955;-0.0217144041619420,0.0436473813656508,-0.0218891924660968;-0.0216928959178655,0.0436041540859873,-0.0218675171028502;-0.0216714151515435,0.0435609820176485,-0.0218458694166572;-0.0216499618228946,0.0435178650801321,-0.0218242493671812;-0.0216285358918993,0.0434748031930601,-0.0218026569141481;-0.0216071373185995,0.0434317962761781,-0.0217810920173451;-0.0215857660630987,0.0433888442493546,-0.0217595546366217;-0.0215644220855617,0.0433459470325821,-0.0217380447318888;-0.0215431053462150,0.0433031045459759,-0.0217165622631191;-0.0215218158053457,0.0432603167097739,-0.0216951071903467;-0.0215005534233027,0.0432175834443372,-0.0216736794736673;-0.0214793181604956,0.0431749046701492,-0.0216522790732378;-0.0214581099773951,0.0431322803078158,-0.0216309059492766;-0.0214369288345327,0.0430897102780652,-0.0216095600620630;-0.0214157746925007,0.0430471945017470,-0.0215882413719375;-0.0213946475119523,0.0430047328998335,-0.0215669498393018;-0.0213735472536009,0.0429623253934181,-0.0215456854246180;-0.0213524738782209,0.0429199719037156,-0.0215244480884096;-0.0213314273466468,0.0428776723520627,-0.0215032377912605;-0.0213104076197736,0.0428354266599165,-0.0214820544938152;-0.0212894146585564,0.0427932347488554,-0.0214608981567790;-0.0212684484240108,0.0427510965405787,-0.0214397687409174;-0.0212475088772120,0.0427090119569058,-0.0214186662070564;-0.0212265959792956,0.0426669809197770,-0.0213975905160823;-0.0212057096914569,0.0426250033512523,-0.0213765416289415;-0.0211848499749510,0.0425830791735125,-0.0213555195066407;-0.0211640167910928,0.0425412083088575,-0.0213345241102463;-0.0211432101012569,0.0424993906797073,-0.0213135554008849;-0.0211224298668773,0.0424576262086013,-0.0212926133397428;-0.0211016760494473,0.0424159148181982,-0.0212716978880660;-0.0210809486105201,0.0423742564312762,-0.0212508090071605;-0.0210602475117076,0.0423326509707317,-0.0212299466583913;-0.0210395727146813,0.0422910983595807,-0.0212091108031834;-0.0210189241811716,0.0422495985209575,-0.0211883014030210;-0.0209983018729680,0.0422081513781150,-0.0211675184194475;-0.0209777057519188,0.0421667568544238,-0.0211467618140656;-0.0209571357799313,0.0421254148733736,-0.0211260315485373;-0.0209365919189714,0.0420841253585711,-0.0211053275845834;-0.0209160741310639,0.0420428882337413,-0.0210846498839838;-0.0208955823782920,0.0420017034227264,-0.0210639984085772;-0.0208751166227973,0.0419605708494865,-0.0210433731202611;-0.0208546768267800,0.0419194904380983,-0.0210227739809916;-0.0208342629524985,0.0418784621127560,-0.0210022009527836;-0.0208138749622696,0.0418374857977707,-0.0209816539977105;-0.0207935128184680,0.0417965614175698,-0.0209611330779040;-0.0207731764835265,0.0417556888966976,-0.0209406381555540;-0.0207528659199361,0.0417148681598146,-0.0209201691929092;-0.0207325810902454,0.0416740991316975,-0.0208997261522759;-0.0207123219570609,0.0416333817372389,-0.0208793089960187;-0.0206920884830469,0.0415927159014475,-0.0208589176865603;-0.0206718806309253,0.0415521015494476,-0.0208385521863813;-0.0206516983634753,0.0415115386064785,-0.0208182124580199;-0.0206315416435338,0.0414710269978955,-0.0207978984640722;-0.0206114104339951,0.0414305666491687,-0.0207776101671920;-0.0205913046978105,0.0413901574858832,-0.0207573475300906;-0.0205712243979889,0.0413497994337390,-0.0207371105155368;-0.0205511694975959,0.0413094924185504,-0.0207168990863567;-0.0205311399597543,0.0412692363662466,-0.0206967132054338;-0.0205111357476440,0.0412290312028709,-0.0206765528357090;-0.0204911568245012,0.0411888768545803,-0.0206564179401798;-0.0204712031536197,0.0411487732476468,-0.0206363084819015;-0.0204512746983494,0.0411087203084551,-0.0206162244239858;-0.0204313714220967,0.0410687179635036,-0.0205961657296013;-0.0204114932883250,0.0410287661394051,-0.0205761323619738;-0.0203916402605537,0.0409888647628844,-0.0205561242843854;-0.0203718123023588,0.0409490137607803,-0.0205361414601751;-0.0203520093773724,0.0409092130600441,-0.0205161838527382;-0.0203322314492828,0.0408694625877399,-0.0204962514255267;-0.0203124784818346,0.0408297622710446,-0.0204763441420488;-0.0202927504388279,0.0407901120372469,-0.0204564619658689;-0.0202730472841192,0.0407505118137488,-0.0204366048606081;-0.0202533689816207,0.0407109615280632,-0.0204167727899430;-0.0202337154953003,0.0406714611078157,-0.0203969657176065;-0.0202140867891815,0.0406320104807434,-0.0203771836073875;-0.0201944828273435,0.0405926095746948,-0.0203574264231307;-0.0201749035739211,0.0405532583176302,-0.0203376941287367;-0.0201553489931041,0.0405139566376206,-0.0203179866881616;-0.0201358190491381,0.0404747044628486,-0.0202983040654171;-0.0201163137063237,0.0404355017216072,-0.0202786462245707;-0.0200968329290166,0.0403963483423005,-0.0202590131297451;-0.0200773766816279,0.0403572442534431,-0.0202394047451185;-0.0200579449286234,0.0403181893836598,-0.0202198210349243;-0.0200385376345239,0.0402791836616858,-0.0202002619634511;-0.0200191547639050,0.0402402270163664,-0.0201807274950427;-0.0199997962813970,0.0402013193766566,-0.0201612175940977;-0.0199804621516852,0.0401624606716214,-0.0201417322250701;-0.0199611523395090,0.0401236508304350,-0.0201222713524682;-0.0199418668096626,0.0400848897823814,-0.0201028349408554;-0.0199226055269946,0.0400461774568536,-0.0200834229548499;-0.0199033684564077,0.0400075137833535,-0.0200640353591242;-0.0198841555628593,0.0399688986914924,-0.0200446721184057;-0.0198649668113605,0.0399303321109900,-0.0200253331974759;-0.0198458021669767,0.0398918139716745,-0.0200060185611708;-0.0198266615948274,0.0398533442034829,-0.0199867281743809;-0.0198075450600858,0.0398149227364597,-0.0199674620020505;-0.0197884525279792,0.0397765495007585,-0.0199482200091784;-0.0197693839637884,0.0397382244266399,-0.0199290021608171;-0.0197503393328479,0.0396999474444727,-0.0199098084220734;-0.0197313186005462,0.0396617184847334,-0.0198906387581077;-0.0197123217323248,0.0396235374780055,-0.0198714931341344;-0.0196933486936789,0.0395854043549802,-0.0198523715154214;-0.0196743994501570,0.0395473190464556,-0.0198332738672906;-0.0196554739673608,0.0395092814833366,-0.0198142001551169;-0.0196365722109454,0.0394712915966352,-0.0197951503443291;-0.0196176941466188,0.0394333493174697,-0.0197761244004092;-0.0195988397401421,0.0393954545770651,-0.0197571222888928;-0.0195800089573294,0.0393576073067526,-0.0197381439753683;-0.0195612017640476,0.0393198074379694,-0.0197191894254774;-0.0195424181262164,0.0392820549022589,-0.0197002586049150;-0.0195236580098081,0.0392443496312700,-0.0196813514794289;-0.0195049213808480,0.0392066915567576,-0.0196624680148197;-0.0194862082054134,0.0391690806105818,-0.0196436081769411;-0.0194675184496346,0.0391315167247082,-0.0196247719316991;-0.0194488520796940,0.0390939998312076,-0.0196059592450529;-0.0194302090618262,0.0390565298622554,-0.0195871700830138;-0.0194115893623184,0.0390191067501325,-0.0195684044116460;-0.0193929929475095,0.0389817304272238,-0.0195496621970657;-0.0193744197837908,0.0389444008260193,-0.0195309434054418;-0.0193558698376056,0.0389071178791130,-0.0195122480029954;-0.0193280883779249,0.0388512807883686,-0.0194842486802704;];
  Derivative.dwdtheta_p2 = [-5773.57325087203,11674.5689397479,-5893.76980649807;-1990.45994664105,4069.61918627863,-2079.52997748180;-1984.98529663331,4058.56506871545,-2073.95818225030;-1979.48442405829,4047.45831095753,-2068.36002618211;-1973.95741048703,4036.29907681688,-2062.73559134611;-1968.40433735193,4025.08752982703,-2057.08495967161;-1962.82528594706,4013.82383324363,-2051.40821294866;-1957.22033742841,4002.50815004502,-2045.70543282834;-1951.58957281414,3991.14064293259,-2039.97670082295;-1945.93307298487,3979.72147433152,-2034.22209830636;-1940.25091868385,3968.25080639103,-2028.44170651417;-1934.54319051734,3956.72880098516,-2022.63560654406;-1928.80996895474,3945.15561971303,-2016.80387935595;-1923.05133432890,3933.53142389949,-2010.94660577230;-1917.26736683637,3921.85637459561,-2005.06386647839;-1911.45814653766,3910.13063257914,-1999.15574202252;-1905.62375335742,3898.35435835502,-1993.22231281628;-1899.76426708481,3886.52771215592,-1987.26365913482;-1893.87976737361,3874.65085394266,-1981.27986111706;-1887.97033374259,3862.72394340481,-1975.27099876599;-1882.03604557563,3850.74713996102,-1969.23715194883;-1876.07698212209,3838.72060275973,-1963.17840039740;-1870.09322249700,3826.64449067953,-1957.09482370827;-1864.08484568126,3814.51896232956,-1950.98650134301;-1858.05193052192,3802.34417605020,-1944.85351262850;-1851.99455573244,3790.12028991335,-1938.69593675706;-1845.91279989291,3777.84746172311,-1932.51385278683;-1839.80674145029,3765.52584901616,-1926.30733964194;-1833.67645871867,3753.15560906220,-1920.07647611272;-1827.52202987945,3740.73689886449,-1913.82134085599;-1821.34353298161,3728.26987516029,-1907.54201239527;-1815.14104594200,3715.75469442138,-1901.23856912103;-1808.91464654549,3703.19151285451,-1894.91108929096;-1802.66441244521,3690.58048640181,-1888.55965103010;-1796.39042116290,3677.92177074142,-1882.18433233125;-1790.09275008898,3665.21552128777,-1875.78521105501;-1783.77147648290,3652.46189319216,-1869.36236493016;-1777.42667747328,3639.66104134318,-1862.91587155382;-1771.05843005825,3626.81312036720,-1856.44580839170;-1764.66681110558,3613.91828462882,-1849.95225277834;-1758.25189735296,3600.97668823133,-1843.43528191733;-1752.03412374643,3588.43145438504,-1837.11714123021;-1745.79283874375,3575.83902416049,-1830.77536659195;-1739.52811939113,3563.19955228173,-1824.41003551782;-1733.24004260402,3550.51319321025,-1818.02122539150;-1726.92868516739,3537.78010114535,-1811.60901346530;-1720.59412373589,3525.00043002465,-1805.17347686039;-1714.23643483412,3512.17433352447,-1798.71469256701;-1707.85569485686,3499.30196506041,-1792.23273744474;-1701.45198006928,3486.38347778771,-1785.72768822269;-1695.02536660716,3473.41902460169,-1779.19962149971;-1688.75030970994,3460.75929925767,-1772.82442531832;-1682.45221469859,3448.05332738719,-1766.42607072715;-1676.13115786936,3435.30126220883,-1760.00463448751;-1669.78721538884,3422.50325668066,-1753.56019323019;-1663.42046329416,3409.65946350073,-1747.09282345566;-1657.03097749312,3396.77003510730,-1740.60260153423;-1650.61883376455,3383.83512367959,-1734.08960370637;-1644.18410775842,3370.85488113798,-1727.55390608287;-1637.72687499615,3357.82945914460,-1720.99558464509;-1631.24721087078,3344.75900910375,-1714.41471524519;-1624.74519064716,3331.64368216227,-1707.81137360633;-1618.22088946227,3318.48362921006,-1701.18563532290;-1611.67438232531,3305.27900088045,-1694.53757586071;-1605.10574411803,3292.02994755070,-1687.86727055728;-1598.51504959486,3278.73661934240,-1681.17479462199;-1591.90237338324,3265.39916612198,-1674.46022313636;-1585.26778998369,3252.01773750100,-1667.72363105419;-1578.61137377011,3238.59248283666,-1660.96509320183;-1571.93319899002,3225.12355123230,-1654.18468427840;-1565.23333976469,3211.61109153770,-1647.38247885599;-1558.51187008943,3198.05525234959,-1640.55855137986;-1551.76886383373,3184.45618201203,-1633.71297616866;-1545.00439474156,3170.81402861689,-1626.84582741466;-1538.21853643150,3157.12894000425,-1619.95717918398;-1531.41136239698,3143.40106376277,-1613.04710541673;-1524.58294600648,3129.63054723013,-1606.11567992727;-1517.73336050378,3115.81753749355,-1599.16297640443;-1510.86267900813,3101.96218139011,-1592.18906841172;-1503.97097451441,3088.06462550709,-1585.19402938747;-1497.05831989345,3074.12501618259,-1578.17793264513;-1490.12478789216,3060.14349950582,-1571.14085137344;-1483.17045113373,3046.12022131745,-1564.08285863661;-1476.19538211787,3032.05532721019,-1557.00402737458;-1469.19965322097,3017.94896252896,-1549.90443040313;-1462.18333669638,3003.80127237163,-1542.78414041424;-1455.14650467450,2989.61240158907,-1535.64322997613;-1448.08922916310,2975.38249478583,-1528.48177153357;-1441.01158204742,2961.11169632038,-1521.29983740804;-1433.91363509044,2946.80015030558,-1514.09749979793;-1426.79545993306,2932.44800060911,-1506.87483077879;-1419.65712809424,2918.05539085372,-1499.63190230342;-1412.49871097131,2903.62246441784,-1492.36878620221;-1405.32027984010,2889.14936443588,-1485.08555418325;-1398.12190585512,2874.63623379854,-1477.78227783252;-1390.90366004978,2860.08321515332,-1470.45902861415;-1383.66561333662,2845.49045090490,-1463.11587787057;-1376.40783650744,2830.85808321547,-1455.75289682272;-1369.13040023353,2816.18625400521,-1448.37015657026;-1361.83337506587,2801.47510495256,-1440.96772809171;-1354.51683143532,2786.72477749473,-1433.54568224474;-1347.51546723520,2772.60808884227,-1426.44146596002;-1340.49417746952,2758.45140312916,-1419.31722155748;-1333.45303321763,2744.25486309679,-1412.17302054923;-1326.39210543733,2730.01861124246,-1405.00893432502;-1319.31146496507,2715.74278981969,-1397.82503415248;-1312.21118251613,2701.42754083862,-1390.62139117726;-1305.09132868474,2687.07300606630,-1383.39807642322;-1297.95197394447,2672.67932702738,-1376.15516079274;-1290.79318864822,2658.24664500417,-1368.89271506676;-1283.61504302851,2643.77510103715,-1361.61080990506;-1276.41760719768,2629.26483592542,-1354.30951584645;-1269.20095114805,2614.71599022702,-1346.98890330897;-1261.96514475207,2600.12870425927,-1339.64904259000;-1254.71025776264,2585.50311809925,-1332.29000386658;-1247.43635981315,2570.83937158409,-1324.91185719549;-1240.14352041777,2556.13760431147,-1317.51467251353;-1232.83180897158,2541.39795563981,-1310.09851963760;-1225.50129475081,2526.62056468882,-1302.66346826501;-1218.15204691297,2511.80557033980,-1295.20958797359;-1210.78413449709,2496.95311123606,-1287.73694822191;-1203.39762642387,2482.06332578321,-1280.24561834944;-1195.99259149584,2467.13635214954,-1272.73566757674;-1188.56909839764,2452.17232826653,-1265.20716500570;-1181.12721569609,2437.17139182905,-1257.66017961966;-1173.66701184046,2422.13368029583,-1250.09478028361;-1166.18855516260,2407.05933088977,-1242.51103574440;-1158.69191387717,2391.94848059841,-1234.90901463092;-1151.17715608174,2376.80126617406,-1227.28878545421;-1143.64434975709,2361.61782413451,-1219.65041660779;-1136.09356276726,2346.39829076304,-1211.99397636767;-1128.52486285982,2331.14280210903,-1204.31953289265;-1120.93831766604,2315.85149398821,-1196.62715422448;-1113.33399470103,2300.52450198307,-1188.91690828801;-1105.71196136393,2285.16196144312,-1181.18886289136;-1098.07228493813,2269.76400748541,-1173.44308572617;-1090.41503259137,2254.33077499472,-1165.67964436771;-1082.74027137603,2238.86239862406,-1157.89860627509;-1075.04806822914,2223.35901279485,-1150.10003879138;-1067.33848997273,2207.82075169748,-1142.28400914391;-1059.61160331390,2192.24774929148,-1134.45058444432;-1051.86747484498,2176.64013930593,-1126.59983168877;-1044.10617104385,2160.99805524000,-1118.73181775821;-1036.32775827389,2145.32163036285,-1110.84660941838;-1028.53230278431,2129.61099771442,-1102.94427332012;-1020.71987071032,2113.86629010561,-1095.02487599953;-1012.89052807323,2098.08764011856,-1087.08848387808;-1005.04434078062,2082.27518010703,-1079.13516326280;-997.181374626627,2066.42904219687,-1071.16498034652;-989.301695291957,2050.54935828616,-1063.17800120796;-981.405368344157,2034.63626004566,-1055.17429181193;-973.733463070797,2019.17435033263,-1047.39690143388;-966.044654493206,2003.67851202510,-1039.60252272506;-958.339008537383,1988.14887751502,-1031.79122201228;-950.616591015315,1972.58557896533,-1023.96306550764;-942.877467625136,1956.98874831031,-1016.11811930866;-935.121703951338,1941.35851725597,-1008.25644939848;-927.349365464910,1925.69501728039,-1000.37812164600;-919.560517523525,1909.99837963401,-992.483201806113;-911.755225371705,1894.26873534003,-984.571755519812;-903.933554140949,1878.50621519466,-976.643848314358;-896.095568849969,1862.71094976756,-968.699545603499;-888.241334404803,1846.88306940208,-960.738912687595;-880.370915599016,1831.02270421570,-952.762014753814;-872.484377113836,1815.12998410025,-944.768916876271;-864.581783518366,1799.20503872236,-936.759684016242;-856.663199269660,1783.24799752363,-928.734381022242;-848.728688713004,1767.25898972116,-920.693072630305;-840.778316081957,1751.23814430768,-912.635823464027;-832.812145498632,1735.18559005204,-904.562698034851;-824.830240973789,1719.10145549949,-896.473760742157;-816.832666407013,1702.98586897195,-888.369075873445;-808.819485586843,1686.83895856833,-880.248707604461;-800.790762191004,1670.66085216498,-872.112719999438;-792.746559786516,1654.45167741589,-863.961177011197;-784.686941829888,1638.21156175310,-855.794142481347;-776.611971667216,1621.94063238690,-847.611680140386;-768.521712534395,1605.63901630624,-839.413853607911;-760.416227557313,1589.30684027912,-831.200726392813;-752.295579751897,1572.94423085271,-822.972361893330;-744.159832024387,1556.55131435387,-814.728823397313;-736.009047171418,1540.12821688931,-806.470174082317;-727.843287880209,1523.67506434603,-798.196477015790;-719.662616728716,1507.19198239153,-789.907795155220;-711.467096185783,1490.67909647420,-781.604191348300;-703.256788611307,1474.13653182362,-773.285728333083;-695.031756256376,1457.56441345081,-764.952468738125;-686.792061263441,1440.96286614862,-756.604475082662;-678.537765666455,1424.33201449200,-748.241809776745;-670.268931391056,1407.67198283834,-739.864535121427;-661.985620254667,1390.98289532770,-731.472713308862;-653.687893966723,1374.26487588324,-723.066406422535;-645.375814128732,1357.51804821139,-714.645676437327;-637.049442234505,1340.74253580225,-706.210585219737;-628.708839670310,1323.93846192995,-697.761194528052;-620.354067714930,1307.10594965275,-689.297566012388;-611.985187539922,1290.24512181352,-680.819761214966;-603.602260209696,1273.35610103999,-672.327841570184;-595.205346681712,1256.43900974506,-663.821868404818;-586.794507806589,1239.49397012706,-655.301902938131;-578.369804328286,1222.52110417010,-646.768006282054;-570.162916009050,1205.98613970284,-638.453761072041;-561.941920117044,1189.42286022462,-630.125339445981;-553.706877720901,1172.83138837282,-621.782802843763;-545.457849781766,1156.21184656892,-613.426212597113;-537.194897153552,1139.56435701905,-605.055629929849;-528.918080583021,1122.88904171413,-596.671115957962;-520.627460709967,1106.18602243026,-588.272731689806;-512.323098067319,1089.45542072889,-579.860538026193;-504.005053081358,1072.69735795729,-571.434595760620;-495.673386071815,1055.91195524875,-562.994965579362;-487.328157252049,1039.09933352291,-554.541708061655;-478.969426729146,1022.25961348597,-546.074883679794;-470.597254504117,1005.39291563110,-537.594552799333;-462.211700472001,988.499360238626,-529.100775679190;-453.812824422085,971.579067376502,-520.593612471865;-445.400686037953,954.632156900383,-512.073123223497;-436.975344897695,937.658748454048,-503.539367874065;-428.536860474047,920.658961469691,-494.992406257536;-420.085292134494,903.632915168120,-486.432298101966;-411.620699141427,886.580728559081,-477.859103029659;-403.143140652377,869.502520441721,-469.272880557405;-394.652675720006,852.398409404571,-460.673690096465;-386.149363292351,835.268513826038,-452.061590952824;-377.633262212965,818.112951874688,-443.436642327328;-369.104431220998,800.931841509411,-434.798903315767;-360.562928951388,783.725300479801,-426.148432909072;-352.008813934991,766.493446326420,-417.485289993437;-343.442144598749,749.236396381133,-408.809533350496;-334.862979265746,731.954267767224,-400.121221657376;-326.271376155444,714.647177399870,-391.420413486938;-317.667393383762,697.315241986295,-382.707167307851;-309.051088963253,679.958578026133,-373.981541484777;-300.422520803192,662.577301811600,-365.243594278455;-291.781746709788,645.171529427918,-356.493383845915;-283.128824386268,627.741376753493,-347.730968240567;-274.463811432991,610.286959460133,-338.956405412310;-265.786765347689,592.808393013541,-330.169753207779;-257.097743525483,575.305792673344,-321.371069370359;-248.396803259069,557.779273493467,-312.560411540376;-239.684001738909,540.228950322512,-303.737837255284;-230.959396053275,522.654937803856,-294.903403949712;-222.223043188431,505.057350376013,-286.057168955651;-213.475000028764,487.436302272892,-277.199189502580;-204.715323356934,469.791907524104,-268.329522717620;-195.944069853974,452.124279955164,-259.448225625637;-187.161296099425,434.433533187756,-250.555355149371;-178.367058571524,416.719780640122,-241.650968109637;-169.561413647277,398.983135527194,-232.735121225388;-160.744417602600,381.223710860890,-223.807871113860;-151.916126612509,363.441619450489,-214.869274290766;-143.225111480037,345.935521605090,-206.069121790484;-134.522684463601,328.406521713589,-197.257504438731;-125.808901833197,310.854732776783,-188.434478847594;-117.083819757588,293.280267592156,-179.600101527298;-108.347494304417,275.683238754119,-170.754428886324;-99.5999814403892,258.063758654366,-161.897517231588;-90.8413370313263,240.421939481990,-153.029422768499;-82.0716168424051,222.757893223959,-144.150201601199;-73.2908765381662,205.071731665131,-135.259909732571;-64.4991716827786,187.363566388794,-126.358603064505;-55.6965577400528,169.633508776684,-117.446337397913;-46.8830900736059,151.881670009321,-108.523168432895;-38.0588239470251,134.108161066337,-99.5891517689039;-29.2238145240152,116.313092726772,-90.6443429048920;-20.3781168684106,98.4965755691000,-81.6887972393259;-11.5217859444381,80.6587199717528,-72.7225700704503;-2.65487661678342,62.7996361132593,-63.7457165963551;6.22255634930358,44.9194339724526,-54.7582919150809;15.1104582878081,27.0182233288764,-45.7603510248229;24.0087746319128,9.09611376285857,-36.7519488239667;32.9174509137883,-8.84678534406642,-27.7331401113014;41.8364327645138,-26.8103648089983,-18.7039795860985;50.7656659139504,-44.7945156474167,-9.66452184823983;59.7050961905668,-62.7991290728301,-0.614821398393741;68.6546695214074,-80.8240964967130,8.44506736195388;77.6143319318400,-98.8693095279973,17.5150901302439;86.5840295455426,-116.934659973047,26.5951927028318;95.5637085843473,-135.020039835342,35.6853209748297;104.553315368061,-153.125341315123,44.7854209399257;113.552796314397,-171.250456809249,53.8954386903155;122.562097938876,-189.395278910997,63.0153204166008;131.581166854584,-207.559700409584,72.1450124075492;140.609949772203,-225.743614290216,81.2844610501188;149.648393499783,-243.946913733643,90.4336128292357;158.696444942620,-262.169492115908,99.5924143276665;167.754051103235,-280.411243008296,108.760812225997;176.821159081103,-298.672060176807,117.938753302360;185.897716072657,-316.951837582148,127.126184432442;194.983669371079,-335.250469379324,136.323052589266;204.078966366243,-353.567849917516,145.529304843143;213.183554544571,-371.903873739797,154.744888361519;222.297381488883,-390.258435582825,163.969750408826;231.420394878310,-408.631430376674,173.203838346397;240.552542488187,-427.022753244616,182.447099632354;249.693772189871,-445.432299502754,191.699481821431;258.844031950706,-463.859964659952,200.960932564929;268.003269833809,-482.305644417409,210.231399610510;277.171433998073,-500.769234668658,219.510830802194;286.348472697907,-519.250631499050,228.799174080098;295.534334283201,-537.749731185681,238.096377480404;304.586018908593,-555.979072276197,247.258266675748;313.646639641317,-574.226344034219,256.429130365838;322.716144749105,-592.491442571109,265.608916503413;331.794482595442,-610.774264190519,274.797573137551;340.881601639458,-629.074705388175,283.995048413555;349.977450435742,-647.392662851504,293.201290572771;359.081977634287,-665.728033459525,302.416247952528;368.195131980351,-684.080714282564,311.639868986001;377.316862314322,-702.450602581993,320.872102202076;386.447117571635,-720.837595810052,330.112896225261;395.585846782623,-739.241591609555,339.362199775540;404.732999072440,-757.662487813733,348.619961668295;413.888523660869,-776.100182445856,357.886130814113;423.052369862300,-794.554573719177,367.160656218761;432.224487085551,-813.025560036578,376.443486983009;441.404824833768,-831.513039990370,385.734572302525;450.593332704312,-850.016912362063,395.033861467767;459.789960388646,-868.537076122145,404.341303863865;468.994657672239,-887.073430429877,413.656848970523;478.207374434368,-905.625874632910,422.980446361824;487.428060648128,-924.194308267292,432.312045706235;496.656666380234,-942.778631057080,441.651596766414;505.893141790921,-961.378742914131,450.999049399101;515.137437133834,-979.994543937884,460.354353555014;524.389502755935,-998.625934415181,469.717459278753;533.649289097328,-1017.27281481990,479.088316708621;542.916746691268,-1035.93508581298,488.466876076638;552.191826163912,-1054.61264824194,497.853087708283;561.474478234267,-1073.30540314072,507.246902022452;570.764653714090,-1092.01325172955,516.648269531350;580.062303507786,-1110.73609541470,526.057140840384;589.367378612228,-1129.47383578812,535.473466647992;598.679830116703,-1148.22637462736,544.897197745583;607.999609202817,-1166.99361389534,554.328285017441;617.326667144311,-1185.77545574001,563.766679440541;626.660955307044,-1204.57180249430,573.212332084531;636.002425148798,-1223.38255667575,582.665194111535;645.351028219186,-1242.20762098629,592.125216776062;654.706716159604,-1261.04689831216,601.592351424956;664.069440703052,-1279.90029172358,611.066549497220;673.439153674043,-1298.76770447451,620.547762523913;682.815806988529,-1317.64904000255,630.035942128088;692.199352653711,-1336.54420192853,639.531040024598;701.589742768033,-1355.45309405651,649.033008020081;710.986929520992,-1374.37562037340,658.541798012779;720.390865193071,-1393.31168504881,668.057361992467;729.801502155628,-1412.26119243484,677.579652040337;739.218792870742,-1431.22404706578,687.108620328851;748.642689891186,-1450.20015365803,696.644219121707;758.073145860244,-1469.18941710976,706.186400773654;767.372424473713,-1487.91495684974,715.596297722823;776.678372008917,-1506.65387471053,725.012888607821;785.990941038826,-1525.40607544837,734.436125711909;795.310084227251,-1544.17146400193,743.865961409730;804.635754328665,-1562.94994549192,753.302348167137;813.967904188123,-1581.74142522096,762.745238541107;823.306486741147,-1600.54580867335,772.194585179623;832.651455013612,-1619.36300151480,781.650340821571;842.002762121659,-1638.19290959231,791.112458296637;851.360361271559,-1657.03543893386,800.580890525182;860.724205759638,-1675.89049574826,810.055590518157;870.094248972171,-1694.75798642498,819.536511377005;879.470444385214,-1713.63781753374,829.023606293485;888.852745564609,-1732.52989582458,838.516828549678;898.241106165747,-1751.43412822736,848.016131517755;907.635479933585,-1770.35042185179,857.521468659985;917.035820702479,-1789.27868398711,867.032793528569;926.442082396059,-1808.21882210183,876.550059765518;935.854219027158,-1827.17074384359,886.073221102580;945.272184697729,-1846.13435703898,895.602231361154;954.695933598672,-1865.10956969321,905.137044452115;964.125420009804,-1884.09628999004,914.677614375789;973.560598299701,-1903.09442629147,924.223895221788;983.001422925642,-1922.10388713762,933.775841168961;992.447848433432,-1941.12458124638,943.333406485202;1001.89982945737,-1960.15641751331,952.896545527431;1011.35732072013,-1979.19930501152,962.465212741482;1020.82027703265,-1998.25315299127,972.039362661963;1030.28865329400,-2017.31787087981,981.618949912130;1039.76240449133,-2036.39336828129,991.203929203859;1049.24148569973,-2055.47955497648,1000.79425533751;1058.72585208217,-2074.57634092251,1010.38988320179;1068.21545888934,-2093.68363625277,1019.99076777370;1077.71026145958,-2112.80135127661,1029.59686411840;1087.21021521878,-2131.92939647917,1039.20812738909;1096.71527568033,-2151.06768252132,1048.82451282703;1106.22539844488,-2170.21612023912,1058.44597576122;1115.74053920037,-2189.37462064398,1068.07247160852;1125.26065372187,-2208.54309492220,1077.70395587338;1134.78569787151,-2227.72145443492,1087.34038414786;1144.31562759833,-2246.90961071784,1096.98171211145;1153.85039893825,-2266.10747548106,1106.62789553100;1163.38996801389,-2285.31496060882,1116.27889026062;1172.93429103456,-2304.53197815939,1125.93465224158;1182.48332429605,-2323.75844036479,1135.59513750218;1192.03702418065,-2342.99425963063,1145.26030215772;1201.59534715697,-2362.23934853589,1154.93010241031;1211.15824977987,-2381.49361983276,1164.60449454885;1220.72568869032,-2400.75698644635,1174.28343494884;1230.29762061540,-2420.02936147463,1183.96688007240;1239.67493020280,-2438.91047877154,1193.45407913570;1249.05693667758,-2457.80101448469,1202.94598865031;1258.44359654871,-2476.70088127305,1212.44256485785;1267.83486641172,-2495.60999196944,1221.94376408705;1277.23070294865,-2514.52825958037,1231.44954275361;1286.63106292790,-2533.45559728578,1240.95985736014;1296.03590320413,-2552.39191843881,1250.47466449601;1305.44518071822,-2571.33713656574,1259.99392083733;1314.85885249709,-2590.29116536564,1269.51758314674;1324.27687565365,-2609.25391871020,1279.04560827338;1333.69920738667,-2628.22531064361,1288.57795315281;1343.12580498076,-2647.20525538231,1298.11457480685;1352.55662580615,-2666.19366731478,1307.65543034352;1361.99162731869,-2685.19046100135,1317.20047695693;1371.43076705970,-2704.19555117401,1326.74967192717;1380.87400265589,-2723.20885273621,1336.30297262024;1390.32129181929,-2742.23028076274,1345.86033648795;1399.77259234706,-2761.25975049929,1355.42172106774;1409.22786212150,-2780.29717736258,1364.98708398271;1418.68705910991,-2799.34247693993,1374.55638294144;1428.15014136447,-2818.39556498915,1384.12957573789;1437.61706702217,-2837.45635743837,1393.70662025137;1447.08779430471,-2856.52477038576,1403.28747444636;1456.56228151841,-2875.60072009943,1412.87209637245;1466.04048705405,-2894.68412301714,1422.46044416423;1475.52236938690,-2913.77489574625,1432.05247604125;1485.00788707650,-2932.87295506332,1441.64815030783;1494.49699876663,-2951.97821791412,1451.24742535304;1503.98966318519,-2971.09060141328,1460.85025965053;1513.48583914414,-2990.21002284425,1470.45661175854;1522.98548553935,-3009.33639965899,1480.06644031970;1532.48856135052,-3028.46964947775,1489.67970406097;1541.99502564111,-3047.60969008900,1499.29636179355;1551.50483755827,-3066.75643944923,1508.91637241283;1561.01795633263,-3085.90981568260,1518.53969489817;1570.53434127835,-3105.06973708095,1528.16628831294;1580.05395179289,-3124.23612210343,1537.79611180434;1589.57674735705,-3143.40888937651,1547.42912460334;1599.10268753476,-3162.58795769356,1557.06528602455;1608.63173197305,-3181.77324601487,1566.70455546620;1618.16384040193,-3200.96467346732,1576.34689240995;1627.69897263432,-3220.16215934428,1585.99225642087;1637.23708856593,-3239.36562310534,1595.64060714730;1646.77814817516,-3258.57498437618,1605.29190432076;1656.32211152307,-3277.79016294838,1614.94610775589;1665.86893875320,-3297.01107877922,1624.60317735035;1675.41859009154,-3316.23765199147,1634.26307308467;1684.97102584639,-3335.46980287323,1643.92575502221;1694.52620640832,-3354.70745187779,1653.59118330907;1704.08409225002,-3373.95051962328,1663.25931817395;1713.58064128521,-3393.07026732084,1672.86559157312;1723.07990841051,-3412.19545966418,1682.47458462668;1732.58185419701,-3431.32601746870,1692.08625766193;1742.08643929790,-3450.46186171470,1701.70057108881;1751.59362444830,-3469.60291354693,1711.31748539960;1761.10337046521,-3488.74909427462,1720.93696116901;1770.61563824743,-3507.90032537121,1730.55895905398;1780.13038877541,-3527.05652847410,1740.18343979359;1789.64758311126,-3546.21762538463,1749.81036420906;1799.16718239852,-3565.38353806775,1759.43969320353;1808.68914786222,-3584.55418865190,1769.07138776207;1818.21344080866,-3603.72949942881,1778.70540895153;1827.74002262539,-3622.90939285333,1788.34171792048;1837.26885478110,-3642.09379154319,1797.98027589907;1846.79989882553,-3661.28261827892,1807.62104419902;1856.33311638933,-3680.47579600351,1817.26398421340;1865.86846918412,-3699.67324782250,1826.90905741672;1875.40591900217,-3718.87489700340,1836.55622536464;1884.94542771653,-3738.08066697591,1846.20544969404;1894.48695728079,-3757.29048133146,1855.85669212284;1904.03046972907,-3776.50426382315,1865.50991444993;1913.57592717589,-3795.72193836555,1875.16507855506;1923.12329181608,-3814.94342903450,1884.82214639881;1932.67252592472,-3834.16866006692,1894.48108002243;1942.22359185702,-3853.39755586071,1904.14184154779;1951.77645204827,-3872.63004097445,1913.80439317727;1961.33106901366,-3891.86604012730,1923.46869719368;1970.88740534832,-3911.10547819879,1933.13471596017;1980.44542372711,-3930.34828022864,1942.80241192011;1990.00508690462,-3949.59437141665,1952.47174759708;1999.56635771501,-3968.84367712234,1962.14268559467;2009.12919907199,-3988.09612286500,1971.81518859648;2018.69357396868,-4007.35163432337,1981.48921936599;2028.25944547752,-4026.61013733544,1991.16474074647;2037.82677675021,-4045.87155789838,2000.84171566090;2047.39553101762,-4065.13582216828,2010.52010711188;2056.96567158966,-4084.40285646000,2020.19987818152;2066.53716185526,-4103.67258724701,2029.88099203143;2076.10996528221,-4122.94494116115,2039.56341190249;2085.68404541713,-4142.21984499251,2049.24710111488;2095.25936588535,-4161.49722568928,2058.93202306799;2104.83589039080,-4180.77701035745,2068.61814124021;2114.41358271599,-4200.05912626078,2078.30541918902;2123.99240672186,-4219.34350082050,2087.99382055071;2133.57232634775,-4238.63006161527,2097.68330904049;2143.15330561122,-4257.91873638085,2107.37384845222;2152.73530860806,-4277.20945301002,2117.06540265843;2162.31829951215,-4296.50213955240,2126.75793561023;2171.90224257540,-4315.79672421424,2136.45141133717;2181.48710212762,-4335.09313535827,2146.14579394716;2191.19638466792,-4354.63964863934,2155.96560448538;2200.90633885042,-4374.18749634090,2165.78607519036;2210.61692951298,-4393.73660784643,2175.60717068167;2220.32812157053,-4413.28691269411,2185.42885565641;2230.03988001498,-4432.83834057671,2195.25109488909;2239.75216991517,-4452.39082134143,2205.07385323157;2249.46495641669,-4471.94428498964,2214.89709561296;2259.17820474190,-4491.49866167682,2224.72078703954;2268.89188018980,-4511.05388171228,2234.54489259465;2278.60594813590,-4530.60987555907,2244.36937743865;2288.32037403224,-4550.16657383378,2254.19420680880;2298.03512340720,-4569.72390730638,2264.01934601918;2307.75016186547,-4589.28180690001,2273.84476046061;2317.46545508797,-4608.84020369088,2283.67041560059;2327.18096883175,-4628.39902890805,2293.49627698315;2336.89666892990,-4647.95821393326,2303.32231022882;2346.61252129145,-4667.51769030076,2313.14848103453;2356.32849190137,-4687.07738969721,2322.97475517353;2366.04454682034,-4706.63724396138,2332.80109849529;2375.76065218484,-4726.19718508416,2342.62747692545;2385.47677420689,-4745.75714520813,2352.45385646565;2395.19287917414,-4765.31705662775,2362.28020319359;2404.90893344961,-4784.87685178879,2372.10648326279;2414.62490347177,-4804.43646328852,2381.93266290262;2424.34075575434,-4823.99582387528,2391.75870841816;2434.05645688626,-4843.55486644850,2401.58458619013;2443.77197353160,-4863.11352405839,2411.41026267481;2453.48727242946,-4882.67172990583,2421.23570440393;2463.20232039390,-4902.22941734227,2431.06087798464;2472.91708431387,-4921.78651986944,2440.88575009938;2482.63153115311,-4941.34297113928,2450.71028750582;2492.34562795004,-4960.89870495367,2460.53445703674;2502.05934181776,-4980.45365526445,2470.35822560003;2511.77263994385,-5000.00775617298,2480.18156017847;2521.48548959042,-5019.56094193029,2490.00442782982;2531.19785809389,-5039.11314693659,2499.82679568656;2540.90971286503,-5058.66430574141,2509.64863095595;2550.62102138880,-5078.21435304318,2519.46990091986;2560.33175122430,-5097.76322368924,2529.29057293472;2570.04187000467,-5117.31085267559,2539.11061443145;2579.75134543702,-5136.85717514673,2548.92999291534;2589.46014530236,-5156.40212639556,2558.74867596600;2599.16823745548,-5175.94564186308,2568.56663123725;2608.87558982491,-5195.48765713839,2578.38382645706;2618.58217041281,-5215.02810795843,2588.20022942749;2628.28794729490,-5234.56693020780,2598.01580802454;2637.99288862037,-5254.10405991864,2607.83053019810;2647.69696261185,-5273.63943327051,2617.64436397193;2657.40013756519,-5293.17298659005,2627.45727744345;2667.10238184955,-5312.70465635106,2637.26923878377;2676.20712228693,-5331.03519757476,2646.47877465941;2685.31169344941,-5349.36538592885,2655.68812617500;2694.41606264398,-5367.69515575139,2664.89726043021;2703.52019725288,-5386.02444153156,2674.10614460042;2712.62406473352,-5404.35317790946,2683.31474593659;2721.72763261840,-5422.68129967596,2692.52303176524;2730.83086851506,-5441.00874177265,2701.73096948833;2739.93374010594,-5459.33543929142,2710.93852658316;2749.03621514831,-5477.66132747448,2720.14567060229;2758.13826147421,-5495.98634171418,2729.35236917352;2767.23984699033,-5514.31041755271,2738.55858999968;2776.34093967796,-5532.63349068206,2747.76430085864;2785.44150759287,-5550.95549694380,2756.96946960320;2794.54151886524,-5569.27637232888,2766.17406416101;2803.64094169956,-5587.59605297748,2775.37805253442;2812.73974437460,-5605.91447517888,2784.58140280051;2821.83789524325,-5624.23157537125,2793.78408311091;2830.93536273248,-5642.54729014145,2802.98606169176;2840.03211534324,-5660.86155622490,2812.18730684359;2849.12812165039,-5679.17431050543,2821.38778694128;2858.22335030258,-5697.48549001504,2830.58747043393;2867.31777002223,-5715.79503193385,2839.78632584483;2876.41134960538,-5734.10287358975,2848.98432177130;2885.50405792162,-5752.40895245839,2858.18142688466;2894.59586391403,-5770.71320616294,2867.37760993013;2903.68673659909,-5789.01557247392,2876.57283972673;2912.77664506658,-5807.31598930908,2885.76708516725;2921.86555847950,-5825.61439473317,2894.96031521811;2930.95344607400,-5843.91072695779,2904.15249891925;2940.04027715928,-5862.20492434125,2913.34360538414;2949.12602111750,-5880.49692538836,2922.53360379963;2958.21064740373,-5898.78666875025,2931.72246342584;2967.29412554583,-5917.07409322432,2940.91015359616;2976.37642514439,-5935.35913775391,2950.09664371712;2985.45751587261,-5953.64174142820,2959.28190326824;2994.53736747628,-5971.92184348211,2968.46590180210;3003.61594977365,-5990.19938329601,2977.64860894410;3012.69323265533,-6008.47430039564,2986.82999439247;3021.76918608426,-6026.74653445191,2996.01002791816;3030.84378009559,-6045.01602528072,3005.18867936473;3039.91698479662,-6063.28271284287,3014.36591864833;3048.98877036669,-6081.54653724378,3023.54171575757;3058.05910705709,-6099.80743873335,3032.71604075340;3067.12796519104,-6118.06535770593,3041.88886376913;3076.19531516353,-6136.32023469988,3051.06015501023;3085.26112744130,-6154.57201039775,3060.22988475436;3094.32537256271,-6172.82062562580,3069.39802335121;3103.38802113768,-6191.06602135402,3078.56454122241;3112.44904384760,-6209.30813869591,3087.72940886152;3121.50841144525,-6227.54691890825,3096.89259683384;3130.56609475473,-6245.78230339109,3106.05407577645;3139.62206467136,-6264.01423368745,3115.21381639804;3148.67629216160,-6282.24265148319,3124.37178947884;3157.72874826298,-6300.46749860686,3133.52796587058;3166.77940408399,-6318.68871702951,3142.68231649634;3175.82823080405,-6336.90624886458,3151.83481235053;3184.87519967337,-6355.12003636766,3160.98542449877;3193.92028201289,-6373.33002193639,3170.13412407783;3202.96344921420,-6391.53614811021,3179.28088229551;3212.00467273951,-6409.73835757036,3188.42567043062;3221.04392412142,-6427.93659313948,3197.56845983283;3230.08117496304,-6446.13079778169,3206.70922192265;3239.11639693774,-6464.32091460225,3215.84792819130;3248.14956178915,-6482.50688684743,3224.98455020063;3257.18064133103,-6500.68865790442,3234.11905958307;3266.20960744729,-6518.86617130113,3243.25142804154;3275.23643209178,-6537.03937070599,3252.38162734936;3284.26108728828,-6555.20819992779,3261.50962935013;3293.28354513040,-6573.37260291557,3270.63540595771;3302.30377778152,-6591.53252375843,3279.75892915615;3311.32175747469,-6609.68790668535,3288.88017099950;3320.33745651254,-6627.83869606503,3297.99910361186;3329.35084726722,-6645.98483640576,3307.11569918720;3338.36190218029,-6664.12627235521,3316.22992998935;3347.37059376269,-6682.26294870028,3325.34176835185;3356.37689459461,-6700.39481036702,3334.45118667794;3365.38077732542,-6718.52180242031,3343.55815744041;3374.38221467363,-6736.64387006387,3352.66265318159;3383.38117942672,-6754.76095863990,3361.76464651318;3392.37764444116,-6772.87301362914,3370.86411011628;3401.37158264227,-6790.97998065055,3379.96101674119;3410.36296702415,-6809.08180546118,3389.05533920742;3419.35177064961,-6827.17843395608,3398.14705040359;3428.33796665007,-6845.26981216803,3407.23612328729;3437.32152822552,-6863.35588626747,3416.32253088509;3446.30242864437,-6881.43660256224,3425.40624629237;3455.28064124345,-6899.51190749757,3434.48724267333;3464.25613942788,-6917.58174765578,3443.56549326084;3473.22889667100,-6935.64606975617,3452.64097135637;3482.19888651428,-6953.70482065485,3461.71365032994;3491.16608256726,-6971.75794734459,3470.78350362000;3500.13045850747,-6989.80539695466,3479.85050473340;3509.09198808035,-7007.84711675070,3488.91462724527;3518.05064509913,-7025.88305413448,3497.97584479892;3527.00640344480,-7043.91315664377,3507.03413110583;3535.95923706600,-7061.93737195224,3516.08945994550;3544.90911997899,-7079.95564786927,3525.14180516543;3553.85602626748,-7097.96793233969,3534.19114068096;3562.79993008266,-7115.97417344380,3543.23744047530;3571.74080564300,-7133.97431939703,3552.28067859933;3581.23596975403,-7153.08870122150,3561.88274967012;3590.72730971098,-7172.19538804381,3571.48095672172;3600.21480105249,-7191.29433073273,3581.07527513552;3609.69841938218,-7210.38548028747,3590.66568035824;3619.17814036875,-7229.46878783791,3600.25214790205;3628.65393974557,-7248.54420464384,3609.83465334420;3638.12579331100,-7267.61168209539,3619.41317232720;3647.59367692812,-7286.67117171281,3628.98768055875;3657.05756652460,-7305.72262514586,3638.55815381142;3666.51743809271,-7324.76599417413,3648.12456792281;3675.97326768929,-7343.80123070679,3657.68689879540;3685.42503143553,-7362.82828678222,3667.24512239641;3694.87270551701,-7381.84711456808,3676.79921475782;3704.31626618365,-7400.85766636122,3686.34915197630;3713.75568974955,-7419.85989458733,3695.89491021305;3723.19095259286,-7438.85375180071,3705.43646569371;3732.62203115593,-7457.83919068457,3714.97379470846;3742.04890194502,-7476.81616405039,3724.50687361175;3751.47154153030,-7495.78462483801,3734.03567882230;3760.88992654578,-7514.74452611543,3743.56018682306;3770.30403368927,-7533.69582107877,3753.08037416110;3779.71383972223,-7552.63846305189,3762.59621744751;3789.11932146973,-7571.57240548640,3772.10769335736;3798.52045582048,-7590.49760196168,3781.61477862970;3807.91721972646,-7609.41400618415,3791.11745006723;3817.30959020323,-7628.32157198785,3800.61568453656;3826.69754432955,-7647.22025333376,3810.10945896789;3836.08105924754,-7666.11000431000,3819.59875035509;3845.46011216231,-7684.99077913125,3829.08353575542;3854.83468034218,-7703.86253213904,3838.56379228970;3864.20474111858,-7722.72521780160,3848.03949714217;3873.57027188565,-7741.57879071311,3857.51062756020;3882.93125010060,-7760.42320559436,3866.97716085454;3892.28765328340,-7779.25841729213,3876.43907439906;3901.63945901667,-7798.08438077900,3885.89634563064;3910.98664494570,-7816.90105115340,3895.34895204919;3920.32918877841,-7835.70838363947,3904.79687121759;3929.66706828524,-7854.50633358686,3914.24008076159;3939.00026129894,-7873.29485647040,3923.67855836961;3948.32874571473,-7892.07390789027,3933.11228179289;3957.65249949006,-7910.84344357160,3942.54122884524;3966.97150064455,-7929.60341936440,3951.96537740302;3976.28572726000,-7948.35379124345,3961.38470540508;3985.59515748030,-7967.09451530826,3970.79919085275;3994.89976951132,-7985.82554778269,3980.20881180963;4004.19954162070,-8004.54684501474,3989.61354640152;4013.49445213811,-8023.25836347684,3999.01337281652;4022.78447945490,-8041.96005976530,4008.40826930481;4032.06960202411,-8060.65189060033,4017.79821417860;4041.34979836033,-8079.33381282564,4027.18318581195;4050.08587079226,-8096.92191899282,4036.01955763139;4058.81768264543,-8114.50145473160,4044.85162740378;4067.54521157217,-8132.07237515196,4053.67937263339;4076.26843528774,-8149.63463549021,4062.50277088782;4084.98733157064,-8167.18819110962,4071.32179979819;4093.70187826234,-8184.73299749993,4080.13643705902;4102.41205326723,-8202.26901027718,4088.94666042809;4111.11783455247,-8219.79618518348,4097.75244772631;4119.81920014811,-8237.31447808715,4106.55377683780;4128.51612814689,-8254.82384498245,4115.35062570980;4137.20859670402,-8272.32424198901,4124.14297235230;4145.89658403740,-8289.81562535238,4132.93079483841;4154.58006842733,-8307.29795144335,4141.71407130393;4163.25902821651,-8324.77117675804,4150.49277994746;4171.93344181000,-8342.23525791779,4159.26689903032;4180.60328767495,-8359.69015166852,4168.03640687622;4189.26854434089,-8377.13581488148,4176.80128187165;4197.92919039916,-8394.57220455202,4185.56150246528;4206.58520450330,-8411.99927780035,4194.31704716830;4215.23656536871,-8429.41699187089,4203.06789455412;4223.88325177264,-8446.82530413222,4211.81402325834;4232.52524255419,-8464.22417207718,4220.55541197882;4241.16251661400,-8481.61355332208,4229.29203947523;4249.79505291443,-8498.99340560722,4238.02388456938;4258.42283047940,-8516.36368679646,4246.75092614494;4267.04582839429,-8533.72435487708,4255.47314314744;4275.66402580579,-8551.07536795947,4264.19051458403;4284.27740192201,-8568.41668427732,4272.90301952364;4292.88593601227,-8585.74826218726,4281.61063709679;4301.48960740696,-8603.07006016845,4290.31334649537;4310.08839549770,-8620.38203682309,4299.01112697289;4318.68227973704,-8637.68415087567,4307.70395784411;4327.27123963846,-8654.97636117301,4316.39181848508;4335.85525477630,-8672.25862668413,4325.07468833305;4344.43430478578,-8689.53090650030,4333.75254688652;4353.00836936265,-8706.79315983433,4342.42537370485;4361.57742826343,-8724.04534602102,4351.09314840850;4370.14146130509,-8741.28742451658,4359.75585067875;4378.70044836520,-8758.51935489884,4368.41346025782;4387.25436938164,-8775.74109686678,4377.06595694859;4395.80320435265,-8792.95261024052,4385.71332061461;4404.34693333667,-8810.15385496112,4394.35553118004;4412.88553645245,-8827.34479109065,4402.99256862961;4421.41899387863,-8844.52537881150,4411.62441300837;4429.94728585405,-8861.69557842687,4420.25104442185;4438.47039267744,-8878.85535036027,4428.87244303583;4446.98829470741,-8896.00465515540,4437.48858907632;4455.50097236223,-8913.14345347577,4446.09946282934;4464.00840612016,-8930.27170610531,4454.70504464121;4472.51057651890,-8947.38937394732,4463.30531491806;4481.00746415578,-8964.49641802480,4471.90025412597;4489.49904968761,-8981.59279948025,4480.48984279086;4497.98531383063,-8998.67847957539,4489.07406149840;4506.46623736041,-9015.75341969115,4497.65289089394;4514.94180111180,-9032.81758132742,4506.22631168246;4523.41198597885,-9049.87092610303,4514.79430462845;4531.87677291470,-9066.91341575536,4523.35685055585;4540.33614293160,-9083.94501214054,4531.91393034802;4548.79007710063,-9100.96567723283,4540.46552494755;4557.23855655187,-9117.97537312490,4549.01161535629;4565.68156247419,-9134.97406202748,4557.55218263526;4574.11907611525,-9151.96170626936,4566.08720790460;4582.55107878122,-9168.93826829680,4574.61667234328;4590.97755183702,-9185.90371067403,4583.14055718940;4599.39847670602,-9202.85799608257,4591.65884373977;4607.81383487005,-9219.80108732144,4600.17151335007;4616.22360786922,-9236.73294730656,4608.67854743453;4624.62777730213,-9253.65353907137,4617.17992746626;4633.02632482530,-9270.56282576556,4625.67563497659;4641.41923215371,-9287.46077065622,4634.16565155564;4649.80648106011,-9304.34733712642,4642.64995885165;4658.18805337545,-9321.22248867607,4651.12853857137;4666.56393098851,-9338.08618892127,4659.60137247975;4674.93409584588,-9354.93840159409,4668.06844239983;4683.29852995198,-9371.77909054278,4676.52973021285;4691.65721536892,-9388.60821973140,4684.98521785806;4700.01013421639,-9405.42575323962,4693.43488733261;4708.35726867161,-9422.23165526264,4701.87872069152;4716.69860096924,-9439.02589011098,4710.31670004757;4725.03411340144,-9455.80842221061,4718.74880757138;4733.36378831762,-9472.57921610244,4727.17502549114;4741.68760812440,-9489.33823644225,4735.59533609258;4750.00555528561,-9506.08544800072,4744.00972171897;4758.31761232219,-9522.82081566316,4752.41816477101;4766.62376181200,-9539.54430442922,4760.82064770667;4774.92398638997,-9556.25587941303,4769.21715304126;4783.21826874781,-9572.95550584285,4777.60766334727;4791.50659163410,-9589.64314906106,4785.99216125433;4799.78893785401,-9606.31877452368,4794.37062944902;4808.06529026951,-9622.98234780077,4802.74305067502;4816.33563179908,-9639.63383457584,4811.10940773284;4824.59994541760,-9656.27320064570,4819.46968347976;4832.85821415659,-9672.90041192080,4827.82386082996;4841.11042110362,-9689.51543442419,4836.17192275404;4849.35654940285,-9706.11823429255,4844.51385227949;4857.59658225441,-9722.70877777493,4852.84963249012;4865.83050291466,-9739.28703123322,4861.17924652624;4874.05829469597,-9755.85296114184,4869.50267758454;4882.27994096665,-9772.40653408754,4877.81990891796;4890.49542515110,-9788.94771676965,4886.13092383585;4898.19932044118,-9804.46048868649,4893.92614400486;4905.89766361513,-9819.96209655514,4901.71576278047;4913.59043734463,-9835.45250556145,4909.49976271271;4921.27762435849,-9850.93168100593,4917.27812640908;4928.95920744256,-9866.39958830362,4925.05083653443;4936.63516943980,-9881.85619298427,4932.81787581107;4944.30549325002,-9897.30146069176,4940.57922701850;4951.97016182989,-9912.73535718413,4948.33487299338;4959.62915819295,-9928.15784833364,4956.08479662959;4967.28246540938,-9943.56890012623,4963.82898087797;4974.93006660598,-9958.96847866160,4971.56740874633;4982.57194496605,-9974.35655015285,4979.30006329929;4990.20808372946,-9989.73308092665,4987.02692765836;4997.83846619244,-10005.0980374229,4994.74798500177;5005.46307570752,-10020.4513861945,5002.46321856436;5013.08189568346,-10035.7930939073,5010.17261163751;5020.69490958524,-10051.1231273399,5017.87614756916;5028.30210093384,-10066.4414533835,5025.57380976361;5035.90345330641,-10081.7480390421,5033.26558168160;5043.49895033581,-10097.0428514315,5040.95144683993;5051.08857571099,-10112.3258577800,5048.63138881183;5058.67231317644,-10127.5970254276,5056.30539122636;5066.25014653260,-10142.8563218267,5063.97343776890;5073.82205963535,-10158.1037145407,5071.63551218056;5081.38803639623,-10173.3391712451,5079.29159825845;5088.94806078222,-10188.5626597266,5086.94167985541;5096.50211681563,-10203.7741478830,5094.58574088000;5104.05018857427,-10218.9736037234,5102.22376529653;5111.59226019097,-10234.1609953676,5109.85573712469;5119.12831585391,-10249.3362910464,5117.48164043985;5126.65833980627,-10264.4994591012,5125.10145937268;5134.18231634630,-10279.6504679838,5132.71517810924;5141.70022982714,-10294.7892862563,5140.32278089082;5149.21206465681,-10309.9158825908,5147.92425201389;5156.71780529820,-10325.0302257700,5155.51957583013;5164.21743626874,-10340.1322846857,5163.10873674605;5171.71094214063,-10355.2220283399,5170.69171922327;5179.19830754055,-10370.2994258440,5178.26850777821;5186.67951714981,-10385.3644464189,5185.83908698224;5194.15455570394,-10400.4170593945,5193.40344146126;5201.62340799291,-10415.4572342101,5200.96155589591;5209.08605886098,-10430.4849404139,5208.51341502146;5216.54249320637,-10445.5001476625,5216.05900362747;5223.99269598174,-10460.5028257217,5223.59830655823;5231.43665219351,-10475.4929444654,5231.13130871209;5238.87434690212,-10490.4704738759,5238.65799504179;5246.30576522197,-10505.4353840438,5246.17835055431;5253.73089232116,-10520.3876451677,5253.69236031063;5261.14971342158,-10535.3272275539,5261.20000942586;5268.56221379869,-10550.2541016166,5268.70128306899;5276.45808332977,-10566.1526531528,5276.68989341557;5284.34698962622,-10582.0372048015,5284.67148052975;5292.22891898770,-10597.9077290352,5292.64603061273;5300.10385776578,-10613.7641984308,5300.61352991796;5307.97179236372,-10629.6065856688,5308.57396475085;5315.83270923667,-10645.4348635340,5316.52732146902;5323.68659489140,-10661.2490049149,5324.47358648199;5331.53343588636,-10677.0489828035,5332.41274625126;5339.37321883151,-10692.8347702956,5340.34478729018;5347.20593038820,-10708.6063405900,5348.26969616372;5355.03155726933,-10724.3636669889,5356.18745948874;5362.85008623895,-10740.1067228974,5364.09806393353;5370.66150411251,-10755.8354818237,5372.00149621812;5378.46579775657,-10771.5499173786,5379.89774311389;5386.26295408874,-10787.2500032755,5387.78679144360;5394.05296007778,-10802.9357133305,5395.66862808145;5401.83580274329,-10818.6070214617,5403.54323995276;5409.61146915591,-10834.2639016897,5411.41061403420;5417.37994643693,-10849.9063281368,5419.27073735339;5425.14122175851,-10865.5342750276,5427.12359698910;5432.89528234340,-10881.1477166881,5434.96918007101;5440.64211546490,-10896.7466275457,5442.80747377961;5448.38170844702,-10912.3309821300,5450.63846534642;5456.11404866405,-10927.9007550712,5458.46214205350;5463.83912354078,-10943.4559211010,5466.27849123375;5471.55692055216,-10958.9964550520,5474.08750027049;5479.26742722358,-10974.5223318578,5481.88915659778;5486.97063113031,-10990.0335265523,5489.68344769986;5494.66651989804,-11005.5300142707,5497.47036111167;5502.35508120223,-11021.0117702479,5505.24988441821;5510.03630276846,-11036.4787698198,5513.02200525489;5517.71017237202,-11051.9309884218,5520.78671130714;5525.37667783806,-11067.3684015896,5528.54399031052;5533.03580704156,-11082.7909849587,5536.29383005073;5540.68754790704,-11098.1987142645,5544.03621836327;5548.33188840863,-11113.5915653417,5551.77114313356;5555.96881657009,-11128.9695141246,5559.49859229692;5563.59832046439,-11144.3325366466,5567.21855383820;5571.22038821401,-11159.6806090403,5574.93101579203;5578.83500799085,-11175.0137075375,5582.63596624273;5586.44216801574,-11190.3318084684,5590.33339332387;5594.04185655899,-11205.6348882625,5598.02328521876;5601.63406193971,-11220.9229234473,5605.70563015982;5609.21877252615,-11236.1958906488,5613.38041642888;5616.79597673554,-11251.4537665917,5621.04763235703;5624.36566303388,-11266.6965280983,5628.70726632444;5631.92781993604,-11281.9241520892,5636.35930676041;5639.48243600562,-11297.1366155827,5644.00374214327;5647.02949985471,-11312.3338956947,5651.64056100013;5654.56900014420,-11327.5159696389,5659.26975190715;5662.10092558335,-11342.6828147261,5666.89130348919;5669.62526492987,-11357.8344083646,5674.50520441982;5677.14200698995,-11372.9707280599,5682.11144342136;5684.65114061785,-11388.0917514139,5689.71000926451;5692.15265471627,-11403.1974561261,5697.30089076867;5699.64653823592,-11418.2878199920,5704.88407680155;5707.13278017564,-11433.3628209041,5712.45955627926;5714.61136958230,-11448.4224368511,5720.02731816624;5722.08229555061,-11463.4666459179,5727.58735147501;5729.54554722328,-11478.4954262857,5735.13964526641;5737.00111379067,-11493.5087562314,5742.68418864918;5744.44898449092,-11508.5066141279,5750.22097078018;5751.88914860987,-11523.4889784439,5757.74998086416;5759.32159548086,-11538.4558277433,5765.27120815372;5766.74631448475,-11553.4071406856,5772.78464194923;5774.16329504984,-11568.3428960255,5780.29027159879;5781.57252665186,-11583.2630726129,5787.78808649819;5788.97399881364,-11598.1676493923,5795.27807609062;5796.36770110549,-11613.0566054036,5802.76022986701;5803.75362314461,-11627.9299197807,5810.23453736545;5811.13175459550,-11642.7875717527,5817.70098817166;5818.50208516949,-11657.6295406426,5825.15957191841;5825.86460462495,-11672.4558058678,5832.61027828578;5833.21930276707,-11687.2663469399,5840.05309700101;5840.56616944784,-11702.0611434643,5847.48801783835;5847.90519456599,-11716.8401751403,5854.91503061910;5855.23636806684,-11731.6034217608,5862.33412521142;5862.55967994231,-11746.3508632121,5869.74529153033;5869.87512023088,-11761.0824794744,5877.14851953770;5877.18267901745,-11775.7982506207,5884.54379924209;5884.48234643323,-11790.4981568171,5891.93112069864;5891.77411265577,-11805.1821783229,5899.31047400910;5899.05796790877,-11819.8502954898,5906.68184932167;5906.33390246221,-11834.5024887627,5914.04523683105;5913.60190663202,-11849.1387386787,5921.40062677822;5920.86197078023,-11863.7590258674,5928.74800945049;5928.11408531479,-11878.3633310506,5936.08737518138;5935.35824068946,-11892.9516350421,5943.41871435048;5942.59442740384,-11907.5239187478,5950.74201738351;5949.82263600328,-11922.0801631654,5958.05727475219;5957.04285707877,-11936.6203493844,5965.36447697417;5964.25508126680,-11951.1444585855,5972.66361461285;5971.45929924953,-11965.6524720411,5979.95467827758;5978.65550175438,-11980.1443711145,5987.23765862323;5985.84367955437,-11994.6201372608,5994.51254635056;5993.02382346756,-12009.0797520252,6001.77933220563;6000.19592435742,-12023.5231970443,6009.03800698015;6007.35997313251,-12037.9504540451,6016.28856151122;6014.51596074657,-12052.3615048455,6023.53098668138;6021.66387819818,-12066.7563313533,6030.76527341828;6028.34330429082,-12080.2093843586,6037.52721865561;6035.01520139428,-12093.6473009553,6044.28157108380;6041.67955987838,-12107.0700617870,6051.02832099628;6048.33637015904,-12120.4776475899,6057.76745873282;6054.98562269798,-12133.8700391920,6064.49897467931;6061.62730800280,-12147.2472175138,6071.22285926776;6068.26141662680,-12160.6091635671,6077.93910297617;6074.88793916913,-12173.9558584562,6084.64769632866;6081.50686627427,-12187.2872833762,6091.34862989493;6088.11818863250,-12200.6034196143,6098.04189429082;6094.72189697930,-12213.9042485482,6104.72748017758;6101.31798209585,-12227.1897516477,6111.40537826246;6107.90643480832,-12240.4599104728,6118.07557929798;6114.48724598834,-12253.7147066747,6124.73807408236;6121.06040655269,-12266.9541219955,6131.39285345927;6127.62590746313,-12280.1781382674,6138.03990831763;6134.18373972662,-12293.3867374135,6144.67922959182;6140.73389439483,-12306.5799014465,6151.31080826121;6147.27636256458,-12319.7576124702,6157.93463535060;6153.81113537735,-12332.9198526775,6164.55070192969;6160.33820401932,-12346.0666043515,6171.15899911318;6166.85755972141,-12359.1978498649,6177.75951806077;6173.36919375919,-12372.3135716803,6184.35224997707;6179.87309745258,-12385.4137523491,6190.93718611132;6186.36926216603,-12398.4983745124,6197.51431775756;6192.85767930844,-12411.5674209002,6204.08363625453;6199.33834033293,-12424.6208743317,6210.64513298549;6205.81123673677,-12437.6587177144,6217.19879937809;6212.27636006161,-12450.6809340452,6223.74462690463;6218.73370189296,-12463.6875064090,6230.28260708157;6225.18325386050,-12476.6784179792,6236.81273146974;6231.62500763773,-12489.6536520176,6243.33499167413;6238.05895494210,-12502.6131918739,6249.84937934392;6244.48508753481,-12515.5570209858,6256.35588617226;6250.90339722087,-12528.4851228789,6262.85450389643;6257.31387584884,-12541.3974811664,6269.34522429752;6263.71651531094,-12554.2940795490,6275.82803920052;6270.11130754274,-12567.1749018148,6282.30294047406;6276.49824452354,-12580.0399318391,6288.76992003074;6282.87731827572,-12592.8891535844,6295.22896982652;6289.24852086508,-12605.7225510998,6301.68008186103;6295.61184440061,-12618.5401085217,6308.12324817738;6301.96728103458,-12631.3418100729,6314.55846086218;6308.31482296212,-12644.1276400625,6320.98571204519;6314.65446242146,-12656.8975828863,6327.40499389953;6320.98619169384,-12669.6516230262,6333.81629864161;6327.31000310334,-12682.3897450502,6340.21961853088;6333.62588901665,-12695.1119336121,6346.61494586974;6339.93384184343,-12707.8181734517,6353.00227300375;6346.23385403591,-12720.5084493943,6359.38159232134;6351.89122315282,-12730.6266403497,6363.88396934566;6360.73975789935,-12748.4401185850,6372.83284335044;6369.57683482100,-12766.2305625803,6381.77016345225;6378.40245143186,-12783.9979673361,6390.69592714259;6387.21660528015,-12801.7423279215,6399.61013194730;6396.01929394864,-12819.4636394749,6408.51277542693;6404.81051505410,-12837.1618972030,6417.40385517624;6413.59026624755,-12854.8370963811,6426.28336882445;6422.35854521421,-12872.4892323535,6435.15131403513;6431.11534967334,-12890.1183005326,6444.00768850611;6439.86067737805,-12907.7242963988,6452.85248996928;6448.59452611557,-12925.3072155010,6461.68571619080;6457.31689370695,-12942.8670534561,6470.50736497088;6466.02777800714,-12960.4038059489,6479.31743414378;6474.72717690476,-12977.9174687319,6488.11592157766;6483.41508832228,-12995.4080376256,6496.90282517469;6492.09151021572,-13012.8755085179,6505.67814287080;6500.75644057473,-13030.3198773639,6514.44187263575;6509.40987742266,-13047.7411401868,6523.19401247317;6518.05181881622,-13065.1392930766,6531.93456042023;6526.68226284551,-13082.5143321901,6540.66351454770;6535.30120763413,-13099.8662537518,6549.38087296005;6543.90865133903,-13117.1950540529,6558.08663379527;6552.50459215032,-13134.5007294511,6566.78079522470;6561.08902829142,-13151.7832763713,6575.46335545317;6569.66195801882,-13169.0426913044,6584.13431271879;6578.22337962223,-13186.2789708083,6592.79366529308;6586.77329142434,-13203.4921115070,6601.44141148071;6595.31169178080,-13220.6821100906,6610.07754961950;6603.83857908020,-13237.8489633157,6618.70207808042;6612.35395174409,-13254.9926680045,6627.31499526755;6620.85780822685,-13272.1132210456,6635.91629961801;6629.35014701543,-13289.2106193928,6644.50598960170;6637.83096662971,-13306.2848600660,6653.08406372160;6646.30026562216,-13323.3359401506,6661.65052051347;6654.75804257773,-13340.3638567972,6670.20535854575;6663.20429611410,-13357.3686072221,6678.74857641979;6671.63902488135,-13374.3501887066,6687.28017276954;6680.06222756184,-13391.3085985970,6695.80014626141;6688.47390287060,-13408.2438343050,6704.30849559464;6696.87404955471,-13425.1558933067,6712.80521950073;6705.26266639366,-13442.0447731433,6721.29031674378;6713.63975219911,-13458.9104714206,6729.76378612023;6722.00530581480,-13475.7529858088,6738.22562645878;6730.35932611663,-13492.5723140427,6746.67583662052;6738.70181201247,-13509.3684539212,6755.11441549862;6747.03276244232,-13526.1414033079,6763.54136201862;6755.35217637790,-13542.8911601299,6771.95667513795;6763.66005282293,-13559.6177223786,6780.36035384622;6771.95639081286,-13576.3210881091,6788.75239716496;6780.67744829076,-13593.8782062743,6797.57262076815;6789.38655531325,-13611.4112996969,6806.38079358511;6798.08371150846,-13628.9203676231,6815.17691523469;6806.76891653556,-13646.4054093618,6823.96098536693;6815.44217008443,-13663.8664242831,6832.73300366279;6824.10347187554,-13681.3034118188,6841.49296983398;6832.75282166018,-13698.7163714626,6850.24088362322;6841.39021922032,-13716.1053027695,6858.97674480404;6850.01566436825,-13733.4702053559,6867.70055318053;6858.62915694703,-13750.8110788995,6876.41230858767;6867.23069682995,-13768.1279231388,6885.11201089090;6875.82028392094,-13785.4207378741,6893.79965998640;6884.39791815401,-13802.6895229657,6902.47525580068;6892.96359949366,-13819.9342783354,6911.13879829088;6901.51732793456,-13837.1550039656,6919.79028744449;6910.05910350147,-13854.3516998988,6928.42972327924;6918.58892624949,-13871.5243662388,6937.05710584342;6927.10679626349,-13888.6730031488,6945.67243521523;6935.61271365862,-13905.7976108533,6954.27571150332;6944.10667857985,-13922.8981896361,6962.86693484637;6952.58869120205,-13939.9747398415,6971.44610541309;6961.05875173009,-13957.0272618737,6980.01322340239;6969.51686039840,-13974.0557561965,6988.56828904291;6977.96301747136,-13991.0602233338,6997.11130259338;6986.39722324287,-14008.0406638685,7005.64226434229;6994.81947803657,-14024.9970784437,7014.16117460797;7003.22978220561,-14041.9294677613,7022.66803373848;7011.62813613278,-14058.8378325830,7031.16284211166;7020.01454023018,-14075.7221737292,7039.64560013485;7028.38899493937,-14092.5824920794,7048.11630824503;7036.75150073128,-14109.4187885724,7056.57496690871;7045.10205810617,-14126.2310642056,7065.02157662188;7053.44066759349,-14143.0193200350,7073.45613790991;7061.76732975195,-14159.7835571755,7081.87865132762;7070.08204516932,-14176.5237768003,7090.28911745902;7078.38481446247,-14193.2399801409,7098.68753691742;7086.67563827737,-14209.9321684875,7107.07391034540;7094.95451728882,-14226.6003431880,7115.44823841452;7103.22145220070,-14243.2445056488,7123.81052182560;7111.47644374566,-14259.8646573338,7132.16076130840;7119.71949268510,-14276.4607997650,7140.49895762158;7127.95059980933,-14293.0329345223,7148.82511155292;7136.16976593722,-14309.5810632428,7157.13922391890;7144.37699191632,-14326.1051876214,7165.44129556484;7152.57227862285,-14342.6053094104,7173.73132736492;7160.75562696145,-14359.0814304194,7182.00932022191;7168.92703786526,-14375.5335525150,7190.27527506723;7177.08651229592,-14391.9616776212,7198.52919286095;7185.23405124339,-14408.3658077186,7206.77107459168;7193.36965572590,-14424.7459448449,7215.00092127644;7201.06712245668,-14440.2453521318,7222.78905447016;7208.75305086789,-14455.7215627692,7230.56555199786;7216.42744159170,-14471.1745780185,7238.33041448713;7224.09029528915,-14486.6043991988,7246.08364259461;7231.74161265001,-14502.0110276872,7253.82523700584;7239.38139439271,-14517.3944649181,7261.55519843517;7247.00964126422,-14532.7547123834,7269.27352762569;7254.62635404030,-14548.0917716328,7276.98022534945;7262.23153352494,-14563.4056442724,7284.67529240689;7269.82518055086,-14578.6963319664,7292.35872962733;7277.40729597897,-14593.9638364353,7300.03053786849;7284.97788069859,-14609.2081594569,7307.69071801665;7292.53693562735,-14624.4293028657,7315.33927098658;7300.08446171119,-14639.6272685530,7322.97619772151;7307.62045992403,-14654.8020584663,7330.60149919285;7315.14493126809,-14669.9536746102,7338.21517640044;7322.65787677349,-14685.0821190450,7345.81723037222;7330.15929749859,-14700.1873938878,7353.40766216454;7337.64919452944,-14715.2695013113,7360.98647286157;7345.12756898021,-14730.3284435448,7368.55366357583;7352.59442199276,-14745.3642228732,7376.10923544766;7360.04975473685,-14760.3768416370,7383.65318964545;7367.49356840987,-14775.3663022329,7391.18552736545;7374.92586423695,-14790.3326071127,7398.70624983173;7382.34664347083,-14805.2757587838,7406.21535829622;7389.75590739175,-14820.1957598092,7413.71285403848;7397.15365730762,-14835.0926128069,7421.19873836590;7404.53989455359,-14849.9663204499,7428.67301261330;7411.91462049239,-14864.8168854666,7436.13567814323;7419.27783651401,-14879.6443106402,7443.58673634566;7426.62954403574,-14894.4485988084,7451.02618863804;7433.96974450206,-14909.2297528638,7458.45403646518;7441.29843938467,-14923.9877757537,7465.87028129927;7448.61563018236,-14938.7226704795,7473.27492463974;7455.92131842110,-14953.4344400976,7480.66796801339;7463.21550565368,-14968.1230877178,7488.04941297399;7470.49819346000,-14982.7886165047,7495.41926110259;7477.76938344673,-14997.4310296764,7502.77751400716;7485.02907724754,-15012.0503305055,7510.12417332287;7492.27727652274,-15026.6465223179,7517.45924071166;7499.51398295949,-15041.2196084935,7524.78271786249;7506.73919827145,-15055.7695924653,7532.09460649100;7513.95292419916,-15070.2964777205,7539.39490833985;7521.15516250952,-15084.8002677990,7546.68362517825;7528.34591499602,-15099.2809662943,7553.96075880215;7535.52518347855,-15113.7385768528,7561.22631103404;7542.69296980351,-15128.1731031741,7568.48028372312;7549.84927584356,-15142.5845490106,7575.72267874501;7556.99410349767,-15156.9729181677,7582.95349800177;7564.12745469100,-15171.3382145031,7590.17274342184;7571.24933137499,-15185.6804419274,7597.38041696008;7578.35973552714,-15199.9996044036,7604.57652059760;7585.45866915106,-15214.2957059471,7611.76105634176;7592.54613427627,-15228.5687506254,7618.93402622601;7599.62213295835,-15242.8187425580,7626.09543230997;7606.68666727879,-15257.0456859170,7633.24527667940;7613.73973934489,-15271.2495849258,7640.38356144600;7620.78135128969,-15285.4304438598,7647.51028874736;7627.81150527211,-15299.5882670463,7654.62546074713;7634.83020347662,-15313.7230588640,7661.72907963463;7641.83744811340,-15327.8348237429,7668.82114762511;7648.83324141816,-15341.9235661648,7675.90166695946;7655.81758565219,-15355.9892906624,7682.97063990434;7662.79048310210,-15370.0320018195,7690.02806875186;7669.75193608013,-15384.0517042713,7697.07395581995;7676.70194692371,-15398.0484027036,7704.10830345186;7683.64051799556,-15412.0221018530,7711.13111401631;7690.56765168373,-15425.9728065070,7718.14238990750;7697.48335040146,-15439.9005215036,7725.14213354498;7704.38761658709,-15453.8052517313,7732.13034737353;7711.28045270402,-15467.6870021289,7739.10703386321;7718.16186124070,-15481.5457776854,7746.07219550922;7725.03184471056,-15495.3815834403,7753.02583483193;7731.89040565190,-15509.1944244826,7759.96795437675;7738.73754662798,-15522.9843059518,7766.89855671418;7745.57327022675,-15536.7512330368,7773.81764443958;7752.39757906103,-15550.4952109764,7780.72522017332;7759.21047576819,-15564.2162450589,7787.62128656050;7766.01196301041,-15577.9143406223,7794.50584627116;7772.80204347430,-15591.5895030536,7801.37890199995;7779.58071987114,-15605.2417377896,7808.24045646633;7786.34799493659,-15618.8710503158,7815.09051241431;7793.10387143076,-15632.4774461669,7821.92907261247;7799.84835213818,-15646.0609309267,7828.75613985402;7806.58143986766,-15659.6215102277,7835.57171695654;7813.30313745223,-15673.1591897510,7842.37580676203;7820.01344774919,-15686.6739752266,7849.16841213691;7826.71237364001,-15700.1658724330,7855.94953597191;7833.39991803009,-15713.6348871965,7862.71918118183;7840.07608384916,-15727.0810253927,7869.47735070599;7846.74087405064,-15740.5042929444,7876.22404750753;7853.39429161213,-15753.9046958233,7882.95927457392;7860.03633953490,-15767.2822400483,7889.68303491648;7866.66702084427,-15780.6369316868,7896.39533157067;7873.28633858908,-15793.9687768535,7903.09616759571;7879.89429584212,-15807.2777817110,7909.78554607484;7886.49089569975,-15820.5639524695,7916.46347011509;7893.07614128188,-15833.8272953862,7923.12994284712;7899.65003573202,-15847.0678167659,7929.78496742542;7906.21258221721,-15860.2855229607,7936.42854702809;7912.76378392799,-15873.4804203697,7943.06068485693;7919.30364407810,-15886.6525154387,7949.68138413706;7925.83216590478,-15899.8018146608,7956.29064811727;7932.34935266857,-15912.9283245758,7962.88848006979;7938.85520765317,-15926.0320517701,7969.47488329017;7945.34973416542,-15939.1130028763,7976.04986109723;7951.83293553534,-15952.1711845739,7982.61341683315;7958.30481511608,-15965.2066035887,7989.16555386335;7964.76537628367,-15978.2192666926,7995.70627557631;7971.21462243722,-15991.2091807035,8002.23558538373;7977.65255699867,-16004.1763524855,8008.75348672029;7984.07918341284,-16017.1207889486,8015.25998304370;7990.49450514738,-16030.0424970486,8021.75507783463;7996.89852569265,-16042.9414837868,8028.23877459662;8003.29124856174,-16055.8177562104,8034.71107685611;8009.67267729028,-16068.6713214117,8041.17198816220;8016.04281543659,-16081.5021865286,8047.62151208683;8022.40166658151,-16094.3103587443,8054.05965222461;8028.74923432834,-16107.0958452871,8060.48641219276;8035.08552230277,-16119.8586534301,8066.90179563104;8041.41053415287,-16132.5987904917,8073.30580620173;8047.72427354911,-16145.3162638349,8079.69844758965;8054.02674418411,-16158.0110808675,8086.07972350194;8060.31794977273,-16170.6832490418,8092.44963766809;8066.59789405209,-16183.3327758550,8098.80819384004;8072.86658078129,-16195.9596688480,8105.15539579181;8079.12401374148,-16208.5639356066,8111.49124731963;8085.37019673592,-16221.1455837607,8117.81575224202;8091.60513358969,-16233.7046209839,8124.12891439940;8097.82882814981,-16246.2410549940,8130.43073765433;8104.04128428516,-16258.7548935529,8136.72122589135;8110.24250588640,-16271.2461444660,8143.00038301692;8116.43249686585,-16283.7148155823,8149.26821295933;8122.61126115753,-16296.1609147943,8155.52471966868;8128.77880271723,-16308.5844500383,8161.76990711698;8134.93512552210,-16320.9854292937,8168.00377929781;8141.08023357089,-16333.3638605829,8174.22634022641;8147.21413088385,-16345.7197519717,8180.43759393970;8153.33682150262,-16358.0531115689,8186.63754449612;8159.44830949017,-16370.3639475261,8192.82619597562;8165.54859893084,-16382.6522680378,8199.00355247961;8171.63769393009,-16394.9180813410,8205.16961813080;8177.71559861477,-16407.1613957156,8211.32439707340;8183.78231713274,-16419.3822194837,8217.46789347279;8189.83785365298,-16431.5805610098,8223.60011151563;8195.88221236555,-16443.7564287009,8229.72105540976;8201.91539748136,-16455.9098310056,8235.83072938404;8207.93741323249,-16468.0407764154,8241.92913768863;8213.94826387173,-16480.1492734631,8248.01628459454;8219.94795367271,-16492.2353307235,8254.09217439376;8225.93648692989,-16504.2989568131,8260.15681139925;8231.91386795849,-16516.3401603904,8266.21019994487;8237.88010109429,-16528.3589501548,8272.25234438519;8243.83519069372,-16540.3553348476,8278.28324909555;8249.77914113384,-16552.3293232511,8284.30291847207;8255.71195681224,-16564.2809241893,8290.31135693153;8261.63364214680,-16576.2101465266,8296.30856891115;8267.54420157605,-16588.1169991691,8302.29455886895;8273.44363955863,-16600.0014910632,8308.26933128317;8279.33196057368,-16611.8636311965,8314.23289065270;8285.20916912057,-16623.7034285971,8320.18524149678;8291.07526971870,-16635.5208923337,8326.12638835486;8296.93026690778,-16647.3160315154,8332.05633578679;8302.77416524763,-16659.0888552920,8337.97508837270;8308.60696931800,-16670.8393728531,8343.88265071278;8314.42868371868,-16682.5675934288,8349.77902742738;8320.23931306941,-16694.2735262890,8355.66422315696;8326.03886200975,-16705.9571807437,8361.53824256192;8331.82733519931,-16717.6185661429,8367.40109032283;8337.60473731715,-16729.2576918759,8373.25277113989;8343.37107306238,-16740.8745673722,8379.09328973345;8349.12634715351,-16752.4692021002,8384.92265084340;8354.87056432892,-16764.0416055684,8390.74085922966;8360.60372934637,-16775.5917873240,8396.54791967163;8366.32584698325,-16787.1197569539,8402.34383696850;8372.03692203638,-16798.6255240837,8408.12861593900;8377.73695932204,-16810.1090983784,8413.90226142148;8383.42596367582,-16821.5704895417,8419.66477827371;8389.10393995268,-16833.0097073161,8425.41617137299;8394.77089302684,-16844.4267614830,8431.15644561599;8400.42682779165,-16855.8216618620,8436.88560591867;8406.07174915967,-16867.1944183114,8442.60365721628;8411.70566206263,-16878.5450407282,8448.31060446344;8417.32857145123,-16889.8735390471,8454.00645263382;8422.94048229520,-16901.1799232414,8459.69120672028;8428.54139958328,-16912.4642033224,8465.36487173482;8434.13132832300,-16923.7263893393,8471.02745270835;8439.71027354082,-16934.9664913791,8476.67895469084;8445.27824028199,-16946.1845195668,8482.31938275121;8450.83523361048,-16957.3804840648,8487.94874197720;8456.38125860902,-16968.5543950734,8493.56703747544;8461.91632037887,-16979.7062628299,8499.17427437125;8467.44042404002,-16990.8360976094,8504.77045780880;8472.95357473090,-17001.9439097240,8510.35559295080;8478.45577760849,-17013.0297095230,8515.92968497867;8483.94703784816,-17024.0935073927,8521.49273909234;8489.42736064371,-17035.1353137566,8527.04476051031;8494.89675120728,-17046.1551390747,8532.58575446954;8500.35521476924,-17057.1529938439,8538.11572622535;8505.80275657829,-17068.1288885977,8543.63468105152;8511.23938190124,-17079.0828339064,8549.14262424008;8516.66509602299,-17090.0148403761,8554.63956110126;8522.07990424670,-17100.9249186500,8560.12549696367;8527.48381189338,-17111.8130794069,8565.60043717393;8532.87682430216,-17122.6793333622,8571.06438709689;8538.25894682996,-17133.5236912670,8576.51735211531;8543.63018485161,-17144.3461639083,8581.95933763002;8548.99054375996,-17155.1467621093,8587.39034905994;8554.34002896535,-17165.9254967285,8592.81039184168;8559.67864589610,-17176.6823786604,8598.21947142989;8565.00639999798,-17187.4174188345,8603.61759329681;8570.32329673462,-17198.1306282163,8609.00476293273;8575.62934158700,-17208.8220178063,8614.38098584533;8580.92454005376,-17219.4915986400,8619.74626756011;8586.20889765102,-17230.1393817886,8625.10061362020;8591.48241991232,-17240.7653783579,8630.44402958622;8596.74511238848,-17251.3695994886,8635.77652103627;8601.99698064772,-17261.9520563563,8641.09809356591;8607.23803027555,-17272.5127601714,8646.40875278814;8612.46826687466,-17283.0517221787,8651.70850433325;8617.68769606492,-17293.5689536576,8656.99735384888;8622.89632348338,-17304.0644659220,8662.27530699991;8628.09415478405,-17314.5382703200,8667.54236946837;8633.28119563809,-17324.9903782339,8672.79854695349;8638.45745173354,-17335.4208010802,8678.04384517155;8643.62292877541,-17345.8295503092,8683.27826985594;8648.77763248554,-17356.2166374054,8688.50182675696;8653.92156860264,-17366.5820738869,8693.71452164192;8659.05474288214,-17376.9258713053,8698.91636029497;8664.17716109630,-17387.2480412465,8704.10734851723;8669.28882903389,-17397.5485953290,8709.28749212644;8674.38975250049,-17407.8275452056,8714.45679695726;8679.47993731806,-17418.0849025615,8719.61526886085;8684.55938932524,-17428.3206791158,8724.76291370520;8689.62811437705,-17438.5348866204,8729.89973737480;8694.68611834503,-17448.7275368604,8735.02574577073;8699.73340711693,-17458.8986416535,8740.14094481045;8704.76998659704,-17469.0482128504,8745.24534042808;8709.79586270571,-17479.1762623345,8750.33893857389;8714.81104137968,-17489.2828020217,8755.42174521468;8719.81552857187,-17499.3678438608,8760.49376633355;8724.80933025111,-17509.4313998323,8765.55500792964;8729.79245240261,-17519.4734819496,8770.60547601854;8734.76490102743,-17529.4941022582,8775.64517663189;8739.72668214261,-17539.4932728355,8780.67411581735;8744.67780178117,-17549.4710057911,8785.69229963873;8749.61826599201,-17559.4273132665,8790.69973417581;8754.54808083985,-17569.3622074349,8795.69642552434;8759.46725240517,-17579.2757005013,8800.68237979591;8764.37578678420,-17589.1678047022,8805.65760311799;8768.89226645288,-17598.2718125245,8810.23757066670;8773.39844642363,-17607.3551098718,8814.80714748869;8777.89433247920,-17616.4177083505,8819.36633939539;8782.37993041831,-17625.4596195990,8823.91515221424;8786.85524605573,-17634.4808552882,8828.45359178892;8791.32028522209,-17643.4814271206,8832.98166397905;8795.77505376393,-17652.4613468309,8837.49937466029;8800.21955754365,-17661.4206261855,8842.00672972428;8804.65380243940,-17670.3592769824,8846.50373507853;8809.07779434511,-17679.2773110516,8850.99039664645;8813.49153917043,-17688.1747402545,8855.46672036730;8817.89504284047,-17697.0515764835,8859.93271219590;8822.28831129608,-17705.9078316628,8864.38837810294;8826.67135049366,-17714.7435177477,8868.83372407478;8831.04416640505,-17723.5586467247,8873.26875611333;8835.40676501753,-17732.3532306111,8877.69348023607;8839.75915233371,-17741.1272814552,8882.10790247592;8844.10133437168,-17749.8808113364,8886.51202888141;8848.43331716477,-17758.6138323646,8890.90586551639;8852.75510676149,-17767.3263566804,8895.28941846007;8857.06670922561,-17776.0183964548,8899.66269380698;8861.36813063598,-17784.6899638893,8904.02569766688;8865.65937708667,-17793.3410712160,8908.37843616485;8869.94045468668,-17801.9717306970,8912.72091544102;8874.21136956004,-17810.5819546244,8917.05314165068;8878.47212784579,-17819.1717553208,8921.37512096424;8882.72273569784,-17827.7411451384,8925.68685956707;8886.96319928487,-17836.2901364593,8929.98836365946;8891.19352479051,-17844.8187416954,8934.27963945676;8895.41371841302,-17853.3269732882,8938.56069318903;8899.62378636550,-17861.8148437091,8942.83153110135;8903.82373487557,-17870.2823654585,8947.09215945336;8908.01357018552,-17878.7295510662,8951.34258451955;8912.19329855227,-17887.1564130917,8955.58281258911;8916.36292624713,-17895.5629641233,8959.81284996576;8920.52245955595,-17903.9492167783,8964.03270296785;8924.67190477907,-17912.3151837036,8968.24237792837;8928.81126823102,-17920.6608775740,8972.44188119456;8932.94055624084,-17928.9863110941,8976.63121912834;8937.05977515172,-17937.2914969965,8980.81039810585;8941.16893132116,-17945.5764480427,8984.97942451768;8945.26803112071,-17953.8411770225,8989.13830476857;8949.35708093620,-17962.0856967542,8993.28704527765;8953.43608716747,-17970.3100200846,8997.42565247818;8957.50505622835,-17978.5141598884,9001.55413281752;8961.56399454683,-17986.6981290687,9005.67249275728;8965.61290856464,-17994.8619405563,9009.78073877297;8969.65180473748,-18003.0056073101,9013.87887735414;8973.68068953496,-18011.1291423171,9017.96691500437;8977.69956944038,-18019.2325585914,9022.04485824104;8982.08188815599,-18028.0665344508,9026.48919253173;8986.45390145649,-18036.8797874223,9030.92312937901;8990.81561620867,-18045.6723312912,9035.34667568687;8995.16703929271,-18054.4441798695,9039.75983837281;8999.50817760175,-18063.1953469955,9044.16262436744;9003.83903804198,-18071.9258465338,9048.55504061448;9008.15962753270,-18080.6356923750,9052.93709407088;9012.46995300601,-18089.3248984357,9057.30879170649;9016.77002140700,-18097.9934786586,9061.67014050427;9021.05983969373,-18106.6414470123,9066.02114746023;9025.33941483685,-18115.2688174910,9070.36181958311;9029.60875382001,-18123.8756041147,9074.69216389472;9033.86786363950,-18132.4618209290,9079.01218742962;9038.11675130420,-18141.0274820048,9083.32189723508;9042.35542383575,-18149.5726014386,9087.62130037122;9046.58388826833,-18158.0971933522,9091.91040391080;9050.80215164865,-18166.6012718924,9096.18921493924;9055.01022103596,-18175.0848512314,9100.45774055457;9059.20810350194,-18183.5479455663,9104.71598786737;9063.39580613064,-18191.9905691191,9108.96396400069;9067.57333601848,-18200.4127361367,9113.20167609004;9071.74070027424,-18208.8144608907,9117.42913128342;9075.89790601892,-18217.1957576774,9121.64633674112;9080.04496038581,-18225.5566408177,9125.85329963584;9084.18187052028,-18233.8971246570,9130.05002715246;9088.30864357988,-18242.2172235649,9134.23652648814;9092.42528673425,-18250.5169519355,9138.41280485221;9096.53180716506,-18258.7963241871,9142.57886946619;9100.62821206598,-18267.0553547619,9146.73472756363;9104.71450864264,-18275.2940581264,9150.88038639017;9108.79070411255,-18283.5124487709,9155.01585320344;9112.85680570505,-18291.7105412094,9159.14113527299;9116.91282066138,-18299.8883499799,9163.25623988037;9120.95875623447,-18308.0458896440,9167.36117431893;9124.99461968907,-18316.1831747868,9171.45594589390;9129.02041830144,-18324.3002200167,9175.54056192218;9133.03615935959,-18332.3970399658,9179.61502973247;9137.04185016316,-18340.4736492895,9183.67935666521;9141.03749802324,-18348.5300626662,9187.73355007242;9145.02311026248,-18356.5662947976,9191.77761731772;9148.99869421492,-18364.5823604081,9195.81156577626;9152.96425722607,-18372.5782742455,9199.83540283475;9156.91980665278,-18380.5540510802,9203.84913589134;9160.86534986317,-18388.5097057051,9207.85277235552;9164.80089423674,-18396.4452529364,9211.84631964830;9168.72644716408,-18404.3607076123,9215.82978520186;9172.64201604718,-18412.2560845939,9219.80317645985;9176.54760829897,-18420.1313987644,9223.76650087699;9180.44323134350,-18427.9866650294,9227.71976591920;9184.32889261596,-18435.8218983167,9231.66297906365;9188.20459956256,-18443.6371135766,9235.59614779861;9192.07035964030,-18451.4323257807,9239.51927962323;9195.92618031735,-18459.2075499233,9243.43238204796;9199.77206907253,-18466.9628010201,9247.33546259395;9203.60803339561,-18474.6980941087,9251.22852879342;9207.43408078711,-18482.4134442485,9255.11158818945;9211.25021875839,-18490.1088665205,9258.98464833600;9215.05645483134,-18497.7843760270,9262.84771679773;9218.85279653862,-18505.4399878919,9266.70080115010;9222.63925142343,-18513.0757172603,9270.54390897922;9226.41582703964,-18520.6915792989,9274.37704788200;9230.18253095160,-18528.2875891952,9278.20022546587;9233.93937073403,-18535.8637621577,9282.01344934875;9237.68635397226,-18543.4201134163,9285.81672715927;9241.42348826195,-18550.9566582216,9289.61006653647;9245.15078120904,-18558.4734118448,9293.39347512974;9248.86824042980,-18565.9703895780,9297.16696059895;9252.57587355087,-18573.4476067341,9300.93053061439;9256.27368820900,-18580.9050786463,9304.68419285657;9259.96169205118,-18588.3428206685,9308.42795501630;9263.63989273443,-18595.7608481746,9312.16182479454;9267.30829792597,-18603.1591765591,9315.88580990255;9270.96691530303,-18610.5378212368,9319.59991806166;9274.61575255279,-18617.8967976422,9323.30415700327;9278.25481737254,-18625.2361212303,9326.99853446894;9281.88411746930,-18632.5558074757,9330.68305821012;9285.50366056005,-18639.8558718729,9334.35773598824;9289.11345437167,-18647.1363299364,9338.02257557475;9292.71350664065,-18654.3971972000,9341.67758475080;9296.30382511345,-18661.6384892177,9345.32277130759;9299.88441754602,-18668.8602215623,9348.95814304591;9303.45529170412,-18676.0624098265,9352.58370777646;9307.01645536309,-18683.2450696223,9356.19947331956;9310.56791630777,-18690.4082165808,9359.80544750519;9314.10968233258,-18697.5518663522,9363.40163817293;9317.64176124153,-18704.6760346061,9366.98805317207;9321.16416084792,-18711.7807370309,9370.56470036129;9324.67688897457,-18718.8659893339,9374.13158760886;9328.17995345349,-18725.9318072412,9377.68872279234;9331.67336212631,-18732.9782064980,9381.23611379895;9335.15712284363,-18740.0052028676,9384.77376852506;9338.63124346544,-18747.0128121321,9388.30169487643;9342.09573186094,-18754.0010500924,9391.81990076816;9345.55059590844,-18760.9699325675,9395.32839412452;9348.99584349533,-18767.9194753946,9398.82718287897;9352.43148251813,-18774.8496944296,9402.31627497419;9355.85752088235,-18781.7606055460,9405.79567836190;9359.27396650247,-18788.6522246358,9409.26540100292;9362.68082730189,-18795.5245676087,9412.72545086704;9366.07811121306,-18802.3776503925,9416.17583593320;9368.74921101227,-18807.7709862085,9418.89411410966;9371.41133341272,-18813.1462669069,9421.60333186451;9374.06448575346,-18818.5035072229,9424.30349657850;9376.70867538319,-18823.8427219110,9426.99461564202;9379.34390966003,-18829.1639257446,9429.67669645508;9381.97019595158,-18834.4671335164,9432.34974642715;9384.58754163486,-18839.7523600377,9435.01377297730;9387.19595409631,-18845.0196201392,9437.66878353406;9389.79544073172,-18850.2689286699,9440.31478553544;9392.38600894605,-18855.5003004976,9442.95178642865;9394.96766615366,-18860.7137505090,9445.57979367044;9397.54041977796,-18865.9092936088,9448.19881472669;9400.10427725173,-18871.0869447206,9450.80885707273;9402.65924601671,-18876.2467187862,9453.40992819292;9405.20533352380,-18881.3886307657,9456.00203558092;9407.74254723286,-18886.5126956372,9458.58518673940;9410.27089461280,-18891.6189283971,9461.15938918016;9412.79038314159,-18896.7073440599,9463.72465042417;9415.30102030588,-18901.7779576577,9466.28097800117;9417.80281360137,-18906.8307842406,9468.82837945003;9420.29577053262,-18911.8658388769,9471.36686231856;9422.77989861280,-18916.8831366517,9473.89643416326;9425.25520536394,-18921.8826926684,9476.41710254960;9427.72169831676,-18926.8645220477,9478.92887505182;9430.17938501069,-18931.8286399277,9481.43175925296;9432.62827299372,-18936.7750614640,9483.92576274467;9435.06836982244,-18941.7038018291,9486.41089312733;9437.49968306193,-18946.6148762130,9488.88715800989;9439.92222028587,-18951.5082998228,9491.35456500996;9442.33598907626,-18956.3840878824,9493.81312175359;9444.74099702363,-18961.2422556327,9496.26283587538;9447.13725172691,-18966.0828183318,9498.70371501851;9449.52476079322,-18970.9057912539,9501.13576683434;9451.90353183803,-18975.7111896904,9503.55899898275;9454.27357248511,-18980.4990289490,9505.97341913193;9456.63489036646,-18985.2693243544,9508.37903495844;9458.98749312210,-18990.0220912471,9510.77585414691;9461.33138840032,-18994.7573449843,9513.16388439032;9463.66658385745,-18999.4751009395,9515.54313338980;9465.99308715785,-19004.1753745022,9517.91360885457;9468.31090597394,-19008.8581810782,9520.27531850201;9470.62004798597,-19013.5235360892,9522.62827005742;9472.92052088228,-19018.1714549729,9524.97247125422;9475.21233235895,-19022.8019531828,9527.30792983371;9477.49549012008,-19027.4150461883,9529.63465354527;9479.77000187741,-19032.0107494745,9531.95265014600;9482.03587535044,-19036.5890785418,9534.26192740084;9484.29311826652,-19041.1500489067,9536.56249308266;9486.54173836056,-19045.6936761005,9538.85435497199;9488.78174337516,-19050.2199756705,9541.13752085711;9491.36427821696,-19055.4348003869,9543.76599425027;9493.93793177159,-19060.6317623078,9546.38550320910;9496.50271209943,-19065.8108776193,9548.99605584235;9499.05862726784,-19070.9721625212,9551.59766026578;9501.60568535131,-19076.1156332279,9554.19032460240;9504.14389443126,-19081.2413059675,9556.77405698221;9506.67326259621,-19086.3491969826,9559.34886554238;9509.19379794154,-19091.4393225296,9561.91475842701;9511.70550856950,-19096.5116988786,9564.47174378719;9514.20840258932,-19101.5663423137,9567.01982978100;9516.70248811698,-19106.6032691329,9569.55902457339;9519.18777327520,-19111.6224956474,9572.08933633612;9521.66426619352,-19116.6240381824,9574.61077324782;9524.13197500821,-19121.6079130765,9577.12334349396;9526.59090786212,-19126.5741366816,9579.62705526664;9529.04107290473,-19131.5227253629,9582.12191676467;9531.48247829226,-19136.4536954993,9584.60793619367;9533.91513218731,-19141.3670634823,9587.08512176572;9536.33904275909,-19146.2628457170,9589.55348169958;9538.75421818323,-19151.1410586212,9592.01302422051;9541.16066664187,-19156.0017186259,9594.46375756034;9543.55839632348,-19160.8448421748,9596.90568995732;9545.94741542290,-19165.6704457244,9599.33882965613;9548.32773214130,-19170.4785457442,9601.76318490786;9550.69935468618,-19175.2691587161,9604.17876396999;9553.06229127128,-19180.0423011347,9606.58557510633;9555.41655011646,-19184.7979895069,9608.98362658685;9557.76213944782,-19189.5362403522,9611.37292668787;9560.09906749759,-19194.2570702026,9613.75348369190;9562.42734250411,-19198.9604956020,9616.12530588763;9564.74697271175,-19203.6465331068,9618.48840156982;9567.05796637088,-19208.3151992854,9620.84277903935;9569.36033173787,-19212.9665107181,9623.18844660313;9571.65407707508,-19217.6004839975,9625.52541257417;9573.93921065067,-19222.2171357278,9627.85368527131;9576.21574073883,-19226.8164825253,9630.17327301952;9578.48367561941,-19231.3985410177,9632.48418414949;9580.74302357812,-19235.9633278445,9634.78642699782;9582.99379290649,-19240.5108596570,9637.08000990704;9585.23599190175,-19245.0411531179,9639.36494122540;9587.46962886665,-19249.5542249011,9641.64122930679;9589.69471210985,-19254.0500916922,9643.90888251104;9591.91124994540,-19258.5287701880,9646.16790920345;9594.11925069299,-19262.9902770963,9648.41831775504;9596.31872267793,-19267.4346291364,9650.66011654249;9598.50967423094,-19271.8618430385,9652.89331394799;9600.69211368814,-19276.2719355437,9655.11791835917;9602.86604939122,-19280.6649234042,9657.33393816934;9605.03148968719,-19285.0408233830,9659.54138177713;9607.18844292833,-19289.3996522537,9661.74025758656;9609.33691747240,-19293.7414268010,9663.93057400720;9611.47692168227,-19298.0661638197,9666.11233945375;9613.60846392614,-19302.3738801156,9668.28556234634;9615.73155257748,-19306.6645925049,9670.45025111043;9617.84619601468,-19310.9383178139,9672.60641417649;9619.95240262157,-19315.1950728797,9674.75405998045;9622.05018078691,-19319.4348745494,9676.89319696324;9624.13953890449,-19323.6577396802,9679.02383357093;9626.22048537321,-19327.8636851396,9681.14597825473;9628.29302859690,-19332.0527278051,9683.25963947086;9630.35717698437,-19336.2248845642,9685.36482568057;9632.41293894937,-19340.3801723143,9687.46154535010;9634.46032291040,-19344.5186079624,9689.54980695056;9636.49933729095,-19348.6402084257,9691.62961895807;9638.52999051926,-19352.7449906306,9693.70098985356;9640.55229102833,-19356.8329715135,9695.76392812282;9642.56624725596,-19360.9041680203,9697.81844225645;9644.57186764452,-19364.9585971061,9699.86454074974;9646.56916064115,-19368.9962757355,9701.90223210278;9648.55813469763,-19373.0172208827,9703.93152482036;9650.53879827019,-19377.0214495308,9705.95242741181;9652.51115981983,-19381.0089786723,9707.96494839125;9654.47522781194,-19384.9798253088,9709.96909627729;9656.43101071637,-19388.9340064508,9711.96487959304;9658.37851700751,-19392.8715391179,9713.95230686624;9660.31775516409,-19396.7924403385,9715.93138662901;9662.24873366931,-19400.6967271500,9717.90212741797;9664.17146101064,-19404.5844165985,9719.86453777414;9666.08594567991,-19408.4555257387,9721.81862624291;9667.99219617315,-19412.3100716339,9723.76440137395;9669.89022099075,-19416.1480713562,9725.70187172134;9671.78002863720,-19419.9695419859,9727.63104584334;9673.66162762118,-19423.7745006117,9729.55193230243;9675.53502645563,-19427.5629643311,9731.46453966544;9677.40023365745,-19431.3349502492,9733.36887650319;9679.25725774761,-19435.0904754799,9735.26495139066;9681.10610725123,-19438.8295571448,9737.15277290702;9682.94679069729,-19442.5522123738,9739.03234963538;9684.77931661879,-19446.2584583046,9740.90369016288;9686.60369355278,-19449.9483120833,9742.76680308082;9688.41993004007,-19453.6217908633,9744.62169698430;9690.22803462524,-19457.2789118059,9746.46838047226;9692.02801585698,-19460.9196920804,9748.30686214779;9693.81988228748,-19464.5441488635,9750.13715061752;9695.60364247296,-19468.1522993397,9751.95925449222;9697.37930497313,-19471.7441607008,9753.77318238617;9699.14687835150,-19475.3197501460,9755.57894291752;9700.90637117526,-19478.8790848822,9757.37654470815;9702.65779201523,-19482.4221821233,9759.16599638362;9704.40114944571,-19485.9490590907,9760.94730657306;9706.13645204465,-19489.4597330127,9762.72048390927;9707.86370839359,-19492.9542211249,9764.48553702869;9709.58292707735,-19496.4325406699,9766.24247457116;9711.29411668440,-19499.8947088973,9767.99130518016;9712.99728580656,-19503.3407430635,9769.73203750259;9714.69244303906,-19506.7706604318,9771.46468018882;9716.37959698039,-19510.1844782723,9773.18924189255;9718.05875623257,-19513.5822138619,9774.90573127104;9719.72992940071,-19516.9638844840,9776.61415698473;9721.39312509323,-19520.3295074285,9778.31452769738;9723.04835192190,-19523.6790999920,9780.00685207619;9724.69561850141,-19527.0126794774,9781.69113879131;9726.33493344993,-19530.3302631941,9783.36739651644;9727.96630538851,-19533.6318684577,9785.03563392821;9729.58974294136,-19536.9175125900,9786.69585970647;9731.20525473585,-19540.1872129192,9788.34808253426;9732.81284940227,-19543.4409867794,9789.99231109761;9734.41253557386,-19546.6788515107,9791.62855408557;9736.00432188696,-19549.9008244594,9793.25682019029;9737.58821698076,-19553.1069229776,9794.87711810690;9739.16422949731,-19556.2971644233,9796.48945653337;9740.73236808163,-19559.4715661601,9798.09384417072;9742.29264138145,-19562.6301455576,9799.69028972276;9743.84505804738,-19565.7729199908,9801.27880189618;9745.38962673279,-19568.8999068405,9802.85938940052;9746.92635609373,-19572.0111234928,9804.43206094804;9748.45525478902,-19575.1065873394,9805.99682525380;9749.97633148013,-19578.1863157775,9807.55369103561;9751.48959483114,-19581.2503262094,9809.10266701389;9752.99505350877,-19584.2986360428,9810.64376191178;9754.49271618224,-19587.3312626905,9812.17698445497;9755.98259152349,-19590.3482235708,9813.70234337190;9757.46468820675,-19593.3495361065,9815.21984739336;9758.93901490886,-19596.3352177257,9816.72950525281;9760.40558030910,-19599.3052858617,9818.23132568621;9761.86439308916,-19602.2597579523,9819.72531743192;9763.31546193302,-19605.1986514402,9821.21148923072;9764.75879552723,-19608.1219837731,9822.68984982595;9766.19440256038,-19611.0297724029,9824.16040796306;9767.62229172356,-19613.9220347867,9825.62317239005;9769.04247171010,-19616.7987883860,9827.07815185721;9770.45495121544,-19619.6600506665,9828.52535511698;9771.85973893733,-19622.5058390986,9829.96479092416;9773.25684357559,-19625.3361711571,9831.39646803568;9774.64627383229,-19628.1510643211,9832.82039521074;9776.02803841152,-19630.9505360739,9834.23658121064;9777.40214601945,-19633.7346039029,9835.64503479878;9778.76860536432,-19636.5032853000,9837.04576474070;9780.12742515634,-19639.2565977606,9838.43877980394;9781.47861410773,-19641.9945587847,9839.82408875811;9783.15323788130,-19645.3826573911,9841.53545094565;9784.81999401491,-19648.7549285141,9843.23886825145;9786.47889148217,-19652.1113901788,9844.93434970876;9788.12993925818,-19655.4520604136,9846.62190435233;9789.77314631968,-19658.7769572502,9848.30154121864;9791.40852164473,-19662.0860987228,9849.97326934545;9793.03607421295,-19665.3795028689,9851.63709777222;9794.65581300532,-19668.6571877288,9853.29303553974;9796.26774700428,-19671.9191713457,9854.94109169034;9797.87188519353,-19675.1654717653,9856.58127526762;9799.46823655813,-19678.3961070361,9858.21359531662;9801.05681008450,-19681.6110952096,9859.83806088377;9802.63761476033,-19684.8104543394,9861.45468101679;9804.21065957442,-19687.9942024819,9863.06346476457;9805.77595351693,-19691.1623576959,9864.66442117740;9807.33350557916,-19694.3149380425,9866.25755930676;9808.88332475349,-19697.4519615853,9867.84288820522;9810.42542003352,-19700.5734463902,9869.42041692664;9811.95980041396,-19703.6794105253,9870.99015452603;9813.48647489043,-19706.7698720606,9872.55211005933;9815.00545245974,-19709.8448490687,9874.10629258372;9816.51674211968,-19712.9043596238,9875.65271115740;9818.02035286897,-19715.9484218025,9877.19137483955;9819.51629370729,-19718.9770536830,9878.72229269034;9821.00457363536,-19721.9902733458,9880.24547377100;9822.48520165452,-19724.9880988725,9881.76092714346;9823.95818676728,-19727.9705483472,9883.26866187084;9825.42353797679,-19730.9376398554,9884.76868701692;9826.88126428709,-19733.8893914843,9886.26101164641;9828.33137470296,-19736.8258213227,9887.74564482486;9829.77387822995,-19739.7469474607,9889.22259561855;9831.20878387428,-19742.6527879903,9890.69187309450;9832.63610064297,-19745.5433610046,9892.15348632057;9834.05583754363,-19748.4186845983,9893.60744436524;9835.46800358450,-19751.2787768672,9895.05375629768;9836.87260777445,-19754.1236559085,9896.49243118769;9838.26965912290,-19756.9533398204,9897.92347810569;9839.65916663988,-19759.7678467025,9899.34690612272;9841.04113933589,-19762.5671946553,9900.76272431035;9842.41558622195,-19765.3514017805,9902.17094174068;9843.78251630957,-19768.1204861806,9903.57156748638;9845.14193861067,-19770.8744659590,9904.96461062053;9846.49386213753,-19773.6133592201,9906.35008021659;9847.83829590295,-19776.3371840692,9907.72798534863;9849.17524891998,-19779.0459586119,9909.09833509095;9850.50473020196,-19781.7397009549,9910.46113851824;9851.82674876271,-19784.4184292056,9911.81640470563;9853.14131361616,-19787.0821614715,9913.16414272844;9854.44843377657,-19789.7309158612,9914.50436166235;9855.74811825838,-19792.3647104835,9915.83707058326;9856.39076797117,-19793.6777598462,9916.50738593968;9857.02649183502,-19794.9768742882,9917.17070527535;9857.65529837678,-19796.2620709383,9917.82703717471;9858.27719612406,-19797.5333669268,9918.47639022293;9858.89219360522,-19798.7907793854,9919.11877300600;9859.50029934920,-19800.0343254471,9919.75419411051;9860.10152188560,-19801.2640222465,9920.38266212378;9860.69586974465,-19802.4798869189,9921.00418563375;9861.28335145711,-19803.6819366014,9921.61877322900;9861.86397555427,-19804.8701884317,9922.22643349857;9862.43775056797,-19806.0446595488,9922.82717503220;9863.00468503057,-19807.2053670929,9923.42100642014;9863.56478747486,-19808.3523282048,9924.00793625307;9864.11806643403,-19809.4855600263,9924.58797312217;9864.66453044172,-19810.6050797003,9925.16112561907;9865.20418803198,-19811.7109043704,9925.72740233585;9865.73704773914,-19812.8030511806,9926.28681186493;9866.26311809789,-19813.8815372760,9926.83936279909;9866.78240764325,-19814.9463798023,9927.38506373151;9867.29492491051,-19815.9975959056,9927.92392325564;9867.80067843510,-19817.0352027324,9928.45594996514;9868.29967675282,-19818.0592174302,9928.98115245406;9868.79192839960,-19819.0696571464,9929.49953931662;9869.27744191144,-19820.0665390290,9930.01111914713;9869.75622582465,-19821.0498802262,9930.51590054026;9870.22828867555,-19822.0196978866,9931.01389209074;9870.69363900054,-19822.9760091589,9931.50510239337;9871.15228533610,-19823.9188311919,9931.98954004309;9871.60423621871,-19824.8481811345,9932.46721363490;9872.04950018496,-19825.7640761360,9932.93813176391;9872.48808577128,-19826.6665333452,9933.40230302509;9872.92000151420,-19827.5555699111,9933.85973601359;9873.34525594994,-19828.4312029823,9934.31043932425;9873.76385761493,-19829.2934497077,9934.75442155216;9874.17581504524,-19830.1423272357,9935.19169129208;9874.58113677686,-19830.9778527143,9935.62225713875;9874.97983134564,-19831.8000432915,9936.04612768676;9875.37190728714,-19832.6089161147,9936.46331153048;9875.75737313678,-19833.4044883308,9936.87381726414;9876.13623742970,-19834.1867770866,9937.27765348173;9876.50850870071,-19834.9557995279,9937.67482877700;9876.87419548431,-19835.7115728000,9938.06535174331;9877.23330631481,-19836.4541140480,9938.44923097395;9877.58584972592,-19837.1834404157,9938.82647506162;9877.93183425121,-19837.8995690467,9939.19709259890;9878.27126842363,-19838.6025170833,9939.56109217780;9878.60416077588,-19839.2923016675,9939.91848239007;9878.93051984005,-19839.9689399398,9940.26927182692;9879.25035414784,-19840.6324490404,9940.61346907920;9879.56367223034,-19841.2828461079,9940.95108273716;9880.18923735550,-19842.5608896092,9941.60346870050;9880.80806536914,-19843.8253770256,9942.24904834725;9881.42016503377,-19845.0763259614,9942.88783050108;9882.02554511099,-19846.3137540187,9943.51982398479;9882.62421436157,-19847.5376787981,9944.14503762037;9883.21618154524,-19848.7481178983,9944.76348022883;9883.80145542082,-19849.9450889160,9945.37516063025;9884.38004474609,-19851.1286094460,9945.98008764373;9884.95195827786,-19852.2986970810,9946.57827008739;9885.51720477182,-19853.4553694116,9947.16971677831;9886.07579298269,-19854.5986440266,9947.75443653259;9886.62773166401,-19855.7285385121,9948.33243816517;9887.17302956834,-19856.8450704526,9948.90373049006;9887.71169544689,-19857.9482574299,9949.46832231992;9888.24373804995,-19859.0381170237,9950.02622246655;9888.76916612643,-19860.1146668114,9950.57743974036;9889.28798842407,-19861.1779243676,9951.12198295063;9889.80021368949,-19862.2279072651,9951.65986090554;9890.30585066793,-19863.2646330736,9952.19108241193;9890.80490810338,-19864.2881193607,9952.71565627538;9891.29739473851,-19865.2983836910,9953.23359130024;9891.78331931475,-19866.2954436269,9953.74489628956;9892.26269057203,-19867.2793167277,9954.24958004497;9892.73551724900,-19868.2500205503,9954.74765136683;9893.20180808295,-19869.2075726486,9955.23911905416;9893.66157180962,-19870.1519905738,9955.72399190445;9894.11481716341,-19871.0832918742,9956.20227871389;9894.56155287718,-19872.0014940951,9956.67398827715;9895.00178768238,-19872.9066147789,9957.13912938748;9895.43553030886,-19873.7986714650,9957.59771083660;9895.86278948498,-19874.6776816897,9958.04974141473;9896.28357393753,-19875.5436629863,9958.49522991056;9896.69789239172,-19876.3966328848,9958.93418511120;9897.10575357111,-19877.2366089120,9959.36661580215;9897.50716619765,-19878.0636085915,9959.79253076733;9897.90213899168,-19878.8776494438,9960.21193878906;9898.29068067182,-19879.6787489857,9960.62484864797;9898.67279995500,-19880.4669247309,9961.03126912298;9899.04850555646,-19881.2421941897,9961.43120899139;9899.41780618961,-19882.0045748686,9961.82467702870;9899.78071056614,-19882.7540842707,9962.21168200866;9900.13722739605,-19883.4907398960,9962.59223270338;9900.48736538738,-19884.2145592403,9962.96633788304;9900.83113324642,-19884.9255597960,9963.33400631606;9901.16853967753,-19885.6237590518,9963.69524676898;9901.49959338331,-19886.3091744926,9964.05006800660;9901.82430306431,-19886.9818235994,9964.39847879165;9902.14267741933,-19887.6417238498,9964.74048788516;9902.45472514500,-19888.2888927170,9965.07610404603;9902.76045493626,-19888.9233476707,9965.40533603146;9902.74697562722,-19888.9161344583,9965.41274825690;9902.72742611616,-19888.8967053119,9965.41402605594;9902.70181486899,-19888.8650772411,9965.40917795500;9902.67015035008,-19888.8212672523,9965.39821247895;9902.63244102188,-19888.7652923480,9965.38113815078;9902.58869534492,-19888.6971695272,9965.35796349158;9902.53892177809,-19888.6169157852,9965.32869702079;9902.48312877813,-19888.5245481135,9965.29334725579;9902.42132480018,-19888.4200834999,9965.25192271230;9902.35351829716,-19888.3035389282,9965.20443190389;9902.27971772036,-19888.1749313788,9965.15088334251;9902.19993151881,-19888.0342778275,9965.09128553785;9902.11416813982,-19887.8815952468,9965.02564699793;9902.02243602851,-19887.7169006047,9964.95397622858;9901.92474362803,-19887.5402108655,9964.87628173367;9901.82109937949,-19887.3515429892,9964.79257201508;9901.71151172200,-19887.1509139319,9964.70285557267;9901.59598909241,-19886.9383406453,9964.60714090410;9901.47453992559,-19886.7138400770,9964.50543650504;9901.34717265424,-19886.4774291703,9964.39775086901;9901.21389570897,-19886.2291248644,9964.28409248746;9901.07471751806,-19885.9689440937,9964.16446984954;9900.92964650777,-19885.6969037889,9964.03889144238;9900.77869110199,-19885.4130208755,9963.90736575078;9900.62185972244,-19885.1173122751,9963.76990125735;9900.45916078865,-19884.8097949047,9963.62650644256;9900.29060271773,-19884.4904856766,9963.47718978448;9900.11619392458,-19884.1594014984,9963.32195975896;9899.93594282171,-19883.8165592734,9963.16082483950;9899.74985781945,-19883.4619759002,9962.99379349742;9899.55794732554,-19883.0956682723,9962.82087420146;9899.36021974545,-19882.7176532787,9962.64207541816;9899.15668348232,-19882.3279478037,9962.45740561166;9898.94734693672,-19881.9265687267,9962.26687324362;9898.73221850686,-19881.5135329220,9962.07048677331;9898.51130658843,-19881.0888572591,9961.86825465754;9898.28461957469,-19880.6525586028,9961.66018535065;9898.05216585639,-19880.2046538126,9961.44628730453;9897.81395382170,-19879.7451597428,9961.22656896847;9897.56999185631,-19879.2740932432,9961.00103878933;9897.32028834327,-19878.7914711579,9960.76970521131;9897.06485166312,-19878.2973103260,9960.53257667615;9896.80369019373,-19877.7916275816,9960.28966162291;9896.53681231038,-19877.2744397534,9960.04096848809;9896.26422638570,-19876.7457636646,9959.78650570551;9895.98594078963,-19876.2056161335,9959.52628170638;9895.70196388947,-19875.6540139728,9959.26030491926;9895.41230404973,-19875.0909739896,9958.98858376989;9895.11696963233,-19874.5165129861,9958.71112668151;9894.81596899627,-19873.9306477585,9958.42794207438;9894.50931049796,-19873.3333950976,9958.13903836623;9894.19700249088,-19872.7247717888,9957.84442397185;9893.87905332581,-19872.1047946118,9957.54410730337;9893.55547135063,-19871.4734803406,9957.23809676999;9893.22626491047,-19870.8308457436,9956.92640077821;9892.89144234752,-19870.1769075835,9956.60902773158;9892.55101200112,-19869.5116826172,9956.28598603082;9892.20498220761,-19868.8351875956,9955.95728407369;9891.85336130069,-19868.1474392644,9955.62293025524;9891.49615761078,-19867.4484543626,9955.28293296736;9891.13337946555,-19866.7382496239,9954.93730059911;9890.76503518963,-19866.0168417757,9954.58604153659;9890.39113310471,-19865.2842475397,9954.22916416290;9890.01168152941,-19864.5404836314,9953.86667685815;9889.62668877928,-19863.7855667601,9953.49858799936;9889.23616316695,-19863.0195136295,9953.12490596062;9888.84011300184,-19862.2423409366,9952.74563911288;9888.43854659036,-19861.4540653725,9952.36079582402;9888.03147223583,-19860.6547036221,9951.97038445888;9887.61889823833,-19859.8442723638,9951.57441337907;9887.20083289496,-19859.0227882702,9951.17289094322;9886.77728449957,-19858.1902680073,9950.76582550673;9886.34826134276,-19857.3467282344,9950.35322542174;9885.91377171206,-19856.4921856051,9949.93509903735;9885.47382389170,-19855.6266567659,9949.51145469935;9885.02842616273,-19854.7501583573,9949.08230075039;9884.57758680291,-19853.8627070131,9948.64764552981;9884.12131408673,-19852.9643193606,9948.20749737369;9883.65961628542,-19852.0550120206,9947.76186461488;9883.19250166682,-19851.1348016069,9947.31075558281;9882.71997849557,-19850.2037047272,9946.85417860377;9882.24205503291,-19849.2617379823,9946.39214200063;9881.75873953661,-19848.3089179659,9945.92465409278;9881.27004026126,-19847.3452612656,9945.45172319648;9880.77596545796,-19846.3707844619,9944.97335762447;9880.27652337428,-19845.3855041280,9944.48956568599;9879.77172225458,-19844.3894368312,9944.00035568707;9879.26157033964,-19843.3825991312,9943.50573593016;9878.74607586675,-19842.3650075809,9943.00571471425;9878.22524706980,-19841.3366787263,9942.50030033490;9877.69909217909,-19840.2976291064,9941.98950108413;9877.16761942147,-19839.2478752531,9941.47332525049;9876.63083702025,-19838.1874336913,9940.95178111899;9876.08875319518,-19837.1163209387,9940.42487697110;9875.54137616238,-19836.0345535060,9939.89262108467;9874.98871413448,-19834.9421478966,9939.35502173406;9874.43077532043,-19833.8391206068,9938.81208718996;9873.86756792557,-19832.7254881253,9938.26382571945;9873.29910015164,-19831.6012669341,9937.71024558600;9872.72538019667,-19830.4664735073,9937.15135504942;9872.14641625506,-19829.3211243122,9936.58716236586;9871.56221651751,-19828.1652358082,9936.01767578777;9870.97278917106,-19826.9988244478,9935.44290356397;9870.37814239890,-19825.8219066755,9934.86285393942;9869.77828438063,-19824.6344989289,9934.27753515550;9869.17322329198,-19823.4366176375,9933.68695544972;9868.56296730490,-19822.2282792236,9933.09112305582;9867.94752458773,-19821.0095001019,9932.49004620392;9867.32690330480,-19819.7802966795,9931.88373312017;9866.70111161667,-19818.5406853557,9931.27219202690;9866.07015768018,-19817.2906825222,9930.65543114278;9865.43404964810,-19816.0303045629,9930.03345868237;9864.79279566954,-19814.7595678543,9929.40628285660;9864.14640388963,-19813.4784887646,9928.77391187240;9863.49488244958,-19812.1870836547,9928.13635393281;9862.83823948674,-19810.8853688772,9927.49361723698;9862.17648313441,-19809.5733607770,9926.84570998007;9861.50962152206,-19808.2510756912,9926.19264035333;9860.83766277520,-19806.9185299491,9925.53441654415;9860.16061501525,-19805.5757398714,9924.87104673573;9859.47848635969,-19804.2227217715,9924.20253910741;9858.79128492200,-19802.8594919544,9923.52890183452;9858.09901881161,-19801.4860667170,9922.85014308829;9857.40169613394,-19800.1024623483,9922.16627103601;9856.69932499030,-19798.7086951291,9921.47729384082;9855.99191347795,-19797.3047813320,9920.78321966181;9855.27946968998,-19795.8907372212,9920.08405665394;9854.56200171553,-19794.4665790532,9919.37981296818;9853.83951763952,-19793.0323230758,9918.67049675130;9853.11202554266,-19791.5879855286,9917.95611614587;9852.37953350169,-19790.1335826431,9917.23667929045;9851.64204958903,-19788.6691306421,9916.51219431933;9850.89958187296,-19787.1946457404,9915.78266936265;9850.15213841753,-19785.7101441440,9915.04811254629;9849.39972728267,-19784.2156420508,9914.30853199205;9848.64235652401,-19782.7111556500,9913.56393581739;9847.88003419293,-19781.1967011225,9912.81433213556;9847.11276833654,-19779.6722946405,9912.05972905551;9846.34056699776,-19778.1379523678,9911.30013468202;9845.56343821509,-19776.5936904594,9910.53555711544;9844.78139002285,-19775.0395250618,9909.76600445193;9843.99443045098,-19773.4754723129,9908.99148478328;9843.20256752510,-19771.9015483420,9908.21200619699;9842.40580926647,-19770.3177692693,9907.42757677613;9841.60416369193,-19768.7241512066,9906.63820459941;9840.79763881412,-19767.1207102571,9905.84389774130;9839.98624264114,-19765.5074625147,9905.04466427175;9839.16998317667,-19763.8844240649,9904.24051225629;9838.34886842006,-19762.2516109841,9903.43144975611;9837.52290636613,-19760.6090393398,9902.61748482786;9836.69210500538,-19758.9567251910,9901.79862552390;9835.85647232373,-19757.2946845871,9900.97487989195;9835.01601630271,-19755.6229335693,9900.14625597541;9834.17074491923,-19753.9414881691,9899.31276181301;9833.32066614584,-19752.2503644093,9898.47440543911;9832.46578795045,-19750.5495783036,9897.63119488347;9831.60611829652,-19748.8391458568,9896.78313817136;9830.74166514295,-19747.1190830642,9895.93024332352;9829.87243644407,-19745.3894059124,9895.07251835606;9828.99844014958,-19743.6501303785,9894.20997128054;9828.11968420464,-19741.9012724305,9893.34261010390;9827.23617654983,-19740.1428480272,9892.47044282854;9826.34792512109,-19738.3748731183,9891.59347745221;9825.45493784969,-19736.5973636440,9890.71172196797;9824.55722266234,-19734.8103355353,9889.82518436433;9823.65478748094,-19733.0138047137,9888.93387262499;9822.74764022299,-19731.2077870918,9888.03779472923;9821.83578880100,-19729.3922985722,9887.13695865135;9820.91924112290,-19727.5673550485,9886.23137236106;9819.99800509208,-19725.7329724049,9885.32104382353;9819.07208860688,-19723.8891665157,9884.40598099886;9818.14149956117,-19722.0359532463,9883.48619184271;9817.20624584397,-19720.1733484521,9882.56168430583;9816.26633533955,-19718.3013679793,9881.63246633427;9815.32177592730,-19716.4200276642,9880.69854586918;9814.37257548202,-19714.5293433337,9879.75993084708;9813.41874187350,-19712.6293308050,9878.81662919952;9812.46028296688,-19710.7200058859,9877.86864885337;9811.49720662235,-19708.8013843741,9876.91599773055;9810.52952069539,-19706.8734820579,9875.95868374826;9809.55723303642,-19704.9363147158,9874.99671481865;9808.58035149118,-19702.9898981164,9874.03009884916;9807.59888390044,-19701.0342480188,9873.05884374228;9806.61283810016,-19699.0693801722,9872.08295739566;9805.62222192126,-19697.0953103158,9871.10244770192;9804.62704318984,-19695.1120541790,9870.11732254884;9803.62730972706,-19693.1196274816,9869.12758981925;9802.62302934904,-19691.1180459330,9868.13325739096;9801.61420986710,-19689.1073252331,9867.13433313697;9800.60085908755,-19687.0874810719,9866.13082492522;9799.58298481157,-19685.0585291288,9865.12274061856;9798.56059483552,-19683.0204850738,9864.11008807499;9797.53369695070,-19680.9733645668,9863.09287514744;9796.50229894333,-19678.9171832572,9862.07110968377;9795.46640859473,-19676.8519567849,9861.04479952691;9794.42603368103,-19674.7777007794,9860.01395251463;9793.38118197341,-19672.6944308599,9858.97857647968;9792.33186123800,-19670.6021626360,9857.93867924983;9791.27807923569,-19668.5009117064,9856.89426864752;9790.21984372251,-19666.3906936603,9855.84535249039;9789.15716244919,-19664.2715240761,9854.79193859072;9788.09004316148,-19662.1434185224,9853.73403475585;9787.01849359988,-19660.0063925572,9852.67164878782;9785.94252149993,-19657.8604617284,9851.60478848370;9784.86213459184,-19655.7056415735,9850.53346163527;9783.77734060072,-19653.5419476196,9849.45767602916;9782.68814724652,-19651.3693953836,9848.37743944684;9781.59456224405,-19649.1880003718,9847.29275966461;9780.49659330291,-19646.9977780805,9846.20364445359;9779.39424812740,-19644.7987439950,9845.11010157956;9778.28753441662,-19642.5909135903,9844.01213880313;9777.17645986461,-19640.3743023314,9842.90976387976;9776.06103215995,-19638.1489256721,9841.80298455955;9774.94125898610,-19635.9147990562,9840.69180858737;9773.81714802119,-19633.6719379166,9839.57624370280;9772.68870693814,-19631.4203576759,9838.45629764019;9771.55594340453,-19629.1600737459,9837.33197812855;9770.41886508269,-19626.8911015280,9836.20329289161;9769.27747962955,-19624.6134564126,9835.07024964772;9768.13179469676,-19622.3271537797,9833.93285610989;9766.98181793076,-19620.0322089987,9832.79111998594;9765.82755697251,-19617.7286374282,9831.64504897821;9764.66901945767,-19615.4164544161,9830.49465078372;9763.50621301645,-19613.0956752991,9829.33993309400;9762.33914527386,-19610.7663154040,9828.18090359541;9761.16782384937,-19608.4283900460,9827.01756996873;9759.99225635711,-19606.0819145300,9825.84993988941;9758.81245040585,-19603.7269041498,9824.67802102750;9757.62841359883,-19601.3633741885,9823.50182104755;9756.44015353399,-19598.9913399181,9822.32134760876;9755.24767780377,-19596.6108166001,9821.13660836482;9754.05099399513,-19594.2218194845,9819.94761096394;9752.85010968969,-19591.8243638110,9818.75436304900;9751.64503246340,-19589.4184648078,9817.55687225715;9750.43576988696,-19587.0041376925,9816.35514622032;9749.22232952541,-19584.5813976715,9815.14919256473;9748.00471893833,-19582.1502599400,9813.93901891116;9746.78294567993,-19579.7107396827,9812.72463287497;9745.55701729863,-19577.2628520726,9811.50604206576;9744.32694133760,-19574.8066122722,9810.28325408784;9743.09272533423,-19572.3420354324,9809.05627653974;9741.85437682053,-19569.8691366931,9807.82511701458;9740.61190332290,-19567.3879311835,9806.58978309987;9739.36531236216,-19564.8984340209,9805.35028237751;9738.11461145351,-19562.4006603120,9804.10662242379;9736.85980810664,-19559.8946251519,9802.85881080947;9735.60090982557,-19557.3803436248,9801.60685509961;9734.33792410880,-19554.8578308036,9800.35076285374;9733.07085844907,-19552.3271017495,9799.09054162563;9731.79972033362,-19549.7881715130,9797.82619896353;9730.52451724398,-19547.2410551329,9796.55774240997;9729.24525665605,-19544.6857676369,9795.28517950180;9727.96194604009,-19542.1223240413,9794.00851777027;9726.67459286076,-19539.5507393512,9792.72776474098;9725.38320457683,-19536.9710285597,9791.44292793362;9724.08778864158,-19534.3832066493,9790.15401486242;9722.78835250255,-19531.7872885906,9788.86103303580;9721.48490360151,-19529.1832893428,9787.56398995642;9720.17744937459,-19526.5712238538,9786.26289312128;9718.86599725221,-19523.9511070600,9784.95775002168;9717.55055465893,-19521.3229538861,9783.64856814299;9716.23112901371,-19518.6867792456,9782.33535496501;9714.90772772970,-19516.0425980403,9781.01811796170;9713.58035821429,-19513.3904251604,9779.69686460125;9712.24902786910,-19510.7302754846,9778.37160234604;9710.91374408998,-19508.0621638800,9777.04233865270;9709.57451426696,-19505.3861052021,9775.70908097199;9708.23134578434,-19502.7021142948,9774.37183674896;9706.88424602059,-19500.0102059904,9773.03061342276;9705.53322234834,-19497.3103951095,9771.68541842676;9704.17828213436,-19494.6026964608,9770.33625918837;9702.81943273978,-19491.8871248419,9768.98314312939;9701.45668151957,-19489.1636950379,9767.62607766544;9700.09003582315,-19486.4324218228,9766.26507020658;9698.71950299394,-19483.6933199587,9764.90012815682;9697.34509036953,-19480.9464041957,9763.53125891437;9695.96680528163,-19478.1916892725,9762.15846987148;9694.58465505604,-19475.4291899157,9760.78176841453;9693.19864701268,-19472.6589208401,9759.40116192398;9691.80878846560,-19469.8808967489,9758.01665777441;9690.41508672298,-19467.0951323333,9756.62826333449;9689.01754908693,-19464.3016422726,9755.23598596683;9687.61618285381,-19461.5004412343,9753.83983302825;9686.21099531394,-19458.6915438739,9752.43981186953;9684.80199375170,-19455.8749648351,9751.03592983546;9683.38918544561,-19453.0507187498,9749.62819426501;9681.97257766813,-19450.2188202375,9748.21661249102;9680.55217768584,-19447.3792839062,9746.80119184043;9679.12799275925,-19444.5321243516,9745.38193963414;9677.70003014299,-19441.6773561578,9743.95886318711;9676.26829708562,-19438.8149938963,9742.53196980820;9674.83280082977,-19435.9450521272,9741.10126680038;9673.39354861202,-19433.0675453982,9739.66676146048;9671.95054766292,-19430.1824882449,9738.22846107932;9670.50380520703,-19427.2898951909,9736.78637294172;9669.05332846294,-19424.3897807479,9735.34050432648;9667.59912464306,-19421.4821594153,9733.89086250623;9666.14120095392,-19418.5670456804,9732.43745474767;9664.67956459585,-19415.6444540183,9730.98028831130;9663.21422276323,-19412.7143988921,9729.51937045164;9661.74518264427,-19409.7768947526,9728.05470841705;9660.27245142125,-19406.8319560386,9726.58630944991;9658.79603627025,-19403.8795971766,9725.11418078637;9657.31594436128,-19400.9198325807,9723.63832965651;9655.83218285830,-19397.9526766531,9722.15876328435;9654.34475891912,-19394.9781437835,9720.67548888771;9652.85367969544,-19391.9962483495,9719.18851367830;9651.35895233285,-19389.0070047163,9717.69784486169;9649.86058397088,-19386.0104272370,9716.20348963738;9648.35858174280,-19383.0065302523,9714.70545519858;9646.85295277588,-19379.9953280905,9713.20374873248;9645.34370419105,-19376.9768350675,9711.69837741992;9643.83084310332,-19373.9510654873,9710.18934843577;9642.31437662140,-19370.9180336411,9708.67666894862;9640.79431184781,-19367.8777538078,9707.16034612081;9639.27065587903,-19364.8302402542,9705.64038710864;9637.74341580520,-19361.7755072344,9704.11679906203;9636.21259871030,-19358.7135689899,9702.58958912477;9634.67821167224,-19355.6444397504,9701.05876443449;9633.14026176259,-19352.5681337327,9699.52433212249;9631.59875604679,-19349.4846651412,9697.98629931393;9630.05370158408,-19346.3940481680,9696.44467312771;9628.50510542730,-19343.2962969924,9694.89946067635;9626.95297462333,-19340.1914257817,9693.35066906638;9625.39731621257,-19337.0794486901,9691.79830539780;9623.83813722937,-19333.9603798597,9690.24237676456;9622.27544470170,-19330.8342334201,9688.68289025422;9620.70924565137,-19327.7010234880,9687.11985294810;9619.13954709380,-19324.5607641677,9685.55327192117;9617.56635603826,-19321.4134695511,9683.98315424222;9615.98967948768,-19318.2591537173,9682.40950697365;9614.40952443878,-19315.0978307329,9680.83233717162;9612.82589788191,-19311.9295146518,9679.25165188593;9611.23880680115,-19308.7542195154,9677.66745816009;9609.64825817432,-19305.5719593524,9676.07976303129;9608.05425897292,-19302.3827481789,9674.48857353039;9606.45681616207,-19299.1865999982,9672.89389668187;9604.85593670068,-19295.9835288011,9671.29573950393;9603.25162754122,-19292.7735485656,9669.69410900838;9601.64389562998,-19289.5566732570,9668.08901220073;9600.03274790670,-19286.3329168278,9666.48045608000;9598.41819130495,-19283.1022932180,9664.86844763899;9596.80023275193,-19279.8648163549,9663.25299386407;9595.17887916848,-19276.6205001528,9661.63410173527;9593.55413746893,-19273.3693585131,9660.01177822607;9591.92601456151,-19270.1114053251,9658.38603030383;9590.29451734785,-19266.8466544647,9656.75686492927;9588.65965272335,-19263.5751197953,9655.12428905690;9587.02142757691,-19260.2968151672,9653.48830963463;9585.37984879109,-19257.0117544181,9651.84893360408;9583.73492324216,-19253.7199513732,9650.20616790049;9582.08665779978,-19250.4214198441,9648.56001945255;9580.43505932737,-19247.1161736302,9646.91049518258;9578.78013468189,-19243.8042265178,9645.25760200650;9577.12189071389,-19240.4855922802,9643.60134683375;9575.46033426741,-19237.1602846780,9641.94173656727;9573.79547218023,-19233.8283174590,9640.27877810367;9572.12731128355,-19230.4897043577,9638.61247833298;9570.45585840221,-19227.1444590961,9636.94284413885;9568.78112035453,-19223.7925953830,9635.26988239837;9567.10310395254,-19220.4341269145,9633.59359998233;9565.42181600159,-19217.0690673734,9631.91400375480;9563.73726330081,-19213.6974304301,9630.23110057361;9562.04945264264,-19210.3192297413,9628.54489728986;9560.35839081322,-19206.9344789513,9626.85540074835;9558.66408459214,-19203.5431916913,9625.16261778730;9556.96654075253,-19200.1453815794,9623.46655523841;9555.26576606098,-19196.7410622205,9621.76721992686;9553.56176727766,-19193.3302472068,9620.06461867135;9551.85455115624,-19189.9129501174,9618.35875828407;9550.14412444384,-19186.4891845184,9616.64964557063;9548.43049388117,-19183.0589639626,9614.93728733021;9546.71366620227,-19179.6223019899,9613.22169035527;9544.99364813488,-19176.1792121274,9611.50286143197;9543.27044639998,-19172.7297078885,9609.78080733967;9541.54406771224,-19169.2738027741,9608.05553485137;9539.81451877969,-19165.8115102718,9606.32705073348;9538.08180630385,-19162.3428438559,9604.59536174578;9536.34593697966,-19158.8678169878,9602.86047464150;9534.60691749564,-19155.3864431158,9601.12239616740;9532.86475453359,-19151.8987356749,9599.38113306349;9531.11945476894,-19148.4047080871,9597.63669206341;9529.37102487038,-19144.9043737611,9595.88907989400;9527.61947150022,-19141.3977460927,9594.13830327572;9525.86480131410,-19137.8848384642,9592.38436892230;9524.10702096107,-19134.3656642449,9590.62728354089;9522.34613708365,-19130.8402367909,9588.86705383204;9520.58215631784,-19127.3085694451,9587.10368648979;9518.81508529291,-19123.7706755371,9585.33718820141;9517.04493063171,-19120.2265683835,9583.56756564771;9515.27169895040,-19116.6762612874,9581.79482550279;9513.49539685852,-19113.1197675390,9580.01897443410;9511.71603095906,-19109.5571004147,9578.24001910253;9509.93360784848,-19105.9882731785,9576.45796616236;9508.14813411644,-19102.4132990802,9574.67282226110;9506.35961634623,-19098.8321913572,9572.88459403986;9504.56806111427,-19095.2449632328,9571.09328813277;9502.77347499060,-19091.6516279178,9569.29891116767;9500.97586453843,-19088.0521986092,9567.50146976544;9499.17523631451,-19084.4466884908,9565.70097054054;9497.19018416285,-19080.4704485849,9563.71453438806;9495.20224746867,-19076.4883956968,9561.72517474419;9493.21143266344,-19072.5005427586,9559.73289809713;9491.21774617215,-19068.5069026897,9557.73771092858;9489.22119441318,-19064.5074883959,9555.73961971358;9487.22178379844,-19060.5023127702,9553.73863092070;9485.21952073325,-19056.4913886925,9551.73475101188;9483.21441161653,-19052.4747290297,9549.72798644260;9481.20646284042,-19048.4523466349,9547.71834366157;9479.19568079067,-19044.4242543487,9545.70582911109;9477.18207184651,-19040.3904649986,9543.69044922686;9475.16564238039,-19036.3509913984,9541.67221043783;9473.14639875846,-19032.3058463491,9539.65111916657;9471.12434734019,-19028.2550426385,9537.62718182898;9469.09949447841,-19024.1985930411,9535.60040483426;9467.07184651954,-19020.1365103185,9533.57079458522;9465.04140980328,-19016.0688072187,9531.53835747784;9463.00819066285,-19011.9954964768,9529.50309990166;9460.97219542483,-19007.9165908145,9527.46502823952;9458.93343040921,-19003.8321029405,9525.42414886764;9456.89190192941,-18999.7420455500,9523.38046815569;9454.84761629225,-18995.6464313252,9521.33399246661;9452.80057979801,-18991.5452729350,9519.28472815686;9450.75079874028,-18987.4385830350,9517.23268157615;9448.69827940611,-18983.3263742676,9515.17785906761;9446.64302807594,-18979.2086592620,9513.12026696772;9444.58505102355,-18975.0854506340,9511.05991160634;9442.52435451613,-18970.9567609862,9508.99679930660;9440.46094481430,-18966.8226029080,9506.93093638512;9438.39482817204,-18962.6829889754,9504.86232915181;9436.32601083665,-18958.5379317511,9502.79098390988;9434.25449904889,-18954.3874437847,9500.71690695596;9432.18029904286,-18950.2315376123,9498.64010457999;9430.10341704603,-18946.0702257568,9496.56058306527;9428.02385927922,-18941.9035207278,9494.47834868840;9425.94163195659,-18937.7314350213,9492.39340771929;9423.85674128573,-18933.5539811204,9490.30576642126;9421.76919346761,-18929.3711714948,9488.21543105095;9419.67899469639,-18925.1830186004,9486.12240785822;9417.58615115977,-18920.9895348804,9484.02670308635;9415.49066903874,-18916.7907327644,9481.92832297198;9413.39255450753,-18912.5866246683,9479.82727374487;9411.29181373391,-18908.3772229952,9477.72356162834;9409.18845287881,-18904.1625401345,9475.61719283883;9407.08247809661,-18899.9425884624,9473.50817358616;9404.97389553497,-18895.7173803415,9471.39651007348;9402.86271133493,-18891.4869281214,9469.28220849721;9400.74893163085,-18887.2512441379,9467.16527504710;9398.63256255035,-18883.0103407137,9465.04571590610;9396.51361021446,-18878.7642301579,9462.92353725058;9394.39208073756,-18874.5129247665,9460.79874525019;9392.26798022723,-18870.2564368217,9458.67134606774;9390.14131478444,-18865.9947785926,9456.54134585946;9388.01209050348,-18861.7279623347,9454.40875077481;9385.88031347201,-18857.4560002904,9452.27356695659;9383.74598977087,-18853.1789046882,9450.13580054078;9381.60912547431,-18848.8966877435,9447.99545765672;9379.46972664980,-18844.6093616582,9445.85254442693;9377.32779935831,-18840.3169386208,9443.70706696740;9375.18334965381,-18836.0194308062,9441.55903138712;9373.03638358390,-18831.7168503761,9439.40844378862;9370.88690718916,-18827.4092094784,9437.25531026742;9368.73492650376,-18823.0965202480,9435.09963691258;9366.58044755498,-18818.7787948061,9432.94142980626;9364.42347636338,-18814.4560452603,9430.78069502383;9362.26401894297,-18810.1282837049,9428.61743863411;9360.10208130090,-18805.7955222209,9426.45166669901;9357.93766943769,-18801.4577728754,9424.28338527377;9355.77078934704,-18797.1150477223,9422.11260040680;9353.60144701609,-18792.7673588022,9419.93931813990;9351.42964842518,-18788.4147181418,9417.76354450805;9349.25539954783,-18784.0571377544,9415.58528553935;9347.07870635106,-18779.6946296402,9413.40454725540;9344.89957479498,-18775.3272057855,9411.22133567083;9342.71801083303,-18770.9548781631,9409.03565679360;9340.53402041196,-18766.5776587326,9406.84751662489;9338.34760947170,-18762.1955594397,9404.65692115910;9336.15878394555,-18757.8085922170,9402.46387638390;9333.96754976008,-18753.4167689834,9400.26838828023;9331.77391283499,-18749.0201016440,9398.07046282211;9329.57787908342,-18744.6186020910,9395.87010597700;9327.37945441163,-18740.2122822025,9393.66732370540;9325.17864471924,-18735.8011538434,9391.46212196116;9322.97545589903,-18731.3852288649,9389.25450669127;9320.76989383715,-18726.9645191047,9387.04448383602;9318.56196441299,-18722.5390363872,9384.83205932894;9316.35167349909,-18718.1087925230,9382.61723909665;9314.13902696133,-18713.6737993090,9380.40002905909;9311.92403065886,-18709.2340685292,9378.18043512944;9309.70669044405,-18704.7896119533,9375.95846321405;9307.48701216245,-18700.3404413379,9373.73411921242;9305.26500165298,-18695.8865684259,9371.50740901741;9303.04066474778,-18691.4280049468,9369.27833851501;9300.81400727219,-18686.9647626164,9367.04691358445;9298.58503504485,-18682.4968531370,9364.81314009816;9296.35375387749,-18678.0242881971,9362.57702392165;9294.12016957536,-18673.5470794721,9360.33857091393;9291.88428793671,-18669.0652386235,9358.09778692694;9289.64611475314,-18664.5787772993,9355.85467780596;9287.40565580944,-18660.0877071338,9353.60924938945;9285.16291688374,-18655.5920397482,9351.36150750912;9282.91790374723,-18651.0917867495,9349.11145798973;9280.67062216454,-18646.5869597317,9346.85910664944;9278.42107789336,-18642.0775702746,9344.60445929946;9276.16927668475,-18637.5636299451,9342.34752174430;9273.91522428295,-18633.0451502960,9340.08829978164;9271.65892642533,-18628.5221428667,9337.82679920223;9269.40038884271,-18623.9946191831,9335.56302579025;9267.13961725898,-18619.4625907574,9333.29698532293;9264.87661739131,-18614.9260690883,9331.02868357071;9262.61139495006,-18610.3850656607,9328.75812629722;9260.34395563889,-18605.8395919462,9326.48531925931;9258.07430515459,-18601.2896594025,9324.21026820697;9255.80244918733,-18596.7352794740,9321.93297888351;9253.52839342039,-18592.1764635915,9319.65345702532;9251.25214353025,-18587.6132231718,9317.37170836194;9248.97370518677,-18583.0455696186,9315.08773861627;9246.69308405282,-18578.4735143217,9312.80155350420;9244.41028578468,-18573.8970686574,9310.51315873496;9242.12531603175,-18569.3162439883,9308.22256001088;9239.83818043671,-18564.7310516635,9305.92976302751;9237.54888463546,-18560.1415030186,9303.63477347365;9235.25743425707,-18555.5476093753,9301.33759703116;9232.96383492393,-18550.9493820421,9299.03823937521;9230.66809225148,-18546.3468323134,9296.73670617401;9228.37021184859,-18541.7399714704,9294.43300308913;9226.07019931719,-18537.1288107805,9292.12713577516;9223.76806025252,-18532.5133614974,9289.81910987998;9221.46380024299,-18527.8936348615,9287.50893104462;9219.15742487034,-18523.2696420994,9285.19660490336;9216.84893970935,-18518.6413944241,9282.88213708353;9214.53835032811,-18514.0089030348,9280.56553320568;9212.22566228802,-18509.3721791176,9278.24679888370;9209.91088114360,-18504.7312338445,9275.92593972449;9207.59401244252,-18500.0860783740,9273.60296132814;9205.27506172583,-18495.4367238511,9271.27786928800;9202.95403452772,-18490.7831814072,9268.95066919060;9200.63093637556,-18486.1254621598,9266.62136661555;9198.30577279001,-18481.4635772133,9264.28996713576;9195.97854928493,-18476.7975376580,9261.95647631728;9193.64927136736,-18472.1273545708,9259.62089971930;9191.31794453767,-18467.4530390151,9257.28324289433;9188.98457428926,-18462.7746020404,9254.94351138782;9186.64916610889,-18458.0920546827,9252.60171073860;9184.31172547657,-18453.4054079646,9250.25784647867;9181.97225786541,-18448.7146728949,9247.91192413312;9179.63076874181,-18444.0198604687,9245.56394922028;9177.28726356539,-18439.3209816676,9243.21392725167;9174.94174778894,-18434.6180474595,9240.86186373192;9172.59422685854,-18429.9110687990,9238.50776415895;9170.02873188446,-18424.7659223687,9235.93390707779;9167.46138040030,-18419.6170303065,9233.35816382245;9164.89217771518,-18414.4644032915,9230.78053975279;9162.32112913151,-18409.3080519894,9228.20104022193;9159.74823994503,-18404.1479870524,9225.61967057630;9157.17351544495,-18398.9842191199,9223.03643615574;9154.59696091361,-18393.8167588171,9220.45134229317;9152.01858162694,-18388.6456167567,9217.86439431512;9149.43838285399,-18383.4708035372,9215.27559754113;9146.85636985737,-18378.2923297446,9212.68495728432;9144.27254789287,-18373.1102059508,9210.09247885092;9141.68692220967,-18367.9244427148,9207.49816754052;9139.09949805028,-18362.7350505820,9204.90202864602;9136.51028065067,-18357.5420400846,9202.30406745372;9133.91927524005,-18352.3454217414,9199.70428924315;9131.32648704101,-18347.1452060578,9197.10269928714;9128.73192126941,-18341.9414035258,9194.49930285178;9126.13558313462,-18336.7340246242,9191.89410519665;9123.53747783920,-18331.5230798183,9189.28711157444;9120.93761057922,-18326.3085795602,9186.67832723134;9118.33598654398,-18321.0905342886,9184.06775740673;9115.73261091607,-18315.8689544286,9181.45540733324;9113.12748887164,-18310.6438503924,9178.84128223702;9110.52062558007,-18305.4152325785,9176.22538733741;9107.91202620403,-18300.1831113722,9173.60772784699;9105.30169589967,-18294.9474971454,9170.98830897183;9102.68963981645,-18289.7084002568,9168.36713591122;9100.07586309715,-18284.4658310515,9165.74421385774;9097.46037087792,-18279.2197998616,9163.11954799734;9094.84316828828,-18273.9703170054,9160.49314350926;9092.22426045117,-18268.7173927884,9157.86500556614;9089.60365248274,-18263.4610375023,9155.23513933378;9086.98134949260,-18258.2012614257,9152.60354997141;9084.35735658371,-18252.9380748239,9149.97024263159;9081.73167885243,-18247.6714879488,9147.33522246022;9079.10432138834,-18242.4015110388,9144.69849459637;9076.47528927456,-18237.1281543193,9142.06006417264;9073.84458758746,-18231.8514280023,9139.41993631482;9071.21222139679,-18226.5713422861,9136.77811614205;9068.57819576573,-18221.2879073563,9134.13460876688;9065.94251575073,-18216.0011333847,9131.48941929506;9063.30518640166,-18210.7110305298,9128.84255282573;9060.66621276172,-18205.4176089370,9126.19401445131;9058.02559986758,-18200.1208787385,9123.54380925771;9055.38335274919,-18194.8208500528,9120.89194232401;9052.73947642993,-18189.5175329854,9118.23841872271;9050.09397592640,-18184.2109376281,9115.58324351950;9047.44685624880,-18178.9010740600,9112.92642177363;9044.79812240058,-18173.5879523464,9110.26795853753;9042.14777937852,-18168.2715825395,9107.60785885695;9039.49583217291,-18162.9519746782,9104.94612777111;9036.84228576730,-18157.6291387880,9102.28277031246;9034.18714513867,-18152.3030848811,9099.61779150680;9031.53041525742,-18146.9738229568,9096.95119637336;9028.87210108729,-18141.6413630006,9094.28298992462;9026.21220758534,-18136.3057149848,9091.61317716641;9023.55073970211,-18130.9668888687,9088.94176309794;9020.88770238149,-18125.6248945980,9086.26875271174;9018.22310056079,-18120.2797421055,9083.59415099376;9015.55693917071,-18114.9314413104,9080.91796292324;9012.88922313522,-18109.5800021187,9078.24019347271;9010.21995737187,-18104.2254344231,9075.56084760818;9007.54914679140,-18098.8677481031,9072.87993028889;9004.87679629819,-18093.5069530250,9070.19744646761;9002.20291078976,-18088.1430590418,9067.51340109022;8999.52749515720,-18082.7760759931,9064.82779909618;8996.85055428492,-18077.4060137053,9062.14064541817;8994.17209305079,-18072.0328819918,9059.45194498233;8991.49211632604,-18066.6566906524,9056.76170270810;8988.81062897528,-18061.2774494738,9054.06992350827;8986.12763585662,-18055.8951682296,9051.37661228909;8983.44314182148,-18050.5098566800,9048.68177395007;8980.75715171469,-18045.1215245717,9045.98541338410;8978.06967037459,-18039.7301816389,9043.28753547754;8975.38070263283,-18034.3358376018,9040.58814511002;8972.69025331451,-18028.9385021678,9037.88724715458;8969.99832723819,-18023.5381850311,9035.18484647768;8967.30492921573,-18018.1348958724,9032.48094793903;8964.61006405254,-18012.7286443594,9029.77555639186;8961.91373654736,-18007.3194401464,9027.06867668269;8959.21595149243,-18001.9072928749,9024.36031365149;8956.51671367333,-17996.4922121727,9021.65047213155;8953.81602786911,-17991.0742076547,9018.93915694958;8951.11389885226,-17985.6532889224,9016.22637292567;8948.41033138865,-17980.2294655643,9013.51212487329;8945.70533023766,-17974.8027471557,9010.79641759934;8942.99890015207,-17969.3731432587,9008.07925590411;8940.29104587804,-17963.9406634220,9005.36064458120;8937.58177215527,-17958.5053171813,9002.64058841774;8934.87108371676,-17953.0671140592,8999.91909219409;8932.15898528914,-17947.6260635650,8997.19616068424;8929.44548159229,-17942.1821751949,8994.47179865534;8926.73057733966,-17936.7354584319,8991.74601086812;8924.01427723810,-17931.2859227457,8989.01880207662;8921.29658598794,-17925.8335775933,8986.29017702836;8918.57750828295,-17920.3784324180,8983.56014046422;8915.85704881031,-17914.9204966503,8980.82869711851;8913.13521225071,-17909.4597797074,8978.09585171893;8910.41200327826,-17903.9962909934,8975.36160898663;8907.68742656058,-17898.5300398994,8972.62597363620;8904.96148675876,-17893.0610358032,8969.88895037564;8902.23418852722,-17887.5892880694,8967.15054390626;8899.50553651405,-17882.1148060499,8964.41075892301;8896.77553536062,-17876.6375990829,8961.66960011406;8894.04418970190,-17871.1576764940,8958.92707216117;8891.31150416628,-17865.6750475953,8956.18317973942;8888.57748337559,-17860.1897216860,8953.43792751734;8885.84213194523,-17854.7017080522,8950.69132015697;8883.10545448407,-17849.2110159670,8947.94336231379;8880.36745559431,-17843.7176546901,8945.19405863655;8877.62813987186,-17838.2216334684,8942.44341376769;8874.88751190594,-17832.7229615356,8939.69143234291;8872.14557627934,-17827.2216481123,8936.93811899143;8869.40233756832,-17821.7177024061,8934.18347833591;8866.65780034269,-17816.2111336116,8931.42751499251;8863.91196916563,-17810.7019509100,8928.67023357074;8861.16484859397,-17805.1901634700,8925.91163867370;8858.41644317796,-17799.6757804469,8923.15173489787;8855.66675746132,-17794.1588109827,8920.39052683315;8852.91579598135,-17788.6392642070,8917.62801906301;8850.16356326882,-17783.1171492358,8914.86421616430;8847.41006384805,-17777.5924751724,8912.09912270744;8844.65530223677,-17772.0652511068,8909.33274325616;8841.89928294641,-17766.5354861164,8906.56508236789;8839.14201048175,-17761.0031892651,8903.79614459335;8836.38348934112,-17755.4683696041,8901.02593447677;8833.62372401651,-17749.9310361715,8898.25445655599;8830.86271899324,-17744.3911979924,8895.48171536216;8828.10047875033,-17738.8488640790,8892.70771542009;8825.33700776017,-17733.3040434302,8889.93246124788;8822.57231048882,-17727.7567450322,8887.15595735729;8819.80639139585,-17722.2069778583,8884.37820825355;8817.03925493435,-17716.6547508686,8881.59921843536;8814.27090555092,-17711.1000730103,8878.81899239489;8811.50134768575,-17705.5429532176,8876.03753461785;8808.73058577258,-17699.9834004119,8873.25484958346;8805.95862423870,-17694.4214235014,8870.47094176448;8803.18546750494,-17688.8570313817,8867.68581562711;8800.41111998566,-17683.2902329351,8864.89947563110;8797.63558608881,-17677.7210370310,8862.11192622970;8794.85887021598,-17672.1494525263,8859.32317186979;8792.08097676213,-17666.5754882644,8856.53321699155;8789.30191011603,-17660.9991530762,8853.74206602894;8786.52167465983,-17655.4204557794,8850.94972340928;8783.74027476931,-17649.8394051790,8848.15619355346;8780.95771481390,-17644.2560100671,8845.36148087596;8778.17399915654,-17638.6702792227,8842.56558978474;8775.38913215368,-17633.0822214120,8839.76852468127;8772.60311815553,-17627.4918453885,8836.97028996067;8769.81596150576,-17621.8991598925,8834.17089001152;8767.02766654166,-17616.3041736518,8831.37032921596;8764.23823759415,-17610.7068953810,8828.56861194973;8761.44767898775,-17605.1073337822,8825.76574258213;8758.65599504045,-17599.5054975440,8822.96172547586;8755.86319006403,-17593.9013953430,8820.15656498743;8753.06926836378,-17588.2950358423,8817.35026546674;8750.27423423859,-17582.6864276925,8814.54283125729;8747.47809198104,-17577.0755795313,8811.73426669624;8744.68084587717,-17571.4624999834,8808.92457611413;8741.88250020686,-17565.8471976609,8806.11376383532;8739.08305924345,-17560.2296811632,8803.30183417760;8736.28252725390,-17554.6099590764,8800.48879145231;8733.48090849887,-17548.9880399742,8797.67463996448;8730.67820723269,-17543.3639324177,8794.85938401274;8727.87442770321,-17537.7376449547,8792.04302788919;8725.06957415196,-17532.1091861204,8789.22557587961;8722.26365081416,-17526.4785644374,8786.40703226337;8719.45666191864,-17520.8457884155,8783.58740131348;8716.64861168784,-17515.2108665516,8780.76668729644;8713.83950433796,-17509.5738073299,8777.94489447252;8711.02934407872,-17503.9346192218,8775.12202709546;8708.21813511353,-17498.2933106860,8772.29808941264;8705.40588163959,-17492.6498901687,8769.47308566516;8702.59258784758,-17487.0043661029,8766.64702008762;8699.77825792199,-17481.3567469094,8763.81989690833;8696.96289604083,-17475.7070409958,8760.99172034911;8694.14650637601,-17470.0552567574,8758.16249462563;8691.32909309295,-17464.4014025765,8755.33222394700;8688.51066035068,-17458.7454868228,8752.50091251595;8685.69121230216,-17453.0875178536,8749.66856452906;8682.87075309382,-17447.4275040129,8746.83518417634;8680.04928686588,-17441.7654536327,8744.00077564157;8677.22681775227,-17436.1013750319,8741.16534310217;8674.40334988054,-17430.4352765168,8738.32889072914;8671.57888737194,-17424.7671663810,8735.49142268717;8668.75343434158,-17419.0970529059,8732.65294313473;8665.92699489812,-17413.4249443598,8729.81345622380;8663.09957314393,-17407.7508489983,8726.97296610005;8660.27117317525,-17402.0747750649,8724.13147690297;8657.44179908185,-17396.3967307899,8721.28899276553;8654.61145494735,-17390.7167243913,8718.44551781450;8651.78014484901,-17385.0347640744,8715.60105617026;8648.94787285791,-17379.3508580321,8712.75561194697;8646.11464303882,-17373.6650144444,8709.90918925243;8643.28045945023,-17367.9772414790,8707.06179218811;8640.44532614438,-17362.2875472908,8704.21342484920;8637.60924716724,-17356.5959400223,8701.36409132458;8634.77222655855,-17350.9024278032,8698.51379569684;8631.93426835190,-17345.2070187512,8695.66254204239;8629.09537657437,-17339.5097209706,8692.81033443108;8625.80910437429,-17332.9131258093,8689.50710597633;8622.52217805395,-17326.3152036958,8686.20320533014;8619.23460140216,-17319.7159622555,8682.89863632216;8615.94637820170,-17313.1154091018,8679.59340277598;8612.65751222935,-17306.5135518361,8676.28750850913;8609.36800725599,-17299.9103980478,8672.98095733322;8606.07786704637,-17293.3059553140,8669.67375305367;8602.78709535932,-17286.7002312001,8666.36589946993;8599.49569594760,-17280.0932332591,8663.05740037538;8596.20367255815,-17273.4849690324,8659.74825955750;8592.91102893169,-17266.8754460488,8656.43848079751;8589.61776880320,-17260.2646718257,8653.12806787087;8586.32389590153,-17253.6526538682,8649.81702454685;8583.02941394959,-17247.0393996694,8646.50535458876;8579.73432666427,-17240.4249167103,8643.19306175382;8576.43863775670,-17233.8092124602,8639.88014979347;8573.14235093174,-17227.1922943761,8636.56662245284;8569.84546988857,-17220.5741699034,8633.25248347133;8566.54799832026,-17213.9548464752,8629.93773658219;8563.24993991395,-17207.3343315128,8626.62238551269;8559.95129835087,-17200.7126324256,8623.30643398416;8556.65207730624,-17194.0897566108,8619.98988571188;8553.35228044944,-17187.4657114540,8616.67274440524;8550.05191144385,-17180.8405043287,8613.35501376761;8546.75097394685,-17174.2141425964,8610.03669749627;8543.44947161005,-17167.5866336070,8606.71779928276;8540.14740807902,-17160.9579846981,8603.39832281247;8536.84478699344,-17154.3282031956,8600.07827176488;8533.54161198708,-17147.6972964136,8596.75764981355;8530.23788668775,-17141.0652716542,8593.43646062601;8526.93361471739,-17134.4321362076,8590.11470786387;8523.62879969207,-17127.7978973522,8586.79239518286;8520.32344522186,-17121.1625623544,8583.46952623264;8517.01755491103,-17114.5261384690,8580.14610465702;8513.71113235785,-17107.8886329388,8576.82213409381;8510.40418115481,-17101.2500529947,8573.49761817497;8507.09670488848,-17094.6104058560,8570.17256052650;8503.78870713944,-17087.9696987298,8566.84696476838;8500.48019148254,-17081.3279388119,8563.52083451480;8497.17116148665,-17074.6851332857,8560.19417337394;8493.86162071484,-17068.0412893233,8556.86698494815;8490.55157272428,-17061.3964140849,8553.53927283380;8487.24102106624,-17054.7505147186,8550.21104062137;8483.92996928617,-17048.1035983612,8546.88229189545;8480.61842092370,-17041.4556721373,8543.55303023474;8477.30637951250,-17034.8067431600,8540.22325921201;8473.99384858050,-17028.1568185307,8536.89298239418;8470.68083164970,-17021.5059053387,8533.56220334223;8467.36733223629,-17014.8540106620,8530.23092561130;8464.05335385064,-17008.2011415665,8526.89915275063;8460.73889999735,-17001.5473051068,8523.56688830369;8457.42397417502,-16994.8925083254,8520.23413580786;8454.10857987658,-16988.2367582532,8516.90089879486;8450.79272058902,-16981.5800619095,8513.56718079041;8447.47639979362,-16974.9224263019,8510.23298531447;8444.15962096582,-16968.2638584261,8506.89831588110;8440.84238757520,-16961.6043652666,8503.56317599851;8437.52470308556,-16954.9439537957,8500.22756916903;8434.20657095490,-16948.2826309743,8496.89149888921;8430.88799463550,-16941.6204037517,8493.55496864976;8427.56897757365,-16934.9572790655,8490.21798193544;8424.24952321007,-16928.2932638416,8486.88054222535;8420.92963497956,-16921.6283649944,8483.54265299264;8417.60931631124,-16914.9625894267,8480.20431770473;8414.28857062834,-16908.2959440296,8476.86553982312;8410.96740134835,-16901.6284356824,8473.52632280353;8407.64581188304,-16894.9600712532,8470.18667009591;8404.32380563845,-16888.2908575985,8466.84658514444;8401.00138601471,-16881.6208015628,8463.50607138733;8397.67855640634,-16874.9499099795,8460.16513225718;8394.35532020205,-16868.2781896702,8456.82377118071;8391.03168078476,-16861.6056474450,8453.48199157880;8387.70764153174,-16854.9322901024,8450.13979686666;8384.38320581446,-16848.2581244297,8446.79719045366;8381.05837699869,-16841.5831572022,8443.45417574341;8377.73315844436,-16834.9073951837,8440.11075613363;8374.40755350588,-16828.2308451272,8436.76693501650;8371.08156553172,-16821.5535137732,8433.42271577822;8367.75519786483,-16814.8754078517,8430.07810179943;8364.42845384225,-16808.1965340802,8426.73309645478;8361.10133679546,-16801.5168991656,8423.38770311335;8357.77385005022,-16794.8365098030,8420.04192513847;8354.44599692645,-16788.1553726758,8416.69576588757;8351.11778073856,-16781.4734944564,8413.34922871253;8347.78920479515,-16774.7908818054,8410.00231695936;8344.46027239921,-16768.1075413723,8406.65503396846;8341.13098684792,-16761.4234797948,8403.30738307434;8337.80135143295,-16754.7387036995,8399.95936760597;8334.47136944016,-16748.0532197015,8396.61099088648;8331.14104414982,-16741.3670344046,8393.26225623336;8327.81037883649,-16734.6801544009,8389.91316695833;8324.47937676905,-16727.9925862713,8386.56372636743;8321.14804121079,-16721.3043365856,8383.21393776101;8317.81637541930,-16714.6154119018,8379.86380443374;8314.48438264652,-16707.9258187669,8376.51332967456;8311.15206613879,-16701.2355637163,8373.16251676676;8307.81942913673,-16694.5446532742,8369.81136898792;8304.48647487540,-16687.8530939535,8366.45988960995;8301.15320658419,-16681.1608922556,8363.10808189909;8297.81962748690,-16674.4680546709,8359.75594911596;8294.48574080170,-16667.7745876784,8356.40349451544;8291.15154974106,-16661.0804977455,8353.05072134677;8287.81705751197,-16654.3857913288,8349.69763285357;8284.48226731566,-16647.6904748732,8346.34423227373;8281.14718234790,-16640.9945548126,8342.99052283958;8277.81180579878,-16634.2980375695,8339.63650777779;8274.47614085286,-16627.6009295555,8336.28219030940;8271.14019068897,-16620.9032371705,8332.92757364973;8267.80395848052,-16614.2049668034,8329.57266100857;8264.46744739528,-16607.5061248319,8326.21745559010;8261.13066059533,-16600.8067176223,8322.86196059274;8257.79360123739,-16594.1067515301,8319.50617920949;8254.45627247244,-16587.4062328993,8316.15011462759;8251.11867744591,-16580.7051680625,8312.79377002868;8247.78081929781,-16574.0035633418,8309.43714858894;8244.44270116243,-16567.3014250475,8306.08025347878;8241.10432616863,-16560.5987594792,8302.72308786315;8237.76569743962,-16553.8955729250,8299.36565490132;8234.42681809316,-16547.1918716620,8296.00795774703;8231.08769124142,-16540.4876619563,8292.64999954842;8227.74831999104,-16533.7829500626,8289.29178344803;8224.40870744320,-16527.0777422249,8285.93331258294;8221.06885669349,-16520.3720446758,8282.57459008457;8217.72877083195,-16513.6658636367,8279.21561907874;8214.38845294322,-16506.9592053184,8275.85640268583;8211.04790610637,-16500.2520759202,8272.49694402066;8207.70713339489,-16493.5444816303,8269.13724619233;8204.36613787690,-16486.8364286263,8265.77731230463;8201.02492261493,-16480.1279230742,8262.41714545565;8197.68349066614,-16473.4189711296,8259.05674873809;8194.34184508204,-16466.7095789365,8255.69612523896;8190.99998890879,-16459.9997526281,8252.33527803987;8187.65792518702,-16453.2894983266,8248.97421021688;8184.31565695182,-16446.5788221432,8245.61292484045;8180.97318723303,-16439.8677301783,8242.25142497574;8177.63051905480,-16433.1562285209,8238.88971368218;8174.28765543594,-16426.4443232495,8235.52779401384;8170.94459938976,-16419.7320204313,8232.16566901923;8167.60135392415,-16413.0193261227,8228.80334174141;8164.25792204156,-16406.3062463691,8225.44081521795;8160.91430673894,-16399.5927872050,8222.07809248086;8157.57051100795,-16392.8789546541,8218.71517655686;8154.22653783464,-16386.1647547290,8215.35207046697;8150.88239019976,-16379.4501934314,8211.98877722691;8147.53807107863,-16372.7352767523,8208.62529984691;8144.19358344107,-16366.0200106716,8205.26164133166;8140.84893025165,-16359.3044011587,8201.89780468054;8137.50411446932,-16352.5884541715,8198.53379288731;8134.15913904779,-16345.8721756575,8195.16960894041;8130.81400693538,-16339.1555715535,8191.80525582285;8127.68604365484,-16332.8754896548,8188.65982021751;8124.55780197145,-16326.5948375177,8185.51409275078;8121.42928491733,-16320.3136212473,8182.36807649020;8118.30049551910,-16314.0318469376,8179.22177449773;8115.17143679792,-16307.7495206717,8176.07518982984;8112.04211176951,-16301.4666485219,8172.92832553754;8108.91252344414,-16295.1832365494,8169.78118466630;8105.78267482656,-16288.8992908042,8166.63377025606;8102.65256891618,-16282.6148173257,8163.48608534138;8099.52220870683,-16276.3298221423,8160.33813295118;8096.39159718696,-16270.0443112711,8157.18991610898;8093.26073733967,-16263.7582907189,8154.04143783286;8090.12963214247,-16257.4717664809,8150.89270113534;8086.99828456763,-16251.1847445421,8147.74370902359;8083.86669758184,-16244.8972308761,8144.59446449920;8080.73487414643,-16238.6092314458,8141.44497055833;8077.60281721730,-16232.3207522030,8138.29523019170;8074.47052974511,-16226.0317990892,8135.14524638471;8071.33801467486,-16219.7423780345,8131.99502211707;8068.20527494628,-16213.4524949582,8128.84456036319;8065.07231349381,-16207.1621557692,8125.69386409216;8061.93913324629,-16200.8713663651,8122.54293626737;8058.80573712740,-16194.5801326330,8119.39177984707;8055.67212805530,-16188.2884604490,8116.24039778391;8052.53830894278,-16181.9963556784,8113.08879302514;8049.40428269742,-16175.7038241761,8109.93696851276;8046.27005222124,-16169.4108717857,8106.78492718317;8043.13562041100,-16163.1175043403,8103.63267196746;8040.00099015816,-16156.8237276623,8100.48020579138;8036.86616434878,-16150.5295475632,8097.32753157521;8033.73114586357,-16144.2349698440,8094.17465223390;8030.59593757795,-16137.9400002947,8091.02157067702;8027.46054236193,-16131.6446446948,8087.86828980870;8024.32496308031,-16125.3489088129,8084.71481252780;8021.18920259250,-16119.0527984072,8081.56114172780;8018.05326375258,-16112.7563192250,8078.40728029674;8014.91714940939,-16106.4594770029,8075.25323111742;8011.78086240641,-16100.1622774670,8072.09899706722;8008.64440558185,-16093.8647263327,8068.94458101823;8005.50778176861,-16087.5668293047,8065.78998583716;8002.37099379435,-16081.2685920772,8062.63521438547;7999.23404448134,-16074.9700203336,8059.48026951914;7996.09693664672,-16068.6711197468,8056.32515408901;7992.95967310228,-16062.3718959792,8053.16987094054;7989.82225665448,-16056.0723546824,8050.01442291379;7986.68469010459,-16049.7725014974,8046.85881284359;7983.54697624870,-16043.4723420551,8043.70304355956;7980.40911787747,-16037.1718819752,8040.54711788586;7977.27111777642,-16030.8711268673,8037.39103864144;7974.13297872591,-16024.5700823305,8034.23480864005;7970.99470350084,-16018.2687539528,8031.07843068995;7967.85629487112,-16011.9671473124,8027.92190759437;7964.71775560125,-16005.6652679765,8024.76524215108;7961.57908845059,-15999.3631215021,8021.60843715267;7958.44029617337,-15993.0607134358,8018.45149538656;7955.30138151840,-15986.7580493131,8015.29441963470;7952.16234722946,-15980.4551346598,8012.13721267396;7949.02319604507,-15974.1519749907,8008.97987727595;7945.88393069861,-15967.8485758107,8005.82241620705;7942.74455391810,-15961.5449426136,8002.66483222826;7939.60506842665,-15955.2410808834,7999.50712809562;7936.46547694190,-15948.9369960932,7996.34930655967;7933.32578217653,-15942.6326937061,7993.19137036594;7930.18598683800,-15936.3281791746,7990.03332225468;7927.04609362850,-15930.0234579408,7986.87516496087;7923.90610524520,-15923.7185354364,7983.71690121439;7920.76602438008,-15917.4134170830,7980.55853373990;7917.62585371994,-15911.1081082917,7977.40006525685;7914.48559594643,-15904.8026144630,7974.24149847947;7911.34525373606,-15898.4969409874,7971.08283611685;7908.20482976037,-15892.1910932453,7967.92408087301;7905.06432668548,-15885.8850766061,7964.76523544657;7901.92374717270,-15879.5788964297,7961.60630253125;7898.78309387791,-15873.2725580649,7958.44728481532;7895.64236945218,-15866.9660668509,7955.28818498221;7892.50157654127,-15860.6594281163,7952.12900570997;7889.36071778591,-15854.3526471796,7948.96974967159;7886.21979582177,-15848.0457293490,7945.81041953495;7883.07881327937,-15841.7386799224,7942.65101796278;7879.93777278416,-15835.4315041876,7939.49154761263;7876.79667695652,-15829.1242074220,7936.33201113699;7873.65552841179,-15822.8167948931,7933.17241118325;7870.51432976016,-15816.5092718579,7930.01275039360;7867.37308360682,-15810.2016435635,7926.85303140521;7864.23179255193,-15803.8939152466,7923.69325685015;7861.09045919052,-15797.5860921340,7920.53342935535;7857.94908611258,-15791.2781794419,7917.37355154264;7854.80767590316,-15784.9701823769,7914.21362602886;7851.66623114214,-15778.6621061352,7911.05365542565;7848.52475440446,-15772.3539559029,7907.89364233968;7845.38324826001,-15766.0457368560,7904.73358937249;7842.24171527361,-15759.7374541604,7901.57349912056;7839.10015800514,-15753.4291129720,7898.41337417534;7835.95857900947,-15747.1207184366,7895.25321712325;7832.81698083641,-15740.8122756899,7892.09303054562;7829.67536603076,-15734.5037898575,7888.93281701871;7826.53373713242,-15728.1952660552,7885.77257911385;7823.39209667615,-15721.8867093882,7882.61231939717;7820.25044719197,-15715.5781249526,7879.45204043003;7817.10879120464,-15709.2695178337,7876.29174476852;7813.96713123410,-15702.9608931069,7873.13143496379;7810.82546979539,-15696.6522558382,7869.97111356213;7807.68380939840,-15690.3436110829,7866.81078310459;7804.54215254821,-15684.0349638868,7863.65044612740;7801.40050174490,-15677.7263192855,7860.49010516170;7798.25885948367,-15671.4176823049,7857.32976273376;7795.11722825461,-15665.1090579607,7854.16942136468;7791.97561054304,-15658.8004512588,7851.00908357075;7788.83400882929,-15652.4918671953,7847.84875186320;7785.69242558874,-15646.1833107561,7844.68842874832;7782.55086329194,-15639.8747869177,7841.52811672749;7779.40932440444,-15633.5663006462,7838.36781829706;7776.26781138690,-15627.2578568981,7835.20753594845;7773.12632669509,-15620.9494606200,7832.04727216815;7769.98487277992,-15614.6411167488,7828.88702943775;7766.84345208729,-15608.3328302112,7825.72681023378;7763.70206705837,-15602.0246059245,7822.56661702799;7760.56072012935,-15595.7164487960,7819.40645228716;7757.41941373153,-15589.4083637229,7816.24631847306;7754.27815029142,-15583.1003555932,7813.08621804268;7751.13693223059,-15576.7924292846,7809.92615344804;7747.99576196581,-15570.4845896655,7806.76612713627;7744.85464190893,-15564.1768415940,7803.60614154958;7741.71357446701,-15557.8691899189,7800.44619912533;7738.57256204226,-15551.5616394791,7797.28630229598;7735.43160703202,-15545.2541951037,7794.12645348912;7732.29071182880,-15538.9468616122,7790.96665512742;7729.14987882030,-15532.6396438143,7787.80690962874;7726.00911038949,-15526.3325465103,7784.64721940611;7722.86840891430,-15520.0255744902,7781.48758686755;7719.72777676802,-15513.7187325350,7778.32801441637;7716.58721631912,-15507.4120254156,7775.16850445098;7713.44672993126,-15501.1054578934,7772.00905936501;7710.30631996324,-15494.7990347203,7768.84968154713;7707.16598876913,-15488.4927606382,7765.69037338127;7704.02573869821,-15482.1866403796,7762.53113724651;7700.88557209503,-15475.8806786677,7759.37197551719;7697.74549129926,-15469.5748802156,7756.21289056270;7694.60549864589,-15463.2692497271,7753.05388474771;7691.46559646507,-15456.9637918961,7749.89496043202;7688.32578708228,-15450.6585114075,7746.73611997072;7685.18607281825,-15444.3534129363,7743.57736571410;7682.04645598884,-15438.0485011477,7740.41870000754;7678.90693890530,-15431.7437806979,7737.26012519179;7675.76752387407,-15425.4392562333,7734.10164360271;7672.62821319693,-15419.1349323908,7730.94325757150;7669.48900917085,-15412.8308137979,7727.78496942447;7666.34991408819,-15406.5269050724,7724.62678148332;7663.21093023648,-15400.2232108230,7721.46869606485;7660.07205989861,-15393.9197356484,7718.31071548119;7656.93330535278,-15387.6164841384,7715.15284203973;7653.79466887246,-15381.3134608731,7711.99507804310;7650.65615272641,-15375.0106704230,7708.83742578917;7647.51775917875,-15368.7081173494,7705.67988757116;7644.37949048889,-15362.4058062042,7702.52246567747;7641.24134891160,-15356.1037415300,7699.36516239191;7638.10333669699,-15349.8019278596,7696.20797999353;7634.96545609038,-15343.5003697168,7693.05092075654;7631.82770933258,-15337.1990716158,7689.89398695063;7628.69009865970,-15330.8980380617,7686.73718084076;7625.55262630317,-15324.5972735500,7683.58050468714;7622.41529448983,-15318.2967825671,7680.42396074535;7619.27810544185,-15311.9965695899,7677.26755126627;7616.14106137676,-15305.6966390860,7674.11127849613;7613.00416450747,-15299.3969955137,7670.95514467644;7609.86741704232,-15293.0976433222,7667.79915204412;7606.73082118494,-15286.7985869511,7664.64330283136;7603.59437913443,-15280.4998308311,7661.48759926578;7600.45809308534,-15274.2013793834,7658.33204357038;7597.32196522741,-15267.9032370198,7655.17663796334;7594.18599774599,-15261.6054081433,7652.02138465838;7591.05019282177,-15255.3078971473,7648.86628586456;7587.91455263086,-15249.0107084163,7645.71134378625;7584.77907934478,-15242.7138463252,7642.55656062328;7581.64377513052,-15236.4173152402,7639.40193857086;7578.50864215049,-15230.1211195179,7636.24747981955;7575.37368256244,-15223.8252635058,7633.09318655529;7572.23889851977,-15217.5297515425,7629.93906095956;7569.10429217115,-15211.2345879572,7626.78510520909;7565.96986566076,-15204.9397770700,7623.63132147609;7562.83562112828,-15198.6453231921,7620.47771192823;7559.70156070885,-15192.3512306253,7617.32427872859;7556.56768653302,-15186.0575036623,7614.17102403560;7553.43400072691,-15179.7641465870,7611.01795000329;7550.30050541203,-15173.4711636739,7607.86505878096;7547.16720270544,-15167.1785591886,7604.71235251347;7544.03409471968,-15160.8863373876,7601.55983334108;7540.90118356280,-15154.5945025184,7598.40750339956;7537.76847133834,-15148.3030588193,7595.25536482012;7534.63596014536,-15142.0120105199,7592.10341972944;7531.50365207844,-15135.7213618403,7588.95167024966;7528.37154922763,-15129.4311169920,7585.80011849841;7525.23965367861,-15123.1412801775,7582.64876658885;7522.10796751251,-15116.8518555900,7579.49761662958;7518.97649280608,-15110.5628474141,7576.34667072478;7515.84523163147,-15104.2742598251,7573.19593097398;7512.71418605651,-15097.9860969895,7570.04539947234;7509.58335814453,-15091.6983630650,7566.89507831051;7506.45274995445,-15085.4110622002,7563.74496957468;7503.32236354075,-15079.1241985348,7560.59507534655;7500.19220095347,-15072.8377761998,7557.44539770334;7497.06226423820,-15066.5517993168,7554.29593871779;7493.93255543619,-15060.2662719992,7551.14670045826;7490.80307658416,-15053.9811983509,7547.99768498853;7487.67382971458,-15047.6965824674,7544.84889436809;7484.54481685536,-15041.4124284351,7541.70033065186;7481.41604003010,-15035.1287403315,7538.55199589037;7478.28750125803,-15028.8455222257,7535.40389212976;7475.15920255395,-15022.5627781774,7532.25602141172;7472.03114592826,-15016.2805122379,7529.10838577344;7468.90333338707,-15009.9987284496,7525.96098724785;7465.77576693202,-15003.7174308459,7522.81382786334;7462.64844856046,-14997.4366234519,7519.66690964394;7459.52138026537,-14991.1563102834,7516.52023460934;7456.39456403533,-14984.8764953479,7513.37380477475;7453.26800185468,-14978.5971826439,7510.22762215107;7450.14169570328,-14972.3183761612,7507.08168874474;7447.01564755679,-14966.0400798810,7503.93600655794;7443.88985938648,-14959.7622977758,7500.79057758838;7440.76433315918,-14953.4850338089,7497.64540382937;7437.63907083766,-14947.2082919358,7494.50048727005;7434.51407438012,-14940.9320761026,7491.35582989498;7431.38934574065,-14934.6563902472,7488.21143368458;7428.26488686888,-14928.3812382983,7485.06730061473;7425.14069971022,-14922.1066241766,7481.92343265712;7422.01678620585,-14915.8325517938,7478.77983177911;7418.89314829250,-14909.5590250529,7475.63649994359;7415.76978790282,-14903.2860478488,7472.49343910934;7412.64670696495,-14897.0136240669,7469.35065123056;7409.52390740301,-14890.7417575851,7466.20813825746;7406.40139113669,-14884.4704522719,7463.06590213571;7403.27916008143,-14878.1997119874,7459.92394480670;7400.15721614853,-14871.9295405836,7456.78226820769;7397.03556124493,-14865.6599419034,7453.64087427148;7393.91419727331,-14859.3909197814,7450.49976492663;7390.79312613226,-14853.1224780437,7447.35894209751;7387.67234971599,-14846.8546205079,7444.21840770413;7384.55186991457,-14840.5873509830,7441.07816366227;7381.43168861385,-14834.3206732697,7437.93821188351;7378.31180769534,-14828.0545911599,7434.79855427497;7375.19222903649,-14821.7891084372,7431.65919273974;7372.07295451050,-14815.5242288771,7428.52012917661;7368.95398598637,-14809.2599562460,7425.38136548010;7365.83532532889,-14802.9962943025,7422.24290354052;7362.71697439869,-14796.7332467963,7419.10474524395;7359.59893505213,-14790.4708174687,7415.96689247218;7356.48120914158,-14784.2090100531,7412.82934710295;7353.36379851502,-14777.9478282740,7409.69211100961;7350.24670501643,-14771.6872758478,7406.55518606144;7347.12993048555,-14765.4273564823,7403.41857412344;7343.23297832874,-14757.5991943215,7399.49546003545;7339.33678211980,-14749.7725436683,7395.57309954745;7335.44134336366,-14741.9474075573,7391.65149418684;7331.54666356142,-14734.1237890158,7387.73064547721;7327.65274421031,-14726.3016910632,7383.81055493823;7323.75958680365,-14718.4811167108,7379.89122408561;7319.86719283110,-14710.6620689630,7375.97265443138;7315.97556377846,-14702.8445508159,7372.05484748365;7312.08470112762,-14695.0285652581,7368.13780474662;7308.19460635672,-14687.2141152706,7364.22152772068;7304.30528094016,-14679.4012038269,7360.30601790245;7300.41672634849,-14671.5898338925,7356.39127678466;7296.52894404843,-14663.7800084256,7352.47730585618;7292.64193550294,-14655.9717303764,7348.56410660208;7288.75570217124,-14648.1650026881,7344.65168050367;7284.87024550871,-14640.3598282956,7340.74002903835;7280.98556696703,-14632.5562101268,7336.82915367983;7277.10166799403,-14624.7541511016,7332.91905589790;7273.21855003387,-14616.9536541327,7329.00973715865;7269.33621452692,-14609.1547221251,7325.10119892434;7265.45466290970,-14601.3573579760,7321.19344265338;7261.57389661513,-14593.5615645754,7317.28646980049;7257.69391707234,-14585.7673448057,7313.38028181662;7253.81472570667,-14577.9747015416,7309.47488014884;7249.93632393978,-14570.1836376506,7305.57026624055;7246.05871318967,-14562.3941559926,7301.66644153143;7242.18189487046,-14554.6062594198,7297.76340745725;7238.30587039268,-14546.8199507772,7293.86116545017;7234.43064116314,-14539.0352329022,7289.95971693854;7230.55620858484,-14531.2521086247,7286.05906334696;7226.68257405718,-14523.4705807673,7282.15920609630;7222.80973897594,-14515.6906521453,7278.26014660383;7218.93770473296,-14507.9123255660,7274.36188628281;7215.06647271665,-14500.1356038299,7270.46442654309;7211.19604431164,-14492.3604897300,7266.56776879064;7207.32642089881,-14484.5869860515,7262.67191442769;7203.45760385554,-14476.8150955727,7258.77686485290;7199.58959455533,-14469.0448210642,7254.88262146105;7195.72239436826,-14461.2761652894,7250.98918564344;7191.85600466054,-14453.5091310043,7247.09655878747;7187.99042679492,-14445.7437209577,7243.20474227706;7184.12566213035,-14437.9799378908,7239.31373749228;7180.26171202219,-14430.2177845377,7235.42354580957;7176.39857782227,-14422.4572636252,7231.53416860183;7172.53626087859,-14414.6983778724,7227.64560723806;7168.67476253572,-14406.9411299918,7223.75786308382;7164.81408413449,-14399.1855226881,7219.87093750089;7160.95422701217,-14391.4315586588,7215.98483184746;7157.09519250237,-14383.6792405943,7212.09954747800;7153.23698193519,-14375.9285711777,7208.21508574348;7149.37959663709,-14368.1795530848,7204.33144799115;7145.52303793084,-14360.4321889842,7200.44863556456;7141.66730713578,-14352.6864815374,7196.56664980379;7137.81240556754,-14344.9424333983,7192.68549204518;7133.95833453826,-14337.2000472142,7188.80516362154;7130.10509535642,-14329.4593256247,7184.92566586198;7126.25268932704,-14321.7202712625,7181.04700009213;7122.40111775153,-14313.9828867531,7177.16916763395;7118.55038192769,-14306.2471747147,7173.29216980579;7114.70048314980,-14298.5131377584,7169.41600792241;7110.85142270865,-14290.7807784884,7165.54068329509;7107.00320189139,-14283.0500995014,7161.66619723139;7103.15582198169,-14275.3211033873,7157.79255103538;7099.30928425973,-14267.5937927287,7153.91974600759;7095.46359000201,-14259.8681701011,7150.04778344485;7091.61874048172,-14252.1442380732,7146.17666464065;7087.77473696834,-14244.4219992061,7142.30639088471;7083.93158072799,-14236.7014560545,7138.43696346340;7080.08927302318,-14228.9826111654,7134.56838365938;7076.24781511288,-14221.2654670791,7130.70065275182;7072.40720825274,-14213.5500263288,7126.83377201644;7068.56745369476,-14205.8362914407,7122.96774272536;7064.72855268748,-14198.1242649340,7119.10256614715;7060.89050647604,-14190.4139493208,7115.23824354699;7057.05331630200,-14182.7053471063,7111.37477618641;7053.21698340352,-14174.9984607887,7107.51216532351;7049.38150901522,-14167.2932928591,7103.65041221285;7045.54689436834,-14159.5898458019,7099.78951810551;7041.71314069066,-14151.8881220943,7095.92948424916;7037.88024920638,-14144.1881242065,7092.07031188778;7034.04822113641,-14136.4898546021,7088.21200226208;7030.21705769815,-14128.7933157375,7084.35455660919;7026.38676010554,-14121.0985100622,7080.49797616277;7022.55732956914,-14113.4054400190,7076.64226215305;7018.72876729610,-14105.7141080437,7072.78741580682;7014.90107449004,-14098.0245165650,7068.93343834733;7011.07425235122,-14090.3366680050,7065.08033099439;7007.24830207659,-14082.6505647789,7061.22809496450;7003.42322485950,-14074.9662092949,7057.37673147053;6999.59902189007,-14067.2836039545,7053.52624172206;6995.77569435488,-14059.6027511522,7049.67662692510;6991.95324343727,-14051.9236532760,7045.82788828243;6988.13167031710,-14044.2463127068,7041.98002699325;6984.31097617083,-14036.5707318187,7038.13304425338;6980.49116217161,-14028.8969129791,7034.28694125526;6976.67222948911,-14021.2248585485,7030.44171918784;6972.85417928979,-14013.5545708810,7026.59737923682;6969.03701273662,-14005.8860523234,7022.75392258439;6965.22073098928,-13998.2193052161,7018.91135040936;6961.40533520409,-13990.5543318927,7015.06966388723;6957.59082653398,-13982.8911346799,7011.22886419000;6953.77720612857,-13975.2297158980,7007.38895248640;6949.96447513414,-13967.5700778602,7003.54992994172;6946.15263469364,-13959.9122228732,6999.71179771791;6942.34168594668,-13952.2561532370,6995.87455697357;6938.53163002955,-13944.6018712450,6992.03820886392;6934.72246807529,-13936.9493791838,6988.20275454090;6930.91420121353,-13929.2986793334,6984.36819515302;6927.10683057065,-13921.6497739671,6980.53453184550;6923.30035726965,-13914.0026653514,6976.70176576012;6919.49478243034,-13906.3573557465,6972.86989803550;6915.69010716922,-13898.7138474059,6969.03892980685;6911.88633259940,-13891.0721425761,6965.20886220601;6908.08345983079,-13883.4322434975,6961.37969636153;6904.28148997009,-13875.7941524038,6957.55143339878;6900.48042412056,-13868.1578715218,6953.72407443960;6896.68026338234,-13860.5234030721,6949.89762060272;6892.88100885222,-13852.8907492685,6946.07207300347;6889.08266162381,-13845.2599123184,6942.24743275397;6885.28522278734,-13837.6308944224,6938.42370096292;6881.48869342992,-13830.0036977749,6934.60087873586;6877.69307463535,-13822.3783245635,6930.77896717503;6873.89836748420,-13814.7547769695,6926.95796737934;6870.10457305387,-13807.1330571676,6923.13788044455;6866.31169241840,-13799.5131673259,6919.31870746302;6862.51972664874,-13791.8951096062,6915.50044952397;6858.72867681259,-13784.2788861638,6911.68310771333;6854.93854397432,-13776.6644991473,6907.86668311371;6851.14932919527,-13769.0519506992,6904.05117680460;6847.36103353346,-13761.4412429552,6900.23658986220;6843.57365804376,-13753.8323780449,6896.42292335947;6839.78720377778,-13746.2253580912,6892.61017836612;6836.00167178404,-13738.6201852108,6888.79835594870;6832.21706310779,-13731.0168615137,6884.98745717048;6828.43337879116,-13723.4153891039,6881.17748309159;6824.65061987305,-13715.8157700787,6877.36843476887;6820.86878738929,-13708.2180065291,6873.56031325608;6817.08788237241,-13700.6221005398,6869.75311960362;6813.30790585186,-13693.0280541891,6865.94685485881;6809.52885885392,-13685.4358695489,6862.14152006574;6805.75074240178,-13677.8455486850,6858.33711626540;6801.97355751533,-13670.2570936564,6854.53364449545;6798.19730521151,-13662.6705065163,6850.73110579053;6794.42198650401,-13655.0857893113,6846.92950118204;6790.64760240338,-13647.5029440817,6843.12883169818;6786.87415391708,-13639.9219728616,6839.32909836406;6783.10164204947,-13632.3428776788,6835.53030220160;6779.33006780179,-13624.7656605549,6831.73244422965;6775.55943217206,-13617.1903235050,6827.93552546373;6771.78973615541,-13609.6168685383,6824.13954691649;6768.02098074364,-13602.0452976574,6820.34450959719;6764.25316692563,-13594.4756128590,6816.55041451214;6760.48629568704,-13586.9078161333,6812.75726266441;6756.72036801052,-13579.3419094644,6808.96505505403;6752.95538487557,-13571.7778948302,6805.17379267784;6749.19134725876,-13564.2157742027,6801.38347652972;6745.42825613339,-13556.6555495470,6797.59410760024;6741.66611246984,-13549.0972228228,6793.80568687703;6737.90491723533,-13541.5407959831,6790.01821534453;6734.14467139414,-13533.9862709751,6786.23169398418;6730.38537590739,-13526.4336497396,6782.44612377428;6726.62703173314,-13518.8829342113,6778.66150568999;6722.86963982656,-13511.3341263191,6774.87784070357;6719.11320113956,-13503.7872279852,6771.09512978399;6715.35771662119,-13496.2422411263,6767.31337389731;6711.60318721744,-13488.6991676526,6763.53257400654;6707.84961387123,-13481.1580094684,6759.75273107153;6704.09699752241,-13473.6187684718,6755.97384604909;6700.34533910799,-13466.0814465551,6752.19591989310;6696.59463956181,-13458.5460456040,6748.41895355427;6692.84489981476,-13451.0125674988,6744.64294798034;6689.09612079476,-13443.4810141134,6740.86790411603;6685.34830342665,-13435.9513873156,6737.09382290294;6681.60144863241,-13428.4236889676,6733.32070527980;6677.85555733089,-13420.8979209249,6729.54855218217;6674.11063043809,-13413.3740850378,6725.77736454273;6670.36666886693,-13405.8521831501,6722.00714329104;6666.62367352739,-13398.3322170996,6718.23788935370;6662.88164532656,-13390.8141887184,6714.46960365438;6659.14058516843,-13383.2980998325,6710.70228711363;6655.40049395415,-13375.7839522621,6706.93594064912;6651.66137258180,-13368.2717478209,6703.17056517542;6647.92322194668,-13360.7614883175,6699.40616160429;6644.18604294104,-13353.2531755541,6695.64273084441;6640.44983645411,-13345.7468113269,6691.88027380141;6636.71460337240,-13338.2423974264,6688.11879137816;6632.98034457930,-13330.7399356373,6684.35828447439;6629.24706095538,-13323.2394277381,6680.59875398698;6625.51475337821,-13315.7408755016,6676.84020080978;6621.78342272252,-13308.2442806948,6673.08262583375;6618.05306986015,-13300.7496450788,6669.32602994694;6614.32369565989,-13293.2569704086,6665.57041403433;6610.59530098783,-13285.7662584340,6661.81577897817;6606.86788670700,-13278.2775108982,6658.06212565759;6603.14145367765,-13270.7907295392,6654.30945494894;6599.41600275705,-13263.3059160888,6650.55776772556;6595.69153479963,-13255.8230722731,6646.80706485789;6591.96805065702,-13248.3421998126,6643.05734721357;6588.24555117782,-13240.8633004217,6639.30861565716;6584.52403720786,-13233.3863758093,6635.56087105043;6580.80350959020,-13225.9114276785,6631.81411425235;6577.08396916479,-13218.4384577264,6628.06834611875;6573.36541676896,-13210.9674676447,6624.32356750277;6569.64785323710,-13203.4984591192,6620.57977925467;6565.93127940070,-13196.0314338298,6616.83698222168;6562.21569608858,-13188.5663934512,6613.09517724840;6558.50110412653,-13181.1033396518,6609.35436517632;6554.78750433763,-13173.6422740947,6605.61454684424;6551.07489754212,-13166.1831984371,6601.87572308804;6547.36328455735,-13158.7261143307,6598.13789474072;6543.65266619797,-13151.2710234214,6594.40106263252;6539.94304327568,-13143.8179273494,6590.66522759073;6536.23441659954,-13136.3668277496,6586.93039043993;6532.52678697561,-13128.9177262506,6583.19655200171;6528.82015520735,-13121.4706244761,6579.46371309500;6525.11452209530,-13114.0255240437,6575.73187453579;6521.40988843721,-13106.5824265655,6572.00103713727;6517.70625502816,-13099.1413336482,6568.27120170989;6514.00362266032,-13091.7022468926,6564.54236906121;6510.30199212315,-13084.2651678940,6560.81453999599;6506.60136420336,-13076.8300982424,6557.08771531626;6502.90173968484,-13069.3970395218,6553.36189582118;6499.20311934878,-13061.9659933110,6549.63708230718;6495.50550397352,-13054.5369611830,6545.91327556782;6491.80889433475,-13047.1099447055,6542.19047639397;6488.11329120534,-13039.6849454404,6538.46868557363;6484.41869535550,-13032.2619649443,6534.74790389218;6480.72510755267,-13024.8410047684,6531.02813213210;6477.03252856146,-13017.4220664579,6527.30937107312;6473.34095914391,-13010.0051515531,6523.59162149226;6469.65040005920,-13002.5902615884,6519.87488416374;6465.96085206390,-12995.1773980929,6516.15915985910;6462.27231591176,-12987.7665625902,6512.44444934702;6458.58479235393,-12980.3577565986,6508.73075339359;6454.89828213879,-12972.9509816306,6505.01807276206;6451.21278601198,-12965.5462391936,6501.30640821293;6447.52830471657,-12958.1435307894,6497.59576050410;6443.84483899282,-12950.7428579145,6493.88613039062;6440.16238957835,-12943.3442220599,6490.17751862489;6436.48095720811,-12935.9476247112,6486.46992595659;6432.80054261436,-12928.5530673487,6482.76335313271;6429.12114652662,-12921.1605514472,6479.05780089743;6425.44276967185,-12913.7700784761,6475.35326999237;6421.76541277432,-12906.3816498997,6471.64976115642;6418.08907655563,-12898.9952671767,6467.94727512577;6414.41376173465,-12891.6109317605,6464.24581263387;6410.73946902769,-12884.2286450991,6460.54537441155;6407.06619914836,-12876.8484086353,6456.84596118693;6403.39395280776,-12869.4702238068,6453.14757368560;6399.72273071412,-12862.0940920454,6449.45021263021;6395.28250991638,-12853.1721971952,6444.97762766358;6390.84372003497,-12844.2531729245,6440.50647916988;6386.40636148342,-12835.3370200728,6436.03676757463;6381.97043467286,-12826.4237394746,6431.56849330094;6377.53594001223,-12817.5133319602,6427.10165676970;6373.10287790789,-12808.6057983546,6422.63625839921;6368.67124876398,-12799.7011394784,6418.17229860550;6364.24105298237,-12790.7993561474,6413.70977780230;6359.81229096238,-12781.9004491725,6409.24869640078;6355.38496310113,-12773.0044193602,6404.78905480988;6350.95906979342,-12764.1112675122,6400.33085343619;6346.53461143158,-12755.2209944252,6395.87409268380;6342.11158840580,-12746.3336008917,6391.41877295465;6337.69000110384,-12737.4490876992,6386.96489464820;6333.26984991111,-12728.5674556307,6382.51245816154;6328.85113521084,-12719.6887054645,6378.06146388958;6324.43385738374,-12710.8128379740,6373.61191222465;6320.01801680844,-12701.9398539284,6369.16380355698;6315.60361386119,-12693.0697540920,6364.71713827439;6311.19064891580,-12684.2025392245,6360.27191676227;6306.77912234401,-12675.3382100810,6355.82813940387;6302.36903451515,-12666.4767674120,6351.38580658002;6297.96038579628,-12657.6182119634,6346.94491866926;6293.55317655217,-12648.7625444766,6342.50547604780;6289.14740714533,-12639.9097656881,6338.06747908959;6284.74307793602,-12631.0598763303,6333.63092816626;6280.34018928220,-12622.2128771307,6329.19582364715;6275.93874153955,-12613.3687688122,6324.76216589930;6271.53873506158,-12604.5275520935,6320.32995528750;6267.14017019937,-12595.6892276884,6315.89919217416;6262.74304730201,-12586.8537963064,6311.46987691961;6258.34736671607,-12578.0212586522,6307.04200988167;6253.95312878604,-12569.1916154263,6302.61559141604;6249.56033385412,-12560.3648673246,6298.19062187611;6245.16898226025,-12551.5410150382,6293.76710161296;6240.77907434226,-12542.7200592543,6289.34503097559;6236.39061043562,-12533.9020006552,6284.92441031057;6232.00359087362,-12525.0868399186,6280.50523996226;6227.61801598737,-12516.2745777182,6276.08752027283;6223.23388610564,-12507.4652147227,6271.67125158210;6218.85120155522,-12498.6587515970,6267.25643422784;6214.46996266044,-12489.8551890009,6262.84306854538;6210.09016974356,-12481.0545275900,6258.43115486794;6205.71182312471,-12472.2567680159,6254.02069352656;6201.33492312163,-12463.4619109250,6249.61168484990;6196.95947005004,-12454.6699569599,6245.20412916454;6192.58546422343,-12445.8809067586,6240.79802679485;6188.21290595305,-12437.0947609547,6236.39337806288;6183.84179554807,-12428.3115201775,6231.99018328862;6179.47213331539,-12419.5311850517,6227.58844278973;6175.10391955981,-12410.7537561979,6223.18815688179;6170.73715458387,-12401.9792342320,6218.78932587803;6166.37183868811,-12393.2076197661,6214.39195008972;6162.00797217080,-12384.4389134074,6209.99602982579;6157.64555532803,-12375.6731157591,6205.60156539297;6153.28458845380,-12366.9102274198,6201.20855709590;6148.92507183998,-12358.1502489841,6196.81700523705;6144.56700577627,-12349.3931810421,6192.42691011668;6140.21039055022,-12340.6390241796,6188.03827203290;6135.85522644725,-12331.8877789781,6183.65109128165;6131.50151375068,-12323.1394460149,6179.26536815674;6127.14925274165,-12314.3940258629,6174.88110294980;6122.79844369926,-12305.6515190908,6170.49829595037;6118.44908690044,-12296.9119262632,6166.11694744580;6114.10118261999,-12288.1752479400,6161.73705772128;6109.75473113066,-12279.4414846774,6157.35862705996;6105.40973270303,-12270.7106370269,6152.98165574274;6101.06618760561,-12261.9827055360,6148.60614404847;6096.72409610481,-12253.2576907479,6144.23209225384;6092.38345846495,-12244.5355932017,6139.85950063347;6088.04427494834,-12235.8164134323,6135.48836945989;6083.70654581501,-12227.1001519701,6131.11869900337;6079.37027132307,-12218.3868093416,6126.75048953223;6075.03545172855,-12209.6763860691,6122.38374131265;6070.70208728525,-12200.9688826706,6118.01845460859;6066.37017824513,-12192.2642996601,6113.65462968213;6062.03972485793,-12183.5626375472,6109.29226679311;6057.71072737138,-12174.8638968376,6104.93136619935;6053.38318603107,-12166.1680780327,6100.57192815647;6049.05710108071,-12157.4751816299,6096.21395291823;6044.73247276177,-12148.7852081222,6091.85744073608;6040.40930131381,-12140.0981579987,6087.50239185956;6036.08758697432,-12131.4140317446,6083.14880653612;6031.76732997864,-12122.7328298404,6078.79668501103;6027.44853056026,-12114.0545527632,6074.44602752768;6023.13118895056,-12105.3792009854,6070.09683432732;6018.81530537879,-12096.7067749757,6065.74910564907;6014.50088007232,-12088.0372751985,6061.40284173013;6010.18791325646,-12079.3707021144,6057.05804280559;6005.87640515453,-12070.7070561798,6052.71470910859;6001.56635598774,-12062.0463378469,6048.37284087007;5997.25776597540,-12053.3885475641,6044.03243831909;5992.95063533474,-12044.7336857756,6039.69350168258;5988.64496428111,-12036.0817529219,6035.35603118558;5984.34075302773,-12027.4327494389,6031.02002705096;5980.03800178589,-12018.7866757589,6026.68548949966;5975.73671076486,-12010.1435323102,6022.35241875057;5971.43688017205,-12001.5033195171,6018.02081502065;5967.13851021270,-11992.8660377997,6013.69067852476;5962.84160109020,-11984.2316875743,6009.36200947578;5958.54615300593,-11975.6002692531,6005.03480808465;5954.25216615936,-11966.9717832446,6000.70907456030;5949.95964074786,-11958.3462299531,5996.38480910958;5945.66857696702,-11949.7236097790,5992.06201193753;5941.37897501036,-11941.1039231188,5987.74068324708;5937.09083506939,-11932.4871703650,5983.42082323915;5932.80415733387,-11923.8733519064,5979.10243211286;5928.51894199139,-11915.2624681275,5974.78551006517;5924.23518922779,-11906.6545194093,5970.47005729123;5919.95289922686,-11898.0495061286,5966.15607398413;5915.67207217046,-11889.4474286583,5961.84356033503;5911.39270823856,-11880.8482873678,5957.53251653313;5907.11480760921,-11872.2520826221,5953.22294276572;5902.83837045852,-11863.6588147828,5948.91483921812;5898.56339696066,-11855.0684842072,5944.60820607368;5894.28988728792,-11846.4810912491,5940.30304351387;5890.01784161062,-11837.8966362582,5935.99935171812;5885.74726009732,-11829.3151195806,5931.69713086412;5881.47814291453,-11820.7365415584,5927.39638112746;5877.21049022684,-11812.1609025298,5923.09710268181;5872.94430219715,-11803.5882028295,5918.79929569910;5868.67957898622,-11795.0184427880,5914.50296034913;5864.41632075308,-11786.4516227323,5910.20809679991;5860.15452765485,-11777.8877429855,5905.91470521754;5855.89419984677,-11769.3268038670,5901.62278576621;5851.63533748210,-11760.7688056920,5897.33233860810;5847.37794071237,-11752.2137487726,5893.04336390365;5843.12200968720,-11743.6616334166,5888.75586181136;5838.86754455427,-11735.1124599283,5884.46983248778;5834.61454545954,-11726.5662286083,5880.18527608768;5830.36301254696,-11718.0229397532,5875.90219276385;5826.11294595873,-11709.4825936560,5871.62058266725;5821.86434583518,-11700.9451906061,5867.34044594700;5817.61721231474,-11692.4107308889,5863.06178275026;5813.37154553408,-11683.8792147865,5858.78459322242;5809.12734562801,-11675.3506425769,5854.50887750698;5804.88461272944,-11666.8250145346,5850.23463574554;5800.64334696950,-11658.3023309303,5845.96186807787;5796.40354847748,-11649.7825920312,5841.69057464189;5792.16521738086,-11641.2657981006,5837.42075557368;5787.92835380530,-11632.7519493983,5833.15241100750;5783.69295787467,-11624.2410461805,5828.88554107577;5779.45902971093,-11615.7330886995,5824.62014590897;5775.22656943435,-11607.2280772041,5820.35622563591;5770.99557716323,-11598.7260119394,5816.09378038337;5766.76605301434,-11590.2268931472,5811.83281027659;5762.53799710236,-11581.7307210650,5807.57331543869;5758.31140954033,-11573.2374959274,5803.31529599115;5754.08629043952,-11564.7472179650,5799.05875205362;5749.86263990937,-11556.2598874049,5794.80368374392;5745.64045805745,-11547.7755044705,5790.55009117801;5741.41974498970,-11539.2940693818,5786.29797447013;5737.20050081019,-11530.8155823551,5782.04733373267;5732.98272562123,-11522.3400436031,5777.79816907622;5728.76641952341,-11513.8674533350,5773.55048060966;5724.55158261553,-11505.3978117566,5769.30426844001;5720.33821499458,-11496.9311190698,5765.05953267250;5716.12631675588,-11488.4673754733,5760.81627341064;5711.91588799290,-11480.0065811620,5756.57449075608;5707.70692879736,-11471.5487363273,5752.33418480869;5703.49943925941,-11463.0938411574,5748.09535566676;5699.29341946723,-11454.6418958367,5743.85800342658;5695.08886950737,-11446.1929005460,5739.62212818279;5690.88578946461,-11437.7468554628,5735.38773002823;5686.68417942207,-11429.3037607612,5731.15480905406;5682.48403946111,-11420.8636166117,5726.92336534966;5678.28536966123,-11412.4264231810,5722.69339900256;5674.08817010038,-11403.9921806329,5718.46491009866;5669.89244085474,-11395.5608891273,5714.23789872211;5665.69818199881,-11387.1325488211,5710.01236495534;5661.50539360525,-11378.7071598673,5705.78830887891;5657.31407574513,-11370.2847224155,5701.56573057180;5653.12422848780,-11361.8652366122,5697.34463011123;5648.93585190087,-11353.4487026001,5693.12500757263;5644.74894605027,-11345.0351205188,5688.90686302979;5640.56351100030,-11336.6244905043,5684.69019655478;5636.37954681346,-11328.2168126893,5680.47500821792;5632.19705355065,-11319.8120872029,5676.26129808783;5628.01603127106,-11311.4103141711,5672.04906623146;5623.83648003215,-11303.0114937163,5667.83831271398;5619.65839988982,-11294.6156259576,5663.62903759899;5615.48179089814,-11286.2227110107,5659.42124094825;5611.30665310966,-11277.8327489880,5655.21492282193;5607.13298657515,-11269.4457399984,5651.01008327845;5602.96079134388,-11261.0616841477,5646.80672237467;5598.79006746324,-11252.6805815382,5642.60484016559;5594.62081497915,-11244.3024322688,5638.40443670469;5590.45303393579,-11235.9272364354,5634.20551204369;5586.28672437576,-11227.5549941301,5630.00806623272;5582.12188633984,-11219.1857054419,5625.81209932004;5577.95851986743,-11210.8193704567,5621.61761135256;5573.79662499612,-11202.4559892569,5617.42460237532;5569.63620176186,-11194.0955619215,5613.23307243169;5565.47725019910,-11185.7380885266,5609.04302156356;5561.31977034048,-11177.3835691444,5604.85444981096;5557.16376221724,-11169.0320038446,5600.66735721250;5553.00922585876,-11160.6833926930,5596.48174380491;5548.85616129301,-11152.3377357525,5592.29760962351;5544.70456854621,-11143.9950330825,5588.11495470181;5540.55444764303,-11135.6552847395,5583.93377907177;5536.40579860655,-11127.3184907764,5579.75408276376;5532.25862145818,-11118.9846512430,5575.57586580641;5528.11291621781,-11110.6537661860,5571.39912822686;5523.96868290367,-11102.3258356488,5567.22387005054;5519.82592153249,-11094.0008596717,5563.05009130136;5515.68463211923,-11085.6788382913,5558.87779200144;5511.54481467750,-11077.3597715418,5554.70697217156;5507.40646921913,-11069.0436594536,5550.53763183064;5503.26959575450,-11060.7305020542,5546.36977099618;5499.13419429231,-11052.4202993678,5542.20338968395;5495.00026483980,-11044.1130514154,5538.03848790825;5490.86780740260,-11035.8087582152,5533.87506568177;5486.73682198473,-11027.5074197817,5529.71312301553;5482.60730858866,-11019.2090361267,5525.55265991900;5478.47926721536,-11010.9136072586,5521.39367640014;5474.35269786420,-11002.6211331827,5517.23617246525;5470.22760053300,-10994.3316139013,5513.08014811911;5466.10397521807,-10986.0450494136,5508.92560336495;5461.98182191411,-10977.7614397154,5504.77253820434;5457.86114061429,-10969.4807847997,5500.62095263735;5453.74193131034,-10961.2030846564,5496.47084666255;5449.62419399234,-10952.9283392720,5492.32222027686;5445.50792864890,-10944.6565486303,5488.17507347570;5441.39313526708,-10936.3877127117,5484.02940625293;5437.27981383239,-10928.1218314937,5479.88521860083;5433.16796432883,-10919.8589049507,5475.74251051015;5429.05758673900,-10911.5989330541,5471.60128197021;5424.94868104383,-10903.3419157722,5467.46153296868;5420.84124722276,-10895.0878530702,5463.32326349167;5416.73528525381,-10886.8367449103,5459.18647352388;5412.63079511347,-10878.5885912518,5455.05116304845;5408.52777677660,-10870.3433920507,5450.91733204687;5404.42623021676,-10862.1011472602,5446.78498049932;5400.32615540587,-10853.8618568304,5442.65410838429;5396.22755231442,-10845.6255207084,5438.52471567887;5392.13042091148,-10837.3921388385,5434.39680235866;5388.03476116443,-10829.1617111616,5430.27036839757;5383.94057303936,-10820.9342376160,5426.14541376822;5379.84785650086,-10812.7097181368,5422.02193844167;5375.75661151190,-10804.4881526562,5417.89994238738;5371.66683803423,-10796.2695411035,5413.77942557353;5367.57853602785,-10788.0538834049,5409.66038796657;5363.49170545148,-10779.8411794838,5405.54282953164;5359.40634626235,-10771.6314292605,5401.42675023233;5355.32245841621,-10763.4246326525,5397.31215003077;5351.24004186731,-10755.2207895742,5393.19902888759;5347.15909656855,-10747.0198999373,5389.08738676200;5343.07962247128,-10738.8219636504,5384.97722361167;5339.00161952550,-10730.6269806193,5380.86853939289;5334.92508767969,-10722.4349507468,5376.76133406042;5329.38664750673,-10711.3043610843,5371.18040566423;5323.85041011605,-10700.1781954376,5365.60169386002;5318.31637495772,-10689.0564527075,5360.02519810002;5312.78454148096,-10677.9391317933,5354.45091783559;5307.25490913391,-10666.8262315917,5348.87885251699;5301.72747736368,-10655.7177509978,5343.30900159344;5296.20224561636,-10644.6136889042,5337.74136451313;5290.67921333717,-10633.5140442022,5332.17594072335;5285.15837997026,-10622.4188157805,5326.61272967032;5279.63974495866,-10611.3280025258,5321.05173079911;5274.12330774463,-10600.2416033233,5315.49294355399;5268.60906776933,-10589.1596170558,5309.93636737817;5263.09702447292,-10578.0820426041,5304.38200171378;5257.58717729455,-10567.0088788470,5298.82984600196;5252.07952567254,-10555.9401246618,5293.27989968300;5246.57406904407,-10544.8757789232,5287.73216219603;5241.07080684545,-10533.8158405043,5282.18663297928;5235.56973851198,-10522.7603082761,5276.64331146998;5230.07086347791,-10511.7091811077,5271.10219710429;5224.57418117675,-10500.6624578664,5265.56328931760;5219.07969104080,-10489.6201374172,5260.02658754407;5213.58739250148,-10478.5822186234,5254.49209121700;5208.09728498939,-10467.5487003465,5248.95979976881;5202.60936793396,-10456.5195814457,5243.42971263077;5197.12364076377,-10445.4948607785,5237.90182923326;5191.64010290655,-10434.4745372007,5232.37614900581;5186.15875378887,-10423.4586095656,5226.85267137675;5180.67959283654,-10412.4470767253,5221.33139577368;5175.20261947430,-10401.4399375294,5215.81232162306;5169.72783312608,-10390.4371908260,5210.29544835059;5164.25523321476,-10379.4388354611,5204.78077538083;5158.78481916229,-10368.4448702789,5199.26830213744;5153.31659038983,-10357.4552941218,5193.75802804327;5147.85054631747,-10346.4701058303,5188.24995252009;5142.38668636436,-10335.4893042426,5182.74407498869;5136.92500994885,-10324.5128881958,5177.24039486906;5131.46551648827,-10313.5408565246,5171.73891158018;5126.00820539907,-10302.5732080619,5166.23962454008;5120.55307609683,-10291.6099416391,5160.74253316594;5115.10012799609,-10280.6510560853,5155.24763687389;5109.64936051063,-10269.6965502281,5149.75493507926;5104.20077305324,-10258.7464228932,5144.26442719640;5098.75436503582,-10247.8006729043,5138.77611263875;5093.31013586938,-10236.8592990835,5133.28999081881;5087.86808496401,-10225.9223002510,5127.80606114821;5082.42821172891,-10214.9896752251,5122.32432303761;5076.99051557239,-10204.0614228224,5116.84477589681;5071.55499590187,-10193.1375418577,5111.36741913468;5066.12165212391,-10182.2180311441,5105.89225215924;5060.69048364419,-10171.3028894928,5100.41927437757;5055.26148986741,-10160.3921157132,5094.94848519580;5049.83467019749,-10149.4857086128,5089.47988401925;5044.41002403739,-10138.5836669976,5084.01347025227;5038.98755078933,-10127.6859896718,5078.54924329843;5033.56724985456,-10116.7926754377,5073.08720256036;5028.14912063338,-10105.9037230957,5067.62734743969;5022.73316252543,-10095.0191314450,5062.16967733735;5017.31937492928,-10084.1388992824,5056.71419165328;5011.90775724277,-10073.2630254034,5051.26088978657;5006.49830886288,-10062.3915086017,5045.80977113551;5001.09102918564,-10051.5243476691,5040.36083509738;4995.68591760623,-10040.6615413957,5034.91408106862;4990.28297351919,-10029.8030885702,5029.46950844499;4984.88219631789,-10018.9489879791,5024.02711662110;4979.48358539506,-10008.0992384076,5018.58690499089;4974.08714014256,-9997.25383863882,5013.14887294738;4968.69285995138,-9986.41278745460,5007.71301988278;4963.30074421167,-9975.57608363481,5002.27934518838;4957.91079231276,-9964.74372595771,4996.84784825468;4952.52300364313,-9953.91571319983,4991.41852847128;4947.13737759045,-9943.09204413611,4985.99138522696;4941.75391354153,-9932.27271753974,4980.56641790966;4936.37261088239,-9921.45773218227,4975.14362590648;4930.99346899821,-9910.64708683360,4969.72300860368;4925.61648727333,-9899.84078026194,4964.30456538666;4920.24166509130,-9889.03881123388,4958.88829564003;4914.86900183486,-9878.24117851436,4953.47419874754;4909.49849688589,-9867.44788086664,4948.06227409212;4904.13014962552,-9856.65891705239,4942.65252105588;4898.76395943402,-9845.87428583163,4937.24493902011;4893.39992569088,-9835.09398596274,4931.83952736526;4888.03804777480,-9824.31801620250,4926.43628547099;4882.67832506363,-9813.54637530605,4921.03521271611;4877.32075693449,-9802.77906202696,4915.63630847868;4871.96534276363,-9792.01607511711,4910.23957213586;4866.61208192657,-9781.25741332688,4904.84500306408;4861.26097379800,-9770.50307540499,4899.45260063892;4855.91201775185,-9759.75306009858,4894.06236423519;4850.56521316123,-9749.00736615319,4888.67429322688;4845.22055939850,-9738.26599231283,4883.28838698719;4839.87805583521,-9727.52893731986,4877.90464488850;4834.53770184216,-9716.79619991513,4872.52306630245;4829.19949678936,-9706.06777883788,4867.14365059984;4823.86344004604,-9695.34367282582,4861.76639715071;4818.52953098065,-9684.62388061507,4856.39130532430;4813.19776896091,-9673.90840094023,4851.01837448908;4807.86815335375,-9663.19723253433,4845.64760401273;4802.54068352532,-9652.49037412887,4840.27899326217;4797.21535884105,-9641.78782445381,4834.91254160352;4791.89217866555,-9631.08958223757,4829.54824840214;4790.92806817843,-9629.15340992255,4828.57822335777;4789.96396498034,-9627.21724878960,4827.60820200776;4788.99986984930,-9625.28110040827,4826.63818514242;4788.03578356140,-9623.34496634432,4825.66817355012;4787.07170689078,-9621.40884815951,4824.69816801726;4786.10764060970,-9619.47274741184,4823.72816932831;4785.14358548847,-9617.53666565540,4822.75817826582;4784.17954229549,-9615.60060444042,4821.78819561035;4783.21551179727,-9613.66456531330,4820.81822214058;4782.25149475839,-9611.72854981658,4819.84825863321;4781.28749194153,-9609.79255948897,4818.87830586306;4780.32350410750,-9607.85659586540,4817.90836460301;4779.35953201515,-9605.92066047688,4816.93843562399;4778.39557642151,-9603.98475485072,4815.96851969507;4777.43163808166,-9602.04888051034,4814.99861758335;4776.46771774883,-9600.11303897541,4814.02873005408;4775.50381617436,-9598.17723176180,4813.05885787055;4774.53993410771,-9596.24146038159,4812.08900179418;4773.57607229646,-9594.30572634306,4811.11916258449;4772.61223148632,-9592.37003115077,4810.14934099909;4771.64841242114,-9590.43437630549,4809.17953779372;4770.68461584290,-9588.49876330422,4808.20975372221;4769.72084249171,-9586.56319364023,4807.23998953653;4768.75709310584,-9584.62766880308,4806.27024598676;4767.79336842169,-9582.69219027852,4805.30052382108;4766.82966917381,-9580.75675954864,4804.33082378583;4765.86599609492,-9578.82137809177,4803.36114662548;4764.90234991588,-9576.88604738256,4802.39149308260;4763.93873136571,-9574.95076889191,4801.42186389793;4762.97514117161,-9573.01554408707,4800.45225981034;4762.01158005892,-9571.08037443157,4799.48268155684;4761.04804875118,-9569.14526138525,4798.51312987260;4760.08454797007,-9567.21020640429,4797.54360549092;4759.12107843548,-9565.27521094119,4796.57410914328;4758.15764086546,-9563.34027644476,4795.60464155930;4757.19423597626,-9561.40540436022,4794.63520346677;4756.23086448230,-9559.47059612907,4793.66579559165;4755.26752709619,-9557.53585318919,4792.69641865805;4754.30422452876,-9555.60117697485,4791.72707338827;4753.34095748900,-9553.66656891663,4790.75776050277;4752.37772668414,-9551.73203044156,4789.78848072022;4751.41453281959,-9549.79756297299,4788.81923475743;4750.45137659898,-9547.86316793071,4787.85002332943;4749.48825872413,-9545.92884673088,4786.88084714942;4748.52517989510,-9543.99460078605,4785.91170692881;4747.56214081017,-9542.06043150523,4784.94260337718;4746.59914216582,-9540.12634029382,4783.97353720234;4745.63618465675,-9538.19232855361,4783.00450911027;4744.67326897594,-9536.25839768289,4782.03551980520;4743.71039581452,-9534.32454907634,4781.06656998953;4742.74756586194,-9532.39078412510,4780.09766036388;4741.78477980583,-9530.45710421676,4779.12879162711;4740.82203833208,-9528.52351073538,4778.15996447628;4739.85934212484,-9526.59000506148,4777.19117960668;4738.89669186648,-9524.65658857203,4776.22243771182;4737.93408823764,-9522.72326264051,4775.25373948346;4736.97153191722,-9520.79002863688,4774.28508561156;4736.00902358235,-9518.85688792756,4773.31647678435;4735.04656390846,-9516.92384187552,4772.34791368827;4734.08415356922,-9514.99089184019,4771.37939700804;4733.12179323658,-9513.05803917756,4770.41092742660;4732.15948358075,-9511.12528524009,4769.44250562515;4731.19722527024,-9509.19263137679,4768.47413228313;4730.23501897180,-9507.26007893322,4767.50580807826;4729.27286535049,-9505.32762925143,4766.53753368651;4728.31076506966,-9503.39528367007,4765.56930978211;4727.34871879092,-9501.46304352431,4764.60113703756;4726.38672717419,-9499.53091014588,4763.63301612363;4725.42479087770,-9497.59888486309,4762.66494770936;4724.46291055794,-9495.66696900081,4761.69693246207;4723.50108686973,-9493.73516388051,4760.72897104738;4722.53932046619,-9491.80347082019,4759.76106412915;4721.57761199874,-9489.87189113451,4758.79321236957;4720.61596211713,-9487.94042613471,4757.82541642909;4719.65437146939,-9486.00907712860,4756.85767696648;4718.69284070191,-9484.07784542063,4755.88999463877;4717.73137045936,-9482.14673231186,4754.92237010133;4716.76996138478,-9480.21573910000,4753.95480400782;4715.80861411948,-9478.28486707935,4752.98729701019;4714.84732930315,-9476.35411754086,4752.01984975872;4713.88610757380,-9474.42349177215,4751.05246290199;4712.92494956777,-9472.49299105747,4750.08513708690;4711.96385591973,-9470.56261667771,4749.11787295867;4711.00282726273,-9468.63236991046,4748.15067116086;4710.04186422812,-9466.70225202995,4747.18353233532;4709.08096744565,-9464.77226430711,4746.21645712227;4708.12013754338,-9462.84240800953,4745.24944616022;4707.15937514774,-9460.91268440151,4744.28250008605;4706.19868088354,-9458.98309474402,4743.31561953497;4705.23805537392,-9457.05364029477,4742.34880514052;4704.27749924041,-9455.12432230814,4741.38205753460;4703.31701310290,-9453.19514203523,4740.41537734744;4702.35659757965,-9451.26610072390,4739.44876520766;4701.39625328731,-9449.33719961870,4738.48222174219;4700.43598084086,-9447.40843996090,4737.51574757633;4699.47578085375,-9445.47982298856,4736.54934333378;4698.51565393773,-9443.55134993645,4735.58300963655;4697.55560070298,-9441.62302203610,4734.61674710504;4696.59562175806,-9439.69484051581,4733.65055635803;4695.63571770994,-9437.76680660063,4732.68443801267;4694.67588916396,-9435.83892151239,4731.71839268448;4693.71613672388,-9433.91118646970,4730.75242098735;4692.75646099185,-9431.98360268794,4729.78652353359;4691.79686256845,-9430.05617137931,4728.82070093386;4690.83734205265,-9428.12889375278,4727.85495379722;4689.87790004183,-9426.20177101412,4726.88928273114;4688.91853713180,-9424.27480436594,4725.92368834146;4687.95925391678,-9422.34799500763,4724.95817123243;4687.00005098942,-9420.42134413543,4723.99273200672;4686.04092894079,-9418.49485294239,4723.02737126538;4685.08188836039,-9416.56852261839,4722.06208960787;4684.12292983615,-9414.64235435019,4721.09688763209;4683.16405395443,-9412.71634932133,4720.13176593430;4682.20526130004,-9410.79050871227,4719.16672510926;4681.24655245622,-9408.86483370028,4718.20176575005;4680.28792800465,-9406.93932545952,4717.23688844826;4679.32938852547,-9405.01398516100,4716.27209379387;4678.37093459727,-9403.08881397265,4715.30738237529;4677.41256679708,-9401.16381305924,4714.34275477936;4676.45428570040,-9399.23898358243,4713.37821159138;4675.49609188117,-9397.31432670082,4712.41375339506;4674.53798591182,-9395.38984356986,4711.44938077257;4673.57996836321,-9393.46553534193,4710.48509430452;4672.62203980469,-9391.54140316632,4709.52089456996;4671.66420080409,-9389.61744818926,4708.55678214642;4670.70645192769,-9387.69367155388,4707.59275760985;4669.74879374026,-9385.77007440024,4706.62882153467;4668.79122680506,-9383.84665786537,4705.66497449378;4667.83375168381,-9381.92342308322,4704.70121705853;4666.87636893673,-9380.00037118466,4703.73754979870;4665.91907912252,-9378.07750329759,4702.77397328261;4664.96188279840,-9376.15482054682,4701.81048807700;4664.00478052005,-9374.23232405413,4700.84709474710;4663.04777284166,-9372.31001493828,4699.88379385664;4662.09086031592,-9370.38789431503,4698.92058596779;4661.13404349404,-9368.46596329710,4697.95747164123;4660.17732292571,-9366.54422299422,4696.99445143615;4659.22069915916,-9364.62267451309,4696.03152591017;4658.26417274109,-9362.70131895745,4695.06869561947;4657.30774421677,-9360.78015742804,4694.10596111868;4655.87328617012,-9357.89878133358,4692.66204018318;];
  Derivative.theta       = [0,0.100000000000000,0.200000000000000,0.300000000000000,0.400000000000000,0.500000000000000,0.600000000000000,0.700000000000000,0.800000000000000,0.900000000000000,1,1.10000000000000,1.20000000000000,1.30000000000000,1.40000000000000,1.50000000000000,1.60000000000000,1.70000000000000,1.80000000000000,1.90000000000000,2,2.10000000000000,2.20000000000000,2.30000000000000,2.40000000000000,2.50000000000000,2.60000000000000,2.70000000000000,2.80000000000000,2.90000000000000,3,3.10000000000000,3.20000000000000,3.30000000000000,3.40000000000000,3.50000000000000,3.60000000000000,3.70000000000000,3.80000000000000,3.90000000000000,4,4.10000000000000,4.20000000000000,4.30000000000000,4.40000000000000,4.50000000000000,4.60000000000000,4.70000000000000,4.80000000000000,4.90000000000000,5,5.10000000000000,5.20000000000000,5.30000000000000,5.40000000000000,5.50000000000000,5.60000000000000,5.70000000000000,5.80000000000000,5.90000000000000,6,6.10000000000000,6.20000000000000,6.30000000000000,6.40000000000000,6.50000000000000,6.60000000000000,6.70000000000000,6.80000000000000,6.90000000000000,7,7.10000000000000,7.20000000000000,7.30000000000000,7.40000000000000,7.50000000000000,7.60000000000000,7.70000000000000,7.80000000000000,7.90000000000000,8,8.10000000000000,8.20000000000000,8.30000000000000,8.40000000000000,8.50000000000000,8.60000000000000,8.70000000000000,8.80000000000000,8.90000000000000,9,9.10000000000000,9.20000000000000,9.30000000000000,9.40000000000000,9.50000000000000,9.60000000000000,9.70000000000000,9.80000000000000,9.90000000000000,10,10.1000000000000,10.2000000000000,10.3000000000000,10.4000000000000,10.5000000000000,10.6000000000000,10.7000000000000,10.8000000000000,10.9000000000000,11,11.1000000000000,11.2000000000000,11.3000000000000,11.4000000000000,11.5000000000000,11.6000000000000,11.7000000000000,11.8000000000000,11.9000000000000,12,12.1000000000000,12.2000000000000,12.3000000000000,12.4000000000000,12.5000000000000,12.6000000000000,12.7000000000000,12.8000000000000,12.9000000000000,13,13.1000000000000,13.2000000000000,13.3000000000000,13.4000000000000,13.5000000000000,13.6000000000000,13.7000000000000,13.8000000000000,13.9000000000000,14,14.1000000000000,14.2000000000000,14.3000000000000,14.4000000000000,14.5000000000000,14.6000000000000,14.7000000000000,14.8000000000000,14.9000000000000,15,15.1000000000000,15.2000000000000,15.3000000000000,15.4000000000000,15.5000000000000,15.6000000000000,15.7000000000000,15.8000000000000,15.9000000000000,16,16.1000000000000,16.2000000000000,16.3000000000000,16.4000000000000,16.5000000000000,16.6000000000000,16.7000000000000,16.8000000000000,16.9000000000000,17,17.1000000000000,17.2000000000000,17.3000000000000,17.4000000000000,17.5000000000000,17.6000000000000,17.7000000000000,17.8000000000000,17.9000000000000,18,18.1000000000000,18.2000000000000,18.3000000000000,18.4000000000000,18.5000000000000,18.6000000000000,18.7000000000000,18.8000000000000,18.9000000000000,19,19.1000000000000,19.2000000000000,19.3000000000000,19.4000000000000,19.5000000000000,19.6000000000000,19.7000000000000,19.8000000000000,19.9000000000000,20,20.1000000000000,20.2000000000000,20.3000000000000,20.4000000000000,20.5000000000000,20.6000000000000,20.7000000000000,20.8000000000000,20.9000000000000,21,21.1000000000000,21.2000000000000,21.3000000000000,21.4000000000000,21.5000000000000,21.6000000000000,21.7000000000000,21.8000000000000,21.9000000000000,22,22.1000000000000,22.2000000000000,22.3000000000000,22.4000000000000,22.5000000000000,22.6000000000000,22.7000000000000,22.8000000000000,22.9000000000000,23,23.1000000000000,23.2000000000000,23.3000000000000,23.4000000000000,23.5000000000000,23.6000000000000,23.7000000000000,23.8000000000000,23.9000000000000,24,24.1000000000000,24.2000000000000,24.3000000000000,24.4000000000000,24.5000000000000,24.6000000000000,24.7000000000000,24.8000000000000,24.9000000000000,25,25.1000000000000,25.2000000000000,25.3000000000000,25.4000000000000,25.5000000000000,25.6000000000000,25.7000000000000,25.8000000000000,25.9000000000000,26,26.1000000000000,26.2000000000000,26.3000000000000,26.4000000000000,26.5000000000000,26.6000000000000,26.7000000000000,26.8000000000000,26.9000000000000,27,27.1000000000000,27.2000000000000,27.3000000000000,27.4000000000000,27.5000000000000,27.6000000000000,27.7000000000000,27.8000000000000,27.9000000000000,28,28.1000000000000,28.2000000000000,28.3000000000000,28.4000000000000,28.5000000000000,28.6000000000000,28.7000000000000,28.8000000000000,28.9000000000000,29,29.1000000000000,29.2000000000000,29.3000000000000,29.4000000000000,29.5000000000000,29.6000000000000,29.7000000000000,29.8000000000000,29.9000000000000,30,30.1000000000000,30.2000000000000,30.3000000000000,30.4000000000000,30.5000000000000,30.6000000000000,30.7000000000000,30.8000000000000,30.9000000000000,31,31.1000000000000,31.2000000000000,31.3000000000000,31.4000000000000,31.5000000000000,31.6000000000000,31.7000000000000,31.8000000000000,31.9000000000000,32,32.1000000000000,32.2000000000000,32.3000000000000,32.4000000000000,32.5000000000000,32.6000000000000,32.7000000000000,32.8000000000000,32.9000000000000,33,33.1000000000000,33.2000000000000,33.3000000000000,33.4000000000000,33.5000000000000,33.6000000000000,33.7000000000000,33.8000000000000,33.9000000000000,34,34.1000000000000,34.2000000000000,34.3000000000000,34.4000000000000,34.5000000000000,34.6000000000000,34.7000000000000,34.8000000000000,34.9000000000000,35,35.1000000000000,35.2000000000000,35.3000000000000,35.4000000000000,35.5000000000000,35.6000000000000,35.7000000000000,35.8000000000000,35.9000000000000,36,36.1000000000000,36.2000000000000,36.3000000000000,36.4000000000000,36.5000000000000,36.6000000000000,36.7000000000000,36.8000000000000,36.9000000000000,37,37.1000000000000,37.2000000000000,37.3000000000000,37.4000000000000,37.5000000000000,37.6000000000000,37.7000000000000,37.8000000000000,37.9000000000000,38,38.1000000000000,38.2000000000000,38.3000000000000,38.4000000000000,38.5000000000000,38.6000000000000,38.7000000000000,38.8000000000000,38.9000000000000,39,39.1000000000000,39.2000000000000,39.3000000000000,39.4000000000000,39.5000000000000,39.6000000000000,39.7000000000000,39.8000000000000,39.9000000000000,40,40.1000000000000,40.2000000000000,40.3000000000000,40.4000000000000,40.5000000000000,40.6000000000000,40.7000000000000,40.8000000000000,40.9000000000000,41,41.1000000000000,41.2000000000000,41.3000000000000,41.4000000000000,41.5000000000000,41.6000000000000,41.7000000000000,41.8000000000000,41.9000000000000,42,42.1000000000000,42.2000000000000,42.3000000000000,42.4000000000000,42.5000000000000,42.6000000000000,42.7000000000000,42.8000000000000,42.9000000000000,43,43.1000000000000,43.2000000000000,43.3000000000000,43.4000000000000,43.5000000000000,43.6000000000000,43.7000000000000,43.8000000000000,43.9000000000000,44,44.1000000000000,44.2000000000000,44.3000000000000,44.4000000000000,44.5000000000000,44.6000000000000,44.7000000000000,44.8000000000000,44.9000000000000,45,45.1000000000000,45.2000000000000,45.3000000000000,45.4000000000000,45.5000000000000,45.6000000000000,45.7000000000000,45.8000000000000,45.9000000000000,46,46.1000000000000,46.2000000000000,46.3000000000000,46.4000000000000,46.5000000000000,46.6000000000000,46.7000000000000,46.8000000000000,46.9000000000000,47,47.1000000000000,47.2000000000000,47.3000000000000,47.4000000000000,47.5000000000000,47.6000000000000,47.7000000000000,47.8000000000000,47.9000000000000,48,48.1000000000000,48.2000000000000,48.3000000000000,48.4000000000000,48.5000000000000,48.6000000000000,48.7000000000000,48.8000000000000,48.9000000000000,49,49.1000000000000,49.2000000000000,49.3000000000000,49.4000000000000,49.5000000000000,49.6000000000000,49.7000000000000,49.8000000000000,49.9000000000000,50,50.1000000000000,50.2000000000000,50.3000000000000,50.4000000000000,50.5000000000000,50.6000000000000,50.7000000000000,50.8000000000000,50.9000000000000,51,51.1000000000000,51.2000000000000,51.3000000000000,51.4000000000000,51.5000000000000,51.6000000000000,51.7000000000000,51.8000000000000,51.9000000000000,52,52.1000000000000,52.2000000000000,52.3000000000000,52.4000000000000,52.5000000000000,52.6000000000000,52.7000000000000,52.8000000000000,52.9000000000000,53,53.1000000000000,53.2000000000000,53.3000000000000,53.4000000000000,53.5000000000000,53.6000000000000,53.7000000000000,53.8000000000000,53.9000000000000,54,54.1000000000000,54.2000000000000,54.3000000000000,54.4000000000000,54.5000000000000,54.6000000000000,54.7000000000000,54.8000000000000,54.9000000000000,55,55.1000000000000,55.2000000000000,55.3000000000000,55.4000000000000,55.5000000000000,55.6000000000000,55.7000000000000,55.8000000000000,55.9000000000000,56,56.1000000000000,56.2000000000000,56.3000000000000,56.4000000000000,56.5000000000000,56.6000000000000,56.7000000000000,56.8000000000000,56.9000000000000,57,57.1000000000000,57.2000000000000,57.3000000000000,57.4000000000000,57.5000000000000,57.6000000000000,57.7000000000000,57.8000000000000,57.9000000000000,58,58.1000000000000,58.2000000000000,58.3000000000000,58.4000000000000,58.5000000000000,58.6000000000000,58.7000000000000,58.8000000000000,58.9000000000000,59,59.1000000000000,59.2000000000000,59.3000000000000,59.4000000000000,59.5000000000000,59.6000000000000,59.7000000000000,59.8000000000000,59.9000000000000,60,60.1000000000000,60.2000000000000,60.3000000000000,60.4000000000000,60.5000000000000,60.6000000000000,60.7000000000000,60.8000000000000,60.9000000000000,61,61.1000000000000,61.2000000000000,61.3000000000000,61.4000000000000,61.5000000000000,61.6000000000000,61.7000000000000,61.8000000000000,61.9000000000000,62,62.1000000000000,62.2000000000000,62.3000000000000,62.4000000000000,62.5000000000000,62.6000000000000,62.7000000000000,62.8000000000000,62.9000000000000,63,63.1000000000000,63.2000000000000,63.3000000000000,63.4000000000000,63.5000000000000,63.6000000000000,63.7000000000000,63.8000000000000,63.9000000000000,64,64.1000000000000,64.2000000000000,64.3000000000000,64.4000000000000,64.5000000000000,64.6000000000000,64.7000000000000,64.8000000000000,64.9000000000000,65,65.1000000000000,65.2000000000000,65.3000000000000,65.4000000000000,65.5000000000000,65.6000000000000,65.7000000000000,65.8000000000000,65.9000000000000,66,66.1000000000000,66.2000000000000,66.3000000000000,66.4000000000000,66.5000000000000,66.6000000000000,66.7000000000000,66.8000000000000,66.9000000000000,67,67.1000000000000,67.2000000000000,67.3000000000000,67.4000000000000,67.5000000000000,67.6000000000000,67.7000000000000,67.8000000000000,67.9000000000000,68,68.1000000000000,68.2000000000000,68.3000000000000,68.4000000000000,68.5000000000000,68.6000000000000,68.7000000000000,68.8000000000000,68.9000000000000,69,69.1000000000000,69.2000000000000,69.3000000000000,69.4000000000000,69.5000000000000,69.6000000000000,69.7000000000000,69.8000000000000,69.9000000000000,70,70.1000000000000,70.2000000000000,70.3000000000000,70.4000000000000,70.5000000000000,70.6000000000000,70.7000000000000,70.8000000000000,70.9000000000000,71,71.1000000000000,71.2000000000000,71.3000000000000,71.4000000000000,71.5000000000000,71.6000000000000,71.7000000000000,71.8000000000000,71.9000000000000,72,72.1000000000000,72.2000000000000,72.3000000000000,72.4000000000000,72.5000000000000,72.6000000000000,72.7000000000000,72.8000000000000,72.9000000000000,73,73.1000000000000,73.2000000000000,73.3000000000000,73.4000000000000,73.5000000000000,73.6000000000000,73.7000000000000,73.8000000000000,73.9000000000000,74,74.1000000000000,74.2000000000000,74.3000000000000,74.4000000000000,74.5000000000000,74.6000000000000,74.7000000000000,74.8000000000000,74.9000000000000,75,75.1000000000000,75.2000000000000,75.3000000000000,75.4000000000000,75.5000000000000,75.6000000000000,75.7000000000000,75.8000000000000,75.9000000000000,76,76.1000000000000,76.2000000000000,76.3000000000000,76.4000000000000,76.5000000000000,76.6000000000000,76.7000000000000,76.8000000000000,76.9000000000000,77,77.1000000000000,77.2000000000000,77.3000000000000,77.4000000000000,77.5000000000000,77.6000000000000,77.7000000000000,77.8000000000000,77.9000000000000,78,78.1000000000000,78.2000000000000,78.3000000000000,78.4000000000000,78.5000000000000,78.6000000000000,78.7000000000000,78.8000000000000,78.9000000000000,79,79.1000000000000,79.2000000000000,79.3000000000000,79.4000000000000,79.5000000000000,79.6000000000000,79.7000000000000,79.8000000000000,79.9000000000000,80,80.1000000000000,80.2000000000000,80.3000000000000,80.4000000000000,80.5000000000000,80.6000000000000,80.7000000000000,80.8000000000000,80.9000000000000,81,81.1000000000000,81.2000000000000,81.3000000000000,81.4000000000000,81.5000000000000,81.6000000000000,81.7000000000000,81.8000000000000,81.9000000000000,82,82.1000000000000,82.2000000000000,82.3000000000000,82.4000000000000,82.5000000000000,82.6000000000000,82.7000000000000,82.8000000000000,82.9000000000000,83,83.1000000000000,83.2000000000000,83.3000000000000,83.4000000000000,83.5000000000000,83.6000000000000,83.7000000000000,83.8000000000000,83.9000000000000,84,84.1000000000000,84.2000000000000,84.3000000000000,84.4000000000000,84.5000000000000,84.6000000000000,84.7000000000000,84.8000000000000,84.9000000000000,85,85.1000000000000,85.2000000000000,85.3000000000000,85.4000000000000,85.5000000000000,85.6000000000000,85.7000000000000,85.8000000000000,85.9000000000000,86,86.1000000000000,86.2000000000000,86.3000000000000,86.4000000000000,86.5000000000000,86.6000000000000,86.7000000000000,86.8000000000000,86.9000000000000,87,87.1000000000000,87.2000000000000,87.3000000000000,87.4000000000000,87.5000000000000,87.6000000000000,87.7000000000000,87.8000000000000,87.9000000000000,88,88.1000000000000,88.2000000000000,88.3000000000000,88.4000000000000,88.5000000000000,88.6000000000000,88.7000000000000,88.8000000000000,88.9000000000000,89,89.1000000000000,89.2000000000000,89.3000000000000,89.4000000000000,89.5000000000000,89.6000000000000,89.7000000000000,89.8000000000000,89.9000000000000,90,90.1000000000000,90.2000000000000,90.3000000000000,90.4000000000000,90.5000000000000,90.6000000000000,90.7000000000000,90.8000000000000,90.9000000000000,91,91.1000000000000,91.2000000000000,91.3000000000000,91.4000000000000,91.5000000000000,91.6000000000000,91.7000000000000,91.8000000000000,91.9000000000000,92,92.1000000000000,92.2000000000000,92.3000000000000,92.4000000000000,92.5000000000000,92.6000000000000,92.7000000000000,92.8000000000000,92.9000000000000,93,93.1000000000000,93.2000000000000,93.3000000000000,93.4000000000000,93.5000000000000,93.6000000000000,93.7000000000000,93.8000000000000,93.9000000000000,94,94.1000000000000,94.2000000000000,94.3000000000000,94.4000000000000,94.5000000000000,94.6000000000000,94.7000000000000,94.8000000000000,94.9000000000000,95,95.1000000000000,95.2000000000000,95.3000000000000,95.4000000000000,95.5000000000000,95.6000000000000,95.7000000000000,95.8000000000000,95.9000000000000,96,96.1000000000000,96.2000000000000,96.3000000000000,96.4000000000000,96.5000000000000,96.6000000000000,96.7000000000000,96.8000000000000,96.9000000000000,97,97.1000000000000,97.2000000000000,97.3000000000000,97.4000000000000,97.5000000000000,97.6000000000000,97.7000000000000,97.8000000000000,97.9000000000000,98,98.1000000000000,98.2000000000000,98.3000000000000,98.4000000000000,98.5000000000000,98.6000000000000,98.7000000000000,98.8000000000000,98.9000000000000,99,99.1000000000000,99.2000000000000,99.3000000000000,99.4000000000000,99.5000000000000,99.6000000000000,99.7000000000000,99.8000000000000,99.9000000000000,100,100.100000000000,100.200000000000,100.300000000000,100.400000000000,100.500000000000,100.600000000000,100.700000000000,100.800000000000,100.900000000000,101,101.100000000000,101.200000000000,101.300000000000,101.400000000000,101.500000000000,101.600000000000,101.700000000000,101.800000000000,101.900000000000,102,102.100000000000,102.200000000000,102.300000000000,102.400000000000,102.500000000000,102.600000000000,102.700000000000,102.800000000000,102.900000000000,103,103.100000000000,103.200000000000,103.300000000000,103.400000000000,103.500000000000,103.600000000000,103.700000000000,103.800000000000,103.900000000000,104,104.100000000000,104.200000000000,104.300000000000,104.400000000000,104.500000000000,104.600000000000,104.700000000000,104.800000000000,104.900000000000,105,105.100000000000,105.200000000000,105.300000000000,105.400000000000,105.500000000000,105.600000000000,105.700000000000,105.800000000000,105.900000000000,106,106.100000000000,106.200000000000,106.300000000000,106.400000000000,106.500000000000,106.600000000000,106.700000000000,106.800000000000,106.900000000000,107,107.100000000000,107.200000000000,107.300000000000,107.400000000000,107.500000000000,107.600000000000,107.700000000000,107.800000000000,107.900000000000,108,108.100000000000,108.200000000000,108.300000000000,108.400000000000,108.500000000000,108.600000000000,108.700000000000,108.800000000000,108.900000000000,109,109.100000000000,109.200000000000,109.300000000000,109.400000000000,109.500000000000,109.600000000000,109.700000000000,109.800000000000,109.900000000000,110,110.100000000000,110.200000000000,110.300000000000,110.400000000000,110.500000000000,110.600000000000,110.700000000000,110.800000000000,110.900000000000,111,111.100000000000,111.200000000000,111.300000000000,111.400000000000,111.500000000000,111.600000000000,111.700000000000,111.800000000000,111.900000000000,112,112.100000000000,112.200000000000,112.300000000000,112.400000000000,112.500000000000,112.600000000000,112.700000000000,112.800000000000,112.900000000000,113,113.100000000000,113.200000000000,113.300000000000,113.400000000000,113.500000000000,113.600000000000,113.700000000000,113.800000000000,113.900000000000,114,114.100000000000,114.200000000000,114.300000000000,114.400000000000,114.500000000000,114.600000000000,114.700000000000,114.800000000000,114.900000000000,115,115.100000000000,115.200000000000,115.300000000000,115.400000000000,115.500000000000,115.600000000000,115.700000000000,115.800000000000,115.900000000000,116,116.100000000000,116.200000000000,116.300000000000,116.400000000000,116.500000000000,116.600000000000,116.700000000000,116.800000000000,116.900000000000,117,117.100000000000,117.200000000000,117.300000000000,117.400000000000,117.500000000000,117.600000000000,117.700000000000,117.800000000000,117.900000000000,118,118.100000000000,118.200000000000,118.300000000000,118.400000000000,118.500000000000,118.600000000000,118.700000000000,118.800000000000,118.900000000000,119,119.100000000000,119.200000000000,119.300000000000,119.400000000000,119.500000000000,119.600000000000,119.700000000000,119.800000000000,119.900000000000,120,120.100000000000,120.200000000000,120.300000000000,120.400000000000,120.500000000000,120.600000000000,120.700000000000,120.800000000000,120.900000000000,121,121.100000000000,121.200000000000,121.300000000000,121.400000000000,121.500000000000,121.600000000000,121.700000000000,121.800000000000,121.900000000000,122,122.100000000000,122.200000000000,122.300000000000,122.400000000000,122.500000000000,122.600000000000,122.700000000000,122.800000000000,122.900000000000,123,123.100000000000,123.200000000000,123.300000000000,123.400000000000,123.500000000000,123.600000000000,123.700000000000,123.800000000000,123.900000000000,124,124.100000000000,124.200000000000,124.300000000000,124.400000000000,124.500000000000,124.600000000000,124.700000000000,124.800000000000,124.900000000000,125,125.100000000000,125.200000000000,125.300000000000,125.400000000000,125.500000000000,125.600000000000,125.700000000000,125.800000000000,125.900000000000,126,126.100000000000,126.200000000000,126.300000000000,126.400000000000,126.500000000000,126.600000000000,126.700000000000,126.800000000000,126.900000000000,127,127.100000000000,127.200000000000,127.300000000000,127.400000000000,127.500000000000,127.600000000000,127.700000000000,127.800000000000,127.900000000000,128,128.100000000000,128.200000000000,128.300000000000,128.400000000000,128.500000000000,128.600000000000,128.700000000000,128.800000000000,128.900000000000,129,129.100000000000,129.200000000000,129.300000000000,129.400000000000,129.500000000000,129.600000000000,129.700000000000,129.800000000000,129.900000000000,130,130.100000000000,130.200000000000,130.300000000000,130.400000000000,130.500000000000,130.600000000000,130.700000000000,130.800000000000,130.900000000000,131,131.100000000000,131.200000000000,131.300000000000,131.400000000000,131.500000000000,131.600000000000,131.700000000000,131.800000000000,131.900000000000,132,132.100000000000,132.200000000000,132.300000000000,132.400000000000,132.500000000000,132.600000000000,132.700000000000,132.800000000000,132.900000000000,133,133.100000000000,133.200000000000,133.300000000000,133.400000000000,133.500000000000,133.600000000000,133.700000000000,133.800000000000,133.900000000000,134,134.100000000000,134.200000000000,134.300000000000,134.400000000000,134.500000000000,134.600000000000,134.700000000000,134.800000000000,134.900000000000,135,135.100000000000,135.200000000000,135.300000000000,135.400000000000,135.500000000000,135.600000000000,135.700000000000,135.800000000000,135.900000000000,136,136.100000000000,136.200000000000,136.300000000000,136.400000000000,136.500000000000,136.600000000000,136.700000000000,136.800000000000,136.900000000000,137,137.100000000000,137.200000000000,137.300000000000,137.400000000000,137.500000000000,137.600000000000,137.700000000000,137.800000000000,137.900000000000,138,138.100000000000,138.200000000000,138.300000000000,138.400000000000,138.500000000000,138.600000000000,138.700000000000,138.800000000000,138.900000000000,139,139.100000000000,139.200000000000,139.300000000000,139.400000000000,139.500000000000,139.600000000000,139.700000000000,139.800000000000,139.900000000000,140,140.100000000000,140.200000000000,140.300000000000,140.400000000000,140.500000000000,140.600000000000,140.700000000000,140.800000000000,140.900000000000,141,141.100000000000,141.200000000000,141.300000000000,141.400000000000,141.500000000000,141.600000000000,141.700000000000,141.800000000000,141.900000000000,142,142.100000000000,142.200000000000,142.300000000000,142.400000000000,142.500000000000,142.600000000000,142.700000000000,142.800000000000,142.900000000000,143,143.100000000000,143.200000000000,143.300000000000,143.400000000000,143.500000000000,143.600000000000,143.700000000000,143.800000000000,143.900000000000,144,144.100000000000,144.200000000000,144.300000000000,144.400000000000,144.500000000000,144.600000000000,144.700000000000,144.800000000000,144.900000000000,145,145.100000000000,145.200000000000,145.300000000000,145.400000000000,145.500000000000,145.600000000000,145.700000000000,145.800000000000,145.900000000000,146,146.100000000000,146.200000000000,146.300000000000,146.400000000000,146.500000000000,146.600000000000,146.700000000000,146.800000000000,146.900000000000,147,147.100000000000,147.200000000000,147.300000000000,147.400000000000,147.500000000000,147.600000000000,147.700000000000,147.800000000000,147.900000000000,148,148.100000000000,148.200000000000,148.300000000000,148.400000000000,148.500000000000,148.600000000000,148.700000000000,148.800000000000,148.900000000000,149,149.100000000000,149.200000000000,149.300000000000,149.400000000000,149.500000000000,149.600000000000,149.700000000000,149.800000000000,149.900000000000,150,150.100000000000,150.200000000000,150.300000000000,150.400000000000,150.500000000000,150.600000000000,150.700000000000,150.800000000000,150.900000000000,151,151.100000000000,151.200000000000,151.300000000000,151.400000000000,151.500000000000,151.600000000000,151.700000000000,151.800000000000,151.900000000000,152,152.100000000000,152.200000000000,152.300000000000,152.400000000000,152.500000000000,152.600000000000,152.700000000000,152.800000000000,152.900000000000,153,153.100000000000,153.200000000000,153.300000000000,153.400000000000,153.500000000000,153.600000000000,153.700000000000,153.800000000000,153.900000000000,154,154.100000000000,154.200000000000,154.300000000000,154.400000000000,154.500000000000,154.600000000000,154.700000000000,154.800000000000,154.900000000000,155,155.100000000000,155.200000000000,155.300000000000,155.400000000000,155.500000000000,155.600000000000,155.700000000000,155.800000000000,155.900000000000,156,156.100000000000,156.200000000000,156.300000000000,156.400000000000,156.500000000000,156.600000000000,156.700000000000,156.800000000000,156.900000000000,157,157.100000000000,157.200000000000,157.300000000000,157.400000000000,157.500000000000,157.600000000000,157.700000000000,157.800000000000,157.900000000000,158,158.100000000000,158.200000000000,158.300000000000,158.400000000000,158.500000000000,158.600000000000,158.700000000000,158.800000000000,158.900000000000,159,159.100000000000,159.200000000000,159.300000000000,159.400000000000,159.500000000000,159.600000000000,159.700000000000,159.800000000000,159.900000000000,160,160.100000000000,160.200000000000,160.300000000000,160.400000000000,160.500000000000,160.600000000000,160.700000000000,160.800000000000,160.900000000000,161,161.100000000000,161.200000000000,161.300000000000,161.400000000000,161.500000000000,161.600000000000,161.700000000000,161.800000000000,161.900000000000,162,162.100000000000,162.200000000000,162.300000000000,162.400000000000,162.500000000000,162.600000000000,162.700000000000,162.800000000000,162.900000000000,163,163.100000000000,163.200000000000,163.300000000000,163.400000000000,163.500000000000,163.600000000000,163.700000000000,163.800000000000,163.900000000000,164,164.100000000000,164.200000000000,164.300000000000,164.400000000000,164.500000000000,164.600000000000,164.700000000000,164.800000000000,164.900000000000,165,165.100000000000,165.200000000000,165.300000000000,165.400000000000,165.500000000000,165.600000000000,165.700000000000,165.800000000000,165.900000000000,166,166.100000000000,166.200000000000,166.300000000000,166.400000000000,166.500000000000,166.600000000000,166.700000000000,166.800000000000,166.900000000000,167,167.100000000000,167.200000000000,167.300000000000,167.400000000000,167.500000000000,167.600000000000,167.700000000000,167.800000000000,167.900000000000,168,168.100000000000,168.200000000000,168.300000000000,168.400000000000,168.500000000000,168.600000000000,168.700000000000,168.800000000000,168.900000000000,169,169.100000000000,169.200000000000,169.300000000000,169.400000000000,169.500000000000,169.600000000000,169.700000000000,169.800000000000,169.900000000000,170,170.100000000000,170.200000000000,170.300000000000,170.400000000000,170.500000000000,170.600000000000,170.700000000000,170.800000000000,170.900000000000,171,171.100000000000,171.200000000000,171.300000000000,171.400000000000,171.500000000000,171.600000000000,171.700000000000,171.800000000000,171.900000000000,172,172.100000000000,172.200000000000,172.300000000000,172.400000000000,172.500000000000,172.600000000000,172.700000000000,172.800000000000,172.900000000000,173,173.100000000000,173.200000000000,173.300000000000,173.400000000000,173.500000000000,173.600000000000,173.700000000000,173.800000000000,173.900000000000,174,174.100000000000,174.200000000000,174.300000000000,174.400000000000,174.500000000000,174.600000000000,174.700000000000,174.800000000000,174.900000000000,175,175.100000000000,175.200000000000,175.300000000000,175.400000000000,175.500000000000,175.600000000000,175.700000000000,175.800000000000,175.900000000000,176,176.100000000000,176.200000000000,176.300000000000,176.400000000000,176.500000000000,176.600000000000,176.700000000000,176.800000000000,176.900000000000,177,177.100000000000,177.200000000000,177.300000000000,177.400000000000,177.500000000000,177.600000000000,177.700000000000,177.800000000000,177.900000000000,178,178.100000000000,178.200000000000,178.300000000000,178.400000000000,178.500000000000,178.600000000000,178.700000000000,178.800000000000,178.900000000000,179,179.100000000000,179.200000000000,179.300000000000,179.400000000000,179.500000000000,179.600000000000,179.700000000000,179.800000000000,179.900000000000,180,180.100000000000,180.200000000000,180.300000000000,180.400000000000,180.500000000000,180.600000000000,180.700000000000,180.800000000000,180.900000000000,181,181.100000000000,181.200000000000,181.300000000000,181.400000000000,181.500000000000,181.600000000000,181.700000000000,181.800000000000,181.900000000000,182,182.100000000000,182.200000000000,182.300000000000,182.400000000000,182.500000000000,182.600000000000,182.700000000000,182.800000000000,182.900000000000,183,183.100000000000,183.200000000000,183.300000000000,183.400000000000,183.500000000000,183.600000000000,183.700000000000,183.800000000000,183.900000000000,184,184.100000000000,184.200000000000,184.300000000000,184.400000000000,184.500000000000,184.600000000000,184.700000000000,184.800000000000,184.900000000000,185,185.100000000000,185.200000000000,185.300000000000,185.400000000000,185.500000000000,185.600000000000,185.700000000000,185.800000000000,185.900000000000,186,186.100000000000,186.200000000000,186.300000000000,186.400000000000,186.500000000000,186.600000000000,186.700000000000,186.800000000000,186.900000000000,187,187.100000000000,187.200000000000,187.300000000000,187.400000000000,187.500000000000,187.600000000000,187.700000000000,187.800000000000,187.900000000000,188,188.100000000000,188.200000000000,188.300000000000,188.400000000000,188.500000000000,188.600000000000,188.700000000000,188.800000000000,188.900000000000,189,189.100000000000,189.200000000000,189.300000000000,189.400000000000,189.500000000000,189.600000000000,189.700000000000,189.800000000000,189.900000000000,190,190.100000000000,190.200000000000,190.300000000000,190.400000000000,190.500000000000,190.600000000000,190.700000000000,190.800000000000,190.900000000000,191,191.100000000000,191.200000000000,191.300000000000,191.400000000000,191.500000000000,191.600000000000,191.700000000000,191.800000000000,191.900000000000,192,192.100000000000,192.200000000000,192.300000000000,192.400000000000,192.500000000000,192.600000000000,192.700000000000,192.800000000000,192.900000000000,193,193.100000000000,193.200000000000,193.300000000000,193.400000000000,193.500000000000,193.600000000000,193.700000000000,193.800000000000,193.900000000000,194,194.100000000000,194.200000000000,194.300000000000,194.400000000000,194.500000000000,194.600000000000,194.700000000000,194.800000000000,194.900000000000,195,195.100000000000,195.200000000000,195.300000000000,195.400000000000,195.500000000000,195.600000000000,195.700000000000,195.800000000000,195.900000000000,196,196.100000000000,196.200000000000,196.300000000000,196.400000000000,196.500000000000,196.600000000000,196.700000000000,196.800000000000,196.900000000000,197,197.100000000000,197.200000000000,197.300000000000,197.400000000000,197.500000000000,197.600000000000,197.700000000000,197.800000000000,197.900000000000,198,198.100000000000,198.200000000000,198.300000000000,198.400000000000,198.500000000000,198.600000000000,198.700000000000,198.800000000000,198.900000000000,199,199.100000000000,199.200000000000,199.300000000000,199.400000000000,199.500000000000,199.600000000000,199.700000000000,199.800000000000,199.900000000000,200,200.100000000000,200.200000000000,200.300000000000,200.400000000000,200.500000000000,200.600000000000,200.700000000000,200.800000000000,200.900000000000,201,201.100000000000,201.200000000000,201.300000000000,201.400000000000,201.500000000000,201.600000000000,201.700000000000,201.800000000000,201.900000000000,202,202.100000000000,202.200000000000,202.300000000000,202.400000000000,202.500000000000,202.600000000000,202.700000000000,202.800000000000,202.900000000000,203,203.100000000000,203.200000000000,203.300000000000,203.400000000000,203.500000000000,203.600000000000,203.700000000000,203.800000000000,203.900000000000,204,204.100000000000,204.200000000000,204.300000000000,204.400000000000,204.500000000000,204.600000000000,204.700000000000,204.800000000000,204.900000000000,205,205.100000000000,205.200000000000,205.300000000000,205.400000000000,205.500000000000,205.600000000000,205.700000000000,205.800000000000,205.900000000000,206,206.100000000000,206.200000000000,206.300000000000,206.400000000000,206.500000000000,206.600000000000,206.700000000000,206.800000000000,206.900000000000,207,207.100000000000,207.200000000000,207.300000000000,207.400000000000,207.500000000000,207.600000000000,207.700000000000,207.800000000000,207.900000000000,208,208.100000000000,208.200000000000,208.300000000000,208.400000000000,208.500000000000,208.600000000000,208.700000000000,208.800000000000,208.900000000000,209,209.100000000000,209.200000000000,209.300000000000,209.400000000000,209.500000000000,209.600000000000,209.700000000000,209.800000000000,209.900000000000,210,210.100000000000,210.200000000000,210.300000000000,210.400000000000,210.500000000000,210.600000000000,210.700000000000,210.800000000000,210.900000000000,211,211.100000000000,211.200000000000,211.300000000000,211.400000000000,211.500000000000,211.600000000000,211.700000000000,211.800000000000,211.900000000000,212,212.100000000000,212.200000000000,212.300000000000,212.400000000000,212.500000000000,212.600000000000,212.700000000000,212.800000000000,212.900000000000,213,213.100000000000,213.200000000000,213.300000000000,213.400000000000,213.500000000000,213.600000000000,213.700000000000,213.800000000000,213.900000000000,214,214.100000000000,214.200000000000,214.300000000000,214.400000000000,214.500000000000,214.600000000000,214.700000000000,214.800000000000,214.900000000000,215,215.100000000000,215.200000000000,215.300000000000,215.400000000000,215.500000000000,215.600000000000,215.700000000000,215.800000000000,215.900000000000,216,216.100000000000,216.200000000000,216.300000000000,216.400000000000,216.500000000000,216.600000000000,216.700000000000,216.800000000000,216.900000000000,217,217.100000000000,217.200000000000,217.300000000000,217.400000000000,217.500000000000,217.600000000000,217.700000000000,217.800000000000,217.900000000000,218,218.100000000000,218.200000000000,218.300000000000,218.400000000000,218.500000000000,218.600000000000,218.700000000000,218.800000000000,218.900000000000,219,219.100000000000,219.200000000000,219.300000000000,219.400000000000,219.500000000000,219.600000000000,219.700000000000,219.800000000000,219.900000000000,220,220.100000000000,220.200000000000,220.300000000000,220.400000000000,220.500000000000,220.600000000000,220.700000000000,220.800000000000,220.900000000000,221,221.100000000000,221.200000000000,221.300000000000,221.400000000000,221.500000000000,221.600000000000,221.700000000000,221.800000000000,221.900000000000,222,222.100000000000,222.200000000000,222.300000000000,222.400000000000,222.500000000000,222.600000000000,222.700000000000,222.800000000000,222.900000000000,223,223.100000000000,223.200000000000,223.300000000000,223.400000000000,223.500000000000,223.600000000000,223.700000000000,223.800000000000,223.900000000000,224,224.100000000000,224.200000000000,224.300000000000,224.400000000000,224.500000000000,224.600000000000,224.700000000000,224.800000000000,224.900000000000,225,225.100000000000,225.200000000000,225.300000000000,225.400000000000,225.500000000000,225.600000000000,225.700000000000,225.800000000000,225.900000000000,226,226.100000000000,226.200000000000,226.300000000000,226.400000000000,226.500000000000,226.600000000000,226.700000000000,226.800000000000,226.900000000000,227,227.100000000000,227.200000000000,227.300000000000,227.400000000000,227.500000000000,227.600000000000,227.700000000000,227.800000000000,227.900000000000,228,228.100000000000,228.200000000000,228.300000000000,228.400000000000,228.500000000000,228.600000000000,228.700000000000,228.800000000000,228.900000000000,229,229.100000000000,229.200000000000,229.300000000000,229.400000000000,229.500000000000,229.600000000000,229.700000000000,229.800000000000,229.900000000000,230,230.100000000000,230.200000000000,230.300000000000,230.400000000000,230.500000000000,230.600000000000,230.700000000000,230.800000000000,230.900000000000,231,231.100000000000,231.200000000000,231.300000000000,231.400000000000,231.500000000000,231.600000000000,231.700000000000,231.800000000000,231.900000000000,232,232.100000000000,232.200000000000,232.300000000000,232.400000000000,232.500000000000,232.600000000000,232.700000000000,232.800000000000,232.900000000000,233,233.100000000000,233.200000000000,233.300000000000,233.400000000000,233.500000000000,233.600000000000,233.700000000000,233.800000000000,233.900000000000,234,234.100000000000,234.200000000000,234.300000000000,234.400000000000,234.500000000000,234.600000000000,234.700000000000,234.800000000000,234.900000000000,235,235.100000000000,235.200000000000,235.300000000000,235.400000000000,235.500000000000,235.600000000000,235.700000000000,235.800000000000,235.900000000000,236,236.100000000000,236.200000000000,236.300000000000,236.400000000000,236.500000000000,236.600000000000,236.700000000000,236.800000000000,236.900000000000,237,237.100000000000,237.200000000000,237.300000000000,237.400000000000,237.500000000000,237.600000000000,237.700000000000,237.800000000000,237.900000000000,238,238.100000000000,238.200000000000,238.300000000000,238.400000000000,238.500000000000,238.600000000000,238.700000000000,238.800000000000,238.900000000000,239,239.100000000000,239.200000000000,239.300000000000,239.400000000000,239.500000000000,239.600000000000,239.700000000000,239.800000000000,239.900000000000,240,240.100000000000,240.200000000000,240.300000000000,240.400000000000,240.500000000000,240.600000000000,240.700000000000,240.800000000000,240.900000000000,241,241.100000000000,241.200000000000,241.300000000000,241.400000000000,241.500000000000,241.600000000000,241.700000000000,241.800000000000,241.900000000000,242,242.100000000000,242.200000000000,242.300000000000,242.400000000000,242.500000000000,242.600000000000,242.700000000000,242.800000000000,242.900000000000,243,243.100000000000,243.200000000000,243.300000000000,243.400000000000,243.500000000000,243.600000000000,243.700000000000,243.800000000000,243.900000000000,244,244.100000000000,244.200000000000,244.300000000000,244.400000000000,244.500000000000,244.600000000000,244.700000000000,244.800000000000,244.900000000000,245,245.100000000000,245.200000000000,245.300000000000,245.400000000000,245.500000000000,245.600000000000,245.700000000000,245.800000000000,245.900000000000,246,246.100000000000,246.200000000000,246.300000000000,246.400000000000,246.500000000000,246.600000000000,246.700000000000,246.800000000000,246.900000000000,247,247.100000000000,247.200000000000,247.300000000000,247.400000000000,247.500000000000,247.600000000000,247.700000000000,247.800000000000,247.900000000000,248,248.100000000000,248.200000000000,248.300000000000,248.400000000000,248.500000000000,248.600000000000,248.700000000000,248.800000000000,248.900000000000,249,249.100000000000,249.200000000000,249.300000000000,249.400000000000,249.500000000000,249.600000000000,249.700000000000,249.800000000000,249.900000000000,250,250.100000000000,250.200000000000,250.300000000000,250.400000000000,250.500000000000,250.600000000000,250.700000000000,250.800000000000,250.900000000000,251,251.100000000000,251.200000000000,251.300000000000,251.400000000000,251.500000000000,251.600000000000,251.700000000000,251.800000000000,251.900000000000,252,252.100000000000,252.200000000000,252.300000000000,252.400000000000,252.500000000000,252.600000000000,252.700000000000,252.800000000000,252.900000000000,253,253.100000000000,253.200000000000,253.300000000000,253.400000000000,253.500000000000,253.600000000000,253.700000000000,253.800000000000,253.900000000000,254,254.100000000000,254.200000000000,254.300000000000,254.400000000000,254.500000000000,254.600000000000,254.700000000000,254.800000000000,254.900000000000,255,255.100000000000,255.200000000000,255.300000000000,255.400000000000,255.500000000000,255.600000000000,255.700000000000,255.800000000000,255.900000000000,256,256.100000000000,256.200000000000,256.300000000000,256.400000000000,256.500000000000,256.600000000000,256.700000000000,256.800000000000,256.900000000000,257,257.100000000000,257.200000000000,257.300000000000,257.400000000000,257.500000000000,257.600000000000,257.700000000000,257.800000000000,257.900000000000,258,258.100000000000,258.200000000000,258.300000000000,258.400000000000,258.500000000000,258.600000000000,258.700000000000,258.800000000000,258.900000000000,259,259.100000000000,259.200000000000,259.300000000000,259.400000000000,259.500000000000,259.600000000000,259.700000000000,259.800000000000,259.900000000000,260,260.100000000000,260.200000000000,260.300000000000,260.400000000000,260.500000000000,260.600000000000,260.700000000000,260.800000000000,260.900000000000,261,261.100000000000,261.200000000000,261.300000000000,261.400000000000,261.500000000000,261.600000000000,261.700000000000,261.800000000000,261.900000000000,262,262.100000000000,262.200000000000,262.300000000000,262.400000000000,262.500000000000,262.600000000000,262.700000000000,262.800000000000,262.900000000000,263,263.100000000000,263.200000000000,263.300000000000,263.400000000000,263.500000000000,263.600000000000,263.700000000000,263.800000000000,263.900000000000,264,264.100000000000,264.200000000000,264.300000000000,264.400000000000,264.500000000000,264.600000000000,264.700000000000,264.800000000000,264.900000000000,265,265.100000000000,265.200000000000,265.300000000000,265.400000000000,265.500000000000,265.600000000000,265.700000000000,265.800000000000,265.900000000000,266,266.100000000000,266.200000000000,266.300000000000,266.400000000000,266.500000000000,266.600000000000,266.700000000000,266.800000000000,266.900000000000,267,267.100000000000,267.200000000000,267.300000000000,267.400000000000,267.500000000000,267.600000000000,267.700000000000,267.800000000000,267.900000000000,268,268.100000000000,268.200000000000,268.300000000000,268.400000000000,268.500000000000,268.600000000000,268.700000000000,268.800000000000,268.900000000000,269,269.100000000000,269.200000000000,269.300000000000,269.400000000000,269.500000000000,269.600000000000,269.700000000000,269.800000000000,269.900000000000,270,270.100000000000,270.200000000000,270.300000000000,270.400000000000,270.500000000000,270.600000000000,270.700000000000,270.800000000000,270.900000000000,271,271.100000000000,271.200000000000,271.300000000000,271.400000000000,271.500000000000,271.600000000000,271.700000000000,271.800000000000,271.900000000000,272,272.100000000000,272.200000000000,272.300000000000,272.400000000000,272.500000000000,272.600000000000,272.700000000000,272.800000000000,272.900000000000,273,273.100000000000,273.200000000000,273.300000000000,273.400000000000,273.500000000000,273.600000000000,273.700000000000,273.800000000000,273.900000000000,274,274.100000000000,274.200000000000,274.300000000000,274.400000000000,274.500000000000,274.600000000000,274.700000000000,274.800000000000,274.900000000000,275,275.100000000000,275.200000000000,275.300000000000,275.400000000000,275.500000000000,275.600000000000,275.700000000000,275.800000000000,275.900000000000,276,276.100000000000,276.200000000000,276.300000000000,276.400000000000,276.500000000000,276.600000000000,276.700000000000,276.800000000000,276.900000000000,277,277.100000000000,277.200000000000,277.300000000000,277.400000000000,277.500000000000,277.600000000000,277.700000000000,277.800000000000,277.900000000000,278,278.100000000000,278.200000000000,278.300000000000,278.400000000000,278.500000000000,278.600000000000,278.700000000000,278.800000000000,278.900000000000,279,279.100000000000,279.200000000000,279.300000000000,279.400000000000,279.500000000000,279.600000000000,279.700000000000,279.800000000000,279.900000000000,280,280.100000000000,280.200000000000,280.300000000000,280.400000000000,280.500000000000,280.600000000000,280.700000000000,280.800000000000,280.900000000000,281,281.100000000000,281.200000000000,281.300000000000,281.400000000000,281.500000000000,281.600000000000,281.700000000000,281.800000000000,281.900000000000,282,282.100000000000,282.200000000000,282.300000000000,282.400000000000,282.500000000000,282.600000000000,282.700000000000,282.800000000000,282.900000000000,283,283.100000000000,283.200000000000,283.300000000000,283.400000000000,283.500000000000,283.600000000000,283.700000000000,283.800000000000,283.900000000000,284,284.100000000000,284.200000000000,284.300000000000,284.400000000000,284.500000000000,284.600000000000,284.700000000000,284.800000000000,284.900000000000,285,285.100000000000,285.200000000000,285.300000000000,285.400000000000,285.500000000000,285.600000000000,285.700000000000,285.800000000000,285.900000000000,286,286.100000000000,286.200000000000,286.300000000000,286.400000000000,286.500000000000,286.600000000000,286.700000000000,286.800000000000,286.900000000000,287,287.100000000000,287.200000000000,287.300000000000,287.400000000000,287.500000000000,287.600000000000,287.700000000000,287.800000000000,287.900000000000,288,288.100000000000,288.200000000000,288.300000000000,288.400000000000,288.500000000000,288.600000000000,288.700000000000,288.800000000000,288.900000000000,289,289.100000000000,289.200000000000,289.300000000000,289.400000000000,289.500000000000,289.600000000000,289.700000000000,289.800000000000,289.900000000000,290,290.100000000000,290.200000000000,290.300000000000,290.400000000000,290.500000000000,290.600000000000,290.700000000000,290.800000000000,290.900000000000,291,291.100000000000,291.200000000000,291.300000000000,291.400000000000,291.500000000000,291.600000000000,291.700000000000,291.800000000000,291.900000000000,292,292.100000000000,292.200000000000,292.300000000000,292.400000000000,292.500000000000,292.600000000000,292.700000000000,292.800000000000,292.900000000000,293,293.100000000000,293.200000000000,293.300000000000,293.400000000000,293.500000000000,293.600000000000,293.700000000000,293.800000000000,293.900000000000,294,294.100000000000,294.200000000000,294.300000000000,294.400000000000,294.500000000000,294.600000000000,294.700000000000,294.800000000000,294.900000000000,295,295.100000000000,295.200000000000,295.300000000000,295.400000000000,295.500000000000,295.600000000000,295.700000000000,295.800000000000,295.900000000000,296,296.100000000000,296.200000000000,296.300000000000,296.400000000000,296.500000000000,296.600000000000,296.700000000000,296.800000000000,296.900000000000,297,297.100000000000,297.200000000000,297.300000000000,297.400000000000,297.500000000000,297.600000000000,297.700000000000,297.800000000000,297.900000000000,298,298.100000000000,298.200000000000,298.300000000000,298.400000000000,298.500000000000,298.600000000000,298.700000000000,298.800000000000,298.900000000000,299,299.100000000000,299.200000000000,299.300000000000,299.400000000000,299.500000000000,299.600000000000,299.700000000000,299.800000000000,299.900000000000,300,300.100000000000,300.200000000000,300.300000000000,300.400000000000,300.500000000000,300.600000000000,300.700000000000,300.800000000000,300.900000000000,301,301.100000000000,301.200000000000,301.300000000000,301.400000000000,301.500000000000,301.600000000000,301.700000000000,301.800000000000,301.900000000000,302,302.100000000000,302.200000000000,302.300000000000,302.400000000000,302.500000000000,302.600000000000,302.700000000000,302.800000000000,302.900000000000,303,303.100000000000,303.200000000000,303.300000000000,303.400000000000,303.500000000000,303.600000000000,303.700000000000,303.800000000000,303.900000000000,304,304.100000000000,304.200000000000,304.300000000000,304.400000000000,304.500000000000,304.600000000000,304.700000000000,304.800000000000,304.900000000000,305,305.100000000000,305.200000000000,305.300000000000,305.400000000000,305.500000000000,305.600000000000,305.700000000000,305.800000000000,305.900000000000,306,306.100000000000,306.200000000000,306.300000000000,306.400000000000,306.500000000000,306.600000000000,306.700000000000,306.800000000000,306.900000000000,307,307.100000000000,307.200000000000,307.300000000000,307.400000000000,307.500000000000,307.600000000000,307.700000000000,307.800000000000,307.900000000000,308,308.100000000000,308.200000000000,308.300000000000,308.400000000000,308.500000000000,308.600000000000,308.700000000000,308.800000000000,308.900000000000,309,309.100000000000,309.200000000000,309.300000000000,309.400000000000,309.500000000000,309.600000000000,309.700000000000,309.800000000000,309.900000000000,310,310.100000000000,310.200000000000,310.300000000000,310.400000000000,310.500000000000,310.600000000000,310.700000000000,310.800000000000,310.900000000000,311,311.100000000000,311.200000000000,311.300000000000,311.400000000000,311.500000000000,311.600000000000,311.700000000000,311.800000000000,311.900000000000,312,312.100000000000,312.200000000000,312.300000000000,312.400000000000,312.500000000000,312.600000000000,312.700000000000,312.800000000000,312.900000000000,313,313.100000000000,313.200000000000,313.300000000000,313.400000000000,313.500000000000,313.600000000000,313.700000000000,313.800000000000,313.900000000000,314,314.100000000000,314.200000000000,314.300000000000,314.400000000000,314.500000000000,314.600000000000,314.700000000000,314.800000000000,314.900000000000,315,315.100000000000,315.200000000000,315.300000000000,315.400000000000,315.500000000000,315.600000000000,315.700000000000,315.800000000000,315.900000000000,316,316.100000000000,316.200000000000,316.300000000000,316.400000000000,316.500000000000,316.600000000000,316.700000000000,316.800000000000,316.900000000000,317,317.100000000000,317.200000000000,317.300000000000,317.400000000000,317.500000000000,317.600000000000,317.700000000000,317.800000000000,317.900000000000,318,318.100000000000,318.200000000000,318.300000000000,318.400000000000,318.500000000000,318.600000000000,318.700000000000,318.800000000000,318.900000000000,319,319.100000000000,319.200000000000,319.300000000000,319.400000000000,319.500000000000,319.600000000000,319.700000000000,319.800000000000,319.900000000000,320,320.100000000000,320.200000000000,320.300000000000,320.400000000000,320.500000000000,320.600000000000,320.700000000000,320.800000000000,320.900000000000,321,321.100000000000,321.200000000000,321.300000000000,321.400000000000,321.500000000000,321.600000000000,321.700000000000,321.800000000000,321.900000000000,322,322.100000000000,322.200000000000,322.300000000000,322.400000000000,322.500000000000,322.600000000000,322.700000000000,322.800000000000,322.900000000000,323,323.100000000000,323.200000000000,323.300000000000,323.400000000000,323.500000000000,323.600000000000,323.700000000000,323.800000000000,323.900000000000,324,324.100000000000,324.200000000000,324.300000000000,324.400000000000,324.500000000000,324.600000000000,324.700000000000,324.800000000000,324.900000000000,325,325.100000000000,325.200000000000,325.300000000000,325.400000000000,325.500000000000,325.600000000000,325.700000000000,325.800000000000,325.900000000000,326,326.100000000000,326.200000000000,326.300000000000,326.400000000000,326.500000000000,326.600000000000,326.700000000000,326.800000000000,326.900000000000,327,327.100000000000,327.200000000000,327.300000000000,327.400000000000,327.500000000000,327.600000000000,327.700000000000,327.800000000000,327.900000000000,328,328.100000000000,328.200000000000,328.300000000000,328.400000000000,328.500000000000,328.600000000000,328.700000000000,328.800000000000,328.900000000000,329,329.100000000000,329.200000000000,329.300000000000,329.400000000000,329.500000000000,329.600000000000,329.700000000000,329.800000000000,329.900000000000,330,330.100000000000,330.200000000000,330.300000000000,330.400000000000,330.500000000000,330.600000000000,330.700000000000,330.800000000000,330.900000000000,331,331.100000000000,331.200000000000,331.300000000000,331.400000000000,331.500000000000,331.600000000000,331.700000000000,331.800000000000,331.900000000000,332,332.100000000000,332.200000000000,332.300000000000,332.400000000000,332.500000000000,332.600000000000,332.700000000000,332.800000000000,332.900000000000,333,333.100000000000,333.200000000000,333.300000000000,333.400000000000,333.500000000000,333.600000000000,333.700000000000,333.800000000000,333.900000000000,334,334.100000000000,334.200000000000,334.300000000000,334.400000000000,334.500000000000,334.600000000000,334.700000000000,334.800000000000,334.900000000000,335,335.100000000000,335.200000000000,335.300000000000,335.400000000000,335.500000000000,335.600000000000,335.700000000000,335.800000000000,335.900000000000,336,336.100000000000,336.200000000000,336.300000000000,336.400000000000,336.500000000000,336.600000000000,336.700000000000,336.800000000000,336.900000000000,337,337.100000000000,337.200000000000,337.300000000000,337.400000000000,337.500000000000,337.600000000000,337.700000000000,337.800000000000,337.900000000000,338,338.100000000000,338.200000000000,338.300000000000,338.400000000000,338.500000000000,338.600000000000,338.700000000000,338.800000000000,338.900000000000,339,339.100000000000,339.200000000000,339.300000000000,339.400000000000,339.500000000000,339.600000000000,339.700000000000,339.800000000000,339.900000000000,340,340.100000000000,340.200000000000,340.300000000000,340.400000000000,340.500000000000,340.600000000000,340.700000000000,340.800000000000,340.900000000000,341,341.100000000000,341.200000000000,341.300000000000,341.400000000000,341.500000000000,341.600000000000,341.700000000000,341.800000000000,341.900000000000,342,342.100000000000,342.200000000000,342.300000000000,342.400000000000,342.500000000000,342.600000000000,342.700000000000,342.800000000000,342.900000000000,343,343.100000000000,343.200000000000,343.300000000000,343.400000000000,343.500000000000,343.600000000000,343.700000000000,343.800000000000,343.900000000000,344,344.100000000000,344.200000000000,344.300000000000,344.400000000000,344.500000000000,344.600000000000,344.700000000000,344.800000000000,344.900000000000,345,345.100000000000,345.200000000000,345.300000000000,345.400000000000,345.500000000000,345.600000000000,345.700000000000,345.800000000000,345.900000000000,346,346.100000000000,346.200000000000,346.300000000000,346.400000000000,346.500000000000,346.600000000000,346.700000000000,346.800000000000,346.900000000000,347,347.100000000000,347.200000000000,347.300000000000,347.400000000000,347.500000000000,347.600000000000,347.700000000000,347.800000000000,347.900000000000,348,348.100000000000,348.200000000000,348.300000000000,348.400000000000,348.500000000000,348.600000000000,348.700000000000,348.800000000000,348.900000000000,349,349.100000000000,349.200000000000,349.300000000000,349.400000000000,349.500000000000,349.600000000000,349.700000000000,349.800000000000,349.900000000000,350,350.100000000000,350.200000000000,350.300000000000,350.400000000000,350.500000000000,350.600000000000,350.700000000000,350.800000000000,350.900000000000,351,351.100000000000,351.200000000000,351.300000000000,351.400000000000,351.500000000000,351.600000000000,351.700000000000,351.800000000000,351.900000000000,352,352.100000000000,352.200000000000,352.300000000000,352.400000000000,352.500000000000,352.600000000000,352.700000000000,352.800000000000,352.900000000000,353,353.100000000000,353.200000000000,353.300000000000,353.400000000000,353.500000000000,353.600000000000,353.700000000000,353.800000000000,353.900000000000,354,354.100000000000,354.200000000000,354.300000000000,354.400000000000,354.500000000000,354.600000000000,354.700000000000,354.800000000000,354.900000000000,355,355.100000000000,355.200000000000,355.300000000000,355.400000000000,355.500000000000,355.600000000000,355.700000000000,355.800000000000,355.900000000000,356,356.100000000000,356.200000000000,356.300000000000,356.400000000000,356.500000000000,356.600000000000,356.700000000000,356.800000000000,356.900000000000,357,357.100000000000,357.200000000000,357.300000000000,357.400000000000,357.500000000000,357.600000000000,357.700000000000,357.800000000000,357.900000000000,358,358.100000000000,358.200000000000,358.300000000000,358.400000000000,358.500000000000,358.600000000000,358.700000000000,358.800000000000,358.900000000000,359,359.100000000000,359.200000000000,359.300000000000,359.400000000000,359.500000000000,359.600000000000,359.700000000000,359.800000000000,359.900000000000,360,360.100000000000,360.200000000000,360.300000000000,360.400000000000,360.500000000000,360.600000000000,360.700000000000,360.800000000000,360.900000000000,361,361.100000000000,361.200000000000,361.300000000000,361.400000000000,361.500000000000,361.600000000000,361.700000000000,361.800000000000,361.900000000000,362,362.100000000000,362.200000000000,362.300000000000,362.400000000000,362.500000000000,362.600000000000,362.700000000000,362.800000000000,362.900000000000,363,363.100000000000,363.200000000000,363.300000000000,363.400000000000,363.500000000000,363.600000000000,363.700000000000,363.800000000000,363.900000000000,364,364.100000000000,364.200000000000,364.300000000000,364.400000000000,364.500000000000,364.600000000000,364.700000000000,364.800000000000,364.900000000000,365,365.100000000000,365.200000000000,365.300000000000,365.400000000000,365.500000000000,365.600000000000,365.700000000000,365.800000000000,365.900000000000,366,366.100000000000,366.200000000000,366.300000000000,366.400000000000,366.500000000000,366.600000000000,366.700000000000,366.800000000000,366.900000000000,367,367.100000000000,367.200000000000,367.300000000000,367.400000000000,367.500000000000,367.600000000000,367.700000000000,367.800000000000,367.900000000000,368,368.100000000000,368.200000000000,368.300000000000,368.400000000000,368.500000000000,368.600000000000,368.700000000000,368.800000000000,368.900000000000,369,369.100000000000,369.200000000000,369.300000000000,369.400000000000,369.500000000000,369.600000000000,369.700000000000,369.800000000000,369.900000000000,370,370.100000000000,370.200000000000,370.300000000000,370.400000000000,370.500000000000,370.600000000000,370.700000000000,370.800000000000,370.900000000000,371,371.100000000000,371.200000000000,371.300000000000,371.400000000000,371.500000000000,371.600000000000,371.700000000000,371.800000000000,371.900000000000,372,372.100000000000,372.200000000000,372.300000000000,372.400000000000,372.500000000000,372.600000000000,372.700000000000,372.800000000000,372.900000000000,373,373.100000000000,373.200000000000,373.300000000000,373.400000000000,373.500000000000,373.600000000000,373.700000000000,373.800000000000,373.900000000000,374,374.150000000000;];

  A              = zeros(size(theta,1),1);
  B              = zeros(size(theta,1),1);
  C              = zeros(size(theta,1),1);
  A(Idx.RH_nd,1) = interp1(Derivative.theta,Derivative.dwdtheta_p2(:,1),theta(Idx.RH_nd,1));
  B(Idx.RH_nd,1) = interp1(Derivative.theta,Derivative.dwdtheta_p2(:,2),theta(Idx.RH_nd,1));
  C(Idx.RH_nd,1) = interp1(Derivative.theta,Derivative.dwdtheta_p2(:,3),theta(Idx.RH_nd,1));
  
  Water.dwdtheta(Idx.RH_nd,1) = A(Idx.RH_nd,1) .* RH(Idx.RH_nd,1) .^2 + B(Idx.RH_nd,1) .* RH(Idx.RH_nd,1) + C(Idx.RH_nd,1);
  %% Correct dwdp
  A              = zeros(size(theta,1),1);
  B              = zeros(size(theta,1),1);
  C              = zeros(size(theta,1),1);
  A(Idx.RH_nd,1) = interp1(Derivative.theta,Derivative.dwdp_p2(:,1),theta(Idx.RH_nd,1));
  B(Idx.RH_nd,1) = interp1(Derivative.theta,Derivative.dwdp_p2(:,2),theta(Idx.RH_nd,1));
  C(Idx.RH_nd,1) = interp1(Derivative.theta,Derivative.dwdp_p2(:,3),theta(Idx.RH_nd,1));
  
  
  Water.dwdp(Idx.RH_nd,1) = A(Idx.RH_nd,1) .* RH(Idx.RH_nd,1) .^2 + B(Idx.RH_nd,1) .* RH(Idx.RH_nd,1) + C(Idx.RH_nd,1);
end

%% Output sort
Output = [Water.wd Water.dwd Water.w Water.dwdp Water.dwdtheta ];


